/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpopt-cons.lsp                 */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpopt-cons.eclh"
/* function definition for CONS-CAR                                           */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object L4042si_cons_car(cl_object v1x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ECL_CONS_CAR(v1x);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4042si_cons_car_va(cl_narg narg, cl_object v2x, ...)
{
 return L4042si_cons_car(v2x);
}
/* function definition for CONS-CDR                                           */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object L4043si_cons_cdr(cl_object v1x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ECL_CONS_CDR(v1x);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4043si_cons_cdr_va(cl_narg narg, cl_object v2x, ...)
{
 return L4043si_cons_cdr(v2x);
}
/* local function LAMBDA5                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4045__lambda5(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  {
   cl_object v4temp;
   v4temp = ECL_NIL;
   {
    cl_fixnum v5;
    v5 = ecl_length(v3);
    if (!((v5)==((cl_fixnum)(2)))){
     goto L7;
    }
   }
   v4temp = LC4044cons_to_lista(v3);
   if ((v3)==(v4temp)) {
    goto L7;
   }
   T0 = ecl_last(v4temp,1);
   if (!(ecl_equal(VV[4],T0))){
    goto L11;
   }
   T0 = ecl_butlast(v4temp,1);
   value0 = CONS(ECL_SYM("LIST",483),T0);
   cl_env_copy->nvalues = 1;
   return value0;
L11:;
   value0 = CONS(ECL_SYM("LIST*",484),v4temp);
   cl_env_copy->nvalues = 1;
   return value0;
L7:;
   value0 = v1;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object LC4045__lambda5_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2]);
 {
  return LC4045__lambda5(v5, v6);
 }
}
/* local function LAMBDA11                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4046__lambda11(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4place;
  cl_object v5value;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4place = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L13;
  }
  si_dm_too_few_arguments(v1);
L13:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5value = v6;
  }
  if (Null(v3)){
   goto L18;
  }
  si_dm_too_many_arguments(v1);
L18:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[8]))->cfun.entry(0) /*  POLICY-INLINE-ACCESSORS */)){
   goto L20;
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[9]))->cfun.entry(0) /*  POLICY-ASSUME-RIGHT-TYPE */)){
   goto L23;
  }
  T0 = v4place;
  goto L22;
L23:;
  T0 = cl_list(3, ECL_SYM("CHECKED-VALUE",2082), ECL_SYM("CONS",253), v4place);
L22:;
  T1 = cl_list(2, T0, v5value);
  value0 = cl_listX(3, ECL_SYM("C-INLINE",2106), T1, VV[10]);
  return value0;
L20:;
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4046__lambda11_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[6]);
 {
  return LC4046__lambda11(v6, v7);
 }
}
/* local function LAMBDA18                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4047__lambda18(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4place;
  cl_object v5value;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4place = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L13;
  }
  si_dm_too_few_arguments(v1);
L13:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5value = v6;
  }
  if (Null(v3)){
   goto L18;
  }
  si_dm_too_many_arguments(v1);
L18:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[8]))->cfun.entry(0) /*  POLICY-INLINE-ACCESSORS */)){
   goto L20;
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[9]))->cfun.entry(0) /*  POLICY-ASSUME-RIGHT-TYPE */)){
   goto L23;
  }
  T0 = v4place;
  goto L22;
L23:;
  T0 = cl_list(3, ECL_SYM("CHECKED-VALUE",2082), ECL_SYM("CONS",253), v4place);
L22:;
  T1 = cl_list(2, T0, v5value);
  value0 = cl_listX(3, ECL_SYM("C-INLINE",2106), T1, VV[12]);
  return value0;
L20:;
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4047__lambda18_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[11]);
 {
  return LC4047__lambda18(v6, v7);
 }
}
/* local function LAMBDA25                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4048__lambda25(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4n;
  cl_object v5list;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4n = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L13;
  }
  si_dm_too_few_arguments(v1);
L13:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5list = v6;
  }
  if (Null(v3)){
   goto L18;
  }
  si_dm_too_many_arguments(v1);
L18:;
  if (!((v4n)==(ecl_make_int8_t(0)))){
   goto L20;
  }
  value0 = cl_list(2, ECL_SYM("CAR",182), v5list);
  return value0;
L20:;
  if (!((v4n)==(ecl_make_int8_t(1)))){
   goto L22;
  }
  value0 = cl_list(2, ECL_SYM("CADR",180), v5list);
  return value0;
L22:;
  if (!((v4n)==(ecl_make_int8_t(2)))){
   goto L24;
  }
  value0 = cl_list(2, ECL_SYM("CADDR",179), v5list);
  return value0;
L24:;
  if (!((v4n)==(ecl_make_int8_t(3)))){
   goto L26;
  }
  value0 = cl_list(2, ECL_SYM("CADDDR",178), v5list);
  return value0;
L26:;
  if (!((v4n)==(ecl_make_int8_t(4)))){
   goto L28;
  }
  T0 = cl_list(2, ECL_SYM("CDDDDR",197), v5list);
  value0 = cl_list(2, ECL_SYM("CAR",182), T0);
  return value0;
L28:;
  if (!((v4n)==(ecl_make_int8_t(5)))){
   goto L30;
  }
  T0 = cl_list(2, ECL_SYM("CDDDDR",197), v5list);
  value0 = cl_list(2, ECL_SYM("CADR",180), T0);
  return value0;
L30:;
  if (!((v4n)==(ecl_make_int8_t(6)))){
   goto L32;
  }
  T0 = cl_list(2, ECL_SYM("CDDDDR",197), v5list);
  value0 = cl_list(2, ECL_SYM("CADDR",179), T0);
  return value0;
L32:;
  if (!((v4n)==(ecl_make_int8_t(7)))){
   goto L34;
  }
  T0 = cl_list(2, ECL_SYM("CDDDDR",197), v5list);
  value0 = cl_list(2, ECL_SYM("CADDDR",178), T0);
  return value0;
L34:;
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4048__lambda25_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[13]);
 {
  return LC4048__lambda25(v6, v7);
 }
}
/* local function LAMBDA33                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4049__lambda33(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4n;
  cl_object v5list;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4n = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L13;
  }
  si_dm_too_few_arguments(v1);
L13:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5list = v6;
  }
  if (Null(v3)){
   goto L18;
  }
  si_dm_too_many_arguments(v1);
L18:;
  if (!((v4n)==(ecl_make_int8_t(0)))){
   goto L20;
  }
  value0 = v5list;
  cl_env_copy->nvalues = 1;
  return value0;
L20:;
  if (!((v4n)==(ecl_make_int8_t(1)))){
   goto L22;
  }
  value0 = cl_list(2, ECL_SYM("CDR",200), v5list);
  return value0;
L22:;
  if (!((v4n)==(ecl_make_int8_t(2)))){
   goto L24;
  }
  value0 = cl_list(2, ECL_SYM("CDDR",199), v5list);
  return value0;
L24:;
  if (!((v4n)==(ecl_make_int8_t(3)))){
   goto L26;
  }
  value0 = cl_list(2, ECL_SYM("CDDDR",198), v5list);
  return value0;
L26:;
  if (!((v4n)==(ecl_make_int8_t(4)))){
   goto L28;
  }
  value0 = cl_list(2, ECL_SYM("CDDDDR",197), v5list);
  return value0;
L28:;
  if (!((v4n)==(ecl_make_int8_t(5)))){
   goto L30;
  }
  T0 = cl_list(2, ECL_SYM("CDDDDR",197), v5list);
  value0 = cl_list(2, ECL_SYM("CDR",200), T0);
  return value0;
L30:;
  if (!((v4n)==(ecl_make_int8_t(6)))){
   goto L32;
  }
  T0 = cl_list(2, ECL_SYM("CDDDDR",197), v5list);
  value0 = cl_list(2, ECL_SYM("CDDR",199), T0);
  return value0;
L32:;
  if (!((v4n)==(ecl_make_int8_t(7)))){
   goto L34;
  }
  T0 = cl_list(2, ECL_SYM("CDDDDR",197), v5list);
  value0 = cl_list(2, ECL_SYM("CDDDR",198), T0);
  return value0;
L34:;
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4049__lambda33_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[14]);
 {
  return LC4049__lambda33(v6, v7);
 }
}
/* local function LAMBDA44                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4050__lambda44(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4x;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4x = v5;
  }
  if (Null(v3)){
   goto L12;
  }
  si_dm_too_many_arguments(v1);
L12:;
  value0 = cl_list(3, ECL_SYM("NTH",604), ecl_make_int8_t(0), v4x);
  return value0;
 }
}
static cl_object LC4050__lambda44_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[15]);
 {
  return LC4050__lambda44(v5, v6);
 }
}
/* local function LAMBDA50                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4051__lambda50(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4x;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4x = v5;
  }
  if (Null(v3)){
   goto L12;
  }
  si_dm_too_many_arguments(v1);
L12:;
  value0 = cl_list(3, ECL_SYM("NTH",604), ecl_make_int8_t(1), v4x);
  return value0;
 }
}
static cl_object LC4051__lambda50_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[16]);
 {
  return LC4051__lambda50(v5, v6);
 }
}
/* local function LAMBDA56                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4052__lambda56(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4x;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4x = v5;
  }
  if (Null(v3)){
   goto L12;
  }
  si_dm_too_many_arguments(v1);
L12:;
  value0 = cl_list(3, ECL_SYM("NTH",604), ecl_make_int8_t(2), v4x);
  return value0;
 }
}
static cl_object LC4052__lambda56_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[17]);
 {
  return LC4052__lambda56(v5, v6);
 }
}
/* local function LAMBDA62                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4053__lambda62(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4x;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4x = v5;
  }
  if (Null(v3)){
   goto L12;
  }
  si_dm_too_many_arguments(v1);
L12:;
  value0 = cl_list(3, ECL_SYM("NTH",604), ecl_make_int8_t(3), v4x);
  return value0;
 }
}
static cl_object LC4053__lambda62_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[18]);
 {
  return LC4053__lambda62(v5, v6);
 }
}
/* local function LAMBDA68                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4054__lambda68(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4x;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4x = v5;
  }
  if (Null(v3)){
   goto L12;
  }
  si_dm_too_many_arguments(v1);
L12:;
  value0 = cl_list(3, ECL_SYM("NTH",604), ecl_make_int8_t(4), v4x);
  return value0;
 }
}
static cl_object LC4054__lambda68_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[19]);
 {
  return LC4054__lambda68(v5, v6);
 }
}
/* local function LAMBDA74                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4055__lambda74(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4x;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4x = v5;
  }
  if (Null(v3)){
   goto L12;
  }
  si_dm_too_many_arguments(v1);
L12:;
  value0 = cl_list(3, ECL_SYM("NTH",604), ecl_make_int8_t(5), v4x);
  return value0;
 }
}
static cl_object LC4055__lambda74_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[20]);
 {
  return LC4055__lambda74(v5, v6);
 }
}
/* local function LAMBDA80                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4056__lambda80(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4x;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4x = v5;
  }
  if (Null(v3)){
   goto L12;
  }
  si_dm_too_many_arguments(v1);
L12:;
  value0 = cl_list(3, ECL_SYM("NTH",604), ecl_make_int8_t(6), v4x);
  return value0;
 }
}
static cl_object LC4056__lambda80_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[21]);
 {
  return LC4056__lambda80(v5, v6);
 }
}
/* local function LAMBDA86                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4057__lambda86(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4x;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4x = v5;
  }
  if (Null(v3)){
   goto L12;
  }
  si_dm_too_many_arguments(v1);
L12:;
  value0 = cl_list(3, ECL_SYM("NTH",604), ecl_make_int8_t(7), v4x);
  return value0;
 }
}
static cl_object LC4057__lambda86_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[22]);
 {
  return LC4057__lambda86(v5, v6);
 }
}
/* local function LAMBDA92                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4058__lambda92(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4x;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4x = v5;
  }
  if (Null(v3)){
   goto L12;
  }
  si_dm_too_many_arguments(v1);
L12:;
  value0 = cl_list(3, ECL_SYM("NTH",604), ecl_make_int8_t(8), v4x);
  return value0;
 }
}
static cl_object LC4058__lambda92_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[23]);
 {
  return LC4058__lambda92(v5, v6);
 }
}
/* local function LAMBDA98                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4059__lambda98(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4x;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4x = v5;
  }
  if (Null(v3)){
   goto L12;
  }
  si_dm_too_many_arguments(v1);
L12:;
  value0 = cl_list(3, ECL_SYM("NTH",604), ecl_make_int8_t(9), v4x);
  return value0;
 }
}
static cl_object LC4059__lambda98_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[24]);
 {
  return LC4059__lambda98(v5, v6);
 }
}
/* local function LAMBDA104                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4060__lambda104(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4x;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4x = v5;
  }
  if (Null(v3)){
   goto L12;
  }
  si_dm_too_many_arguments(v1);
L12:;
  value0 = cl_list(2, ECL_SYM("CDR",200), v4x);
  return value0;
 }
}
static cl_object LC4060__lambda104_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[25]);
 {
  return LC4060__lambda104(v5, v6);
 }
}
/* local function LAMBDA109                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4061__lambda109(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4place;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4place = v5;
  }
  if (Null(v3)){
   goto L12;
  }
  si_dm_too_many_arguments(v1);
L12:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[8]))->cfun.entry(0) /*  POLICY-INLINE-ACCESSORS */)){
   goto L14;
  }
  {
   cl_object v5;                                  /*  VARS                    */
   cl_object v6;                                  /*  VALS                    */
   cl_object v7;                                  /*  STORES                  */
   cl_object v8;                                  /*  STORE-FORM              */
   cl_object v9;                                  /*  ACCESS-FORM             */
   value0 = (cl_env_copy->function=(ECL_SYM("GET-SETF-EXPANSION",412)->symbol.gfdef))->cfun.entry(2, v4place, v2env) /*  GET-SETF-EXPANSION */;
   {
    v5 = value0;
    v6 = cl_env_copy->values[1];
    v7 = cl_env_copy->values[2];
    v8 = cl_env_copy->values[3];
    v9 = cl_env_copy->values[4];
   }
   {
    cl_object v10store_var;
    cl_object v11saved_place;
    v10store_var = ecl_car(v7);
    v11saved_place = cl_gensym(0);
    {
     cl_object v12;
     v12 = (ECL_SYM("LIST",483)->symbol.gfdef);
     {
      cl_object v13;
      cl_object v14;
      cl_object v15;
      {
       cl_object v16;
       T1 = ecl_list1(v11saved_place);
       v16 = ecl_append(v5,T1);
       if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v13 = v16;
      }
      v14 = ECL_NIL;
      v15 = v13;
      {
       cl_object v16;
       cl_object v17;
       cl_object v18;
       {
        cl_object v19;
        T1 = ecl_list1(v9);
        v19 = ecl_append(v6,T1);
        if (ecl_unlikely(!ECL_LISTP(v19))) FEtype_error_list(v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v16 = v19;
       }
       v17 = ECL_NIL;
       v18 = v16;
       {
        cl_object v19;
        cl_object v20;
        v19 = ecl_list1(ECL_NIL);
        v20 = v19;
L33:;
        if (!(ecl_endp(v15))){
         goto L35;
        }
        goto L34;
L35:;
        v14 = ECL_CONS_CAR(v15);
        {
         cl_object v21;
         v21 = ECL_CONS_CDR(v15);
         if (ecl_unlikely(!ECL_LISTP(v21))) FEtype_error_list(v21);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         v15 = v21;
        }
        if (!(ecl_endp(v18))){
         goto L43;
        }
        goto L34;
L43:;
        v17 = ECL_CONS_CAR(v18);
        {
         cl_object v21;
         v21 = ECL_CONS_CDR(v18);
         if (ecl_unlikely(!ECL_LISTP(v21))) FEtype_error_list(v21);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         v18 = v21;
        }
        {
         cl_object v21;
         v21 = v20;
         if (ecl_unlikely(ECL_ATOM(v21))) FEtype_error_cons(v21);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         T1 = v21;
        }
        T2 = ecl_function_dispatch(cl_env_copy,v12)(2, v14, v17);
        v20 = ecl_list1(T2);
        (ECL_CONS_CDR(T1)=v20,T1);
        goto L33;
L34:;
        T0 = ecl_cdr(v19);
        goto L19;
       }
      }
     }
    }
L19:;
    T1 = CONS(VV[32],v5);
    T2 = cl_list(2, ECL_SYM("DECLARE",276), T1);
    T3 = cl_list(3, VV[33], v11saved_place, ECL_SYM("LIST",483));
    T4 = cl_list(2, ECL_SYM("CONS-CDR",1886), v11saved_place);
    T5 = cl_list(2, v10store_var, T4);
    T6 = ecl_list1(T5);
    T7 = cl_list(2, VV[32], v10store_var);
    T8 = cl_list(2, ECL_SYM("DECLARE",276), T7);
    T9 = cl_list(2, ECL_SYM("CONS-CAR",1885), v11saved_place);
    T10 = cl_list(3, ECL_SYM("SETQ",754), v11saved_place, T9);
    T11 = cl_list(5, ECL_SYM("LET",479), T6, T8, v8, T10);
    T12 = cl_list(3, ECL_SYM("WHEN",909), v11saved_place, T11);
    value0 = cl_list(6, ECL_SYM("LET*",480), T0, T2, T3, T12, v11saved_place);
    return value0;
   }
  }
L14:;
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4061__lambda109_va(cl_narg narg, cl_object v5, cl_object v6env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[26]);
 {
  return LC4061__lambda109(v5, v6env);
 }
}
/* local function CONS-TO-LISTA                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4044cons_to_lista(cl_object v1x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2tem;
  v2tem = ecl_last(v1x,1);
  if (!(ECL_CONSP(v2tem))){
   goto L3;
  }
  T0 = ecl_car(v2tem);
  if (!(ECL_CONSP(T0))){
   goto L3;
  }
  T0 = ecl_caar(v2tem);
  if (!((T0)==(ECL_SYM("CONS",253)))){
   goto L3;
  }
  T0 = ecl_cdar(v2tem);
  {
   cl_fixnum v3;
   v3 = ecl_length(T0);
   if (!((v3)==((cl_fixnum)(2)))){
    goto L3;
   }
  }
  T0 = ecl_butlast(v1x,1);
  T1 = ecl_cdar(v2tem);
  v1x = ecl_append(T0,T1);
  goto L1;
L3:;
  value0 = v1x;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4044cons_to_lista_va(cl_narg narg, cl_object v3x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[3]);
 {
  return LC4044cons_to_lista(v3x);
 }
}
#include "cmp/cmpopt-cons.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclb7l3yuLt5Sym9_HXf0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPOPT-CONS.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclb7l3yuLt5Sym9_HXf0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  ecl_cmp_defun(VV[34]);                          /*  CONS-CAR                */
  ecl_cmp_defun(VV[35]);                          /*  CONS-CDR                */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4045__lambda5_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("CONS",253), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4046__lambda11_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("RPLACA",735), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4047__lambda18_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("RPLACD",736), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4048__lambda25_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("NTH",604), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4049__lambda33_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("NTHCDR",606), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4050__lambda44_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("FIRST",373), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4051__lambda50_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("SECOND",743), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4052__lambda56_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("THIRD",860), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4053__lambda62_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("FOURTH",391), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4054__lambda68_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("FIFTH",353), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4055__lambda74_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("SIXTH",785), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4056__lambda80_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("SEVENTH",755), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4057__lambda86_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("EIGHTH",328), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4058__lambda92_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("NINTH",585), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4059__lambda98_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("TENTH",857), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4060__lambda104_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("REST",722), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4061__lambda109_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("POP",646), ECL_SYM("COMPILER-MACRO",240), T0);
 }
}
