/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmppass1-top.lsp                */
#include <ecl/ecl-cmp.h>
#include "cmp/cmppass1-top.eclh"
/* function definition for T1EXPR                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3451t1expr(cl_object v1form)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,VV[1],ECL_NIL);         /*  *CURRENT-TOPLEVEL-FORM* */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[3]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[2])) /*  CMP-ENV-COPY */;
 ecl_bds_bind(cl_env_copy,VV[2],T0);              /*  *CMP-ENV*               */
 T0 = L3452t1expr_(v1form);
 T1 = CONS(T0,ecl_cmp_symbol_value(cl_env_copy,VV[4]));
 ecl_cmp_setq(cl_env_copy,VV[4],T1);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[4]);
 cl_env_copy->nvalues = 1;
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L3451t1expr_va(cl_narg narg, cl_object v2form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[0]);
 {
  return L3451t1expr(v2form);
 }
}
/* function definition for T1EXPR*                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3452t1expr_(cl_object v1form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = CONS(v1form,ecl_cmp_symbol_value(cl_env_copy,VV[1]));
 ecl_bds_bind(cl_env_copy,VV[1],T0);              /*  *CURRENT-TOPLEVEL-FORM* */
 ecl_bds_bind(cl_env_copy,VV[8],v1form);          /*  *CURRENT-FORM*          */
 ecl_bds_bind(cl_env_copy,VV[9],ecl_make_int8_t(0)); /*  *SETJMPS*            */
 v1form = (cl_env_copy->function=ecl_fdefinition(VV[10]))->cfun.entry(1, v1form) /*  CHK-SYMBOL-MACROLET */;
 if (ECL_CONSP(v1form)) {
  goto L4;
 }
 value0 = L3455t1ordinary(ECL_NIL);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
L4:;
 {
  cl_object v2;
  cl_object v3;
  cl_object v4fd;
  v2 = ecl_car(v1form);
  v3 = ecl_cdr(v1form);
  v4fd = ECL_NIL;
  {
   cl_object v5;
   cl_object v6;
   cl_object v7;
   v5 = ecl_cmp_symbol_value(cl_env_copy,VV[7]);
   v6 = v2;
   v7 = v5;
   if (Null(ecl_memql(v6,v7))){
    goto L9;
   }
  }
  (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(0) /*  PRINT-CURRENT-FORM */;
L9:;
  if (!(ECL_CONSP(v2))){
   goto L14;
  }
  value0 = L3455t1ordinary(v1form);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L14:;
  if (ECL_SYMBOLP(v2)) {
   goto L16;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(2, VV[14], v2) /*  CMPERR */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L16:;
  if (!((v2)==(ECL_SYM("QUOTE",682)))){
   goto L18;
  }
  value0 = L3455t1ordinary(ECL_NIL);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L18:;
  v4fd = ecl_gethash_safe(v2,ecl_cmp_symbol_value(cl_env_copy,VV[15]),ECL_NIL);
  if (Null(v4fd)){
   goto L20;
  }
  value0 = ecl_function_dispatch(cl_env_copy,v4fd)(1, v3);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L20:;
  if (Null(ecl_gethash_safe(v2,ecl_cmp_symbol_value(cl_env_copy,VV[16]),ECL_NIL))){
   goto L23;
  }
  value0 = L3455t1ordinary(v1form);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L23:;
  v4fd = (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, v2) /*  CMP-COMPILER-MACRO-FUNCTION */;
  if (Null(v4fd)){
   goto L25;
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(1, v2) /*  INLINE-POSSIBLE */)){
   goto L25;
  }
  {
   cl_object v5success;
   v5success = ECL_NIL;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[19]))->cfun.entry(2, v4fd, v1form) /*  CMP-EXPAND-MACRO */;
   {
    const int v6 = cl_env_copy->nvalues;
    v4fd = value0;
    cl_object v7;
    v7 = (v6<=1)? ECL_NIL : cl_env_copy->values[1];
    v5success = v7;
   }
   if (Null(v5success)){
    goto L25;
   }
  }
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[20]))){
   goto L33;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(1, v1form) /*  CMP-EVAL */;
L33:;
  ecl_bds_bind(cl_env_copy,VV[20],ECL_NIL);       /*  *COMPILE-TIME-TOO*      */
  T0 = CONS(ECL_SYM("MACROEXPAND",521),ecl_cmp_symbol_value(cl_env_copy,VV[1]));
  ecl_cmp_setq(cl_env_copy,VV[1],T0);
  value0 = L3452t1expr_(v4fd);
  ecl_bds_unwind_n(cl_env_copy,4);
  return value0;
L25:;
  v4fd = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v2) /*  CMP-MACRO-FUNCTION */;
  if (Null(v4fd)){
   goto L37;
  }
  T0 = CONS(ECL_SYM("MACROEXPAND",521),ecl_cmp_symbol_value(cl_env_copy,VV[1]));
  ecl_cmp_setq(cl_env_copy,VV[1],T0);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[19]))->cfun.entry(2, v4fd, v1form) /*  CMP-EXPAND-MACRO */;
  value0 = L3452t1expr_(T0);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L37:;
  value0 = L3455t1ordinary(v1form);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3452t1expr__va(cl_narg narg, cl_object v5form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[5]);
 {
  return L3452t1expr_(v5form);
 }
}
/* function definition for T1/C1EXPR                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3453t1_c1expr(cl_object v1form)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (ecl_cmp_symbol_value(cl_env_copy,VV[25])!=ECL_NIL) {
  goto L2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v1form) /*  C1EXPR */;
 return value0;
L2:;
 value0 = L3452t1expr_(v1form);
 return value0;
}
static cl_object L3453t1_c1expr_va(cl_narg narg, cl_object v2form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[24]);
 {
  return L3453t1_c1expr(v2form);
 }
}
/* function definition for C1EVAL-WHEN                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3454c1eval_when(cl_object v1args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[29]))->cfun.entry(3, ECL_SYM("EVAL-WHEN",342), v1args, ecl_make_int8_t(1)) /*  CHECK-ARGS-NUMBER */;
 {
  cl_object v2load_flag;
  cl_object v3compile_flag;
  cl_object v4execute_flag;
  v2load_flag = ECL_NIL;
  v3compile_flag = ECL_NIL;
  v4execute_flag = ECL_NIL;
  {
   cl_object v5;
   v5 = ecl_car(v1args);
   goto L10;
L9:;
   {
    cl_object v6situation;
    v6situation = ecl_car(v5);
    if (!((v6situation)==(ECL_SYM("LOAD",489)))){
     goto L20;
    }
    goto L17;
L20:;
    goto L18;
L18:;
    if (!((v6situation)==(ECL_SYM("LOAD-TOPLEVEL",1306)))){
     goto L15;
    }
    goto L16;
L17:;
L16:;
    v2load_flag = ECL_T;
    goto L14;
L15:;
    if (!((v6situation)==(ECL_SYM("COMPILE",235)))){
     goto L29;
    }
    goto L26;
L29:;
    goto L27;
L27:;
    if (!((v6situation)==(ECL_SYM("COMPILE-TOPLEVEL",1238)))){
     goto L24;
    }
    goto L25;
L26:;
L25:;
    v3compile_flag = ECL_T;
    goto L14;
L24:;
    if (!((v6situation)==(ECL_SYM("EVAL",341)))){
     goto L38;
    }
    goto L35;
L38:;
    goto L36;
L36:;
    if (!((v6situation)==(ECL_SYM("EXECUTE",1262)))){
     goto L33;
    }
    goto L34;
L35:;
L34:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[25]))){
     goto L41;
    }
    value0 = ecl_cmp_symbol_value(cl_env_copy,VV[20]);
    if (value0!=ECL_NIL) {
     goto L45;
    }
    goto L43;
L45:;
    v3compile_flag = value0;
    goto L43;
L43:;
    goto L14;
L41:;
    v4execute_flag = ECL_T;
    goto L14;
L33:;
    (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(2, VV[36], v6situation) /*  CMPERR */;
L14:;
   }
   v5 = ecl_cdr(v5);
L10:;
   if (Null(v5)){
    goto L50;
   }
   goto L9;
L50:;
  }
  if (ecl_cmp_symbol_value(cl_env_copy,VV[25])!=ECL_NIL) {
   goto L52;
  }
  if (Null(v4execute_flag)){
   goto L56;
  }
  T0 = ecl_cdr(v1args);
  goto L54;
L56:;
  T0 = ECL_NIL;
  goto L54;
L54:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[37]))->cfun.entry(1, T0) /*  C1PROGN */;
  return value0;
L52:;
  if (Null(v2load_flag)){
   goto L58;
  }
  ecl_bds_bind(cl_env_copy,VV[20],v3compile_flag); /*  *COMPILE-TIME-TOO*     */
  T0 = ecl_cdr(v1args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[37]))->cfun.entry(1, T0) /*  C1PROGN */;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L58:;
  if (Null(v3compile_flag)){
   goto L60;
  }
  T0 = ecl_cdr(v1args);
  T1 = CONS(ECL_SYM("PROGN",674),T0);
  (cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(1, T1) /*  CMP-EVAL */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[37]))->cfun.entry(1, ECL_NIL) /*  C1PROGN */;
  return value0;
L60:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[37]))->cfun.entry(1, ECL_NIL) /*  C1PROGN */;
  return value0;
 }
}
static cl_object L3454c1eval_when_va(cl_narg narg, cl_object v5args, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[28]);
 {
  return L3454c1eval_when(v5args);
 }
}
/* function definition for T1ORDINARY                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3455t1ordinary(cl_object v1form)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[20]))){
  goto L2;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(1, v1form) /*  CMP-EVAL */;
L2:;
 ecl_bds_bind(cl_env_copy,VV[25],ECL_NIL);        /*  *COMPILE-TOPLEVEL*      */
 ecl_bds_bind(cl_env_copy,VV[20],ECL_NIL);        /*  *COMPILE-TIME-TOO*      */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v1form) /*  C1EXPR */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(3, VV[41], VV[42], T0) /*  MAKE-C1FORM* */;
 value0 = L3456add_load_time_values(T1);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L3455t1ordinary_va(cl_narg narg, cl_object v2form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[11]);
 {
  return L3455t1ordinary(v2form);
 }
}
/* function definition for ADD-LOAD-TIME-VALUES                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3456add_load_time_values(cl_object v1form)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2previous;
  if (!(ECL_CONSP(ecl_cmp_symbol_value(cl_env_copy,VV[44])))){
   goto L6;
  }
  T0 = cl_nreverse(ecl_cmp_symbol_value(cl_env_copy,VV[44]));
  goto L4;
L6:;
  T0 = ECL_NIL;
  goto L4;
L4:;
  T1 = cl_nreverse(ecl_cmp_symbol_value(cl_env_copy,VV[45]));
  v2previous = ecl_append(T0,T1);
  if (Null(v2previous)){
   goto L2;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[44],T0);
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[45],T0);
  T0 = ecl_list1(v1form);
  T1 = ecl_nconc(v2previous,T0);
  v1form = (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(3, ECL_SYM("PROGN",674), VV[42], T1) /*  MAKE-C1FORM* */;
 }
L2:;
 value0 = v1form;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3456add_load_time_values_va(cl_narg narg, cl_object v2form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[39]);
 {
  return L3456add_load_time_values(v2form);
 }
}
/* function definition for T1DEFMACRO                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3457t1defmacro(cl_object v1args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[29]))->cfun.entry(3, ECL_SYM("LOAD-TIME-VALUE",491), v1args, ecl_make_int8_t(2)) /*  CHECK-ARGS-NUMBER */;
 {
  cl_object v2;
  cl_object v3name;
  cl_object v4lambda_list;
  v2 = v1args;
  if (!(v2==ECL_NIL)){
   goto L5;
  }
  si_dm_too_few_arguments(v1args);
L5:;
  {
   cl_object v5;
   v5 = ecl_car(v2);
   v2 = ecl_cdr(v2);
   v3name = v5;
  }
  if (!(v2==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1args);
L11:;
  {
   cl_object v5;
   v5 = ecl_car(v2);
   v2 = ecl_cdr(v2);
   v4lambda_list = v5;
  }
  {
   cl_object v5;                                  /*  FUNCTION                */
   value0 = (cl_env_copy->function=(ECL_SYM("EXPAND-DEFMACRO",1077)->symbol.gfdef))->cfun.entry(3, v3name, v4lambda_list, v2) /*  EXPAND-DEFMACRO */;
   {
    v5 = value0;
   }
   {
    cl_object v6fn;
    v6fn = (cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(2, v5, ecl_cmp_symbol_value(cl_env_copy,VV[2])) /*  CMP-EVAL */;
    (cl_env_copy->function=ecl_fdefinition(VV[49]))->cfun.entry(2, v3name, v6fn) /*  CMP-ENV-REGISTER-GLOBAL-MACRO */;
   }
   T0 = CONS(ECL_SYM("DEFMACRO",285),v1args);
   T1 = cl_macroexpand(1, T0);
   value0 = L3452t1expr_(T1);
   return value0;
  }
 }
}
static cl_object L3457t1defmacro_va(cl_narg narg, cl_object v5args, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[47]);
 {
  return L3457t1defmacro(v5args);
 }
}
/* function definition for C1LOAD-TIME-VALUE                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3458c1load_time_value(cl_object v1args)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[29]))->cfun.entry(4, ECL_SYM("LOAD-TIME-VALUE",491), v1args, ecl_make_int8_t(1), ecl_make_int8_t(2)) /*  CHECK-ARGS-NUMBER */;
 {
  cl_object v2;
  cl_object v3loc;
  v2 = ecl_car(v1args);
  v3loc = ECL_NIL;
  if (ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,VV[44]))) {
   goto L6;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(1, v2) /*  CMP-EVAL */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[52]))->cfun.entry(1, T0) /*  C1CONSTANT-VALUE */;
  return value0;
L6:;
  if (ECL_LISTP(v2)) {
   goto L10;
  }
  if (!(ECL_SYMBOLP(v2))){
   goto L8;
  }
  goto L9;
L10:;
L9:;
  v3loc = (cl_env_copy->function=ecl_fdefinition(VV[53]))->cfun.entry(0) /*  DATA-EMPTY-LOC */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v2) /*  C1EXPR */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(4, ECL_SYM("LOAD-TIME-VALUE",491), VV[42], v3loc, T0) /*  MAKE-C1FORM* */;
  T2 = CONS(T1,ecl_cmp_symbol_value(cl_env_copy,VV[44]));
  ecl_cmp_setq(cl_env_copy,VV[44],T2);
  goto L5;
L8:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(1, v2) /*  CMP-EVAL */;
  v3loc = (cl_env_copy->function=ecl_fdefinition(VV[54]))->cfun.entry(1, T0) /*  ADD-OBJECT */;
L5:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(5, VV[55], ECL_SYM("TYPE",1356), ECL_T, VV[42], v3loc) /*  MAKE-C1FORM* */;
  return value0;
 }
}
static cl_object L3458c1load_time_value_va(cl_narg narg, cl_object v4args, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[51]);
 {
  return L3458c1load_time_value(v4args);
 }
}
/* function definition for T1FSET                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3459t1fset(cl_object v1args)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2form;
  v2form = CONS(ECL_SYM("FSET",1090),v1args);
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[20]))){
   goto L3;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(1, v2form) /*  CMP-EVAL */;
L3:;
  ecl_bds_bind(cl_env_copy,VV[25],ECL_NIL);       /*  *COMPILE-TOPLEVEL*      */
  ecl_bds_bind(cl_env_copy,VV[20],ECL_NIL);       /*  *COMPILE-TIME-TOO*      */
  T0 = L3460c1fset(v2form);
  value0 = L3456add_load_time_values(T0);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3459t1fset_va(cl_narg narg, cl_object v3args, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[57]);
 {
  return L3459t1fset(v3args);
 }
}
/* function definition for C1FSET                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3460c1fset(cl_object v1form)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3;
  cl_object v4fname;
  cl_object v5def;
  cl_object v6macro;
  cl_object v7pprint;
  v2 = ecl_cdr(v1form);
  v3 = v2;
  if (!(v3==ECL_NIL)){
   goto L5;
  }
  si_dm_too_few_arguments(v2);
L5:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4fname = v8;
  }
  if (!(v3==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v2);
L11:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5def = v8;
  }
  if (Null(v3)){
   goto L17;
  }
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v6macro = v8;
   goto L16;
  }
L17:;
  v6macro = ECL_NIL;
L16:;
  if (Null(v3)){
   goto L23;
  }
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v7pprint = v8;
   goto L22;
  }
L23:;
  v7pprint = ECL_NIL;
L22:;
  if (Null(v3)){
   goto L28;
  }
  si_dm_too_many_arguments(v2);
L28:;
  {
   cl_object v8fun_form;
   ecl_bds_bind(cl_env_copy,VV[61],ECL_T);        /*  *USE-C-GLOBAL*          */
   v8fun_form = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v5def) /*  C1EXPR */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[62]))->cfun.entry(1, v8fun_form) /*  C1FORM-NAME */;
   if (!((T0)==(VV[63]))){
    ecl_bds_unwind1(cl_env_copy);
    goto L30;
   }
   {
    cl_object v9function_list;
    cl_object v10fun_object;
    cl_object v11form;
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[65]))->cfun.entry(1, v8fun_form) /*  C1FORM-ARGS */;
    v9function_list = ecl_car(T0);
    {
     cl_object v12;
     v12 = v9function_list;
     {
      cl_object v13;
      v13 = v12;
      {
       bool v14;
       v14 = ECL_LISTP(v13);
       if (ecl_unlikely(!(v14)))
         FEwrong_type_argument(VV[68],v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v12)){
      goto L39;
     }
     {
      cl_object v13;
      v13 = ECL_CONS_CDR(v12);
      v9function_list = v13;
      v12 = ECL_CONS_CAR(v12);
     }
L39:;
     v10fun_object = v12;
    }
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[65]))->cfun.entry(1, v8fun_form) /*  C1FORM-ARGS */;
    v11form = ecl_cadr(T0);
    if (!(v9function_list==ECL_NIL)){
     ecl_bds_unwind1(cl_env_copy);
     goto L30;
    }
    T0 = ecl_fdefinition(VV[69]);
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[70]))->cfun.entry(1, v10fun_object) /*  FUN-REFERENCED-VARS */;
    if (Null(cl_every(2, T0, T1))){
     ecl_bds_unwind1(cl_env_copy);
     goto L30;
    }
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[62]))->cfun.entry(1, v11form) /*  C1FORM-NAME */;
    if (!((T0)==(ECL_SYM("VARIABLE",901)))){
     ecl_bds_unwind1(cl_env_copy);
     goto L30;
    }
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[65]))->cfun.entry(1, v11form) /*  C1FORM-ARGS */;
    T1 = ecl_car(T0);
    T2 = (cl_env_copy->function=ecl_fdefinition(VV[71]))->cfun.entry(1, v10fun_object) /*  FUN-VAR */;
    if (!((T1)==(T2))){
     ecl_bds_unwind1(cl_env_copy);
     goto L30;
    }
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[72]))->cfun.entry(1, v10fun_object) /*  FUN-NO-ENTRY */)){
     goto L51;
    }
    if (Null(v6macro)){
     goto L53;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(2, VV[73], v4fname) /*  CMPERR */;
L53:;
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(7, ECL_SYM("FSET",1090), VV[42], v10fun_object, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  MAKE-C1FORM* */;
    ecl_bds_unwind1(cl_env_copy);
    return value0;
L51:;
    if (!((v6macro)==(ECL_NIL))){
     goto L60;
    }
    goto L57;
L60:;
    goto L58;
L58:;
    if (!((v6macro)==(ECL_T))){
     ecl_bds_unwind1(cl_env_copy);
     goto L30;
    }
    goto L56;
L57:;
L56:;
    if (ECL_FIXNUMP(v7pprint)||ECL_BIGNUMP(v7pprint)) {
     goto L64;
    }
    if (!(v7pprint==ECL_NIL)){
     ecl_bds_unwind1(cl_env_copy);
     goto L30;
    }
    goto L63;
L64:;
L63:;
    if (!(ECL_CONSP(v4fname))){
     ecl_bds_unwind1(cl_env_copy);
     goto L30;
    }
    T0 = ecl_car(v4fname);
    if (!((T0)==(ECL_SYM("QUOTE",682)))){
     ecl_bds_unwind1(cl_env_copy);
     goto L30;
    }
    {
     cl_object v12fname;
     v12fname = ecl_cadr(v4fname);
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[54]))->cfun.entry(9, v12fname, VV[76], ECL_T, VV[77], ECL_T, VV[78], ECL_T, VV[79], ECL_T) /*  ADD-OBJECT */;
    }
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v4fname) /*  C1EXPR */;
    T2 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v6macro) /*  C1EXPR */;
    T3 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v7pprint) /*  C1EXPR */;
    T4 = cl_list(4, T1, v8fun_form, T2, T3);
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(7, ECL_SYM("FSET",1090), VV[42], v10fun_object, T0, v6macro, v7pprint, T4) /*  MAKE-C1FORM* */;
    ecl_bds_unwind1(cl_env_copy);
    return value0;
   }
  }
L30:;
  value0 = L3455t1ordinary(v1form);
  return value0;
 }
}
static cl_object L3460c1fset_va(cl_narg narg, cl_object v8form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[58]);
 {
  return L3460c1fset(v8form);
 }
}
#include "cmp/cmppass1-top.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclkf0cz6eCL3Bn9_N3T0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPPASS1-TOP.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclkf0cz6eCL3Bn9_N3T0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(_ecl_static_0);
  ecl_cmp_defun(VV[81]);                          /*  T1EXPR                  */
  si_Xmake_special(VV[7]);
  if (ecl_boundp(cl_env_copy,VV[7])) {
   goto L6;
  }
  T0 = VVtemp[0];
  ecl_cmp_setq(cl_env_copy,VV[7],T0);
L6:;
  ecl_cmp_defun(VV[82]);                          /*  T1EXPR*                 */
  ecl_cmp_defun(VV[83]);                          /*  T1/C1EXPR               */
  ecl_cmp_defun(VV[84]);                          /*  C1EVAL-WHEN             */
  ecl_cmp_defun(VV[85]);                          /*  T1ORDINARY              */
  ecl_cmp_defun(VV[86]);                          /*  ADD-LOAD-TIME-VALUES    */
  ecl_cmp_defun(VV[87]);                          /*  T1DEFMACRO              */
  ecl_cmp_defun(VV[88]);                          /*  C1LOAD-TIME-VALUE       */
  ecl_cmp_defun(VV[89]);                          /*  T1FSET                  */
  ecl_cmp_defun(VV[90]);                          /*  C1FSET                  */
 }
}
