/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/lsp/cmdline.lsp                     */
#include <ecl/ecl-cmp.h>
#include "lsp/cmdline.eclh"
/* function definition for COMMAND-ARGS                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L758command_args()
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2i;
  v1 = si_argc();
  v2i = ecl_make_int8_t(0);
  {
   cl_object v3;
   cl_object v4;
   v3 = ecl_list1(ECL_NIL);
   v4 = v3;
L6:;
   if (!(ecl_greatereq(v2i,v1))){
    goto L8;
   }
   goto L7;
L8:;
   {
    cl_object v5;
    v5 = v4;
    if (ecl_unlikely(ECL_ATOM(v5))) FEtype_error_cons(v5);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T0 = v5;
   }
   T1 = si_argv(v2i);
   v4 = ecl_list1(T1);
   (ECL_CONS_CDR(T0)=v4,T0);
   v2i = ecl_one_plus(v2i);
   goto L6;
L7:;
   value0 = ecl_cdr(v3);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L758command_args_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[7]);
 {
  return L758command_args();
 }
}
/* function definition for COMMAND-ARG-ERROR                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L759command_arg_error(cl_narg narg, cl_object v1str, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[8]);
 {
  cl_object v2fmt_args;
  ecl_va_list args; ecl_va_start(args,v1str,narg,1);
  v2fmt_args = cl_grab_rest_args(args);
  ecl_va_end(args);
  T0 = (ECL_SYM("FORMAT",389)->symbol.gfdef);
  cl_apply(4, T0, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*ERROR-OUTPUT*",35)), v1str, v2fmt_args);
  ecl_princ(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HELP-MESSAGE*",1923)),ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*ERROR-OUTPUT*",35)));
  value0 = si_quit(1, ecl_make_int8_t(1));
  return value0;
 }
}
/* function definition for PRODUCE-INIT-CODE                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L761produce_init_code(cl_object v1option_list, cl_object v2rules)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3match_option;
  cl_object v4commands;
  cl_object v5stop;
  cl_object v6loadrc;
  {
   cl_object v7;
   v7 = ecl_make_cfun_va((cl_objectfn)LC760__lambda8_va,ECL_NIL,Cblock,2);
   v3match_option = v7;
  }
  v4commands = ECL_NIL;
  v5stop = ECL_NIL;
  v6loadrc = ECL_T;
  goto L8;
L7:;
  {
   cl_object v7option;
   cl_object v8rule;
   {
    cl_object v9;
    v9 = v1option_list;
    {
     cl_object v10;
     v10 = v9;
     {
      bool v11;
      v11 = ECL_LISTP(v10);
      if (ecl_unlikely(!(v11)))
         FEwrong_type_argument(VV[15],v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v9)){
     goto L16;
    }
    {
     cl_object v10;
     v10 = ECL_CONS_CDR(v9);
     v1option_list = v10;
     v9 = ECL_CONS_CAR(v9);
    }
L16:;
    v7option = v9;
   }
   {
    cl_object v9;
    v9 = v2rules;
    goto L26;
L25:;
    {
     cl_object v10;
     cl_object v11;
     {
      cl_object v12;
      v12 = v9;
      if (ecl_unlikely(ECL_ATOM(v12))) FEtype_error_cons(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v10 = v12;
     }
     v11 = ECL_CONS_CAR(v10);
     if (Null(v11)){
      goto L28;
     }
     {
      cl_object v12;
      {
       cl_object v13;
       v13 = v11;
       if (ecl_unlikely(ECL_ATOM(v13))) FEtype_error_cons(v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v13;
      }
      v12 = ECL_CONS_CAR(T0);
      if (Null(ecl_function_dispatch(cl_env_copy,v3match_option)(2, v7option, v12))){
       goto L28;
      }
      v8rule = v11;
      goto L22;
     }
    }
L28:;
    v9 = ECL_CONS_CDR(v9);
L26:;
    if (v9==ECL_NIL) {
     goto L41;
    }
    goto L25;
L41:;
    v8rule = ECL_NIL;
   }
L22:;
   if (v8rule!=ECL_NIL) {
    goto L43;
   }
   {
    cl_object v9;
    v9 = v2rules;
    goto L51;
L50:;
    {
     cl_object v10;
     cl_object v11;
     {
      cl_object v12;
      v12 = v9;
      if (ecl_unlikely(ECL_ATOM(v12))) FEtype_error_cons(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v10 = v12;
     }
     v11 = ECL_CONS_CAR(v10);
     if (Null(v11)){
      goto L53;
     }
     {
      cl_object v12;
      {
       cl_object v13;
       v13 = v11;
       if (ecl_unlikely(ECL_ATOM(v13))) FEtype_error_cons(v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v13;
      }
      v12 = ECL_CONS_CAR(T0);
      if (Null(ecl_function_dispatch(cl_env_copy,v3match_option)(2, VV[16], v12))){
       goto L53;
      }
      v8rule = v11;
      goto L47;
     }
    }
L53:;
    v9 = ECL_CONS_CDR(v9);
L51:;
    if (v9==ECL_NIL) {
     goto L66;
    }
    goto L50;
L66:;
    v8rule = ECL_NIL;
   }
L47:;
   v5stop = ECL_T;
   if (v8rule!=ECL_NIL) {
    goto L43;
   }
   L759command_arg_error(2, VV[17], v7option);
L43:;
   {
    cl_object v9;
    v9 = ecl_cadddr(v8rule);
    if (!((v9)==(VV[18]))){
     goto L72;
    }
    v6loadrc = ECL_NIL;
    goto L70;
L72:;
    if (!((v9)==(VV[19]))){
     goto L75;
    }
    v6loadrc = ECL_T;
    goto L70;
L75:;
    if (!((v9)==(VV[20]))){
     goto L70;
    }
    T0 = CONS(v7option,v1option_list);
    T1 = cl_list(2, ECL_SYM("QUOTE",682), T0);
    v1option_list = ecl_list1(T1);
    v5stop = ECL_T;
   }
L70:;
   {
    cl_object v9;
    cl_object v10;
    T0 = ecl_caddr(v8rule);
    v9 = cl_copy_tree(T0);
    v10 = ecl_cadr(v8rule);
    {
     cl_object v11;
     v11 = ecl_make_bool(ecl_equal(v10,ecl_make_int8_t(0)));
     if (Null(v11)){
      goto L86;
     }
     goto L84;
L86:;
     if (!(ecl_equal(v10,ECL_SYM("&OPTIONAL",13)))){
      goto L88;
     }
     if (v1option_list==ECL_NIL) {
      goto L91;
     }
     {
      cl_object v12;
      v12 = ecl_car(v1option_list);
      {
       cl_object v13;
       v13 = v2rules;
       goto L97;
L96:;
       {
        cl_object v14;
        cl_object v15;
        {
         cl_object v16;
         v16 = v13;
         if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         v14 = v16;
        }
        v15 = ECL_CONS_CAR(v14);
        if (Null(v15)){
         goto L99;
        }
        {
         cl_object v16;
         {
          cl_object v17;
          v17 = v15;
          if (ecl_unlikely(ECL_ATOM(v17))) FEtype_error_cons(v17);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v17;
         }
         v16 = ECL_CONS_CAR(T0);
         if (Null(ecl_function_dispatch(cl_env_copy,v3match_option)(2, v12, v16))){
          goto L99;
         }
         if (Null(v15)){
          goto L88;
         }
         goto L89;
        }
       }
L99:;
       v13 = ECL_CONS_CDR(v13);
L97:;
       if (v13==ECL_NIL) {
        goto L112;
       }
       goto L96;
L112:;
       goto L88;
      }
     }
L91:;
L89:;
     cl_nsubst(3, ECL_T, ecl_make_int8_t(1), v9);
     goto L84;
L88:;
     if (!(v1option_list==ECL_NIL)){
      goto L114;
     }
     L759command_arg_error(2, VV[21], v7option);
     goto L84;
L114:;
     if ((v10)==(ECL_SYM("REST",722))) {
      goto L118;
     }
     if (!((v10)==(ECL_SYM("&REST",14)))){
      goto L116;
     }
     goto L117;
L118:;
L117:;
     cl_nsubst(3, v1option_list, v10, v9);
     v1option_list = ECL_NIL;
     goto L84;
L116:;
     {
      cl_object v12;
      v12 = v1option_list;
      {
       cl_object v13;
       v13 = v12;
       {
        bool v14;
        v14 = ECL_LISTP(v13);
        if (ecl_unlikely(!(v14)))
         FEwrong_type_argument(VV[15],v13);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v12)){
       goto L127;
      }
      {
       cl_object v13;
       v13 = ECL_CONS_CDR(v12);
       v1option_list = v13;
       v12 = ECL_CONS_CAR(v12);
      }
L127:;
      T0 = v12;
     }
     cl_nsubst(3, T0, ecl_make_int8_t(1), v9);
    }
L84:;
    v4commands = CONS(v9,v4commands);
   }
  }
L8:;
  if (v5stop!=ECL_NIL) {
   goto L134;
  }
  if (v1option_list==ECL_NIL) {
   goto L134;
  }
  goto L7;
L134:;
  T0 = cl_nreverse(v4commands);
  T1 = ecl_append(T0,VV[23]);
  T2 = cl_listX(3, ECL_SYM("LET",479), VV[22], T1);
  cl_env_copy->nvalues = 3;
  cl_env_copy->values[2] = v1option_list;
  cl_env_copy->values[1] = v6loadrc;
  cl_env_copy->values[0] = T2;
  return cl_env_copy->values[0];
 }
}
static cl_object L761produce_init_code_va(cl_narg narg, cl_object v7option_list, cl_object v8rules, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[10]);
 {
  return L761produce_init_code(v7option_list, v8rules);
 }
}
/* function definition for PROCESS-COMMAND-ARGS                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L767process_command_args(volatile cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object volatile v1args;
  cl_object volatile v2rules;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L767process_command_argskeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[2])) {
    v1args = ecl_cdr(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*COMMAND-ARGS*",1927)));
   } else {
    v1args = keyvars[0];
   }
   if (Null(keyvars[3])) {
    v2rules = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("+DEFAULT-COMMAND-ARG-RULES+",1925));
   } else {
    v2rules = keyvars[1];
   }
  }
  {
   cl_object volatile v3;                         /*  COMMANDS                */
   cl_object volatile v4;                         /*  LOADRC                  */
   value0 = L761produce_init_code(v1args, v2rules);
   {
    const int v5 = cl_env_copy->nvalues;
    v3 = value0;
    cl_object v6;
    v6 = (v5<=1)? ECL_NIL : cl_env_copy->values[1];
    v4 = v6;
   }
   {
    volatile cl_object env1 = env0;
    env1 = ECL_NIL;
    CLV0 = env1 = CONS(ECL_NIL,env1);
    CLV1 = env1 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env1); /*  TAGBODY       */
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
     if (__ecl_frs_push_result!=0) {
     if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
      goto L4;
     }
     if (cl_env_copy->values[0]==ecl_make_int8_t(1)) {
      goto L5;
     }
     ecl_internal_error("GO found an inexistent tag");
     } else {
     {
      cl_object v5;
      v5 = ecl_make_cclosure_va((cl_objectfn)LC762__lambda93,env1,Cblock,0);
      T0 = v5;
     }
     {
      cl_object v5;
      v5 = ecl_make_cfun_va((cl_objectfn)LC763__lambda95_va,ECL_NIL,Cblock,1);
      T1 = v5;
     }
     T2 = (cl_env_copy->function=(VV[26]->symbol.gfdef))->cfun.entry(6, ECL_SYM("NAME",1309), ECL_SYM("CONTINUE",252), ECL_SYM("FUNCTION",1273), T0, VV[28], T1) /*  MAKE-RESTART */;
     {
      cl_object v5;
      v5 = ecl_make_cclosure_va((cl_objectfn)LC764__lambda97,env1,Cblock,0);
      T3 = v5;
     }
     {
      cl_object v5;
      v5 = ecl_make_cfun_va((cl_objectfn)LC765__lambda99_va,ECL_NIL,Cblock,1);
      T4 = v5;
     }
     T5 = (cl_env_copy->function=(VV[26]->symbol.gfdef))->cfun.entry(6, ECL_SYM("NAME",1309), ECL_SYM("ABORT",79), ECL_SYM("FUNCTION",1273), T3, VV[28], T4) /*  MAKE-RESTART */;
     T6 = cl_list(2, T2, T5);
     T7 = CONS(T6,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5)));
     ecl_bds_bind(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5),T7); /*  *RESTART-CLUSTERS* */
     {
      cl_object v5;
      v5 = ecl_make_cfun_va((cl_objectfn)LC766__lambda101_va,ECL_NIL,Cblock,1);
      T0 = v5;
     }
     T1 = CONS(ECL_SYM("ERROR",339),T0);
     T2 = ecl_list1(T1);
     T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
     ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
     if (Null(v4)){
      goto L12;
     }
     {
      cl_object v5;
      v5 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*LISP-INIT-FILE-LIST*",1924));
      goto L17;
L16:;
      {
       cl_object v6file;
       v6file = ecl_car(v5);
       if (Null(cl_load(7, v6file, ECL_SYM("IF-DOES-NOT-EXIST",1277), ECL_NIL, ECL_SYM("SEARCH-LIST",1342), ECL_NIL, ECL_SYM("VERBOSE",1363), ECL_NIL))){
        goto L21;
       }
       goto L12;
L21:;
      }
      v5 = ecl_cdr(v5);
L17:;
      if (Null(v5)){
       goto L25;
      }
      goto L16;
L25:;
     }
L12:;
     value0 = cl_eval(v3);
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     ecl_bds_unwind1(cl_env_copy);
     return value0;
L4:;
     {
      cl_object v5;
      v5 = ECL_CONS_CAR(CLV0);
      if (Null(v5)){
       goto L29;
      }
      value0 = si_dm_too_many_arguments(ECL_NIL);
      ecl_frs_pop_n(cl_env_copy, 1);
      return value0;
L29:;
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 1;
      ecl_frs_pop_n(cl_env_copy, 1);
      return value0;
     }
L5:;
     {
      cl_object v5;
      v5 = ECL_CONS_CAR(CLV0);
      if (Null(v5)){
       goto L33;
      }
      si_dm_too_many_arguments(ECL_NIL);
L33:;
      value0 = si_quit(2, ecl_make_int8_t(-1), ECL_NIL);
      ecl_frs_pop_n(cl_env_copy, 1);
      return value0;
     }
     }
    }
   }
  }
 }
}
/* local function LAMBDA8                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC760__lambda8(cl_object v1k, cl_object v2r)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(v2r))){
  goto L2;
 }
 {
  cl_object v3;
  v3 = (ECL_SYM("STRING=",825)->symbol.gfdef);
  {
   cl_object v4;
   v4 = v2r;
   goto L8;
L7:;
   {
    cl_object v5;
    cl_object v6;
    {
     cl_object v7;
     v7 = v4;
     if (ecl_unlikely(ECL_ATOM(v7))) FEtype_error_cons(v7);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v7;
    }
    v6 = ECL_CONS_CAR(v5);
    if (Null(cl_stringE(2, v1k, v6))){
     goto L10;
    }
    value0 = v5;
    cl_env_copy->nvalues = 1;
    return value0;
   }
L10:;
   v4 = ECL_CONS_CDR(v4);
L8:;
   if (v4==ECL_NIL) {
    goto L18;
   }
   goto L7;
L18:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
L2:;
 value0 = cl_stringE(2, v1k, v2r);
 return value0;
}
static cl_object LC760__lambda8_va(cl_narg narg, cl_object v5k, cl_object v6r, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[11]);
 {
  return LC760__lambda8(v5k, v6r);
 }
}
/* closure LAMBDA93                                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC762__lambda93(cl_narg narg, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV0) = v1temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* local function LAMBDA95                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC763__lambda95(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_write_string(2, VV[30], v1stream);
 return value0;
}
static cl_object LC763__lambda95_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[29]);
 {
  return LC763__lambda95(v2stream);
 }
}
/* closure LAMBDA97                                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC764__lambda97(cl_narg narg, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV0) = v1temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(1));
 }
 }
}
/* local function LAMBDA99                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC765__lambda99(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_write_string(2, VV[33], v1stream);
 return value0;
}
static cl_object LC765__lambda99_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[32]);
 {
  return LC765__lambda99(v2stream);
 }
}
/* local function LAMBDA101                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC766__lambda101(cl_object v1c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[0]))){
  goto L2;
 }
 value0 = (cl_env_copy->function=(ECL_SYM("INVOKE-DEBUGGER",447)->symbol.gfdef))->cfun.entry(1, v1c) /*  INVOKE-DEBUGGER */;
 return value0;
L2:;
 cl_format(3, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*ERROR-OUTPUT*",35)), VV[35], v1c);
 value0 = si_quit(1, ecl_make_int8_t(1));
 return value0;
}
static cl_object LC766__lambda101_va(cl_narg narg, cl_object v2c, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[34]);
 {
  return LC766__lambda101(v2c);
 }
}
#include "lsp/cmdline.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecldD4pCprV6IBm9_d400M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:LSP;CMDLINE.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecldD4pCprV6IBm9_d400M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  si_Xmake_special(VV[0]);
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(ECL_SYM("*LISP-INIT-FILE-LIST*",1924));
  T0 = VVtemp[1];
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*LISP-INIT-FILE-LIST*",1924),T0);
  si_Xmake_special(ECL_SYM("*HELP-MESSAGE*",1923));
  T0 = VVtemp[2];
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*HELP-MESSAGE*",1923),T0);
  ecl_cmp_defun(VV[38]);                          /*  COMMAND-ARGS            */
  si_Xmake_special(ECL_SYM("*COMMAND-ARGS*",1927));
  T0 = L758command_args();
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*COMMAND-ARGS*",1927),T0);
  si_Xmake_special(ECL_SYM("*UNPROCESSED-ECL-COMMAND-ARGS*",1929));
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*UNPROCESSED-ECL-COMMAND-ARGS*",1929),T0);
  (void)0; /* No entry created for COMMAND-ARG-ERROR */
  si_Xmake_constant(ECL_SYM("+DEFAULT-COMMAND-ARG-RULES+",1925), VV[9]);
  ecl_cmp_defun(VV[39]);                          /*  PRODUCE-INIT-CODE       */
  ecl_cmp_defun(VV[40]);                          /*  PROCESS-COMMAND-ARGS    */
 }
}
