/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpbackend-cxx/cmpc-inl-lspfun.lsp */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpc-inl-lspfun.eclh"
#include "cmp/cmpc-inl-lspfun.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclyZPZF6tlGTNq9_pHY0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPBACKEND-CXX;CMPC-INL-LSPFUN.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclyZPZF6tlGTNq9_pHY0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0, T1, T2, T3, T4, T5, T6;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  {
   cl_object v1;
   cl_object v2;
   cl_object v3;
   v1 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
   v2 = VV[1];
   v3 = v1;
   if (Null(ecl_memql(v2,v3))){
    goto L4;
   }
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,VV[2]);
  goto L3;
L4:;
  T0 = ECL_NIL;
L3:;
  {
   cl_object v1;
   cl_object v2;
   cl_object v3;
   v1 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
   v2 = VV[24];
   v3 = v1;
   if (Null(ecl_memql(v2,v3))){
    goto L10;
   }
  }
  T1 = VVtemp[1];
  goto L9;
L10:;
  T1 = ECL_NIL;
L9:;
  {
   cl_object v1;
   cl_object v2;
   cl_object v3;
   v1 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
   v2 = VV[25];
   v3 = v1;
   if (Null(ecl_memql(v2,v3))){
    goto L16;
   }
  }
  T2 = VVtemp[2];
  goto L15;
L16:;
  T2 = ECL_NIL;
L15:;
  T3 = ecl_append(T1,T2);
  T4 = cl_listX(22, VV[3], VV[4], VV[5], VV[6], VV[7], VV[8], VV[9], VV[10], VV[11], VV[12], VV[13], VV[14], VV[15], VV[16], VV[17], VV[18], VV[19], VV[20], VV[21], VV[22], VV[23], T3);
  T5 = ecl_append(T0,T4);
  T6 = CONS(VV[0],T5);
  (cl_env_copy->function=(ECL_SYM("PROCLAIM",669)->symbol.gfdef))->cfun.entry(1, T6) /*  PROCLAIM */;
 }
}
