/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpbackend-cxx/cmppass2-loc.lsp */
#include <ecl/ecl-cmp.h>
#include "cmp/cmppass2-loc.eclh"
/* function definition for WT-LOC                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3914wt_loc(cl_object v1loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_CONSP(v1loc))){
  goto L2;
 }
 {
  cl_object v2fd;
  T0 = ecl_car(v1loc);
  v2fd = ecl_gethash_safe(T0,ecl_cmp_symbol_value(cl_env_copy,VV[1]),ECL_NIL);
  if (Null(v2fd)){
   goto L5;
  }
  T0 = ecl_cdr(v1loc);
  value0 = cl_apply(2, v2fd, T0);
  return value0;
L5:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(2, VV[0], v1loc) /*  UNKNOWN-LOCATION */;
  return value0;
 }
L2:;
 if (!(ECL_SYMBOLP(v1loc))){
  goto L7;
 }
 {
  cl_object v3txt;
  v3txt = ecl_gethash_safe(v1loc,ecl_cmp_symbol_value(cl_env_copy,VV[1]),VV[3]);
  if (!((v3txt)==(VV[3]))){
   goto L10;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(2, VV[0], v1loc) /*  UNKNOWN-LOCATION */;
L10:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, v3txt) /*  WT */;
  return value0;
 }
L7:;
 if (!(ECL_STRINGP(v1loc))){
  goto L12;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, v1loc) /*  WT */;
 return value0;
L12:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(1, v1loc) /*  VAR-P */)){
  goto L14;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[6]))->cfun.entry(1, v1loc) /*  WT-VAR */;
 return value0;
L14:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[7]))->cfun.entry(1, v1loc) /*  VV-P */)){
  goto L16;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[8]))->cfun.entry(1, v1loc) /*  WT-VV */;
 return value0;
L16:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(2, VV[0], v1loc) /*  UNKNOWN-LOCATION */;
 return value0;
}
static cl_object L3914wt_loc_va(cl_narg narg, cl_object v4loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[0]);
 {
  return L3914wt_loc(v4loc);
 }
}
/* function definition for WT-FIXNUM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3915wt_fixnum(cl_narg narg, cl_object v1value, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[10]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[10]);
 {
  cl_object v2vv;
  va_list args; va_start(args,v1value);
  {
   int i = 1;
   if (i >= narg) {
    v2vv = ECL_NIL;
   } else {
    i++;
    v2vv = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = ecl_princ(v1value,ecl_cmp_symbol_value(cl_env_copy,VV[11]));
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for WT-NUMBER                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3916wt_number(cl_narg narg, cl_object v1value, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[13]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[13]);
 {
  cl_object v2vv;
  va_list args; va_start(args,v1value);
  {
   int i = 1;
   if (i >= narg) {
    v2vv = ECL_NIL;
   } else {
    i++;
    v2vv = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, v1value) /*  WT */;
  return value0;
 }
}
/* function definition for WT-CHARACTER                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3917wt_character(cl_narg narg, cl_object v1value, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[15]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[15]);
 {
  cl_object v2vv;
  va_list args; va_start(args,v1value);
  {
   int i = 1;
   if (i >= narg) {
    v2vv = ECL_NIL;
   } else {
    i++;
    v2vv = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = cl_char_code(v1value);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, T0) /*  WT */;
  return value0;
 }
}
/* function definition for WT-VALUE                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3918wt_value(cl_object v1i)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, VV[18], v1i, VV[19]) /*  WT */;
 return value0;
}
static cl_object L3918wt_value_va(cl_narg narg, cl_object v2i, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[17]);
 {
  return L3918wt_value(v2i);
 }
}
/* function definition for WT-KEYVARS                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3919wt_keyvars(cl_object v1i)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, VV[22], v1i, VV[19]) /*  WT */;
 return value0;
}
static cl_object L3919wt_keyvars_va(cl_narg narg, cl_object v2i, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[21]);
 {
  return L3919wt_keyvars(v2i);
 }
}
/* function definition for WT-THE                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3920wt_the(cl_object v1type, cl_object v2loc)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L3914wt_loc(v2loc);
 return value0;
}
static cl_object L3920wt_the_va(cl_narg narg, cl_object v3type, cl_object v4loc, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[24]);
 {
  return L3920wt_the(v3type, v4loc);
 }
}
/* function definition for WT-CALL                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3921wt_call(cl_narg narg, cl_object v1fun, cl_object v2args, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[26]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[26]);
 {
  cl_object v3fname;
  cl_object v4env;
  va_list args; va_start(args,v2args);
  {
   int i = 2;
   if (i >= narg) {
    v3fname = ECL_NIL;
   } else {
    i++;
    v3fname = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4env = ECL_NIL;
   } else {
    i++;
    v4env = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(v4env)){
   goto L4;
  }
  T0 = ECL_T;
  ecl_cmp_setq(cl_env_copy,VV[27],T0);
  (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, VV[28], v4env, VV[29]) /*  WT */;
  L3921wt_call(2, v1fun, v2args);
  (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, VV[30]) /*  WT */;
  goto L3;
L4:;
  (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(2, v1fun, VV[31]) /*  WT */;
  {
   cl_object v5comma;
   v5comma = VV[32];
   {
    cl_object v6;
    v6 = v2args;
    goto L16;
L15:;
    {
     cl_object v7arg;
     v7arg = ecl_car(v6);
     (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(2, v5comma, v7arg) /*  WT */;
     v5comma = VV[33];
    }
    v6 = ecl_cdr(v6);
L16:;
    if (Null(v6)){
     goto L25;
    }
    goto L15;
L25:;
   }
  }
  (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, VV[30]) /*  WT */;
L3:;
  if (Null(v3fname)){
   goto L27;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[34]))->cfun.entry(1, v3fname) /*  WT-COMMENT */;
  return value0;
L27:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for WT-CALL-INDIRECT                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3922wt_call_indirect(cl_object v1fun_loc, cl_object v2args, cl_object v3fname, cl_object v4function_p)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5narg;
  v5narg = ecl_make_fixnum(ecl_length(v2args));
  if (Null(v4function_p)){
   goto L4;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(4, VV[37], v1fun_loc, VV[38], v5narg) /*  WT */;
  goto L3;
L4:;
  if (Null(v3fname)){
   goto L6;
  }
  if (!(ECL_SYMBOLP(v3fname))){
   goto L6;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(4, VV[37], v1fun_loc, VV[39], v5narg) /*  WT */;
  goto L3;
L6:;
  (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(4, VV[40], v1fun_loc, VV[41], v5narg) /*  WT */;
L3:;
  {
   cl_object v6;
   v6 = v2args;
   goto L13;
L12:;
   {
    cl_object v7arg;
    v7arg = ecl_car(v6);
    (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(2, VV[33], v7arg) /*  WT */;
   }
   v6 = ecl_cdr(v6);
L13:;
   if (Null(v6)){
    goto L20;
   }
   goto L12;
L20:;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, VV[30]) /*  WT */;
  if (Null(v3fname)){
   goto L23;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[34]))->cfun.entry(1, v3fname) /*  WT-COMMENT */;
  return value0;
L23:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3922wt_call_indirect_va(cl_narg narg, cl_object v6fun_loc, cl_object v7args, cl_object v8fname, cl_object v9function_p, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[36]);
 {
  return L3922wt_call_indirect(v6fun_loc, v7args, v8fname, v9function_p);
 }
}
/* function definition for WT-CALL-GLOBAL-STACK                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3923wt_call_global_stack(cl_object v1loc, cl_object v2fname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, VV[44], v1loc, VV[30]) /*  WT */;
 if (Null(v2fname)){
  goto L3;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[34]))->cfun.entry(1, v2fname) /*  WT-COMMENT */;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3923wt_call_global_stack_va(cl_narg narg, cl_object v3loc, cl_object v4fname, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[43]);
 {
  return L3923wt_call_global_stack(v3loc, v4fname);
 }
}
/* function definition for WT-CALL-LOCAL-STACK                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3924wt_call_local_stack(cl_object v1fun, cl_object v2args, cl_object v3type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, VV[47]) /*  WT */;
 {
  cl_fixnum v4;
  v4 = ecl_length(v2args);
  {
   cl_fixnum v5;
   v5 = (v4)<=(ecl_fixnum(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("C-ARGUMENTS-LIMIT",1056))))?v4:ecl_fixnum(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("C-ARGUMENTS-LIMIT",1056)));
   T0 = cl_subseq(3, v2args, ecl_make_int8_t(0), ecl_make_fixnum(v5));
   {
    cl_fixnum v6;
    v6 = ecl_length(v2args);
    L3925wt_call_normal(4, v1fun, T0, v3type, ecl_make_fixnum(v6));
   }
  }
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, VV[30]) /*  WT */;
 return value0;
}
static cl_object L3924wt_call_local_stack_va(cl_narg narg, cl_object v4fun, cl_object v5args, cl_object v6type, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[46]);
 {
  return L3924wt_call_local_stack(v4fun, v5args, v6type);
 }
}
/* function definition for WT-CALL-NORMAL                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3925wt_call_normal(cl_narg narg, cl_object v1fun, cl_object v2args, cl_object v3type, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[48]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[48]);
 {
  cl_object v4narg;
  va_list args; va_start(args,v3type);
  {
   int i = 3;
   if (i >= narg) {
    v4narg = ecl_make_fixnum(ecl_length(v2args));
   } else {
    i++;
    v4narg = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if ((cl_env_copy->function=ecl_fdefinition(VV[50]))->cfun.entry(1, v1fun) /*  FUN-CFUN */!=ECL_NIL) {
   goto L2;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[53]))->cfun.entry(1, v1fun) /*  FUN-NAME */;
  (cl_env_copy->function=ecl_fdefinition(VV[51]))->cfun.entry(2, VV[52], T0) /*  BABOON */;
L2:;
  {
   cl_object v5minarg;
   cl_object v6maxarg;
   cl_object v7fun_c_name;
   cl_object v8fun_lisp_name;
   cl_object v9env;
   v5minarg = (cl_env_copy->function=ecl_fdefinition(VV[54]))->cfun.entry(1, v1fun) /*  FUN-MINARG */;
   v6maxarg = (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, v1fun) /*  FUN-MAXARG */;
   v7fun_c_name = (cl_env_copy->function=ecl_fdefinition(VV[50]))->cfun.entry(1, v1fun) /*  FUN-CFUN */;
   v8fun_lisp_name = (cl_env_copy->function=ecl_fdefinition(VV[53]))->cfun.entry(1, v1fun) /*  FUN-NAME */;
   v9env = ECL_NIL;
   {
    cl_object v10;
    v10 = (cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(1, v1fun) /*  FUN-CLOSURE */;
    if (!((v10)==(VV[57]))){
     goto L11;
    }
    if (!(ecl_plusp(ecl_cmp_symbol_value(cl_env_copy,VV[58])))){
     goto L9;
    }
    v9env = L3927environment_accessor(v1fun);
    goto L9;
L11:;
    if (!((v10)==(VV[60]))){
     goto L9;
    }
    {
     cl_object v11lex_lvl;
     v11lex_lvl = (cl_env_copy->function=ecl_fdefinition(VV[61]))->cfun.entry(1, v1fun) /*  FUN-LEVEL */;
     {
      cl_object v12n;
      v12n = ecl_make_int8_t(0);
      goto L19;
L18:;
      {
       cl_object v13j;
       cl_object v14x;
       T0 = ecl_minus(v11lex_lvl,v12n);
       v13j = ecl_minus(T0,ecl_make_int8_t(1));
       v14x = (cl_env_copy->function=ecl_fdefinition(VV[62]))->cfun.entry(1, v13j) /*  LEX-ENV-VAR-NAME */;
       v2args = CONS(v14x,v2args);
      }
      v12n = ecl_one_plus(v12n);
L19:;
      if (!(ecl_lower(v12n,v11lex_lvl))){
       goto L27;
      }
      goto L18;
L27:;
     }
    }
   }
L9:;
   if (cl_LE(3, v5minarg, v4narg, v6maxarg)!=ECL_NIL) {
    goto L29;
   }
   value0 = v8fun_lisp_name;
   if (value0!=ECL_NIL) {
    goto L33;
   }
   T0 = VV[65];
   goto L31;
L33:;
   T0 = value0;
   goto L31;
L31:;
   (cl_env_copy->function=ecl_fdefinition(VV[63]))->cfun.entry(2, VV[64], T0) /*  CMPERR */;
L29:;
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[66]))->cfun.entry(1, v1fun) /*  FUN-NEEDS-NARG */)){
    goto L35;
   }
   v2args = CONS(v4narg,v2args);
L35:;
   value0 = L3921wt_call(4, v7fun_c_name, v2args, ECL_NIL, v9env);
   return value0;
  }
 }
}
/* function definition for WT-FDEFINITION                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3926wt_fdefinition(cl_object v1fun_name)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2name;
  cl_object v3package;
  cl_object v4safe;
  v2name = si_function_block_name(v1fun_name);
  v3package = cl_symbol_package(v2name);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[69]))->cfun.entry(0) /*  SAFE-COMPILE */;
  value0 = Null(T0)?ECL_T:ECL_NIL;
  if (value0!=ECL_NIL) {
   goto L6;
  }
  T0 = cl_find_package(VV[70]);
  if ((v3package)==(T0)) {
   goto L11;
  }
  T0 = cl_find_package(VV[71]);
  if ((v3package)==(T0)) {
   goto L11;
  }
  T0 = cl_find_package(VV[72]);
  if (!((v3package)==(T0))){
   goto L9;
  }
  goto L10;
L11:;
L10:;
  if (Null(cl_fboundp(v1fun_name))){
   goto L9;
  }
  T0 = cl_fdefinition(v1fun_name);
  v4safe = cl_functionp(T0);
  goto L4;
L9:;
  v4safe = ECL_NIL;
  goto L4;
L6:;
  v4safe = value0;
  goto L4;
L4:;
  if (v4safe!=ECL_NIL) {
   goto L15;
  }
  {
   cl_object v5vv;
   T0 = (ECL_SYM("EQUAL",337)->symbol.gfdef);
   v5vv = (cl_env_copy->function=ecl_fdefinition(VV[73]))->cfun.entry(3, v1fun_name, ECL_SYM("TEST",1353), T0) /*  GET-OBJECT */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, VV[74], v5vv, VV[30]) /*  WT */;
   return value0;
  }
L15:;
  if (!((v2name)==(v1fun_name))){
   goto L19;
  }
  {
   cl_object v6vv;
   v6vv = (cl_env_copy->function=ecl_fdefinition(VV[73]))->cfun.entry(1, v2name) /*  GET-OBJECT */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, VV[31], v6vv, VV[75]) /*  WT */;
   return value0;
  }
L19:;
  {
   cl_object v7setf_loc;
   {
    cl_object v8;
    cl_object v9;
    cl_object v10;
    v8 = ecl_cmp_symbol_value(cl_env_copy,VV[76]);
    v9 = v2name;
    v10 = v8;
    v7setf_loc = ecl_assql(v9,v10);
   }
   if (v7setf_loc!=ECL_NIL) {
    goto L26;
   }
   {
    cl_object v8setf_vv;
    cl_object v9name_vv;
    v8setf_vv = (cl_env_copy->function=ecl_fdefinition(VV[77]))->cfun.entry(0) /*  DATA-EMPTY-LOC* */;
    T0 = (ECL_SYM("EQUAL",337)->symbol.gfdef);
    v9name_vv = (cl_env_copy->function=ecl_fdefinition(VV[73]))->cfun.entry(3, v2name, ECL_SYM("TEST",1353), T0) /*  GET-OBJECT */;
    v7setf_loc = cl_list(3, v2name, v8setf_vv, v9name_vv);
    T0 = CONS(v7setf_loc,ecl_cmp_symbol_value(cl_env_copy,VV[76]));
    ecl_cmp_setq(cl_env_copy,VV[76],T0);
   }
L26:;
   T0 = ecl_cadr(v7setf_loc);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, VV[78], T0, VV[30]) /*  WT */;
   return value0;
  }
 }
}
static cl_object L3926wt_fdefinition_va(cl_narg narg, cl_object v8fun_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[68]);
 {
  return L3926wt_fdefinition(v8fun_name);
 }
}
/* function definition for ENVIRONMENT-ACCESSOR                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3927environment_accessor(cl_object v1fun)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2env_var;
  cl_object v3expected_env_size;
  v2env_var = (cl_env_copy->function=ecl_fdefinition(VV[80]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[81])) /*  ENV-VAR-NAME */;
  v3expected_env_size = (cl_env_copy->function=ecl_fdefinition(VV[82]))->cfun.entry(1, v1fun) /*  FUN-ENV */;
  if (!(ecl_lower(v3expected_env_size,ecl_cmp_symbol_value(cl_env_copy,VV[83])))){
   goto L4;
  }
  T0 = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[83]),v3expected_env_size);
  value0 = cl_format(4, ECL_NIL, VV[84], T0, v2env_var);
  return value0;
L4:;
  value0 = v2env_var;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3927environment_accessor_va(cl_narg narg, cl_object v4fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[59]);
 {
  return L3927environment_accessor(v4fun);
 }
}
/* function definition for WT-MAKE-CLOSURE                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3928wt_make_closure(cl_object v1fun)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2closure;
  cl_object v3narg;
  cl_object v4variadic_entrypoint;
  cl_object v5cfun;
  cl_object v6entrypoint;
  cl_object v7narg_fixed;
  v2closure = (cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(1, v1fun) /*  FUN-CLOSURE */;
  v3narg = (cl_env_copy->function=ecl_fdefinition(VV[87]))->cfun.entry(1, v1fun) /*  FUN-FIXED-NARG */;
  v4variadic_entrypoint = (cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v1fun) /*  FUN-VARIADIC-ENTRYPOINT */;
  v5cfun = (cl_env_copy->function=ecl_fdefinition(VV[50]))->cfun.entry(1, v1fun) /*  FUN-CFUN */;
  value0 = v4variadic_entrypoint;
  if (value0!=ECL_NIL) {
   goto L8;
  }
  v6entrypoint = v5cfun;
  goto L6;
L8:;
  v6entrypoint = value0;
  goto L6;
L6:;
  v7narg_fixed = (cl_env_copy->function=ecl_fdefinition(VV[89]))->cfun.entry(1, v1fun) /*  FUN-FIXED-NARG-MAIN-ENTRYPOINT */;
  if (!((v2closure)==(VV[57]))){
   goto L11;
  }
  T0 = L3927environment_accessor(v1fun);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(7, VV[90], v6entrypoint, VV[91], T0, VV[92], v7narg_fixed, VV[30]) /*  WT */;
  return value0;
L11:;
  if (!((v2closure)==(VV[60]))){
   goto L13;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[51]))->cfun.entry(2, ECL_SYM("FORMAT-CONTROL",1272), VV[93]) /*  BABOON */;
  return value0;
L13:;
  if (Null(v3narg)){
   goto L15;
  }
  if (Null(v4variadic_entrypoint)){
   goto L18;
  }
  T0 = VV[94];
  goto L17;
L18:;
  T0 = VV[95];
L17:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(5, T0, v6entrypoint, VV[96], v7narg_fixed, VV[30]) /*  WT */;
  return value0;
L15:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(5, VV[94], v6entrypoint, VV[96], v7narg_fixed, VV[30]) /*  WT */;
  return value0;
 }
}
static cl_object L3928wt_make_closure_va(cl_narg narg, cl_object v8fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[86]);
 {
  return L3928wt_make_closure(v8fun);
 }
}
/* function definition for WT-TO-OBJECT-CONVERSION                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3929wt_to_object_conversion(cl_object v1loc_host_type, cl_object v2loc)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3record;
  cl_object v4coercer;
  v3record = (cl_env_copy->function=ecl_fdefinition(VV[99]))->cfun.entry(1, v1loc_host_type) /*  HOST-TYPE-RECORD */;
  if (Null(v3record)){
   goto L5;
  }
  v4coercer = (cl_env_copy->function=ecl_fdefinition(VV[100]))->cfun.entry(1, v3record) /*  HOST-TYPE-TO-LISP */;
  goto L3;
L5:;
  v4coercer = ECL_NIL;
  goto L3;
L3:;
  if (v4coercer!=ECL_NIL) {
   goto L7;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[63]))->cfun.entry(2, VV[101], v1loc_host_type) /*  CMPERR */;
L7:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(4, v4coercer, VV[31], v2loc, VV[30]) /*  WT */;
  return value0;
 }
}
static cl_object L3929wt_to_object_conversion_va(cl_narg narg, cl_object v5loc_host_type, cl_object v6loc, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[98]);
 {
  return L3929wt_to_object_conversion(v5loc_host_type, v6loc);
 }
}
/* function definition for WT-FROM-OBJECT-CONVERSION                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3930wt_from_object_conversion(cl_object v1dest_type, cl_object v2loc_type, cl_object v3host_type, cl_object v4loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5record;
  cl_object v6coercer;
  v5record = (cl_env_copy->function=ecl_fdefinition(VV[99]))->cfun.entry(1, v3host_type) /*  HOST-TYPE-RECORD */;
  if (Null(v5record)){
   goto L5;
  }
  v6coercer = (cl_env_copy->function=ecl_fdefinition(VV[104]))->cfun.entry(1, v5record) /*  HOST-TYPE-FROM-LISP */;
  goto L3;
L5:;
  v6coercer = ECL_NIL;
  goto L3;
L3:;
  if (v6coercer!=ECL_NIL) {
   goto L7;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[63]))->cfun.entry(2, VV[105], v3host_type) /*  CMPERR */;
L7:;
  if ((cl_env_copy->function=ecl_fdefinition(VV[106]))->cfun.entry(0) /*  POLICY-ASSUME-NO-ERRORS */!=ECL_NIL) {
   goto L12;
  }
  if (Null(cl_subtypep(3, v2loc_type, v1dest_type, ecl_cmp_symbol_value(cl_env_copy,VV[107])))){
   goto L10;
  }
  goto L11;
L12:;
L11:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[108]))->cfun.entry(1, v5record) /*  HOST-TYPE-FROM-LISP-UNSAFE */;
  goto L9;
L10:;
  T0 = v6coercer;
L9:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(4, T0, VV[31], v4loc, VV[30]) /*  WT */;
  return value0;
 }
}
static cl_object L3930wt_from_object_conversion_va(cl_narg narg, cl_object v7dest_type, cl_object v8loc_type, cl_object v9host_type, cl_object v10loc, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[103]);
 {
  return L3930wt_from_object_conversion(v7dest_type, v8loc_type, v9host_type, v10loc);
 }
}
/* function definition for WT-COERCE-LOC                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3933wt_coerce_loc(cl_object v1dest_host_type, cl_object v2loc)
{
 cl_object T0;
 volatile cl_object lex0[4];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 lex0[0] = v1dest_host_type;                      /*  DEST-HOST-TYPE          */
L1:;
 lex0[0] = (cl_env_copy->function=ecl_fdefinition(VV[111]))->cfun.entry(1, lex0[0]) /*  LISP-TYPE->HOST-TYPE */;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[112]))->cfun.entry(1, lex0[0]) /*  HOST-TYPE->LISP-TYPE */;
 lex0[1] = T0;                                    /*  DEST-TYPE               */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[113]))->cfun.entry(1, v2loc) /*  LOC-LISP-TYPE */;
 lex0[2] = T0;                                    /*  LOC-TYPE                */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[114]))->cfun.entry(1, v2loc) /*  LOC-HOST-TYPE */;
 lex0[3] = T0;                                    /*  LOC-HOST-TYPE           */
 if (!((lex0[0])==(lex0[3]))){
  goto L4;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, v2loc) /*  WT  */;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 if (!((lex0[0])==(ECL_SYM("CHAR",1403)))){
  goto L12;
 }
 goto L9;
L12:;
 goto L10;
L10:;
 if (!((lex0[0])==(ECL_SYM("UNSIGNED-CHAR",1430)))){
  goto L16;
 }
 goto L9;
L16:;
 goto L14;
L14:;
 if (!((lex0[0])==(VV[122]))){
  goto L7;
 }
 goto L8;
L9:;
L8:;
 if (!((lex0[3])==(ECL_SYM("CHAR",1403)))){
  goto L24;
 }
 goto L21;
L24:;
 goto L22;
L22:;
 if (!((lex0[3])==(ECL_SYM("UNSIGNED-CHAR",1430)))){
  goto L28;
 }
 goto L21;
L28:;
 goto L26;
L26:;
 if (!((lex0[3])==(VV[122]))){
  goto L19;
 }
 goto L20;
L21:;
L20:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[124]))->cfun.entry(1, lex0[0]) /*  HOST-TYPE->C-NAME */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(5, VV[31], T0, VV[41], v2loc, VV[30]) /*  WT */;
 return value0;
L19:;
 if (!((lex0[3])==(ECL_SYM("OBJECT",1315)))){
  goto L31;
 }
 LC3932ensure_valid_object_type(lex0, lex0[1]);
 value0 = L3930wt_from_object_conversion(lex0[1], lex0[2], lex0[0], v2loc);
 return value0;
L31:;
 value0 = LC3931coercion_error(0, lex0);
 return value0;
L7:;
 if (!((lex0[0])==(ECL_SYM("FLOAT",1410)))){
  goto L40;
 }
 goto L37;
L40:;
 goto L38;
L38:;
 if (!((lex0[0])==(ECL_SYM("DOUBLE",1408)))){
  goto L44;
 }
 goto L37;
L44:;
 goto L42;
L42:;
 if (!((lex0[0])==(ECL_SYM("LONG-DOUBLE",1417)))){
  goto L35;
 }
 goto L36;
L37:;
L36:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[129]))->cfun.entry(1, lex0[3]) /*  C-NUMBER-HOST-TYPE-P */)){
  goto L47;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[124]))->cfun.entry(1, lex0[0]) /*  HOST-TYPE->C-NAME */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(5, VV[31], T0, VV[41], v2loc, VV[30]) /*  WT */;
 return value0;
L47:;
 if (!((lex0[3])==(ECL_SYM("OBJECT",1315)))){
  goto L49;
 }
 LC3932ensure_valid_object_type(lex0, ECL_SYM("FLOAT",376));
 value0 = L3930wt_from_object_conversion(lex0[1], lex0[2], lex0[0], v2loc);
 return value0;
L49:;
 value0 = LC3931coercion_error(0, lex0);
 return value0;
L35:;
 if (!((lex0[0])==(ECL_SYM("CSFLOAT",1404)))){
  goto L57;
 }
 goto L54;
L57:;
 goto L55;
L55:;
 if (!((lex0[0])==(ECL_SYM("CDFLOAT",1405)))){
  goto L61;
 }
 goto L54;
L61:;
 goto L59;
L59:;
 if (!((lex0[0])==(ECL_SYM("CLFLOAT",1406)))){
  goto L52;
 }
 goto L53;
L54:;
L53:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[129]))->cfun.entry(1, lex0[3]) /*  C-NUMBER-HOST-TYPE-P */)){
  goto L64;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[124]))->cfun.entry(1, lex0[0]) /*  HOST-TYPE->C-NAME */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(5, VV[31], T0, VV[41], v2loc, VV[30]) /*  WT */;
 return value0;
L64:;
 if (!((lex0[3])==(ECL_SYM("OBJECT",1315)))){
  goto L66;
 }
 LC3932ensure_valid_object_type(lex0, VV[133]);
 value0 = L3930wt_from_object_conversion(lex0[1], lex0[2], lex0[0], v2loc);
 return value0;
L66:;
 value0 = LC3931coercion_error(0, lex0);
 return value0;
L52:;
 if (!((lex0[0])==(VV[135]))){
  goto L69;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[129]))->cfun.entry(1, lex0[3]) /*  C-NUMBER-HOST-TYPE-P */)){
  goto L72;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, VV[136]) /*  WT */;
 return value0;
L72:;
 if (!((lex0[3])==(ECL_SYM("OBJECT",1315)))){
  goto L74;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, VV[31], v2loc, VV[137]) /*  WT */;
 return value0;
L74:;
 value0 = LC3931coercion_error(0, lex0);
 return value0;
L69:;
 if (!((lex0[0])==(ECL_SYM("OBJECT",1315)))){
  goto L76;
 }
 if (!((lex0[3])==(VV[139]))){
  goto L84;
 }
 goto L81;
L84:;
 goto L82;
L82:;
 if (!((lex0[3])==(VV[140]))){
  goto L88;
 }
 goto L81;
L88:;
 goto L86;
L86:;
 if (!((lex0[3])==(VV[142]))){
  goto L79;
 }
 goto L80;
L81:;
L80:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[144]))->cfun.entry(1, ECL_SYM("SPEED",794)) /*  CMP-ENV-OPTIMIZATION */;
 if (!(ecl_greatereq(T0,ecl_make_int8_t(1)))){
  goto L79;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[145]))->cfun.entry(2, VV[146], lex0[3]) /*  CMPWARN-STYLE */;
L79:;
 value0 = L3929wt_to_object_conversion(lex0[3], v2loc);
 return value0;
L76:;
 if (!((lex0[0])==(ECL_SYM("POINTER-VOID",1420)))){
  goto L92;
 }
 if (!((lex0[3])==(ECL_SYM("OBJECT",1315)))){
  goto L95;
 }
 value0 = L3930wt_from_object_conversion(lex0[1], lex0[2], lex0[0], v2loc);
 return value0;
L95:;
 if (!((lex0[3])==(ECL_SYM("CSTRING",1407)))){
  goto L98;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, VV[149], v2loc, VV[30]) /*  WT */;
 return value0;
L98:;
 value0 = LC3931coercion_error(0, lex0);
 return value0;
L92:;
 if (!((lex0[0])==(ECL_SYM("CSTRING",1407)))){
  goto L101;
 }
 value0 = LC3931coercion_error(0, lex0);
 return value0;
L101:;
 if (!((lex0[0])==(VV[151]))){
  goto L104;
 }
 if (!((lex0[3])==(ECL_SYM("OBJECT",1315)))){
  goto L107;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, VV[152], v2loc, VV[30]) /*  WT */;
 return value0;
L107:;
 if (!((lex0[3])==(ECL_SYM("POINTER-VOID",1420)))){
  goto L110;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, VV[149], v2loc, VV[30]) /*  WT */;
 return value0;
L110:;
 value0 = LC3931coercion_error(0, lex0);
 return value0;
L104:;
 if (!((lex0[0])==(VV[139]))){
  goto L118;
 }
 goto L115;
L118:;
 goto L116;
L116:;
 if (!((lex0[0])==(VV[140]))){
  goto L122;
 }
 goto L115;
L122:;
 goto L120;
L120:;
 if (!((lex0[0])==(VV[142]))){
  goto L113;
 }
 goto L114;
L115:;
L114:;
 if (!((lex0[3])==(ECL_SYM("OBJECT",1315)))){
  goto L125;
 }
 value0 = L3930wt_from_object_conversion(ECL_SYM("SSE-PACK",1902), lex0[2], lex0[0], v2loc);
 return value0;
L125:;
 if (!((lex0[3])==(VV[139]))){
  goto L133;
 }
 goto L130;
L133:;
 goto L131;
L131:;
 if (!((lex0[3])==(VV[140]))){
  goto L137;
 }
 goto L130;
L137:;
 goto L135;
L135:;
 if (!((lex0[3])==(VV[142]))){
  goto L128;
 }
 goto L129;
L130:;
L129:;
 if (!((lex0[0])==(VV[139]))){
  goto L141;
 }
 if (!((lex0[3])==(VV[140]))){
  goto L143;
 }
 T0 = VV[153];
 goto L140;
L143:;
 if (!((lex0[3])==(VV[142]))){
  goto L145;
 }
 T0 = VV[154];
 goto L140;
L145:;
 T0 = si_ecase_error(lex0[3], VV[141]);
 goto L140;
L141:;
 if (!((lex0[0])==(VV[140]))){
  goto L147;
 }
 if (!((lex0[3])==(VV[139]))){
  goto L149;
 }
 T0 = VV[155];
 goto L140;
L149:;
 if (!((lex0[3])==(VV[142]))){
  goto L151;
 }
 T0 = VV[156];
 goto L140;
L151:;
 T0 = si_ecase_error(lex0[3], VV[157]);
 goto L140;
L147:;
 if (!((lex0[0])==(VV[142]))){
  goto L153;
 }
 if (!((lex0[3])==(VV[139]))){
  goto L155;
 }
 T0 = VV[158];
 goto L140;
L155:;
 if (!((lex0[3])==(VV[140]))){
  goto L157;
 }
 T0 = VV[159];
 goto L140;
L157:;
 T0 = si_ecase_error(lex0[3], VV[160]);
 goto L140;
L153:;
 T0 = si_ecase_error(lex0[0], VV[138]);
L140:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(4, T0, VV[31], v2loc, VV[30]) /*  WT */;
 return value0;
L128:;
 value0 = LC3931coercion_error(0, lex0);
 return value0;
L113:;
 if ((cl_env_copy->function=ecl_fdefinition(VV[161]))->cfun.entry(1, lex0[0]) /*  C-INTEGER-HOST-TYPE-P */!=ECL_NIL) {
  goto L159;
 }
 value0 = LC3931coercion_error(0, lex0);
 return value0;
L159:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[129]))->cfun.entry(1, lex0[3]) /*  C-NUMBER-HOST-TYPE-P */)){
  goto L161;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[124]))->cfun.entry(1, lex0[0]) /*  HOST-TYPE->C-NAME */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(5, VV[31], T0, VV[41], v2loc, VV[30]) /*  WT */;
 return value0;
L161:;
 if (!((ECL_SYM("OBJECT",1315))==(lex0[3]))){
  goto L163;
 }
 LC3932ensure_valid_object_type(lex0, lex0[1]);
 value0 = L3930wt_from_object_conversion(lex0[1], lex0[2], lex0[0], v2loc);
 return value0;
L163:;
 value0 = LC3931coercion_error(0, lex0);
 return value0;
}
static cl_object L3933wt_coerce_loc_va(cl_narg narg, cl_object v3dest_host_type, cl_object v4loc, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[110]);
 {
  return L3933wt_coerce_loc(v3dest_host_type, v4loc);
 }
}
/* function definition for WT-C-INLINE-LOC                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3934wt_c_inline_loc(cl_object volatile v1output_host_type, cl_object volatile v2c_expression, cl_object volatile v3coerced_arguments, cl_object volatile v4side_effects, cl_object volatile v5output_vars)
{
 cl_object T0;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v6s;
  v6s = cl_make_string_input_stream(3, v2c_expression, ecl_make_int8_t(0), ECL_NIL);
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    if (Null(v5output_vars)){
     goto L4;
    }
    if ((v5output_vars)==(ECL_SYM("VALUES",899))) {
     goto L4;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(0) /*  WT-NL */;
L4:;
    {
     cl_object v7c;
     v7c = cl_read_char(3, v6s, ECL_NIL, ECL_NIL);
     goto L10;
L9:;
     if (!(((v7c)==ECL_CODE_CHAR((ecl_character)(64))))){
      goto L13;
     }
     {
      cl_object v8object;
      v8object = cl_read(1, v6s);
      if (!(ECL_CONSP(v8object))){
       goto L19;
      }
      T0 = ecl_car(v8object);
      if ((T0)==(ECL_SYM("RETURN",727))) {
       goto L16;
      }
      goto L17;
L19:;
      goto L17;
L17:;
      (cl_env_copy->function=ecl_fdefinition(VV[63]))->cfun.entry(2, VV[165], v8object) /*  CMPERR */;
L16:;
      if (!((v5output_vars)==(ECL_SYM("VALUES",899)))){
       goto L21;
      }
      (cl_env_copy->function=ecl_fdefinition(VV[63]))->cfun.entry(1, VV[166]) /*  CMPERR */;
      goto L12;
L21:;
      {
       cl_object v9;
       cl_object v10;
       value0 = ecl_cadr(v8object);
       if (value0!=ECL_NIL) {
        goto L25;
       }
       v9 = ecl_make_int8_t(0);
       goto L23;
L25:;
       v9 = value0;
       goto L23;
L23:;
       v10 = ecl_make_fixnum(ecl_length(v5output_vars));
       if (!(ecl_lower(v9,v10))){
        goto L28;
       }
       T0 = ecl_nth(ecl_to_size(v9),v5output_vars);
       (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, T0) /*  WT */;
       goto L12;
L28:;
       (cl_env_copy->function=ecl_fdefinition(VV[63]))->cfun.entry(3, VV[167], v9, v10) /*  CMPERR */;
       goto L12;
      }
     }
L13:;
     if (!(((v7c)==ECL_CODE_CHAR((ecl_character)(35))))){
      goto L30;
     }
     {
      cl_object v11k;
      cl_object v12next_char;
      cl_object v13index;
      v11k = cl_read_char(1, v6s);
      v12next_char = cl_peek_char(4, ECL_NIL, v6s, ECL_NIL, ECL_NIL);
      v13index = cl_digit_char_p(2, v11k, ecl_make_int8_t(36));
      if (!((v11k)==(ECL_CODE_CHAR(35)))){
       goto L35;
      }
      (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, ECL_CODE_CHAR(35)) /*  WT */;
      goto L12;
L35:;
      if (v13index==ECL_NIL) {
       goto L39;
      }
      if (Null(v12next_char)){
       goto L37;
      }
      if (Null(cl_alphanumericp(v12next_char))){
       goto L37;
      }
      goto L38;
L39:;
L38:;
      (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(2, ECL_CODE_CHAR(35), v11k) /*  WT */;
      goto L12;
L37:;
      {
       cl_fixnum v14;
       v14 = ecl_length(v3coerced_arguments);
       if (!(ecl_lower(v13index,ecl_make_fixnum(v14)))){
        goto L42;
       }
      }
      T0 = ecl_nth(ecl_to_size(v13index),v3coerced_arguments);
      (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, T0) /*  WT */;
      goto L12;
L42:;
      (cl_env_copy->function=ecl_fdefinition(VV[63]))->cfun.entry(1, VV[168]) /*  CMPERR */;
      goto L12;
     }
L30:;
     cl_write_char(2, v7c, ecl_cmp_symbol_value(cl_env_copy,VV[11]));
L12:;
     v7c = cl_read_char(3, v6s, ECL_NIL, ECL_NIL);
L10:;
     if (v7c==ECL_NIL) {
      goto L46;
     }
     goto L9;
L46:;
     cl_env_copy->values[0] = ECL_NIL;
     cl_env_copy->nvalues = 1;
    }
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   cl_close(1, v6s);
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
}
static cl_object L3934wt_c_inline_loc_va(cl_narg narg, cl_object v7output_host_type, cl_object v8c_expression, cl_object v9coerced_arguments, cl_object v10side_effects, cl_object v11output_vars, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[163]);
 {
  return L3934wt_c_inline_loc(v7output_host_type, v8c_expression, v9coerced_arguments, v10side_effects, v11output_vars);
 }
}
/* function definition for SET-UNKNOWN-LOC                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3935set_unknown_loc(cl_object v1destination, cl_object v2loc)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(2, VV[171], v1destination) /*  UNKNOWN-LOCATION */;
 return value0;
}
static cl_object L3935set_unknown_loc_va(cl_narg narg, cl_object v3destination, cl_object v4loc, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[170]);
 {
  return L3935set_unknown_loc(v3destination, v4loc);
 }
}
/* function definition for SET-LOC                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3936set_loc(cl_object v1destination, cl_object v2loc)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_make_bool((v1destination)==(v2loc));
  if (Null(v3)){
   goto L3;
  }
  value0 = v3;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (!(ECL_SYMBOLP(v1destination))){
   goto L5;
  }
  T0 = cl_gethash(3, v1destination, ecl_cmp_symbol_value(cl_env_copy,VV[173]), VV[170]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(1, v2loc);
  return value0;
L5:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(1, v1destination) /*  VAR-P */)){
   goto L7;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[174]))->cfun.entry(2, v2loc, v1destination) /*  SET-VAR */;
  return value0;
L7:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[7]))->cfun.entry(1, v1destination) /*  VV-P */)){
   goto L9;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[175]))->cfun.entry(2, v2loc, v1destination) /*  SET-VV */;
  return value0;
L9:;
  if (!(ECL_ATOM(v1destination))){
   goto L11;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(3, VV[171], v1destination, v2loc) /*  UNKNOWN-LOCATION */;
  return value0;
L11:;
  {
   cl_object v4fd;
   T0 = ecl_car(v1destination);
   v4fd = ecl_gethash_safe(T0,ecl_cmp_symbol_value(cl_env_copy,VV[173]),ECL_NIL);
   if (Null(v4fd)){
    goto L14;
   }
   T0 = ecl_cdr(v1destination);
   value0 = cl_apply(3, v4fd, v2loc, T0);
   return value0;
L14:;
   (cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(0) /*  WT-NL  */;
   L3914wt_loc(v1destination);
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[114]))->cfun.entry(1, v1destination) /*  LOC-HOST-TYPE */;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[177]))->cfun.entry(2, T0, v2loc) /*  COERCE-LOC */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, VV[176], T1, VV[178]) /*  WT */;
   return value0;
  }
 }
}
static cl_object L3936set_loc_va(cl_narg narg, cl_object v5destination, cl_object v6loc, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[171]);
 {
  return L3936set_loc(v5destination, v6loc);
 }
}
/* function definition for SET-TRASH-LOC                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3937set_trash_loc(cl_narg narg, cl_object v1loc, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[180]);
 {
  va_list args; va_start(args,v1loc);
  va_end(args);
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[181]))->cfun.entry(1, v1loc) /*  LOC-WITH-SIDE-EFFECTS-P */)){
   goto L1;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(2, v1loc, VV[178]) /*  WT-NL */;
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for SET-VALUE0-LOC                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3938set_value0_loc(cl_object v1loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[177]))->cfun.entry(2, ECL_SYM("OBJECT",1315), v1loc) /*  COERCE-LOC */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(3, VV[184], T0, VV[178]) /*  WT-NL */;
 return value0;
}
static cl_object L3938set_value0_loc_va(cl_narg narg, cl_object v2loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[183]);
 {
  return L3938set_value0_loc(v2loc);
 }
}
/* function definition for SET-THE-LOC                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3939set_the_loc(cl_object v1loc, cl_object v2type, cl_object v3orig_loc)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L3936set_loc(v3orig_loc, v1loc);
 return value0;
}
static cl_object L3939set_the_loc_va(cl_narg narg, cl_object v4loc, cl_object v5type, cl_object v6orig_loc, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[186]);
 {
  return L3939set_the_loc(v4loc, v5type, v6orig_loc);
 }
}
/* function definition for SET-LEAVE-LOC                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3940set_leave_loc(cl_object v1loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if ((v1loc)==(VV[189])) {
  goto L4;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[190]))->cfun.entry(1, v1loc) /*  USES-VALUES */)){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[177]))->cfun.entry(2, ECL_SYM("OBJECT",1315), v1loc) /*  COERCE-LOC */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(3, VV[184], T0, VV[178]) /*  WT-NL */;
 return value0;
L2:;
 if (!((v1loc)==(VV[191]))){
  goto L6;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(1, VV[192]) /*  WT-NL */;
 return value0;
L6:;
 {
  cl_object v2;
  v2 = ecl_make_bool((v1loc)==(VV[193]));
  if (Null(v2)){
   goto L9;
  }
  value0 = v2;
  cl_env_copy->nvalues = 1;
  return value0;
L9:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[177]))->cfun.entry(2, ECL_SYM("OBJECT",1315), v1loc) /*  COERCE-LOC */;
  (cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(3, VV[184], T0, VV[178]) /*  WT-NL */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(1, VV[192]) /*  WT-NL */;
  return value0;
 }
}
static cl_object L3940set_leave_loc_va(cl_narg narg, cl_object v3loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[188]);
 {
  return L3940set_leave_loc(v3loc);
 }
}
/* function definition for SET-VALUEZ-LOC                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3941set_valuez_loc(cl_object v1loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = ecl_make_bool((v1loc)==(VV[189]));
  if (Null(v2)){
   goto L3;
  }
  value0 = v2;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[190]))->cfun.entry(1, v1loc) /*  USES-VALUES */)){
   goto L5;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[177]))->cfun.entry(2, ECL_SYM("OBJECT",1315), v1loc) /*  COERCE-LOC */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(3, VV[196], T0, VV[178]) /*  WT-NL */;
  return value0;
L5:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[177]))->cfun.entry(2, ECL_SYM("OBJECT",1315), v1loc) /*  COERCE-LOC */;
  (cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(3, VV[196], T0, VV[178]) /*  WT-NL */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(1, VV[192]) /*  WT-NL */;
  return value0;
 }
}
static cl_object L3941set_valuez_loc_va(cl_narg narg, cl_object v3loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[195]);
 {
  return L3941set_valuez_loc(v3loc);
 }
}
/* function definition for WT-FFI-DATA-REF                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3942wt_ffi_data_ref(cl_object v1data, cl_object v2ffi_tag)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(5, VV[199], v1data, VV[91], v2ffi_tag, VV[30]) /*  WT */;
 return value0;
}
static cl_object L3942wt_ffi_data_ref_va(cl_narg narg, cl_object v3data, cl_object v4ffi_tag, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[198]);
 {
  return L3942wt_ffi_data_ref(v3data, v4ffi_tag);
 }
}
/* function definition for WT-FFI-DATA-SET                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3943wt_ffi_data_set(cl_object v1value, cl_object v2data, cl_object v3ffi_tag)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(7, VV[202], v2data, VV[91], v3ffi_tag, VV[91], v1value, VV[203]) /*  WT */;
 return value0;
}
static cl_object L3943wt_ffi_data_set_va(cl_narg narg, cl_object v4value, cl_object v5data, cl_object v6ffi_tag, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[201]);
 {
  return L3943wt_ffi_data_set(v4value, v5data, v6ffi_tag);
 }
}
/* local function ENSURE-VALID-OBJECT-TYPE                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3932ensure_valid_object_type(volatile cl_object *lex0, cl_object v1a_lisp_type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(3, ECL_SYM("AND",89), lex0[2], v1a_lisp_type);
 if (Null(cl_subtypep(3, T0, ECL_NIL, ecl_cmp_symbol_value(cl_env_copy,VV[107])))){
  goto L2;
 }
 value0 = LC3931coercion_error(1, lex0, ECL_NIL);
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* local function COERCION-ERROR                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3931coercion_error(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[115]);
 {
  cl_object v1write_zero;
  va_list args; va_start(args,lex0);
  {
   int i = 0;
   if (i >= narg) {
    v1write_zero = ECL_T;
   } else {
    i++;
    v1write_zero = va_arg(args,cl_object);
   }
  }
  va_end(args);
  (cl_env_copy->function=ecl_fdefinition(VV[116]))->cfun.entry(5, VV[117], lex0[2], lex0[3], lex0[1], lex0[0]) /*  CMPWARN */;
  if (Null(v1write_zero)){
   goto L3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, VV[118]) /*  WT */;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
#include "cmp/cmppass2-loc.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclZjloU0oQAPwo9_UWc0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPBACKEND-CXX;CMPPASS2-LOC.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclZjloU0oQAPwo9_UWc0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  ecl_cmp_defun(VV[205]);                         /*  WT-LOC                  */
  ecl_cmp_defun(VV[206]);                         /*  WT-FIXNUM               */
  ecl_cmp_defun(VV[207]);                         /*  WT-NUMBER               */
  ecl_cmp_defun(VV[208]);                         /*  WT-CHARACTER            */
  ecl_cmp_defun(VV[209]);                         /*  WT-VALUE                */
  ecl_cmp_defun(VV[210]);                         /*  WT-KEYVARS              */
  ecl_cmp_defun(VV[211]);                         /*  WT-THE                  */
  ecl_cmp_defun(VV[212]);                         /*  WT-CALL                 */
  ecl_cmp_defun(VV[213]);                         /*  WT-CALL-INDIRECT        */
  ecl_cmp_defun(VV[214]);                         /*  WT-CALL-GLOBAL-STACK    */
  ecl_cmp_defun(VV[215]);                         /*  WT-CALL-LOCAL-STACK     */
  ecl_cmp_defun(VV[216]);                         /*  WT-CALL-NORMAL          */
  ecl_cmp_defun(VV[217]);                         /*  WT-FDEFINITION          */
  ecl_cmp_defun(VV[218]);                         /*  ENVIRONMENT-ACCESSOR    */
  ecl_cmp_defun(VV[219]);                         /*  WT-MAKE-CLOSURE         */
  ecl_cmp_defun(VV[220]);                         /*  WT-TO-OBJECT-CONVERSION */
  ecl_cmp_defun(VV[221]);                         /*  WT-FROM-OBJECT-CONVERSION */
  ecl_cmp_defun(VV[222]);                         /*  WT-COERCE-LOC           */
  ecl_cmp_defun(VV[223]);                         /*  WT-C-INLINE-LOC         */
  ecl_cmp_defun(VV[224]);                         /*  SET-UNKNOWN-LOC         */
  ecl_cmp_defun(VV[225]);                         /*  SET-LOC                 */
  ecl_cmp_defun(VV[226]);                         /*  SET-TRASH-LOC           */
  ecl_cmp_defun(VV[227]);                         /*  SET-VALUE0-LOC          */
  ecl_cmp_defun(VV[228]);                         /*  SET-THE-LOC             */
  ecl_cmp_defun(VV[229]);                         /*  SET-LEAVE-LOC           */
  ecl_cmp_defun(VV[230]);                         /*  SET-VALUEZ-LOC          */
  ecl_cmp_defun(VV[231]);                         /*  WT-FFI-DATA-REF         */
  ecl_cmp_defun(VV[232]);                         /*  WT-FFI-DATA-SET         */
}
