/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/proclamations.lsp               */
#include <ecl/ecl-cmp.h>
#include "cmp/proclamations.eclh"
/* function definition for PUT-PROPERTY                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4151put_property(cl_object v1symbol, cl_object v2property, cl_object v3value, cl_object v4collection)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v4collection)){
  goto L2;
 }
 {
  cl_object v5;
  T0 = ecl_gethash_safe(v1symbol,v4collection,ECL_NIL);
  v5 = si_put_f(T0, v3value, v2property);
  si_hash_set(v1symbol, v4collection, v5);
  value0 = v3value;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L2:;
 value0 = si_put_sysprop(v1symbol, v2property, v3value);
 return value0;
}
static cl_object L4151put_property_va(cl_narg narg, cl_object v6symbol, cl_object v7property, cl_object v8value, cl_object v9collection, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[0]);
 {
  return L4151put_property(v6symbol, v7property, v8value, v9collection);
 }
}
/* function definition for REM-PROPERTY                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4152rem_property(cl_object v1symbol, cl_object v2property, cl_object v3collection)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v3collection)){
  goto L2;
 }
 {
  cl_object v4;
  cl_object v5;                                   /*  FLAG                    */
  T0 = cl_gethash(2, v1symbol, v3collection);
  value0 = si_rem_f(T0, v2property);
  {
   v4 = value0;
   v5 = cl_env_copy->values[1];
  }
  si_hash_set(v1symbol, v3collection, v4);
  value0 = v5;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L2:;
 value0 = si_rem_sysprop(v1symbol, v2property);
 return value0;
}
static cl_object L4152rem_property_va(cl_narg narg, cl_object v4symbol, cl_object v5property, cl_object v6collection, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[2]);
 {
  return L4152rem_property(v4symbol, v5property, v6collection);
 }
}
/* closure GET-PROPERTY                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4153get_property(cl_narg narg, cl_object v1symbol, cl_object v2property, cl_object v3collection, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  NOT-FOUND               */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[4]);
 {
L1:;
  if (Null(v3collection)){
   goto L2;
  }
  {
   cl_object v4value;
   T0 = ecl_gethash_safe(v1symbol,v3collection,ECL_NIL);
   v4value = cl_getf(3, T0, v2property, ECL_CONS_CAR(CLV0));
   if (!((v4value)==(ECL_CONS_CAR(CLV0)))){
    goto L5;
   }
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = ECL_NIL;
   cl_env_copy->values[0] = ECL_NIL;
   return cl_env_copy->values[0];
L5:;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = ECL_T;
   cl_env_copy->values[0] = v4value;
   return cl_env_copy->values[0];
  }
L2:;
  value0 = si_get_sysprop(v1symbol, v2property);
  return value0;
 }
 }
}
/* closure GET-GLOBAL-PROPERTY                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4154get_global_property(cl_narg narg, cl_object v1symbol, cl_object v2property, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  NOT-FOUND               */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[5]);
 {
L1:;
  {
   cl_object v3value;
   T0 = ecl_gethash_safe(v1symbol,ecl_cmp_symbol_value(cl_env_copy,VV[6]),ECL_NIL);
   v3value = cl_getf(3, T0, v2property, ECL_CONS_CAR(CLV0));
   if (!((v3value)==(ECL_CONS_CAR(CLV0)))){
    goto L3;
   }
   value0 = si_get_sysprop(v1symbol, v2property);
   return value0;
L3:;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = ECL_T;
   cl_env_copy->values[0] = v3value;
   return cl_env_copy->values[0];
  }
 }
 }
}
/* function definition for FUNCTION-IS-PURE                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4155function_is_pure(cl_object v1fname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, v1fname, VV[8], ecl_cmp_symbol_value(cl_env_copy,VV[6])) /*  GET-PROPERTY */;
 return value0;
}
static cl_object L4155function_is_pure_va(cl_narg narg, cl_object v2fname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[7]);
 {
  return L4155function_is_pure(v2fname);
 }
}
/* function definition for FUNCTION-MAY-HAVE-SIDE-EFFECTS                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4156function_may_have_side_effects(cl_object v1fname)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, v1fname, VV[11], ecl_cmp_symbol_value(cl_env_copy,VV[6])) /*  GET-PROPERTY */;
 value0 = Null(T0)?ECL_T:ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4156function_may_have_side_effects_va(cl_narg narg, cl_object v2fname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[10]);
 {
  return L4156function_may_have_side_effects(v2fname);
 }
}
/* function definition for FUNCTION-MAY-CHANGE-SP                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4157function_may_change_sp(cl_object v1fname)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, v1fname, VV[11], ecl_cmp_symbol_value(cl_env_copy,VV[6])) /*  GET-PROPERTY */;
 if (value0!=ECL_NIL) {
  goto L4;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, v1fname, VV[14], ecl_cmp_symbol_value(cl_env_copy,VV[6])) /*  GET-PROPERTY */;
 goto L2;
L4:;
 T0 = value0;
 goto L2;
L2:;
 value0 = Null(T0)?ECL_T:ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4157function_may_change_sp_va(cl_narg narg, cl_object v2fname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[13]);
 {
  return L4157function_may_change_sp(v2fname);
 }
}
/* function definition for FUNCTION-NO-SP-CHANGE                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4158function_no_sp_change(cl_object v1fname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, v1fname, VV[14], ecl_cmp_symbol_value(cl_env_copy,VV[6])) /*  GET-PROPERTY */;
 return value0;
}
static cl_object L4158function_no_sp_change_va(cl_narg narg, cl_object v2fname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[16]);
 {
  return L4158function_no_sp_change(v2fname);
 }
}
/* function definition for PARSE-FUNCTION-PROCLAMATION                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4159parse_function_proclamation(cl_narg narg, cl_object v1name, cl_object v2arg_types, cl_object v3return_type, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[18]);
 {
  cl_object v4properties;
  ecl_va_list args; ecl_va_start(args,v3return_type,narg,3);
  v4properties = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(3, v1name, VV[19], ecl_cmp_symbol_value(cl_env_copy,VV[6])) /*  GET-PROPERTY */)){
   goto L1;
  }
  (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(2, VV[20], v1name) /*  WARN */;
L1:;
  T0 = cl_list(2, v2arg_types, v3return_type);
  (cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(3, v1name, T0, ecl_cmp_symbol_value(cl_env_copy,VV[6])) /*  PROCLAIM-FUNCTION */;
  {
   cl_object v5;
   cl_object v6p;
   cl_object v7;
   {
    cl_object v8;
    v8 = v4properties;
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v8;
   }
   v6p = ECL_NIL;
   v7 = v5;
L9:;
   if (!(ecl_endp(v7))){
    goto L11;
   }
   goto L10;
L11:;
   v6p = ECL_CONS_CAR(v7);
   {
    cl_object v8;
    v8 = ECL_CONS_CDR(v7);
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v7 = v8;
   }
   if (!((v6p)==(VV[24]))){
    goto L20;
   }
   L4151put_property(v1name, VV[14], ECL_T, ecl_cmp_symbol_value(cl_env_copy,VV[6]));
   goto L19;
L20:;
   if (!((v6p)==(ECL_SYM("PREDICATE",1324)))){
    goto L27;
   }
   goto L24;
L27:;
   goto L25;
L25:;
   if (!((v6p)==(VV[26]))){
    goto L22;
   }
   goto L23;
L24:;
L23:;
   L4151put_property(v1name, VV[8], ECL_T, ecl_cmp_symbol_value(cl_env_copy,VV[6]));
   L4151put_property(v1name, VV[11], ECL_T, ecl_cmp_symbol_value(cl_env_copy,VV[6]));
   goto L19;
L22:;
   if (!((v6p)==(VV[29]))){
    goto L36;
   }
   goto L33;
L36:;
   goto L34;
L34:;
   if (!((v6p)==(ECL_SYM("READER",1010)))){
    goto L31;
   }
   goto L32;
L33:;
L32:;
   L4151put_property(v1name, VV[11], ECL_T, ecl_cmp_symbol_value(cl_env_copy,VV[6]));
   goto L19;
L31:;
   cl_error(3, VV[31], v6p, v1name);
L19:;
   goto L9;
L10:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function LAMBDA55                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4160__lambda55(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = VV[39];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4160__lambda55_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[37]);
 {
  return LC4160__lambda55(v4, v5);
 }
}
/* local function LAMBDA69                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4161__lambda69(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = ECL_SYM("LIST",483);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4161__lambda69_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[44]);
 {
  return LC4161__lambda69(v4, v5);
 }
}
/* local function LAMBDA77                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4162__lambda77(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = ECL_SYM("LIST",483);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4162__lambda77_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[47]);
 {
  return LC4162__lambda77(v4, v5);
 }
}
/* local function LAMBDA82                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4163__lambda82(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4163__lambda82_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[49]);
 {
  return LC4163__lambda82(v4, v5);
 }
}
/* local function LAMBDA87                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4164__lambda87(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = VV[52];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4164__lambda87_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[51]);
 {
  return LC4164__lambda87(v4, v5);
 }
}
/* local function LAMBDA92                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4165__lambda92(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = VV[55];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4165__lambda92_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[54]);
 {
  return LC4165__lambda92(v4, v5);
 }
}
/* local function LAMBDA97                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4166__lambda97(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = VV[58];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4166__lambda97_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[57]);
 {
  return LC4166__lambda97(v4, v5);
 }
}
/* local function LAMBDA102                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4167__lambda102(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4167__lambda102_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[60]);
 {
  return LC4167__lambda102(v4, v5);
 }
}
/* local function LAMBDA107                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4168__lambda107(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = ECL_SYM("ARRAY-INDEX",1877);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4168__lambda107_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[61]);
 {
  return LC4168__lambda107(v4, v5);
 }
}
/* local function LAMBDA112                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4169__lambda112(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = VV[64];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4169__lambda112_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[63]);
 {
  return LC4169__lambda112(v4, v5);
 }
}
/* local function LAMBDA153                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4170__lambda153(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = VV[73];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4170__lambda153_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[72]);
 {
  return LC4170__lambda153(v4, v5);
 }
}
/* local function LAMBDA170                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4171__lambda170(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = VV[80];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4171__lambda170_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[79]);
 {
  return LC4171__lambda170(v4, v5);
 }
}
/* local function LAMBDA175                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4172__lambda175(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = ECL_SYM("UNSIGNED-BYTE",889);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4172__lambda175_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[82]);
 {
  return LC4172__lambda175(v4, v5);
 }
}
#include "cmp/proclamations.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclsqrgy6Iu8B5n9_AOi0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;PROCLAMATIONS.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclsqrgy6Iu8B5n9_AOi0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
  cl_object volatile CLV0;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  ecl_cmp_defun(VV[85]);                          /*  PUT-PROPERTY            */
  ecl_cmp_defun(VV[86]);                          /*  REM-PROPERTY            */
  {
   cl_object env1 = env0;
   T0 = CONS(ECL_NIL,ECL_NIL);
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(T0,env1);                   /*  NOT-FOUND               */
   {
    cl_object v1;
    v1 = ecl_make_cclosure_va((cl_objectfn)LC4153get_property,env1,Cblock,3);
    T0 = v1;
   }
   si_fset(2, VV[4], T0);
   {
    cl_object v1;
    v1 = ecl_make_cclosure_va((cl_objectfn)LC4154get_global_property,env1,Cblock,2);
    T0 = v1;
   }
   si_fset(2, VV[5], T0);
  }
  ecl_cmp_defun(VV[87]);                          /*  FUNCTION-IS-PURE        */
  ecl_cmp_defun(VV[88]);                          /*  FUNCTION-MAY-HAVE-SIDE-EFFECTS */
  ecl_cmp_defun(VV[89]);                          /*  FUNCTION-MAY-CHANGE-SP  */
  ecl_cmp_defun(VV[90]);                          /*  FUNCTION-NO-SP-CHANGE   */
  ecl_cmp_defun(VV[91]);                          /*  PARSE-FUNCTION-PROCLAMATION */
  si_do_deftype(3, VV[33], VVtemp[1], VVtemp[2]);
  si_do_deftype(3, VV[34], VVtemp[3], VVtemp[4]);
  si_do_deftype(3, VV[35], VVtemp[5], ECL_SYM("LIST",483));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4160__lambda55_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[36], VVtemp[6], T0);
  si_do_deftype(3, VV[40], VVtemp[7], VVtemp[8]);
  si_do_deftype(3, VV[41], VVtemp[9], VVtemp[10]);
  si_do_deftype(3, VV[42], VVtemp[11], VVtemp[12]);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4161__lambda69_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[43], VVtemp[13], T0);
  si_do_deftype(3, VV[45], VVtemp[14], VVtemp[15]);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4162__lambda77_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[46], VVtemp[16], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4163__lambda82_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[48], VVtemp[17], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4164__lambda87_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[50], VVtemp[18], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4165__lambda92_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[53], VVtemp[19], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4166__lambda97_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[56], VVtemp[20], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4167__lambda102_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[59], VVtemp[21], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4168__lambda107_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, ECL_SYM("INTEGER-LENGTH",441), VVtemp[22], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4169__lambda112_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[62], VVtemp[23], T0);
  si_do_deftype(3, VV[65], VVtemp[24], VVtemp[25]);
  si_do_deftype(3, VV[66], VVtemp[26], VVtemp[27]);
  si_do_deftype(3, ECL_SYM("PATHNAME-DEVICE",633), VVtemp[28], VVtemp[29]);
  si_do_deftype(3, ECL_SYM("PATHNAME-DIRECTORY",634), VVtemp[30], VVtemp[31]);
  si_do_deftype(3, ECL_SYM("PATHNAME-HOST",635), VVtemp[32], VVtemp[33]);
  si_do_deftype(3, ECL_SYM("PATHNAME-NAME",637), VVtemp[34], VVtemp[35]);
  si_do_deftype(3, ECL_SYM("PATHNAME-TYPE",638), VVtemp[36], VVtemp[35]);
  si_do_deftype(3, ECL_SYM("PATHNAME-VERSION",639), VVtemp[37], VVtemp[38]);
  si_do_deftype(3, VV[67], VVtemp[39], ECL_SYM("LIST",483));
  si_do_deftype(3, VV[68], VVtemp[40], ECL_SYM("LIST",483));
  si_do_deftype(3, VV[69], VVtemp[41], VVtemp[42]);
  si_do_deftype(3, VV[70], VVtemp[43], VVtemp[44]);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4170__lambda153_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[71], VVtemp[45], T0);
  si_do_deftype(3, VV[74], VVtemp[46], VVtemp[47]);
  si_do_deftype(3, VV[75], VVtemp[48], VVtemp[49]);
  si_do_deftype(3, VV[76], VVtemp[50], VVtemp[51]);
  si_do_deftype(3, VV[77], VVtemp[52], ECL_T);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4171__lambda170_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[78], VVtemp[53], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4172__lambda175_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[81], VVtemp[54], T0);
  si_do_deftype(3, VV[83], VVtemp[55], ECL_T);
  si_do_deftype(3, ECL_SYM("INSTANCE",1380), VVtemp[56], ECL_SYM("STANDARD-OBJECT",980));
  (cl_env_copy->function=(ECL_SYM("PROCLAIM",669)->symbol.gfdef))->cfun.entry(1, VVtemp[57]) /*  PROCLAIM */;
  si_Xmake_special(VV[6]);
  T0 = cl_make_hash_table(8, ECL_SYM("SIZE",1345), ecl_make_fixnum(1536), ECL_SYM("REHASH-SIZE",1334), _ecl_static_0, ECL_SYM("REHASH-THRESHOLD",1335), _ecl_static_1, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
  VVtemp[58]=si_hash_table_fill(T0, VVtemp[59]);
  if (ecl_boundp(cl_env_copy,VV[6])) {
   goto L86;
  }
  T0 = VVtemp[58];
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
L86:;
  T0 = cl_adjoin(2, VV[6], ecl_cmp_symbol_value(cl_env_copy,VV[84]));
  ecl_cmp_setq(cl_env_copy,VV[84],T0);
 }
}
