/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpbackend-cxx/cmppass2-cont.lsp */
#include <ecl/ecl-cmp.h>
#include "cmp/cmppass2-cont.eclh"
/* function definition for C2BLOCK                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3850c2block(cl_object v1c1form, cl_object v2blk, cl_object v3body)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  v4 = ecl_cmp_symbol_value(cl_env_copy,VV[1]);
  ecl_structure_set(v2blk,VV[2],(cl_fixnum)(5),v4);
 }
 {
  cl_object v4;
  v4 = ecl_cmp_symbol_value(cl_env_copy,VV[3]);
  ecl_structure_set(v2blk,VV[2],(cl_fixnum)(6),v4);
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(1, v2blk) /*  BLK-VAR */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, T0) /*  VAR-REF */;
 if (!(ecl_plusp(T1))){
  goto L6;
 }
 {
  cl_object v4blk_var;
  v4blk_var = (cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(1, v2blk) /*  BLK-VAR */;
  ecl_bds_push(cl_env_copy,VV[6]);                /*  *ENV-LVL*               */
  (cl_env_copy->function=ecl_fdefinition(VV[7]))->cfun.entry(1, v4blk_var) /*  CHECK-VREF */;
  {
   cl_object v5;
   cl_object v6;
   v5 = ecl_cmp_symbol_value(cl_env_copy,VV[10]);
   v6 = ecl_cmp_symbol_value(cl_env_copy,VV[11]);
   ecl_bds_bind(cl_env_copy,VV[12],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*   */
   ecl_bds_bind(cl_env_copy,VV[10],v5);           /*  *TEMP*                  */
   ecl_bds_bind(cl_env_copy,VV[11],v6);           /*  *LCL*                   */
   (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[14]))->cfun.entry(1, v4blk_var) /*  VAR-KIND */;
   if (!((ECL_SYM("OBJECT",1315))==(T0))){
    goto L13;
   }
   {
    cl_object v7;
    v7 = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(0) /*  NEXT-LCL */;
    ecl_structure_set(v4blk_var,VV[16],(cl_fixnum)(10),v7);
   }
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(3, VV[18], v4blk_var, VV[19]) /*  WT-NL */;
L13:;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(1, v4blk_var) /*  VAR-REF-CCB */;
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, T0) /*  ENV-GROWS */)){
    goto L17;
   }
   {
    cl_object v7env_lvl;
    v7env_lvl = ecl_cmp_symbol_value(cl_env_copy,VV[6]);
    T0 = ecl_cmp_symbol_value(cl_env_copy,VV[22]);
    T2 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
    ecl_cmp_setq(cl_env_copy,VV[6],T2);
    T1 = ecl_cmp_symbol_value(cl_env_copy,VV[6]);
    (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(7, VV[18], T0, VV[23], T1, VV[24], v7env_lvl, VV[19]) /*  WT-NL */;
   }
L17:;
   (cl_env_copy->function=ecl_fdefinition(VV[25]))->cfun.entry(2, VV[26], v4blk_var) /*  BIND */;
   {
    cl_object v7;
    cl_object v8;
    v7 = ecl_cmp_symbol_value(cl_env_copy,VV[10]);
    v8 = ecl_cmp_symbol_value(cl_env_copy,VV[11]);
    ecl_bds_bind(cl_env_copy,VV[12],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*  */
    ecl_bds_bind(cl_env_copy,VV[10],v7);          /*  *TEMP*                  */
    ecl_bds_bind(cl_env_copy,VV[11],v8);          /*  *LCL*                   */
    (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
    T0 = CONS(VV[29],ecl_cmp_symbol_value(cl_env_copy,VV[28]));
    ecl_bds_bind(cl_env_copy,VV[28],T0);          /*  *UNWIND-EXIT*           */
    (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(3, VV[30], v4blk_var, VV[31]) /*  WT-NL */;
    (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[32]) /*  WT-NL */;
    (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(1, VV[34]) /*  UNWIND-EXIT */;
    (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[35]) /*  WT-NL */;
    (cl_env_copy->function=ecl_fdefinition(VV[36]))->cfun.entry(1, v3body) /*  C2EXPR */;
    (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[37]) /*  WT-NL */;
    ecl_bds_unwind1(cl_env_copy);
    (cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
    ecl_bds_unwind1(cl_env_copy);
    ecl_bds_unwind1(cl_env_copy);
    ecl_bds_unwind1(cl_env_copy);
   }
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(1, v4blk_var) /*  VAR-REF-CCB */)){
    goto L34;
   }
   T0 = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[39]),ecl_make_int8_t(1));
   ecl_cmp_setq(cl_env_copy,VV[39],T0);
L34:;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
   ecl_bds_unwind_n(cl_env_copy,4);
   return value0;
  }
 }
L6:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[36]))->cfun.entry(1, v3body) /*  C2EXPR */;
 return value0;
}
static cl_object L3850c2block_va(cl_narg narg, cl_object v7c1form, cl_object v8blk, cl_object v9body, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[0]);
 {
  return L3850c2block(v7c1form, v8blk, v9body);
 }
}
/* function definition for C2RETURN-FROM                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3851c2return_from(cl_object v1c1form, cl_object v2blk, cl_object v3nonlocal, cl_object v4val)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v3nonlocal)){
  goto L2;
 }
 ecl_bds_bind(cl_env_copy,VV[3],VV[34]);          /*  *DESTINATION*           */
 (cl_env_copy->function=ecl_fdefinition(VV[42]))->cfun.entry(1, v4val) /*  C2EXPR* */;
 ecl_bds_unwind1(cl_env_copy);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[43]))->cfun.entry(2, v2blk, VV[44]) /*  UNWIND-FLEE */;
 return value0;
L2:;
 {
  cl_object v5;
  cl_object v6;
  v5 = (cl_env_copy->function=ecl_fdefinition(VV[45]))->cfun.entry(1, v2blk) /*  BLK-DESTINATION */;
  v6 = (cl_env_copy->function=ecl_fdefinition(VV[46]))->cfun.entry(1, v2blk) /*  BLK-EXIT */;
  ecl_bds_bind(cl_env_copy,VV[3],v5);             /*  *DESTINATION*           */
  ecl_bds_bind(cl_env_copy,VV[1],v6);             /*  *EXIT*                  */
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[36]))->cfun.entry(1, v4val) /*  C2EXPR */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3851c2return_from_va(cl_narg narg, cl_object v7c1form, cl_object v8blk, cl_object v9nonlocal, cl_object v10val, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[41]);
 {
  return L3851c2return_from(v7c1form, v8blk, v9nonlocal, v10val);
 }
}
/* function definition for C2TAGBODY                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3852c2tagbody(cl_object v1c1form, cl_object v2tag_loc, cl_object v3body)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[14]))->cfun.entry(1, v2tag_loc) /*  VAR-KIND */;
 if (!(T0==ECL_NIL)){
  goto L2;
 }
 {
  cl_object v4;
  v4 = v3body;
  goto L7;
L6:;
  {
   cl_object v5tag;
   v5tag = ecl_car(v4);
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[50]))->cfun.entry(1, v5tag) /*  TAG-P */)){
    goto L11;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[51]))->cfun.entry(1, v5tag) /*  TAG-REF */;
   if (!(ecl_plusp(T0))){
    goto L11;
   }
   {
    cl_object v6;
    v6 = (cl_env_copy->function=ecl_fdefinition(VV[52]))->cfun.entry(1, ECL_T) /*  NEXT-LABEL */;
    ecl_structure_set(v5tag,VV[53],(cl_fixnum)(5),v6);
   }
L11:;
  }
  v4 = ecl_cdr(v4);
L7:;
  if (Null(v4)){
   goto L17;
  }
  goto L6;
L17:;
  value0 = L3853c2tagbody_body(v3body);
  return value0;
 }
L2:;
 {
  cl_object v5;
  cl_object v6;
  cl_object v7;
  cl_object v8;
  cl_object v9;
  v5 = ecl_cmp_symbol_value(cl_env_copy,VV[39]);
  v6 = ecl_cmp_symbol_value(cl_env_copy,VV[6]);
  v7 = ecl_cmp_symbol_value(cl_env_copy,VV[55]);
  v8 = ecl_cmp_symbol_value(cl_env_copy,VV[11]);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(1, v2tag_loc) /*  VAR-REF-CCB */;
  v9 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, T0) /*  ENV-GROWS */;
  ecl_bds_bind(cl_env_copy,VV[39],v5);            /*  *ENV*                   */
  ecl_bds_bind(cl_env_copy,VV[6],v6);             /*  *ENV-LVL*               */
  ecl_bds_bind(cl_env_copy,VV[55],v7);            /*  *LEX*                   */
  ecl_bds_bind(cl_env_copy,VV[11],v8);            /*  *LCL*                   */
  ecl_bds_bind(cl_env_copy,VV[12],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*    */
  if (Null(v9)){
   goto L24;
  }
  {
   cl_object v10env_lvl;
   v10env_lvl = ecl_cmp_symbol_value(cl_env_copy,VV[6]);
   (cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(0) /*  MAYBE-OPEN-INLINE-BLOCK */;
   T1 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
   ecl_cmp_setq(cl_env_copy,VV[6],T1);
   T0 = ecl_cmp_symbol_value(cl_env_copy,VV[6]);
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(5, VV[57], T0, VV[24], v10env_lvl, VV[19]) /*  WT-NL */;
  }
L24:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[14]))->cfun.entry(1, v2tag_loc) /*  VAR-KIND */;
  if (!((ECL_SYM("OBJECT",1315))==(T0))){
   goto L30;
  }
  {
   cl_object v10;
   v10 = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(0) /*  NEXT-LCL */;
   ecl_structure_set(v2tag_loc,VV[16],(cl_fixnum)(10),v10);
  }
  (cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(0) /*  MAYBE-OPEN-INLINE-BLOCK */;
  (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(3, VV[18], v2tag_loc, VV[19]) /*  WT-NL */;
L30:;
  (cl_env_copy->function=ecl_fdefinition(VV[25]))->cfun.entry(2, VV[26], v2tag_loc) /*  BIND */;
  {
   cl_object v10;
   cl_object v11;
   v10 = ecl_cmp_symbol_value(cl_env_copy,VV[10]);
   v11 = ecl_cmp_symbol_value(cl_env_copy,VV[11]);
   ecl_bds_bind(cl_env_copy,VV[12],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*   */
   ecl_bds_bind(cl_env_copy,VV[10],v10);          /*  *TEMP*                  */
   ecl_bds_bind(cl_env_copy,VV[11],v11);          /*  *LCL*                   */
   (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
   T0 = CONS(VV[29],ecl_cmp_symbol_value(cl_env_copy,VV[28]));
   ecl_bds_bind(cl_env_copy,VV[28],T0);           /*  *UNWIND-EXIT*           */
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(3, VV[30], v2tag_loc, VV[31]) /*  WT-NL */;
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[32]) /*  WT-NL */;
   {
    cl_object v12;
    v12 = v3body;
    goto L48;
L47:;
    {
     cl_object v13tag;
     v13tag = ecl_car(v12);
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[50]))->cfun.entry(1, v13tag) /*  TAG-P */)){
      goto L52;
     }
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[51]))->cfun.entry(1, v13tag) /*  TAG-REF */;
     if (!(ecl_plusp(T0))){
      goto L52;
     }
     {
      cl_object v14;
      v14 = (cl_env_copy->function=ecl_fdefinition(VV[52]))->cfun.entry(1, ECL_T) /*  NEXT-LABEL */;
      ecl_structure_set(v13tag,VV[53],(cl_fixnum)(5),v14);
     }
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v13tag) /*  TAG-JUMP */;
     T1 = (cl_env_copy->function=ecl_fdefinition(VV[61]))->cfun.entry(1, v13tag) /*  TAG-INDEX */;
     (cl_env_copy->function=ecl_fdefinition(VV[58]))->cfun.entry(4, T0, VV[60], VV[34], T1) /*  UNWIND-COND */;
L52:;
    }
    v12 = ecl_cdr(v12);
L48:;
    if (Null(v12)){
     goto L59;
    }
    goto L47;
L59:;
   }
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(1, v2tag_loc) /*  VAR-REF-CCB */)){
    goto L43;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[62]) /*  WT-NL */;
L43:;
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[35]) /*  WT-NL */;
   L3853c2tagbody_body(v3body);
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[37]) /*  WT-NL */;
   ecl_bds_unwind1(cl_env_copy);
   (cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
  ecl_bds_unwind_n(cl_env_copy,5);
  return value0;
 }
}
static cl_object L3852c2tagbody_va(cl_narg narg, cl_object v10c1form, cl_object v11tag_loc, cl_object v12body, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[48]);
 {
  return L3852c2tagbody(v10c1form, v11tag_loc, v12body);
 }
}
/* function definition for C2TAGBODY-BODY                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3853c2tagbody_body(cl_object v1body)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3this_form;
  cl_object v4rest;
  v2 = v1body;
  v3this_form = ECL_NIL;
  v4rest = ECL_NIL;
L5:;
  if (!(ECL_ATOM(v2))){
   goto L7;
  }
  goto L6;
L7:;
  {
   cl_object v5;
   v5 = v2;
   v3this_form = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v4rest = v5;
  }
  v2 = ECL_CONS_CDR(v2);
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[50]))->cfun.entry(1, v3this_form) /*  TAG-P */)){
   goto L19;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v3this_form) /*  TAG-JUMP */;
  (cl_env_copy->function=ecl_fdefinition(VV[66]))->cfun.entry(1, T0) /*  WT-LABEL */;
  goto L18;
L19:;
  if (!(ecl_endp(v4rest))){
   goto L21;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[36]))->cfun.entry(1, v3this_form) /*  C2EXPR */;
  goto L18;
L21:;
  {
   cl_object v5next_form;
   cl_object v6maybe_tag;
   v5next_form = ecl_car(v4rest);
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[50]))->cfun.entry(1, v5next_form) /*  TAG-P */)){
    goto L25;
   }
   v6maybe_tag = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v5next_form) /*  TAG-JUMP */;
   goto L24;
L25:;
   v6maybe_tag = ECL_NIL;
L24:;
   {
    cl_object v7;
    v7 = (cl_env_copy->function=ecl_fdefinition(VV[68]))->cfun.entry(1, v6maybe_tag) /*  LABELP */;
    if (Null(v7)){
     goto L29;
    }
    T0 = v6maybe_tag;
    goto L28;
L29:;
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[52]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L28:;
    ecl_bds_bind(cl_env_copy,VV[1],T0);           /*  *EXIT*                  */
    T0 = cl_adjoin(2, ecl_cmp_symbol_value(cl_env_copy,VV[1]), ecl_cmp_symbol_value(cl_env_copy,VV[28]));
    ecl_bds_bind(cl_env_copy,VV[28],T0);          /*  *UNWIND-EXIT*           */
    ecl_bds_bind(cl_env_copy,VV[3],VV[69]);       /*  *DESTINATION*           */
    (cl_env_copy->function=ecl_fdefinition(VV[36]))->cfun.entry(1, v3this_form) /*  C2EXPR */;
    ecl_bds_unwind1(cl_env_copy);
    if (v7!=ECL_NIL) {
     ecl_bds_unwind1(cl_env_copy);
     ecl_bds_unwind1(cl_env_copy);
     goto L18;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[66]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[1])) /*  WT-LABEL */;
    ecl_bds_unwind1(cl_env_copy);
    ecl_bds_unwind1(cl_env_copy);
   }
  }
L18:;
  goto L5;
L6:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3853c2tagbody_body_va(cl_narg narg, cl_object v5body, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[54]);
 {
  return L3853c2tagbody_body(v5body);
 }
}
/* function definition for C2GO                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3854c2go(cl_object v1c1form, cl_object v2tag, cl_object v3nonlocal)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v3nonlocal)){
  goto L2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[43]))->cfun.entry(2, v2tag, VV[72]) /*  UNWIND-FLEE */;
 return value0;
L2:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v2tag) /*  TAG-JUMP */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[73]))->cfun.entry(1, T0) /*  UNWIND-JUMP */;
 return value0;
}
static cl_object L3854c2go_va(cl_narg narg, cl_object v4c1form, cl_object v5tag, cl_object v6nonlocal, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[71]);
 {
  return L3854c2go(v4c1form, v5tag, v6nonlocal);
 }
}
/* function definition for C2THROW                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3855c2throw(cl_object v1c1form, cl_object v2tag, cl_object v3val)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4loc;
  v4loc = ECL_NIL;
  {
   cl_object v5;
   v5 = (cl_env_copy->function=ecl_fdefinition(VV[76]))->cfun.entry(1, v2tag) /*  C1FORM-NAME */;
   if (!((v5)==(ECL_SYM("VARIABLE",901)))){
    goto L10;
   }
   goto L7;
L10:;
   goto L8;
L8:;
   if (!((v5)==(VV[78]))){
    goto L5;
   }
   goto L6;
L7:;
L6:;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[81]))->cfun.entry(1, v2tag) /*  C1FORM-ARGS */;
   v4loc = ecl_car(T0);
   goto L3;
L5:;
   v4loc = (cl_env_copy->function=ecl_fdefinition(VV[82]))->cfun.entry(0) /*  MAKE-TEMP-VAR */;
   ecl_bds_bind(cl_env_copy,VV[3],v4loc);         /*  *DESTINATION*           */
   (cl_env_copy->function=ecl_fdefinition(VV[42]))->cfun.entry(1, v2tag) /*  C2EXPR* */;
   ecl_bds_unwind1(cl_env_copy);
  }
L3:;
  ecl_bds_bind(cl_env_copy,VV[3],VV[34]);         /*  *DESTINATION*           */
  (cl_env_copy->function=ecl_fdefinition(VV[42]))->cfun.entry(1, v3val) /*  C2EXPR* */;
  ecl_bds_unwind1(cl_env_copy);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[43]))->cfun.entry(2, v4loc, VV[83]) /*  UNWIND-FLEE */;
  return value0;
 }
}
static cl_object L3855c2throw_va(cl_narg narg, cl_object v5c1form, cl_object v6tag, cl_object v7val, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[75]);
 {
  return L3855c2throw(v5c1form, v6tag, v7val);
 }
}
/* function definition for C2CATCH                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3856c2catch(cl_object v1c1form, cl_object v2tag, cl_object v3body)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4new_destination;
  cl_object v5code;
  v4new_destination = (cl_env_copy->function=ecl_fdefinition(VV[86]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[3])) /*  TMP-DESTINATION */;
  v5code = cl_gensym(1, VV[87]);
  ecl_bds_bind(cl_env_copy,VV[3],VV[88]);         /*  *DESTINATION*           */
  (cl_env_copy->function=ecl_fdefinition(VV[42]))->cfun.entry(1, v2tag) /*  C2EXPR* */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_bind(cl_env_copy,VV[3],v4new_destination); /*  *DESTINATION*        */
  (cl_env_copy->function=ecl_fdefinition(VV[89]))->cfun.entry(2, VV[90], v5code) /*  WT-COMMENT */;
  {
   cl_object v6;
   cl_object v7;
   v6 = ecl_cmp_symbol_value(cl_env_copy,VV[10]);
   v7 = ecl_cmp_symbol_value(cl_env_copy,VV[11]);
   ecl_bds_bind(cl_env_copy,VV[12],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*   */
   ecl_bds_bind(cl_env_copy,VV[10],v6);           /*  *TEMP*                  */
   ecl_bds_bind(cl_env_copy,VV[11],v7);           /*  *LCL*                   */
   (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
   T0 = CONS(VV[29],ecl_cmp_symbol_value(cl_env_copy,VV[28]));
   ecl_bds_bind(cl_env_copy,VV[28],T0);           /*  *UNWIND-EXIT*           */
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(3, VV[30], VV[88], VV[31]) /*  WT-NL */;
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[32]) /*  WT-NL */;
   if (!((v4new_destination)==(VV[69]))){
    goto L18;
   }
   goto L14;
L18:;
   goto L16;
L16:;
   if (!((v4new_destination)==(VV[34]))){
    goto L21;
   }
   goto L14;
L21:;
   goto L15;
L15:;
   T0 = ecl_one_plus(ecl_cmp_symbol_value(cl_env_copy,VV[94]));
   ecl_bds_bind(cl_env_copy,VV[94],T0);           /*  *OPENED-C-BRACES*       */
   {
    cl_object v8;
    v8 = (cl_env_copy->function=ecl_fdefinition(VV[68]))->cfun.entry(1, ECL_NIL) /*  LABELP */;
    if (Null(v8)){
     goto L25;
    }
    T0 = ECL_NIL;
    goto L24;
L25:;
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[52]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L24:;
    ecl_bds_bind(cl_env_copy,VV[1],T0);           /*  *EXIT*                  */
    T0 = cl_adjoin(2, ecl_cmp_symbol_value(cl_env_copy,VV[1]), ecl_cmp_symbol_value(cl_env_copy,VV[28]));
    ecl_bds_bind(cl_env_copy,VV[28],T0);          /*  *UNWIND-EXIT*           */
    (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(1, VV[34]) /*  UNWIND-EXIT */;
    if (v8!=ECL_NIL) {
     ecl_bds_unwind1(cl_env_copy);
     ecl_bds_unwind1(cl_env_copy);
     ecl_bds_unwind1(cl_env_copy);
     goto L14;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[66]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[1])) /*  WT-LABEL */;
    ecl_bds_unwind1(cl_env_copy);
    ecl_bds_unwind1(cl_env_copy);
    ecl_bds_unwind1(cl_env_copy);
   }
L14:;
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[35]) /*  WT-NL */;
   T0 = ecl_one_plus(ecl_cmp_symbol_value(cl_env_copy,VV[94]));
   ecl_bds_bind(cl_env_copy,VV[94],T0);           /*  *OPENED-C-BRACES*       */
   (cl_env_copy->function=ecl_fdefinition(VV[42]))->cfun.entry(1, v3body) /*  C2EXPR* */;
   ecl_bds_unwind1(cl_env_copy);
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[37]) /*  WT-NL */;
   ecl_bds_unwind1(cl_env_copy);
   (cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
  }
  (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[95]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[89]))->cfun.entry(2, VV[96], v5code) /*  WT-COMMENT */;
  ecl_bds_unwind1(cl_env_copy);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(1, v4new_destination) /*  UNWIND-EXIT */;
  return value0;
 }
}
static cl_object L3856c2catch_va(cl_narg narg, cl_object v6c1form, cl_object v7tag, cl_object v8body, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[85]);
 {
  return L3856c2catch(v6c1form, v7tag, v8body);
 }
}
/* function definition for C2UNWIND-PROTECT                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3857c2unwind_protect(cl_object v1c1form, cl_object v2form, cl_object v3body)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  cl_object v5;
  v4 = ecl_cmp_symbol_value(cl_env_copy,VV[10]);
  v5 = ecl_cmp_symbol_value(cl_env_copy,VV[11]);
  ecl_bds_bind(cl_env_copy,VV[12],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*    */
  ecl_bds_bind(cl_env_copy,VV[10],v4);            /*  *TEMP*                  */
  ecl_bds_bind(cl_env_copy,VV[11],v5);            /*  *LCL*                   */
  (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
  T0 = cl_list(2, VV[102], VV[100]);
  T1 = CONS(T0,ecl_cmp_symbol_value(cl_env_copy,VV[28]));
  ecl_bds_bind(cl_env_copy,VV[28],T1);            /*  *UNWIND-EXIT*           */
  (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(3, VV[103], VV[101], VV[19]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(6, ecl_cmp_symbol_value(cl_env_copy,VV[22]), VV[18], VV[100], VV[104], VV[101], VV[105]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[106]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[107]) /*  WT-NL */;
  {
   cl_object v6;
   cl_object v7;
   v6 = ecl_cmp_symbol_value(cl_env_copy,VV[10]);
   v7 = ecl_cmp_symbol_value(cl_env_copy,VV[11]);
   ecl_bds_bind(cl_env_copy,VV[12],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*   */
   ecl_bds_bind(cl_env_copy,VV[10],v6);           /*  *TEMP*                  */
   ecl_bds_bind(cl_env_copy,VV[11],v7);           /*  *LCL*                   */
   (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
   T0 = CONS(VV[29],ecl_cmp_symbol_value(cl_env_copy,VV[28]));
   ecl_bds_bind(cl_env_copy,VV[28],T0);           /*  *UNWIND-EXIT*           */
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(3, VV[30], VV[108], VV[31]) /*  WT-NL */;
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[32]) /*  WT-NL */;
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[109]) /*  WT-NL */;
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[35]) /*  WT-NL */;
   ecl_bds_bind(cl_env_copy,VV[3],VV[34]);        /*  *DESTINATION*           */
   (cl_env_copy->function=ecl_fdefinition(VV[42]))->cfun.entry(1, v2form) /*  C2EXPR* */;
   ecl_bds_unwind1(cl_env_copy);
   (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[37]) /*  WT-NL */;
   ecl_bds_unwind1(cl_env_copy);
   (cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
  }
  (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[95]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(3, VV[110], VV[100], VV[31]) /*  WT-NL */;
  ecl_bds_bind(cl_env_copy,VV[3],VV[69]);         /*  *DESTINATION*           */
  (cl_env_copy->function=ecl_fdefinition(VV[42]))->cfun.entry(1, v3body) /*  C2EXPR* */;
  ecl_bds_unwind1(cl_env_copy);
  (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(3, VV[111], VV[100], VV[31]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, VV[112]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(1, VV[34]) /*  UNWIND-EXIT */;
  ecl_bds_unwind1(cl_env_copy);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3857c2unwind_protect_va(cl_narg narg, cl_object v6c1form, cl_object v7form, cl_object v8body, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[98]);
 {
  return L3857c2unwind_protect(v6c1form, v7form, v8body);
 }
}
#include "cmp/cmppass2-cont.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecl9eZtIjD8mfip9_dAb0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPBACKEND-CXX;CMPPASS2-CONT.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecl9eZtIjD8mfip9_dAb0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(_ecl_static_0);
  ecl_cmp_defun(VV[114]);                         /*  C2BLOCK                 */
  ecl_cmp_defun(VV[115]);                         /*  C2RETURN-FROM           */
  ecl_cmp_defun(VV[116]);                         /*  C2TAGBODY               */
  ecl_cmp_defun(VV[117]);                         /*  C2TAGBODY-BODY          */
  ecl_cmp_defun(VV[118]);                         /*  C2GO                    */
  ecl_cmp_defun(VV[119]);                         /*  C2THROW                 */
  ecl_cmp_defun(VV[120]);                         /*  C2CATCH                 */
  ecl_cmp_defun(VV[121]);                         /*  C2UNWIND-PROTECT        */
}
