/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpbackend-cxx/cmpc-fun-inl.lsp */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpc-fun-inl.eclh"
/* function definition for MAKE-INLINE-INFO                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3711make_inline_info(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  cl_object v8;
  cl_object v9;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[18];
   cl_parse_key(args,9,L3711make_inline_infokeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1 = keyvars[0];
   v2 = keyvars[1];
   v3 = keyvars[2];
   v4 = keyvars[3];
   v5 = keyvars[4];
   v6 = keyvars[5];
   v7 = keyvars[6];
   v8 = keyvars[7];
   v9 = keyvars[8];
  }
  value0 = si_make_structure(10, VV[5], v1, v2, v3, v4, v5, v6, v7, v8, v9);
  return value0;
 }
}
/* local function LAMBDA2                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3712__lambda2(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(8), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(8));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3712__lambda2_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[9]);
 {
  return LC3712__lambda2(v5, v6si__x);
 }
}
/* local function LAMBDA7                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3713__lambda7(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(7), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(7));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3713__lambda7_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[11]);
 {
  return LC3713__lambda7(v5, v6si__x);
 }
}
/* local function LAMBDA12                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3714__lambda12(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(6), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(6));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3714__lambda12_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[13]);
 {
  return LC3714__lambda12(v5, v6si__x);
 }
}
/* local function LAMBDA17                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3715__lambda17(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(5), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(5));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3715__lambda17_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[15]);
 {
  return LC3715__lambda17(v5, v6si__x);
 }
}
/* local function LAMBDA22                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3716__lambda22(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(4), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(4));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3716__lambda22_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[17]);
 {
  return LC3716__lambda22(v5, v6si__x);
 }
}
/* local function LAMBDA27                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3717__lambda27(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3717__lambda27_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[19]);
 {
  return LC3717__lambda27(v5, v6si__x);
 }
}
/* local function LAMBDA32                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3718__lambda32(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3718__lambda32_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[21]);
 {
  return LC3718__lambda32(v5, v6si__x);
 }
}
/* local function LAMBDA37                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3719__lambda37(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3719__lambda37_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[23]);
 {
  return LC3719__lambda37(v5, v6si__x);
 }
}
/* local function LAMBDA42                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3720__lambda42(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3720__lambda42_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[25]);
 {
  return LC3720__lambda42(v5, v6si__x);
 }
}
/* local function DEFINE-C-INLINER                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3721define_c_inliner(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4fname;
  cl_object v5lambda_list;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4fname = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5lambda_list = v6;
  }
  T0 = cl_list(2, ECL_SYM("QUOTE",682), v4fname);
  T1 = cl_list(3, ECL_SYM("GETHASH",415), T0, VV[28]);
  T2 = cl_listX(3, ECL_SYM("BLOCK",139), ECL_NIL, v3);
  T3 = cl_list(3, ECL_SYM("LAMBDA",454), v5lambda_list, T2);
  T4 = cl_list(2, ECL_SYM("FUNCTION",398), T3);
  value0 = cl_list(3, ECL_SYM("SETF",753), T1, T4);
  return value0;
 }
}
static cl_object LC3721define_c_inliner_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[27]);
 {
  return LC3721define_c_inliner(v6, v7);
 }
}
/* function definition for APPLY-INLINER                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3722apply_inliner(cl_object v1fname, cl_object v2return_type, cl_object v3inlined_args)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4fd;
  v4fd = ecl_gethash_safe(v1fname,ecl_cmp_symbol_value(cl_env_copy,VV[28]),ECL_NIL);
  if (Null(v4fd)){
   goto L3;
  }
  value0 = cl_apply(3, v4fd, v2return_type, v3inlined_args);
  return value0;
L3:;
  value0 = L3723default_c_inliner(v1fname, v2return_type, v3inlined_args);
  return value0;
 }
}
static cl_object L3722apply_inliner_va(cl_narg narg, cl_object v5fname, cl_object v6return_type, cl_object v7inlined_args, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[30]);
 {
  return L3722apply_inliner(v5fname, v6return_type, v7inlined_args);
 }
}
/* function definition for DEFAULT-C-INLINER                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3723default_c_inliner(cl_object v1fname, cl_object v2return_type, cl_object v3inlined_args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4arg_types;
  cl_object v5ii;
  {
   cl_object v6;
   v6 = ecl_fdefinition(VV[33]);
   {
    cl_object v7;
    cl_object v8;
    cl_object v9;
    {
     cl_object v10;
     v10 = v3inlined_args;
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v7 = v10;
    }
    v8 = ECL_NIL;
    v9 = v7;
    {
     cl_object v10;
     cl_object v11;
     v10 = ecl_list1(ECL_NIL);
     v11 = v10;
L11:;
     if (!(ecl_endp(v9))){
      goto L13;
     }
     goto L12;
L13:;
     v8 = ECL_CONS_CAR(v9);
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v9);
      if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v9 = v12;
     }
     {
      cl_object v12;
      v12 = v11;
      if (ecl_unlikely(ECL_ATOM(v12))) FEtype_error_cons(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v12;
     }
     T1 = ecl_function_dispatch(cl_env_copy,v6)(1, v8);
     v11 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v11,T0);
     goto L11;
L12:;
     v4arg_types = ecl_cdr(v10);
     goto L2;
    }
   }
  }
L2:;
  v5ii = L3724inline_function(3, v1fname, v4arg_types, v2return_type);
  if (Null(v5ii)){
   goto L31;
  }
  value0 = L3725apply_inline_info(v5ii, v3inlined_args);
  return value0;
L31:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3723default_c_inliner_va(cl_narg narg, cl_object v6fname, cl_object v7return_type, cl_object v8inlined_args, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[31]);
 {
  return L3723default_c_inliner(v6fname, v7return_type, v8inlined_args);
 }
}
/* function definition for INLINE-FUNCTION                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3724inline_function(cl_narg narg, cl_object v1fname, cl_object v2arg_types, cl_object v3return_type, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[39]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[39]);
 {
  cl_object v4return_host_type;
  va_list args; va_start(args,v3return_type);
  {
   int i = 3;
   if (i >= narg) {
    v4return_host_type = VV[42];
   } else {
    i++;
    v4return_host_type = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[43]))->cfun.entry(1, v1fname) /*  INLINE-POSSIBLE */)){
   goto L3;
  }
  if (ecl_gethash_safe(v1fname,ecl_cmp_symbol_value(cl_env_copy,VV[44]),ECL_NIL)!=ECL_NIL) {
   goto L3;
  }
  {
   cl_object v5ii;
   v5ii = L3728get_inline_info(v1fname, v2arg_types, v3return_type, v4return_host_type);
   value0 = v5ii;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for APPLY-INLINE-INFO                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3725apply_inline_info(cl_object v1ii, cl_object v2inlined_locs)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3arg_types;
  cl_object v4out_host_type;
  cl_object v5side_effects_p;
  cl_object v6fun;
  cl_object v7one_liner;
  v3arg_types = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(1, v1ii) /*  INLINE-INFO-ARG-TYPES */;
  v4out_host_type = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, v1ii) /*  INLINE-INFO-RETURN-HOST-TYPE */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[24]))->cfun.entry(1, v1ii) /*  INLINE-INFO-NAME */;
  v5side_effects_p = (cl_env_copy->function=ecl_fdefinition(VV[47]))->cfun.entry(1, T0) /*  FUNCTION-MAY-HAVE-SIDE-EFFECTS */;
  v6fun = (cl_env_copy->function=ecl_fdefinition(VV[10]))->cfun.entry(1, v1ii) /*  INLINE-INFO-EXPANSION */;
  v7one_liner = (cl_env_copy->function=ecl_fdefinition(VV[7]))->cfun.entry(1, v1ii) /*  INLINE-INFO-ONE-LINER */;
  T0 = ecl_list1(v4out_host_type);
  value0 = L3733produce_inline_loc(v2inlined_locs, v3arg_types, T0, v6fun, v5side_effects_p, v7one_liner);
  return value0;
 }
}
static cl_object L3725apply_inline_info_va(cl_narg narg, cl_object v8ii, cl_object v9inlined_locs, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[40]);
 {
  return L3725apply_inline_info(v8ii, v9inlined_locs);
 }
}
/* function definition for CHOOSE-INLINE-INFO                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3727choose_inline_info(cl_object v1ia, cl_object v2ib, cl_object v3return_type, cl_object v4return_host_type)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if ((v4return_host_type)==(VV[42])) {
  goto L2;
 }
 if ((v4return_host_type)==(ECL_SYM("VOID",1424))) {
  goto L2;
 }
 {
  cl_object v5info_type;
  v5info_type = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, v2ib) /*  INLINE-INFO-RETURN-HOST-TYPE */;
  if ((v4return_host_type)==(v5info_type)) {
   goto L2;
  }
  if ((v5info_type)==(VV[51])) {
   goto L2;
  }
 }
 value0 = v1ia;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!(v1ia==ECL_NIL)){
  goto L8;
 }
 value0 = v2ib;
 cl_env_copy->nvalues = 1;
 return value0;
L8:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(1, v1ia) /*  INLINE-INFO-ARG-TYPES */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(1, v2ib) /*  INLINE-INFO-ARG-TYPES */;
 if (!(ecl_equal(T0,T1))){
  goto L10;
 }
 value0 = v1ia;
 cl_env_copy->nvalues = 1;
 return value0;
L10:;
 {
  cl_object v5;
  v5 = ecl_make_cfun_va((cl_objectfn)LC3726__lambda67_va,ECL_NIL,Cblock,2);
  T0 = v5;
 }
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(1, v1ia) /*  INLINE-INFO-ARG-TYPES */;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(1, v2ib) /*  INLINE-INFO-ARG-TYPES */;
 if (Null(cl_every(3, T0, T1, T2))){
  goto L12;
 }
 value0 = v2ib;
 cl_env_copy->nvalues = 1;
 return value0;
L12:;
 value0 = v1ia;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3727choose_inline_info_va(cl_narg narg, cl_object v5ia, cl_object v6ib, cl_object v7return_type, cl_object v8return_host_type, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[50]);
 {
  return L3727choose_inline_info(v5ia, v6ib, v7return_type, v8return_host_type);
 }
}
/* function definition for GET-INLINE-INFO                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3728get_inline_info(cl_object v1fname, cl_object v2types, cl_object v3return_type, cl_object v4return_host_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5output;
  v5output = ECL_NIL;
  if ((cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(0) /*  SAFE-COMPILE */!=ECL_NIL) {
   goto L3;
  }
  {
   cl_object v6;
   v6 = (cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(2, v1fname, VV[58]) /*  INLINE-INFORMATION */;
   goto L8;
L7:;
   {
    cl_object v7x;
    v7x = ecl_car(v6);
    {
     cl_object v8other;
     v8other = L3731inline_type_matches(v7x, v2types, v3return_type);
     if (Null(v8other)){
      goto L12;
     }
     v5output = L3727choose_inline_info(v5output, v8other, v3return_type, v4return_host_type);
    }
L12:;
   }
   v6 = ecl_cdr(v6);
L8:;
   if (Null(v6)){
    goto L18;
   }
   goto L7;
L18:;
  }
L3:;
  {
   cl_object v6;
   v6 = (cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(2, v1fname, VV[60]) /*  INLINE-INFORMATION */;
   goto L24;
L23:;
   {
    cl_object v7x;
    v7x = ecl_car(v6);
    {
     cl_object v8other;
     v8other = L3731inline_type_matches(v7x, v2types, v3return_type);
     if (Null(v8other)){
      goto L28;
     }
     v5output = L3727choose_inline_info(v5output, v8other, v3return_type, v4return_host_type);
    }
L28:;
   }
   v6 = ecl_cdr(v6);
L24:;
   if (Null(v6)){
    goto L34;
   }
   goto L23;
L34:;
  }
  value0 = v5output;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for TO-FIXNUM-FLOAT-TYPE                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3729to_fixnum_float_type(cl_object v1type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = VV[62];
  goto L5;
L4:;
  {
   cl_object v3i;
   v3i = ecl_car(v2);
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[53]))->cfun.entry(3, v3i, v1type, ecl_cmp_symbol_value(cl_env_copy,VV[54])) /*  TYPE>= */)){
    goto L9;
   }
   value0 = v3i;
   cl_env_copy->nvalues = 1;
   return value0;
L9:;
  }
  v2 = ecl_cdr(v2);
L5:;
  if (Null(v2)){
   goto L13;
  }
  goto L4;
L13:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3729to_fixnum_float_type_va(cl_narg narg, cl_object v3type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[61]);
 {
  return L3729to_fixnum_float_type(v3type);
 }
}
/* function definition for MAXIMUM-FLOAT-TYPE                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3730maximum_float_type(cl_object v1t1, cl_object v2t2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(v1t1==ECL_NIL)){
  goto L6;
 }
 value0 = v2t2;
 goto L4;
L6:;
 value0 = ECL_NIL;
 goto L4;
L4:;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 if ((v1t1)==(ECL_SYM("LONG-FLOAT",510))) {
  goto L12;
 }
 if (!((v2t2)==(ECL_SYM("LONG-FLOAT",510)))){
  goto L10;
 }
 goto L11;
L12:;
L11:;
 value0 = ECL_SYM("LONG-FLOAT",510);
 goto L8;
L10:;
 value0 = ECL_NIL;
 goto L8;
L8:;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 if ((v1t1)==(ECL_SYM("DOUBLE-FLOAT",317))) {
  goto L18;
 }
 if (!((v2t2)==(ECL_SYM("DOUBLE-FLOAT",317)))){
  goto L16;
 }
 goto L17;
L18:;
L17:;
 value0 = ECL_SYM("DOUBLE-FLOAT",317);
 goto L14;
L16:;
 value0 = ECL_NIL;
 goto L14;
L14:;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 if ((v1t1)==(ECL_SYM("SINGLE-FLOAT",781))) {
  goto L24;
 }
 if (!((v2t2)==(ECL_SYM("SINGLE-FLOAT",781)))){
  goto L22;
 }
 goto L23;
L24:;
L23:;
 value0 = ECL_SYM("SINGLE-FLOAT",781);
 goto L20;
L22:;
 value0 = ECL_NIL;
 goto L20;
L20:;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 value0 = ECL_SYM("FIXNUM",374);
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3730maximum_float_type_va(cl_narg narg, cl_object v3t1, cl_object v4t2, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[64]);
 {
  return L3730maximum_float_type(v3t1, v4t2);
 }
}
/* function definition for INLINE-TYPE-MATCHES                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3731inline_type_matches(cl_object v1inline_info, cl_object v2arg_types, cl_object v3return_type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if ((cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v1inline_info) /*  INLINE-INFO-MULTIPLE-VALUES */!=ECL_NIL) {
  goto L2;
 }
 {
  cl_object v4;
  v4 = ecl_cmp_symbol_value(cl_env_copy,VV[67]);
  if (!((v4)==(VV[69]))){
   goto L9;
  }
  goto L6;
L9:;
  goto L7;
L7:;
  if (!((v4)==(VV[70]))){
   goto L2;
  }
  goto L3;
L6:;
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 {
  cl_object v4rts;
  cl_object v5number_max;
  v4rts = ECL_NIL;
  v5number_max = ECL_NIL;
  {
   cl_object v6arg_types;
   cl_object v7types;
   v6arg_types = v2arg_types;
   v7types = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(1, v1inline_info) /*  INLINE-INFO-ARG-TYPES */;
   goto L19;
L18:;
   {
    cl_object v8arg_type;
    cl_object v9type;
    v8arg_type = ecl_car(v6arg_types);
    v9type = ecl_car(v7types);
    if (!((v9type)==(VV[72]))){
     goto L24;
    }
    {
     cl_object v10new_type;
     v10new_type = L3729to_fixnum_float_type(v8arg_type);
     if (v10new_type!=ECL_NIL) {
      goto L27;
     }
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     return value0;
L27:;
     v4rts = CONS(v10new_type,v4rts);
     v5number_max = L3730maximum_float_type(v5number_max, v10new_type);
     goto L21;
    }
L24:;
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[53]))->cfun.entry(3, v9type, v8arg_type, ecl_cmp_symbol_value(cl_env_copy,VV[54])) /*  TYPE>= */)){
     goto L32;
    }
    v4rts = CONS(v9type,v4rts);
    goto L21;
L32:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
   }
L21:;
   v6arg_types = ecl_cdr(v6arg_types);
   v7types = ecl_cdr(v7types);
L19:;
   if (ecl_endp(v6arg_types)) {
    goto L39;
   }
   if (ecl_endp(v7types)) {
    goto L39;
   }
   goto L18;
L39:;
   if (v6arg_types!=ECL_NIL) {
    goto L43;
   }
   if (Null(v7types)){
    goto L14;
   }
   goto L42;
L43:;
L42:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L14:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, v1inline_info) /*  INLINE-INFO-RETURN-HOST-TYPE */;
  if ((T0)==(VV[51])) {
   goto L47;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[14]))->cfun.entry(1, v1inline_info) /*  INLINE-INFO-EXACT-RETURN-TYPE */;
  if (T0==ECL_NIL) {
   goto L47;
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[73]))->cfun.entry(0) /*  POLICY-ASSUME-RIGHT-TYPE */)){
   goto L45;
  }
  {
   cl_object v6inline_return_type;
   v6inline_return_type = (cl_env_copy->function=ecl_fdefinition(VV[16]))->cfun.entry(1, v1inline_info) /*  INLINE-INFO-RETURN-TYPE */;
   if (Null(v5number_max)){
    goto L52;
   }
   if (!((v5number_max)==(ECL_SYM("FIXNUM",374)))){
    goto L56;
   }
   v5number_max = ECL_SYM("INTEGER",439);
   goto L55;
L56:;
L55:;
   if (Null(v5number_max)){
    goto L45;
   }
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[53]))->cfun.entry(3, v6inline_return_type, v5number_max, ecl_cmp_symbol_value(cl_env_copy,VV[54])) /*  TYPE>= */)){
    goto L45;
   }
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[53]))->cfun.entry(3, v5number_max, v3return_type, ecl_cmp_symbol_value(cl_env_copy,VV[54])) /*  TYPE>= */)){
    goto L45;
   }
   goto L46;
L52:;
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[53]))->cfun.entry(3, v6inline_return_type, v3return_type, ecl_cmp_symbol_value(cl_env_copy,VV[54])) /*  TYPE>= */)){
    goto L45;
   }
   goto L46;
  }
L47:;
L46:;
  {
   cl_object v6inline_info;
   v6inline_info = cl_copy_structure(v1inline_info);
   {
    cl_object v7;
    v7 = cl_nreverse(v4rts);
    ecl_structure_set(v6inline_info,VV[1],(cl_fixnum)(3),v7);
   }
   value0 = v6inline_info;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L45:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3731inline_type_matches_va(cl_narg narg, cl_object v7inline_info, cl_object v8arg_types, cl_object v9return_type, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[59]);
 {
  return L3731inline_type_matches(v7inline_info, v8arg_types, v9return_type);
 }
}
/* function definition for PRODUCE-INLINE-LOC                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3733produce_inline_loc(cl_object v1inlined_arguments, cl_object v2arg_types, cl_object v3output_host_type, cl_object v4c_expression, cl_object v5side_effects, cl_object v6one_liner)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v7args_to_be_saved;
  cl_object v8coerced_arguments;
  v7args_to_be_saved = ECL_NIL;
  v8coerced_arguments = ECL_NIL;
  {
   cl_fixnum v9;
   v9 = ecl_length(v4c_expression);
   if (!((v9)>((cl_fixnum)(1)))){
    goto L4;
   }
  }
  {
   ecl_character v9;
   v9 = ecl_char(v4c_expression,(cl_fixnum)(0));
   if (!((ECL_CODE_CHAR(v9))==(ECL_CODE_CHAR(64)))){
    goto L4;
   }
  }
  {
   cl_object v9ndx;
   v9ndx = ecl_make_int8_t(1);
   goto L10;
L9:;
   {
    cl_object v10c;
    v10c = cl_char(v4c_expression, v9ndx);
    if (!((v10c)==(ECL_CODE_CHAR(59)))){
     goto L14;
    }
    T0 = ecl_one_plus(v9ndx);
    v4c_expression = cl_subseq(2, v4c_expression, T0);
    goto L4;
L14:;
    if (ecl_alphanumericp(ECL_CHAR_CODE(v10c))) {
     goto L18;
    }
    v7args_to_be_saved = ECL_NIL;
    goto L4;
L18:;
    {
     cl_fixnum v11;
     v11 = ECL_CHAR_CODE(v10c);
     {
      cl_fixnum v12;
      v12 = (ecl_character)(48);
      T0 = ecl_minus(ecl_make_fixnum(v11),ecl_make_fixnum(v12));
      v7args_to_be_saved = CONS(T0,v7args_to_be_saved);
     }
    }
   }
   v9ndx = ecl_one_plus(v9ndx);
L10:;
   {
    cl_fixnum v10;
    v10 = ecl_length(v4c_expression);
    if (ecl_greatereq(v9ndx,ecl_make_fixnum(v10))) {
     goto L25;
    }
   }
   goto L9;
L25:;
  }
L4:;
  v8coerced_arguments = (cl_env_copy->function=ecl_fdefinition(VV[75]))->cfun.entry(3, v1inlined_arguments, v2arg_types, v7args_to_be_saved) /*  COERCE-LOCS */;
  if (!(v3output_host_type==ECL_NIL)){
   goto L29;
  }
  if (Null(v5side_effects)){
   goto L32;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[76]))->cfun.entry(0) /*  WT-NL    */;
  (cl_env_copy->function=ecl_fdefinition(VV[77]))->cfun.entry(5, v3output_host_type, v4c_expression, v8coerced_arguments, ECL_T, ECL_NIL) /*  WT-C-INLINE-LOC */;
  if (Null(v6one_liner)){
   goto L31;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, VV[79]) /*  WT */;
  goto L31;
L32:;
  (cl_env_copy->function=ecl_fdefinition(VV[80]))->cfun.entry(2, VV[81], v4c_expression) /*  CMPNOTE */;
L31:;
  (cl_env_copy->function=ecl_fdefinition(VV[76]))->cfun.entry(1, VV[82]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[76]))->cfun.entry(1, VV[83]) /*  WT-NL */;
  value0 = VV[70];
  cl_env_copy->nvalues = 1;
  return value0;
L29:;
  if (Null(v6one_liner)){
   goto L39;
  }
  if (!(ecl_equalp(v3output_host_type,VV[84]))){
   goto L42;
  }
  T0 = ECL_SYM("VALUES",899);
  goto L41;
L42:;
  T0 = ECL_NIL;
L41:;
  value0 = cl_list(6, ECL_SYM("C-INLINE",2106), v3output_host_type, v4c_expression, v8coerced_arguments, v5side_effects, T0);
  return value0;
L39:;
  if (!(ecl_equalp(v3output_host_type,VV[84]))){
   goto L44;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[77]))->cfun.entry(5, v3output_host_type, v4c_expression, v8coerced_arguments, v5side_effects, ECL_SYM("VALUES",899)) /*  WT-C-INLINE-LOC */;
  value0 = VV[69];
  cl_env_copy->nvalues = 1;
  return value0;
L44:;
  {
   cl_object v9;
   v9 = ecl_make_cfun_va((cl_objectfn)LC3732make_output_var_va,ECL_NIL,Cblock,1);
   (cl_env_copy->function=ecl_fdefinition(VV[90]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
   {
    cl_object v10output_vars;
    {
     cl_object v11;
     cl_object v12;
     cl_object v13;
     {
      cl_object v14;
      v14 = v3output_host_type;
      if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v11 = v14;
     }
     v12 = ECL_NIL;
     v13 = v11;
     {
      cl_object v14;
      cl_object v15;
      v14 = ecl_list1(ECL_NIL);
      v15 = v14;
L56:;
      if (!(ecl_endp(v13))){
       goto L58;
      }
      goto L57;
L58:;
      v12 = ECL_CONS_CAR(v13);
      {
       cl_object v16;
       v16 = ECL_CONS_CDR(v13);
       if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v13 = v16;
      }
      {
       cl_object v16;
       v16 = v15;
       if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v16;
      }
      T1 = ecl_function_dispatch(cl_env_copy,v9)(1, v12);
      v15 = ecl_list1(T1);
      (ECL_CONS_CDR(T0)=v15,T0);
      goto L56;
L57:;
      v10output_vars = ecl_cdr(v14);
      goto L48;
     }
    }
L48:;
    (cl_env_copy->function=ecl_fdefinition(VV[77]))->cfun.entry(5, v3output_host_type, v4c_expression, v8coerced_arguments, v5side_effects, v10output_vars) /*  WT-C-INLINE-LOC */;
    {
     cl_fixnum v11;
     v11 = ecl_length(v10output_vars);
     if (!((v11)==((cl_fixnum)(1)))){
      goto L75;
     }
    }
    value0 = ecl_car(v10output_vars);
    cl_env_copy->nvalues = 1;
    return value0;
L75:;
    {
     cl_object v11;
     cl_object v12v;
     cl_object v13;
     {
      cl_object v14;
      v14 = v10output_vars;
      if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v11 = v14;
     }
     v12v = ECL_NIL;
     v13 = v11;
     {
      cl_object v14i;
      v14i = ecl_make_int8_t(0);
      if (!(ecl_endp(v13))){
       goto L86;
      }
      goto L85;
L86:;
      v12v = ECL_CONS_CAR(v13);
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v13);
       if (ecl_unlikely(!ECL_LISTP(v15))) FEtype_error_list(v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v13 = v15;
      }
L84:;
      T0 = cl_list(2, VV[92], v14i);
      (cl_env_copy->function=ecl_fdefinition(VV[91]))->cfun.entry(2, T0, v12v) /*  SET-LOC */;
      if (!(ecl_endp(v13))){
       goto L95;
      }
      goto L85;
L95:;
      v12v = ECL_CONS_CAR(v13);
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v13);
       if (ecl_unlikely(!ECL_LISTP(v15))) FEtype_error_list(v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v13 = v15;
      }
      v14i = ecl_one_plus(v14i);
      goto L84;
L85:;
     }
    }
    {
     cl_fixnum v11;
     v11 = ecl_length(v10output_vars);
     (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(3, VV[94], ecl_make_fixnum(v11), VV[79]) /*  WT */;
    }
    value0 = VV[69];
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
static cl_object L3733produce_inline_loc_va(cl_narg narg, cl_object v11inlined_arguments, cl_object v12arg_types, cl_object v13output_host_type, cl_object v14c_expression, cl_object v15side_effects, cl_object v16one_liner, ...)
{
 if (ecl_unlikely(narg!=6)) FEwrong_num_arguments(VV[48]);
 {
  return L3733produce_inline_loc(v11inlined_arguments, v12arg_types, v13output_host_type, v14c_expression, v15side_effects, v16one_liner);
 }
}
/* function definition for NEGATE-ARGUMENT                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3734negate_argument(cl_object v1argument, cl_object v2dest_loc)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3inlined_arg;
  cl_object v4host_type;
  v3inlined_arg = (cl_env_copy->function=ecl_fdefinition(VV[97]))->cfun.entry(2, v1argument, ECL_NIL) /*  EMIT-INLINE-FORM */;
  v4host_type = (cl_env_copy->function=ecl_fdefinition(VV[98]))->cfun.entry(1, v3inlined_arg) /*  LOC-HOST-TYPE */;
  T0 = ecl_fdefinition(VV[48]);
  T1 = ecl_list1(v3inlined_arg);
  T3 = (cl_env_copy->function=ecl_fdefinition(VV[98]))->cfun.entry(1, v2dest_loc) /*  LOC-HOST-TYPE */;
  if (!((T3)==(VV[51]))){
   goto L6;
  }
  if (!((v4host_type)==(VV[51]))){
   goto L8;
  }
  T2 = VV[99];
  goto L5;
L8:;
  if (!((v4host_type)==(ECL_SYM("OBJECT",1315)))){
   goto L10;
  }
  T2 = VV[100];
  goto L5;
L10:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  if (!((v4host_type)==(VV[51]))){
   goto L12;
  }
  T2 = VV[101];
  goto L5;
L12:;
  if (!((v4host_type)==(ECL_SYM("OBJECT",1315)))){
   goto L14;
  }
  T2 = VV[102];
  goto L5;
L14:;
  value0 = ecl_cmp_symbol_value(cl_env_copy,VV[103]);
  cl_env_copy->nvalues = 1;
  return value0;
L5:;
  value0 = cl_apply(3, T0, T1, T2);
  return value0;
 }
}
static cl_object L3734negate_argument_va(cl_narg narg, cl_object v5argument, cl_object v6dest_loc, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[96]);
 {
  return L3734negate_argument(v5argument, v6dest_loc);
 }
}
/* local function LAMBDA67                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3726__lambda67(cl_object v1t1, cl_object v2t2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[53]))->cfun.entry(3, v1t1, v2t2, ecl_cmp_symbol_value(cl_env_copy,VV[54])) /*  TYPE>= */;
 return value0;
}
static cl_object LC3726__lambda67_va(cl_narg narg, cl_object v3t1, cl_object v4t2, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[52]);
 {
  return LC3726__lambda67(v3t1, v4t2);
 }
}
/* local function MAKE-OUTPUT-VAR                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3732make_output_var(cl_object v1type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2var;
  v2var = (cl_env_copy->function=ecl_fdefinition(VV[86]))->cfun.entry(2, VV[87], v1type) /*  MAKE-LCL-VAR */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v1type) /*  HOST-TYPE->C-NAME */;
  (cl_env_copy->function=ecl_fdefinition(VV[76]))->cfun.entry(4, T0, VV[89], v2var, VV[79]) /*  WT-NL */;
  value0 = v2var;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC3732make_output_var_va(cl_narg narg, cl_object v3type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[85]);
 {
  return LC3732make_output_var(v3type);
 }
}
#include "cmp/cmpc-fun-inl.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclFm5N8QifhQYq9_O0Y0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPBACKEND-CXX;CMPC-FUN-INL.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclFm5N8QifhQYq9_O0Y0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  si_define_structure(VV[1], _ecl_static_0, ECL_NIL, ECL_NIL, VVtemp[1], VVtemp[2], VV[2], ECL_NIL, ECL_NIL, ECL_NIL, VVtemp[3], ecl_make_int8_t(9), ECL_NIL, ECL_NIL, VV[3]);
  VV[5]=cl_find_class(1, VV[1]);
  ecl_cmp_defun(VV[105]);                         /*  MAKE-INLINE-INFO        */
  {
   cl_object v1package;
   v1package = cl_symbol_package(VV[7]);
   if (Null(v1package)){
    goto L9;
   }
   if (Null(si_package_locked_p(v1package))){
    goto L9;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L9;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[4], VVtemp[5], VVtemp[6], ECL_SYM("PACKAGE",1321), v1package);
  }
L9:;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC3712__lambda2_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  si_put_sysprop(VV[7], VV[8], T0);
  {
   cl_object v2package;
   v2package = cl_symbol_package(VV[10]);
   if (Null(v2package)){
    goto L17;
   }
   if (Null(si_package_locked_p(v2package))){
    goto L17;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L17;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[4], VVtemp[5], VVtemp[7], ECL_SYM("PACKAGE",1321), v2package);
  }
L17:;
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC3713__lambda7_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  si_put_sysprop(VV[10], VV[8], T0);
  {
   cl_object v3package;
   v3package = cl_symbol_package(VV[12]);
   if (Null(v3package)){
    goto L25;
   }
   if (Null(si_package_locked_p(v3package))){
    goto L25;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L25;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[4], VVtemp[5], VVtemp[8], ECL_SYM("PACKAGE",1321), v3package);
  }
L25:;
  {
   cl_object volatile v4;
   v4 = ecl_make_cfun_va((cl_objectfn)LC3714__lambda12_va,ECL_NIL,Cblock,2);
   T0 = v4;
  }
  si_put_sysprop(VV[12], VV[8], T0);
  {
   cl_object v4package;
   v4package = cl_symbol_package(VV[14]);
   if (Null(v4package)){
    goto L33;
   }
   if (Null(si_package_locked_p(v4package))){
    goto L33;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L33;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[4], VVtemp[5], VVtemp[9], ECL_SYM("PACKAGE",1321), v4package);
  }
L33:;
  {
   cl_object volatile v5;
   v5 = ecl_make_cfun_va((cl_objectfn)LC3715__lambda17_va,ECL_NIL,Cblock,2);
   T0 = v5;
  }
  si_put_sysprop(VV[14], VV[8], T0);
  {
   cl_object v5package;
   v5package = cl_symbol_package(VV[16]);
   if (Null(v5package)){
    goto L41;
   }
   if (Null(si_package_locked_p(v5package))){
    goto L41;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L41;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[4], VVtemp[5], VVtemp[10], ECL_SYM("PACKAGE",1321), v5package);
  }
L41:;
  {
   cl_object volatile v6;
   v6 = ecl_make_cfun_va((cl_objectfn)LC3716__lambda22_va,ECL_NIL,Cblock,2);
   T0 = v6;
  }
  si_put_sysprop(VV[16], VV[8], T0);
  {
   cl_object v6package;
   v6package = cl_symbol_package(VV[18]);
   if (Null(v6package)){
    goto L49;
   }
   if (Null(si_package_locked_p(v6package))){
    goto L49;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L49;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[4], VVtemp[5], VVtemp[11], ECL_SYM("PACKAGE",1321), v6package);
  }
L49:;
  {
   cl_object volatile v7;
   v7 = ecl_make_cfun_va((cl_objectfn)LC3717__lambda27_va,ECL_NIL,Cblock,2);
   T0 = v7;
  }
  si_put_sysprop(VV[18], VV[8], T0);
  {
   cl_object v7package;
   v7package = cl_symbol_package(VV[20]);
   if (Null(v7package)){
    goto L57;
   }
   if (Null(si_package_locked_p(v7package))){
    goto L57;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L57;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[4], VVtemp[5], VVtemp[12], ECL_SYM("PACKAGE",1321), v7package);
  }
L57:;
  {
   cl_object volatile v8;
   v8 = ecl_make_cfun_va((cl_objectfn)LC3718__lambda32_va,ECL_NIL,Cblock,2);
   T0 = v8;
  }
  si_put_sysprop(VV[20], VV[8], T0);
  {
   cl_object v8package;
   v8package = cl_symbol_package(VV[22]);
   if (Null(v8package)){
    goto L65;
   }
   if (Null(si_package_locked_p(v8package))){
    goto L65;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L65;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[4], VVtemp[5], VVtemp[13], ECL_SYM("PACKAGE",1321), v8package);
  }
L65:;
  {
   cl_object volatile v9;
   v9 = ecl_make_cfun_va((cl_objectfn)LC3719__lambda37_va,ECL_NIL,Cblock,2);
   T0 = v9;
  }
  si_put_sysprop(VV[22], VV[8], T0);
  {
   cl_object v9package;
   v9package = cl_symbol_package(VV[24]);
   if (Null(v9package)){
    goto L73;
   }
   if (Null(si_package_locked_p(v9package))){
    goto L73;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L73;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[4], VVtemp[5], VVtemp[14], ECL_SYM("PACKAGE",1321), v9package);
  }
L73:;
  {
   cl_object volatile v10;
   v10 = ecl_make_cfun_va((cl_objectfn)LC3720__lambda42_va,ECL_NIL,Cblock,2);
   T0 = v10;
  }
  si_put_sysprop(VV[24], VV[8], T0);
  ecl_cmp_defmacro(VV[106]);                      /*  DEFINE-C-INLINER        */
  ecl_cmp_defun(VV[107]);                         /*  APPLY-INLINER           */
  ecl_cmp_defun(VV[108]);                         /*  DEFAULT-C-INLINER       */
  ecl_cmp_defun(VV[109]);                         /*  INLINE-FUNCTION         */
  ecl_cmp_defun(VV[110]);                         /*  APPLY-INLINE-INFO       */
  ecl_cmp_defun(VV[111]);                         /*  CHOOSE-INLINE-INFO      */
  (void)0; /* No entry created for GET-INLINE-INFO */
  ecl_cmp_defun(VV[112]);                         /*  TO-FIXNUM-FLOAT-TYPE    */
  ecl_cmp_defun(VV[113]);                         /*  MAXIMUM-FLOAT-TYPE      */
  ecl_cmp_defun(VV[114]);                         /*  INLINE-TYPE-MATCHES     */
  ecl_cmp_defun(VV[115]);                         /*  PRODUCE-INLINE-LOC      */
  ecl_cmp_defun(VV[116]);                         /*  NEGATE-ARGUMENT         */
 }
}
