/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpbackend-cxx/cmpc-wt.lsp      */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpc-wt.eclh"
/* function definition for WT1                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3671wt1(cl_object v1form)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (floatp(v1form)) {
  goto L2;
 }
 if (ECL_FIXNUMP(v1form)||ECL_BIGNUMP(v1form)) {
  goto L6;
 }
 if (ECL_STRINGP(v1form)) {
  goto L6;
 }
 if (!(ECL_CHARACTERP(v1form))){
  goto L4;
 }
 goto L5;
L6:;
L5:;
 value0 = ecl_princ(v1form,ecl_cmp_symbol_value(cl_env_copy,VV[1]));
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 if (Null(si_of_class_p(2, v1form, VV[2]))){
  goto L9;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[3]))->cfun.entry(1, v1form) /*  WT-VAR */;
 return value0;
L9:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, v1form) /*  WT-LOC */;
 return value0;
L2:;
 if (Null(si_float_nan_p(v1form))){
  goto L11;
 }
 value0 = cl_format(2, ecl_cmp_symbol_value(cl_env_copy,VV[1]), VV[5]);
 return value0;
L11:;
 if (Null(si_float_infinity_p(v1form))){
  goto L13;
 }
 if (!(ecl_minusp(v1form))){
  goto L15;
 }
 value0 = cl_format(2, ecl_cmp_symbol_value(cl_env_copy,VV[1]), VV[6]);
 return value0;
L15:;
 value0 = cl_format(2, ecl_cmp_symbol_value(cl_env_copy,VV[1]), VV[7]);
 return value0;
L13:;
 if (!(ECL_SINGLE_FLOAT_P(v1form))){
  goto L17;
 }
 value0 = cl_format(3, ecl_cmp_symbol_value(cl_env_copy,VV[1]), VV[8], v1form);
 return value0;
L17:;
 if (!(ECL_DOUBLE_FLOAT_P(v1form))){
  goto L19;
 }
 value0 = cl_format(3, ecl_cmp_symbol_value(cl_env_copy,VV[1]), VV[9], v1form);
 return value0;
L19:;
 if (!(ECL_LONG_FLOAT_P(v1form))){
  goto L21;
 }
 value0 = cl_format(3, ecl_cmp_symbol_value(cl_env_copy,VV[1]), VV[10], v1form);
 return value0;
L21:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3671wt1_va(cl_narg narg, cl_object v2form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[0]);
 {
  return L3671wt1(v2form);
 }
}
/* function definition for WT-H1                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3672wt_h1(cl_object v1form)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,VV[1],ecl_cmp_symbol_value(cl_env_copy,VV[13])); /*  *COMPILER-OUTPUT1* */
 value0 = L3671wt1(v1form);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L3672wt_h1_va(cl_narg narg, cl_object v2form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[12]);
 {
  return L3672wt_h1(v2form);
 }
}
/* function definition for WT                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3673wt(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1forms;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1forms = cl_grab_rest_args(args);
  ecl_va_end(args);
  {
   cl_object v2;
   v2 = ecl_fdefinition(VV[0]);
   {
    cl_object v3;
    cl_object v4;
    cl_object v5;
    {
     cl_object v6;
     v6 = v1forms;
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v3 = v6;
    }
    v4 = ECL_NIL;
    v5 = v3;
L7:;
    if (!(ecl_endp(v5))){
     goto L9;
    }
    goto L8;
L9:;
    v4 = ECL_CONS_CAR(v5);
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v6;
    }
    ecl_function_dispatch(cl_env_copy,v2)(1, v4);
    goto L7;
L8:;
    value0 = v1forms;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for WT-H                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3674wt_h(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1forms;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1forms = cl_grab_rest_args(args);
  ecl_va_end(args);
  {
   cl_object v2;
   v2 = ecl_fdefinition(VV[12]);
   {
    cl_object v3;
    cl_object v4;
    cl_object v5;
    {
     cl_object v6;
     v6 = v1forms;
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v3 = v6;
    }
    v4 = ECL_NIL;
    v5 = v3;
L7:;
    if (!(ecl_endp(v5))){
     goto L9;
    }
    goto L8;
L9:;
    v4 = ECL_CONS_CAR(v5);
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v6;
    }
    ecl_function_dispatch(cl_env_copy,v2)(1, v4);
    goto L7;
L8:;
    value0 = v1forms;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for WT-NL-H                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3675wt_nl_h(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1forms;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1forms = cl_grab_rest_args(args);
  ecl_va_end(args);
  (ecl_terpri(ecl_cmp_symbol_value(cl_env_copy,VV[13])));
  {
   cl_object v2;
   v2 = ecl_fdefinition(VV[12]);
   {
    cl_object v3;
    cl_object v4;
    cl_object v5;
    {
     cl_object v6;
     v6 = v1forms;
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v3 = v6;
    }
    v4 = ECL_NIL;
    v5 = v3;
L8:;
    if (!(ecl_endp(v5))){
     goto L10;
    }
    goto L9;
L10:;
    v4 = ECL_CONS_CAR(v5);
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v6;
    }
    ecl_function_dispatch(cl_env_copy,v2)(1, v4);
    goto L8;
L9:;
    value0 = v1forms;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for PRINC-H                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3676princ_h(cl_object v1form)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_princ(v1form,ecl_cmp_symbol_value(cl_env_copy,VV[13]));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3676princ_h_va(cl_narg narg, cl_object v2form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[23]);
 {
  return L3676princ_h(v2form);
 }
}
/* function definition for WT-NL                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3677wt_nl(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1forms;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1forms = cl_grab_rest_args(args);
  ecl_va_end(args);
  L3679wt_nl_indent();
  {
   cl_object v2;
   v2 = ecl_fdefinition(VV[0]);
   {
    cl_object v3;
    cl_object v4;
    cl_object v5;
    {
     cl_object v6;
     v6 = v1forms;
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v3 = v6;
    }
    v4 = ECL_NIL;
    v5 = v3;
L8:;
    if (!(ecl_endp(v5))){
     goto L10;
    }
    goto L9;
L10:;
    v4 = ECL_CONS_CAR(v5);
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v6;
    }
    ecl_function_dispatch(cl_env_copy,v2)(1, v4);
    goto L8;
L9:;
    value0 = v1forms;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for WT-NL1                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3678wt_nl1(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1forms;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1forms = cl_grab_rest_args(args);
  ecl_va_end(args);
  L3671wt1(ECL_CODE_CHAR(10));
  {
   cl_object v2;
   v2 = ecl_fdefinition(VV[0]);
   {
    cl_object v3;
    cl_object v4;
    cl_object v5;
    {
     cl_object v6;
     v6 = v1forms;
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v3 = v6;
    }
    v4 = ECL_NIL;
    v5 = v3;
L8:;
    if (!(ecl_endp(v5))){
     goto L10;
    }
    goto L9;
L10:;
    v4 = ECL_CONS_CAR(v5);
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v6;
    }
    ecl_function_dispatch(cl_env_copy,v2)(1, v4);
    goto L8;
L9:;
    value0 = v1forms;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for WT-NL-INDENT                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3679wt_nl_indent()
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_cmp_symbol_value(cl_env_copy,VV[31]);
  T1 = v1;
  {
   cl_object v2;
   v2 = ((ecl_float_nan_p(ECL_SYM_VAL(cl_env_copy,VV[30])) || ecl_lowereq(ECL_SYM_VAL(cl_env_copy,VV[32]),ECL_SYM_VAL(cl_env_copy,VV[30])))?ECL_SYM_VAL(cl_env_copy,VV[32]):ECL_SYM_VAL(cl_env_copy,VV[30]));
   if (ecl_unlikely((ecl_fixnum(v2))>=(v1)->vector.dim))
           FEwrong_index(ECL_NIL,v1,-1,ecl_make_fixnum(ecl_fixnum(v2)),(v1)->vector.dim);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   T2 = v2;
  }
  T0 = ecl_aref_unsafe(T1,ecl_fixnum(T2));
 }
 value0 = L3671wt1(T0);
 return value0;
}
static cl_object L3679wt_nl_indent_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[26]);
 {
  return L3679wt_nl_indent();
 }
}
/* function definition for WT-OPEN-BRACE                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3680wt_open_brace()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 L3671wt1(ECL_CODE_CHAR(123));
 T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[32]),ecl_make_int8_t(1));
 ecl_cmp_setq(cl_env_copy,VV[32],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[32]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3680wt_open_brace_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[36]);
 {
  return L3680wt_open_brace();
 }
}
/* function definition for WT-NL-OPEN-BRACE                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3681wt_nl_open_brace()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 L3679wt_nl_indent();
 value0 = L3680wt_open_brace();
 return value0;
}
static cl_object L3681wt_nl_open_brace_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[38]);
 {
  return L3681wt_nl_open_brace();
 }
}
/* function definition for WT-NL-CLOSE-MANY-BRACES                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3682wt_nl_close_many_braces(cl_object v1final_value)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2diff;
  v2diff = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[32]),v1final_value);
  if (!(ecl_minusp(v2diff))){
   goto L3;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(2, ECL_SYM("FORMAT-CONTROL",1272), VV[42]) /*  BABOON */;
L3:;
  {
   cl_object v3;
   cl_object v4i;
   v3 = v2diff;
   v4i = ecl_make_int8_t(0);
L7:;
   if (!(ecl_greatereq(v4i,v3))){
    goto L9;
   }
   goto L8;
L9:;
   L3683wt_nl_close_brace();
   v4i = ecl_one_plus(v4i);
   goto L7;
L8:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3682wt_nl_close_many_braces_va(cl_narg narg, cl_object v5final_value, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[40]);
 {
  return L3682wt_nl_close_many_braces(v5final_value);
 }
}
/* function definition for WT-NL-CLOSE-BRACE                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3683wt_nl_close_brace()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ecl_plusp(ecl_cmp_symbol_value(cl_env_copy,VV[32])))){
  goto L2;
 }
 T0 = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[32]),ecl_make_int8_t(1));
 ecl_cmp_setq(cl_env_copy,VV[32],T0);
 L3679wt_nl_indent();
 value0 = L3671wt1(ECL_CODE_CHAR(125));
 return value0;
L2:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(2, ECL_SYM("FORMAT-CONTROL",1272), VV[42]) /*  BABOON */;
 return value0;
}
static cl_object L3683wt_nl_close_brace_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[43]);
 {
  return L3683wt_nl_close_brace();
 }
}
/* local function WITH-INDENTATION                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3684with_indentation(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  value0 = cl_listX(3, ECL_SYM("LET",479), VV[48], v3);
  return value0;
 }
}
static cl_object LC3684with_indentation_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[47]);
 {
  return LC3684with_indentation(v4, v5);
 }
}
/* function definition for WT-NL-GO                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3685wt_nl_go(cl_object v1label)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 L3679wt_nl_indent();
 value0 = L3686wt_go(v1label);
 return value0;
}
static cl_object L3685wt_nl_go_va(cl_narg narg, cl_object v2label, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[50]);
 {
  return L3685wt_nl_go(v2label);
 }
}
/* function definition for WT-GO                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3686wt_go(cl_object v1label)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_structure_set(v1label,VV[53],(cl_fixnum)(2),ECL_T);
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, v1label) /*  LABEL-ID */;
 value0 = L3673wt(3, VV[54], T0, VV[56]);
 return value0;
}
static cl_object L3686wt_go_va(cl_narg narg, cl_object v2label, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[51]);
 {
  return L3686wt_go(v2label);
 }
}
/* function definition for WT-LABEL                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3687wt_label(cl_object v1label)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v1label) /*  LABEL-USED-P */)){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, v1label) /*  LABEL-ID */;
 value0 = L3678wt_nl1(3, VV[60], T0, VV[61]);
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3687wt_label_va(cl_narg narg, cl_object v2label, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[58]);
 {
  return L3687wt_label(v2label);
 }
}
/* function definition for WT-FILTERED-COMMENT                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3688wt_filtered_comment(cl_object v1text, cl_object v2stream, cl_object v3single_line)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v3single_line)){
  goto L3;
 }
 cl_fresh_line(1, v2stream);
 ecl_princ(VV[64],v2stream);
 goto L2;
L3:;
 cl_format(2, v2stream, VV[65]);
L2:;
 {
  cl_fixnum v4l;
  {
   cl_object v5;
   {
    cl_fixnum v6;
    v6 = ecl_length(v1text);
    v5 = ecl_make_integer((v6)-1);
   }
   {
    bool v6;
    v6 = ECL_FIXNUMP(v5);
    if (ecl_unlikely(!(v6)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v5);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
   }
   v4l = ecl_fixnum(v5);
  }
  {
   cl_fixnum v5n;
   v5n = (cl_fixnum)(0);
   goto L13;
L12:;
   {
    cl_object v6c;
    cl_object v7code;
    v6c = ECL_CODE_CHAR(ecl_char(v1text,v5n));
    v7code = ecl_make_fixnum(ECL_CHAR_CODE(v6c));
    if ((v6c)==(ECL_CODE_CHAR(10))) {
     goto L20;
    }
    if (!((v6c)==(ECL_CODE_CHAR(9)))){
     goto L18;
    }
    goto L19;
L20:;
L19:;
    ecl_princ(v6c,v2stream);
    goto L15;
L18:;
    if ((ecl_fixnum(v7code))<((cl_fixnum)(32))) {
     goto L24;
    }
    if (!((ecl_fixnum(v7code))>((cl_fixnum)(127)))){
     goto L22;
    }
    goto L23;
L24:;
L23:;
    cl_format(3, v2stream, VV[66], v7code);
    goto L15;
L22:;
    if (!((ECL_CHAR_CODE(v6c))==((ecl_character)(42)))){
     goto L26;
    }
    T0 = ecl_make_integer((v5n)+1);
    T1 = ecl_elt(v1text,ecl_to_size(T0));
    if (!((ECL_CHAR_CODE(T1))==((ecl_character)(47)))){
     goto L26;
    }
    ecl_princ_char((ecl_character)(92),v2stream);
    goto L15;
L26:;
    ecl_princ(v6c,v2stream);
   }
L15:;
   v5n = (v5n)+1;
L13:;
   if (!((v5n)<(v4l))){
    goto L31;
   }
   goto L12;
L31:;
  }
  {
   ecl_character v5;
   v5 = ecl_char(v1text,v4l);
   ecl_princ(ECL_CODE_CHAR(v5),v2stream);
  }
 }
 value0 = cl_format(2, v2stream, VV[67]);
 return value0;
}
static cl_object L3688wt_filtered_comment_va(cl_narg narg, cl_object v4text, cl_object v5stream, cl_object v6single_line, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[63]);
 {
  return L3688wt_filtered_comment(v4text, v5stream, v6single_line);
 }
}
/* function definition for DO-WT-COMMENT                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3689do_wt_comment(cl_object v1message_or_format, cl_object v2args, cl_object v3single_line_p)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_SYMBOLP(v1message_or_format))){
  goto L5;
 }
 if (Null(cl_symbol_package(v1message_or_format))){
  goto L2;
 }
 goto L3;
L5:;
 goto L3;
L3:;
 if (!(ECL_STRINGP(v1message_or_format))){
  goto L8;
 }
 if (Null(v2args)){
  goto L10;
 }
 T1 = (ECL_SYM("FORMAT",389)->symbol.gfdef);
 T0 = cl_apply(4, T1, ECL_NIL, v1message_or_format, v2args);
 goto L7;
L10:;
 T0 = v1message_or_format;
 goto L7;
L8:;
 T0 = cl_princ_to_string(v1message_or_format);
L7:;
 value0 = L3688wt_filtered_comment(T0, ecl_cmp_symbol_value(cl_env_copy,VV[1]), v3single_line_p);
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3689do_wt_comment_va(cl_narg narg, cl_object v4message_or_format, cl_object v5args, cl_object v6single_line_p, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[69]);
 {
  return L3689do_wt_comment(v4message_or_format, v5args, v6single_line_p);
 }
}
/* function definition for WT-COMMENT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3690wt_comment(cl_narg narg, cl_object v1message, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[71]);
 {
  cl_object v2extra;
  ecl_va_list args; ecl_va_start(args,v1message,narg,1);
  v2extra = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = L3689do_wt_comment(v1message, v2extra, ECL_NIL);
  return value0;
 }
}
/* function definition for WT-COMMENT-NL                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3691wt_comment_nl(cl_narg narg, cl_object v1message, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[73]);
 {
  cl_object v2extra;
  ecl_va_list args; ecl_va_start(args,v1message,narg,1);
  v2extra = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = L3689do_wt_comment(v1message, v2extra, ECL_T);
  return value0;
 }
}
/* function definition for WT-FILTERED-DATA                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3692wt_filtered_data(cl_narg narg, cl_object v1string, cl_object v2stream, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[76]);
 {
  cl_object v3one_liner;
  cl_object v4external_format;
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L3692wt_filtered_datakeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v3one_liner = keyvars[0];
   if (Null(keyvars[3])) {
    v4external_format = ECL_SYM("UTF-8",1759);
   } else {
    v4external_format = keyvars[1];
   }
  }
  v1string = si_string_to_octets(5, v1string, ECL_SYM("EXTERNAL-FORMAT",1267), v4external_format, ECL_SYM("ELEMENT-TYPE",1255), ECL_SYM("BASE-CHAR",122));
  {
   cl_object v5;
   cl_object v6wt_data_column;
   v5 = ecl_make_fixnum(ecl_length(v1string));
   v6wt_data_column = ecl_make_int8_t(80);
   T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[75]),v5);
   ecl_cmp_setq(cl_env_copy,VV[75],T0);
   if (Null(v3one_liner)){
    goto L10;
   }
   T0 = VV[77];
   goto L9;
L10:;
   T0 = VV[78];
L9:;
   cl_format(2, v2stream, T0);
   {
    cl_object v7i;
    v7i = ecl_make_int8_t(0);
    goto L15;
L14:;
    v6wt_data_column = ecl_minus(v6wt_data_column,ecl_make_int8_t(1));
    if (!(ecl_lower(v6wt_data_column,ecl_make_int8_t(0)))){
     goto L19;
    }
    cl_format(2, v2stream, VV[79]);
    v6wt_data_column = ecl_make_int8_t(79);
L19:;
    {
     cl_object v8x;
     {
      cl_object v9;
      v9 = v1string;
      T0 = v9;
      {
       cl_object v10;
       v10 = v7i;
       if (ecl_unlikely((ecl_fixnum(v10))>=(v9)->vector.dim))
           FEwrong_index(ECL_NIL,v9,-1,ecl_make_fixnum(ecl_fixnum(v10)),(v9)->vector.dim);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T1 = v10;
      }
      v8x = ecl_aref_unsafe(T0,ecl_fixnum(T1));
     }
     T0 = cl_char_code(v8x);
     if ((ecl_fixnum(T0))<((cl_fixnum)(32))) {
      goto L33;
     }
     T0 = cl_char_code(v8x);
     if (!((ecl_fixnum(T0))>((cl_fixnum)(127)))){
      goto L31;
     }
     goto L32;
L33:;
L32:;
     if (!(((v8x)==ECL_CODE_CHAR((ecl_character)(10))))){
      goto L35;
     }
     ecl_princ(VV[80],v2stream);
     goto L23;
L35:;
     if (!(((v8x)==ECL_CODE_CHAR((ecl_character)(9))))){
      goto L37;
     }
     ecl_princ(VV[81],v2stream);
     goto L23;
L37:;
     T0 = cl_char_code(v8x);
     cl_format(3, v2stream, VV[82], T0);
     goto L23;
L31:;
     if (!(ecl_char_code(v8x)==ecl_char_code(ECL_CODE_CHAR(92)))){
      goto L39;
     }
     ecl_princ(VV[83],v2stream);
     goto L23;
L39:;
     if (!(ecl_char_code(v8x)==ecl_char_code(ECL_CODE_CHAR(34)))){
      goto L41;
     }
     ecl_princ(VV[84],v2stream);
     goto L23;
L41:;
     ecl_princ(v8x,v2stream);
    }
L23:;
    v7i = ecl_one_plus(v7i);
L15:;
    if (!(ecl_lower(v7i,v5))){
     goto L45;
    }
    goto L14;
L45:;
   }
   ecl_princ_char((ecl_character)(34),v2stream);
   value0 = v1string;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for C-FILTERED-STRING                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3693c_filtered_string(volatile cl_narg narg, cl_object volatile v1string, ...)
{
 cl_object T0;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[86]);
 {
  cl_object volatile v2args;
  ecl_va_list args; ecl_va_start(args,v1string,narg,1);
  v2args = cl_grab_rest_args(args);
  ecl_va_end(args);
  {
   volatile cl_object v3aux_stream;
   v3aux_stream = cl_make_string_output_stream(0);
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    volatile bool unwinding = FALSE;
    ecl_frame_ptr next_fr;
    {
     ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
     if (__ecl_frs_push_result!=0) {
       unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
     } else {
     T0 = ecl_fdefinition(VV[76]);
     cl_apply(6, T0, v1string, v3aux_stream, VV[87], ECL_T, v2args);
     cl_env_copy->values[0] = cl_get_output_stream_string(v3aux_stream);
     }
    }
    ecl_frs_pop(cl_env_copy);
    ecl_stack_frame_push_values(_ecl_inner_frame);
    cl_close(1, v3aux_stream);
    ecl_stack_frame_pop_values(_ecl_inner_frame);
    if (unwinding) ecl_unwind(cl_env_copy,next_fr);
    ecl_stack_frame_close(_ecl_inner_frame);
    return cl_env_copy->values[0];
   }
  }
 }
}
/* function definition for C-INLINE-SAFE-STRING                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3694c_inline_safe_string(cl_object v1constant_string)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_fixnum v3;
  cl_fixnum v4;
  cl_object v5c;
  cl_fixnum v6;
  cl_fixnum v7;
  {
   cl_object v8;
   v8 = v1constant_string;
   if (ecl_unlikely(!ECL_VECTORP(v8))) FEtype_error_vector(v8);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v2 = v8;
  }
  v3 = (cl_fixnum)(0);
  v4 = (cl_fixnum)(0);
  v5c = ECL_NIL;
  v6 = v3;
  v7 = v4;
  {
   cl_object v8;
   cl_object v9;
   v8 = ecl_list1(ECL_NIL);
   v9 = v8;
   v7 = ecl_length(v2);
L13:;
   if (!((v6)>=(v7))){
    goto L17;
   }
   goto L14;
L17:;
   {
    cl_object v10;
    v10 = v2;
    T1 = v10;
    {
     cl_fixnum v11;
     v11 = v6;
     if (ecl_unlikely((v11)>=(v10)->vector.dim))
           FEwrong_index(ECL_NIL,v10,-1,ecl_make_fixnum(v11),(v10)->vector.dim);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T2 = ecl_make_fixnum(v11);
    }
    v5c = ecl_aref_unsafe(T1,ecl_fixnum(T2));
   }
   {
    cl_object v10;
    v10 = ecl_make_integer((v6)+1);
    {
     bool v11;
     v11 = ECL_FIXNUMP(v10);
     if (ecl_unlikely(!(v11)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
    v6 = ecl_fixnum(v10);
   }
   if (!(((v5c)==ECL_CODE_CHAR((ecl_character)(35))))){
    goto L36;
   }
   goto L33;
L36:;
   goto L34;
L34:;
   if (!(((v5c)==ECL_CODE_CHAR((ecl_character)(64))))){
    goto L31;
   }
   goto L32;
L33:;
L32:;
   {
    cl_object v10;
    v10 = v9;
    if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T1 = v10;
   }
   v9 = ecl_list1(v5c);
   (ECL_CONS_CDR(T1)=v9,T1);
L31:;
   {
    cl_object v10;
    v10 = v9;
    if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T1 = v10;
   }
   v9 = ecl_list1(v5c);
   (ECL_CONS_CDR(T1)=v9,T1);
   goto L13;
L14:;
   T0 = ecl_cdr(v8);
   goto L2;
  }
 }
L2:;
 T1 = cl_concatenate(2, ECL_SYM("STRING",808), T0);
 value0 = L3693c_filtered_string(1, T1);
 return value0;
}
static cl_object L3694c_inline_safe_string_va(cl_narg narg, cl_object v2constant_string, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[89]);
 {
  return L3694c_inline_safe_string(v2constant_string);
 }
}
#include "cmp/cmpc-wt.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclJ2QtS0vr7c0n9_lOX0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPBACKEND-CXX;CMPC-WT.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclJ2QtS0vr7c0n9_lOX0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  ecl_cmp_defun(VV[96]);                          /*  WT1                     */
  ecl_cmp_defun(VV[97]);                          /*  WT-H1                   */
  ecl_cmp_defun(VV[98]);                          /*  WT                      */
  ecl_cmp_defun(VV[99]);                          /*  WT-H                    */
  ecl_cmp_defun(VV[100]);                         /*  WT-NL-H                 */
  ecl_cmp_defun(VV[101]);                         /*  PRINC-H                 */
  ecl_cmp_defun(VV[102]);                         /*  WT-NL                   */
  ecl_cmp_defun(VV[103]);                         /*  WT-NL1                  */
  si_Xmake_special(VV[30]);
  if (ecl_boundp(cl_env_copy,VV[30])) {
   goto L27;
  }
  T0 = ecl_make_int8_t(10);
  ecl_cmp_setq(cl_env_copy,VV[30],T0);
L27:;
  si_Xmake_special(VV[31]);
  if (ecl_boundp(cl_env_copy,VV[31])) {
   goto L34;
  }
  T0 = VVtemp[1];
  ecl_cmp_setq(cl_env_copy,VV[31],T0);
L34:;
  ecl_cmp_defun(VV[104]);                         /*  WT-NL-INDENT            */
  ecl_cmp_defun(VV[105]);                         /*  WT-OPEN-BRACE           */
  ecl_cmp_defun(VV[106]);                         /*  WT-NL-OPEN-BRACE        */
  ecl_cmp_defun(VV[107]);                         /*  WT-NL-CLOSE-MANY-BRACES */
  ecl_cmp_defun(VV[108]);                         /*  WT-NL-CLOSE-BRACE       */
  ecl_cmp_defmacro(VV[109]);                      /*  WITH-INDENTATION        */
  ecl_cmp_defun(VV[110]);                         /*  WT-NL-GO                */
  ecl_cmp_defun(VV[111]);                         /*  WT-GO                   */
  ecl_cmp_defun(VV[112]);                         /*  WT-LABEL                */
  ecl_cmp_defun(VV[113]);                         /*  WT-FILTERED-COMMENT     */
  ecl_cmp_defun(VV[114]);                         /*  DO-WT-COMMENT           */
  ecl_cmp_defun(VV[115]);                         /*  WT-COMMENT              */
  ecl_cmp_defun(VV[116]);                         /*  WT-COMMENT-NL           */
  si_Xmake_special(VV[75]);
  if (ecl_boundp(cl_env_copy,VV[75])) {
   goto L79;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[75],T0);
L79:;
  ecl_cmp_defun(VV[117]);                         /*  WT-FILTERED-DATA        */
  ecl_cmp_defun(VV[118]);                         /*  C-FILTERED-STRING       */
  ecl_cmp_defun(VV[119]);                         /*  C-INLINE-SAFE-STRING    */
 }
}
