/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpbackend-cxx/cmppass2-var.lsp */
#include <ecl/ecl-cmp.h>
#include "cmp/cmppass2-var.eclh"
/* function definition for C2LET-REPLACEABLE-VAR-REF-P                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3889c2let_replaceable_var_ref_p(cl_object v1var, cl_object v2form, cl_object v3rest_forms)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(1, v2form) /*  C1FORM-NAME */;
 if (!((T0)==(ECL_SYM("VARIABLE",901)))){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(1, v1var) /*  VAR-SET-NODES */;
 if (!(T0==ECL_NIL)){
  goto L2;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[3]))->cfun.entry(1, v1var) /*  LOCAL-VAR-P */)){
  goto L2;
 }
 {
  cl_object v4var1;
  {
   cl_object v5;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(1, v2form) /*  C1FORM-ARGS */;
   v5 = ecl_car(T0);
   T0 = si_of_class_p(2, v5, VV[6]);
   if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[6],v5);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v4var1 = v5;
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[3]))->cfun.entry(1, v4var1) /*  LOCAL-VAR-P */)){
   goto L9;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[7]))->cfun.entry(1, v1var) /*  UNBOXED-VAR-P */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[7]))->cfun.entry(1, v4var1) /*  UNBOXED-VAR-P */;
  if (!((T0)==(T1))){
   goto L9;
  }
  if ((cl_env_copy->function=ecl_fdefinition(VV[8]))->cfun.entry(2, v4var1, v3rest_forms) /*  VAR-CHANGED-IN-FORM-LIST */!=ECL_NIL) {
   goto L9;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(1, v1var) /*  VAR-NAME */;
  (cl_env_copy->function=ecl_fdefinition(VV[9]))->cfun.entry(2, VV[10], T0) /*  CMPDEBUG */;
  (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(2, v1var, v2form) /*  NSUBST-VAR */;
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L9:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3889c2let_replaceable_var_ref_p_va(cl_narg narg, cl_object v5var, cl_object v6form, cl_object v7rest_forms, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[0]);
 {
  return L3889c2let_replaceable_var_ref_p(v5var, v6form, v7rest_forms);
 }
}
/* function definition for LOCATIVE-TYPE-FROM-VAR-KIND                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3890locative_type_from_var_kind(cl_object v1kind)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3;
  v2 = v1kind;
  v3 = VV[15];
  T0 = ecl_assql(v2,v3);
 }
 value0 = ecl_cdr(T0);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3890locative_type_from_var_kind_va(cl_narg narg, cl_object v2kind, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[14]);
 {
  return L3890locative_type_from_var_kind(v2kind);
 }
}
/* function definition for BUILD-DEBUG-LEXICAL-ENV                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3891build_debug_lexical_env(cl_narg narg, cl_object v1var_locations, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[17]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[17]);
 {
  cl_object v2first;
  va_list args; va_start(args,v1var_locations);
  {
   int i = 1;
   if (i >= narg) {
    v2first = ECL_NIL;
   } else {
    i++;
    v2first = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v3filtered_locations;
   cl_object v4filtered_codes;
   v3filtered_locations = ECL_NIL;
   v4filtered_codes = ECL_NIL;
   {
    cl_object v5;
    cl_object v6var;
    cl_object v7;
    {
     cl_object v8;
     v8 = v1var_locations;
     if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v8;
    }
    v6var = ECL_NIL;
    v7 = v5;
    {
     cl_object v8name;
     v8name = ECL_NIL;
     {
      cl_object v9code;
      v9code = ECL_NIL;
      {
       cl_object v10loc;
       v10loc = ECL_NIL;
L13:;
       if (!(ecl_endp(v7))){
        goto L15;
       }
       goto L14;
L15:;
       v6var = ECL_CONS_CAR(v7);
       {
        cl_object v11;
        v11 = ECL_CONS_CDR(v7);
        if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v7 = v11;
       }
       T0 = cl_find_package(VV[20]);
       ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T0); /*  *PACKAGE*    */
       T0 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(1, v6var) /*  VAR-NAME */;
       v8name = cl_format(3, ECL_NIL, VV[21], T0);
       ecl_bds_unwind1(cl_env_copy);
       T0 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v6var) /*  VAR-KIND */;
       v9code = L3890locative_type_from_var_kind(T0);
       v10loc = (cl_env_copy->function=ecl_fdefinition(VV[23]))->cfun.entry(1, v6var) /*  VAR-LOC */;
       if (Null(v9code)){
        goto L29;
       }
       if (!(ECL_CONSP(v10loc))){
        goto L29;
       }
       T0 = ecl_car(v10loc);
       if (!((T0)==(VV[24]))){
        goto L29;
       }
       T0 = CONS(v8name,v9code);
       v4filtered_codes = CONS(T0,v4filtered_codes);
       v3filtered_locations = CONS(v10loc,v3filtered_locations);
L29:;
       goto L13;
L14:;
      }
     }
    }
   }
   if (Null(v4filtered_codes)){
    goto L37;
   }
   T0 = ECL_T;
   ecl_cmp_setq(cl_env_copy,VV[25],T0);
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, VV[27]) /*  WT-NL */;
   {
    cl_object v5;
    cl_object v6name;
    cl_object v7code;
    cl_object v8;
    {
     cl_object v9;
     v9 = v4filtered_codes;
     if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v9;
    }
    v6name = ECL_NIL;
    v7code = ECL_NIL;
    v8 = v5;
    {
     cl_object v9i;
     v9i = ecl_make_int8_t(0);
     if (!(ecl_endp(v8))){
      goto L52;
     }
     goto L51;
L52:;
     {
      cl_object v10;
      v10 = ECL_CONS_CAR(v8);
      v6name = ecl_car(v10);
      v10 = ecl_cdr(v10);
      v7code = v10;
     }
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v8);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v8 = v10;
     }
L50:;
     if (!(ecl_zerop(v9i))){
      goto L67;
     }
     T0 = VV[28];
     goto L66;
L67:;
     T0 = VV[29];
L66:;
     (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(5, T0, v6name, VV[30], v7code, VV[31]) /*  WT-NL */;
     if (!(ecl_endp(v8))){
      goto L69;
     }
     goto L51;
L69:;
     {
      cl_object v10;
      v10 = ECL_CONS_CAR(v8);
      v6name = ecl_car(v10);
      v10 = ecl_cdr(v10);
      v7code = v10;
     }
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v8);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v8 = v10;
     }
     v9i = ecl_one_plus(v9i);
     goto L50;
L51:;
    }
   }
   (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(1, VV[34]) /*  WT */;
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, VV[35]) /*  WT-NL */;
   if (Null(v2first)){
    goto L89;
   }
   T0 = VV[36];
   goto L88;
L89:;
   T0 = VV[37];
L88:;
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(2, T0, VV[38]) /*  WT-NL */;
   {
    cl_object v5;
    cl_object v6var_loc;
    cl_object v7;
    {
     cl_object v8;
     v8 = v3filtered_locations;
     if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v8;
    }
    v6var_loc = ECL_NIL;
    v7 = v5;
L97:;
    if (!(ecl_endp(v7))){
     goto L99;
    }
    goto L98;
L99:;
    v6var_loc = ECL_CONS_CAR(v7);
    {
     cl_object v8;
     v8 = ECL_CONS_CDR(v7);
     if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v7 = v8;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(3, VV[39], v6var_loc, VV[40]) /*  WT */;
    goto L97;
L98:;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(1, VV[34]) /*  WT */;
   {
    cl_fixnum v5;
    v5 = ecl_length(v3filtered_locations);
    T0 = ecl_plus(ecl_make_int8_t(2),ecl_make_fixnum(v5));
    (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(3, VV[41], T0, VV[42]) /*  WT-NL */;
   }
   if (v2first!=ECL_NIL) {
    goto L37;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, VV[43]) /*  WT-NL */;
L37:;
   value0 = v4filtered_codes;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for POP-DEBUG-LEXICAL-ENV                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3892pop_debug_lexical_env()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, VV[43]) /*  WT-NL */;
 return value0;
}
static cl_object L3892pop_debug_lexical_env_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[45]);
 {
  return L3892pop_debug_lexical_env();
 }
}
/* function definition for C2LET*                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3893c2let_(cl_object v1c1form, cl_object v2vars, cl_object v3forms, cl_object v4body)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[48]))->cfun.entry(1, v1c1form) /*  C1FORM-VOLATILE* */;
 ecl_bds_bind(cl_env_copy,VV[47],T0);             /*  *VOLATILE*              */
 ecl_bds_push(cl_env_copy,VV[49]);                /*  *UNWIND-EXIT*           */
 ecl_bds_push(cl_env_copy,VV[50]);                /*  *ENV*                   */
 ecl_bds_push(cl_env_copy,VV[51]);                /*  *ENV-LVL*               */
 ecl_bds_bind(cl_env_copy,VV[52],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*     */
 {
  cl_object v5;
  cl_object v6var;
  cl_object v7;
  {
   cl_object v8;
   v8 = v2vars;
   if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v5 = v8;
  }
  v6var = ECL_NIL;
  v7 = v5;
  {
   cl_object v8rest_forms;
   T0 = ecl_list1(v4body);
   v8rest_forms = ecl_append(v3forms,T0);
   {
    cl_object v9form;
    v9form = ECL_NIL;
    {
     cl_object v10;
     cl_object v11;
     cl_object v12used_vars;
     v10 = ecl_list1(ECL_NIL);
     v11 = v10;
     v12used_vars = ECL_NIL;
     {
      cl_object v13;
      cl_object v14;
      cl_object v15used_forms;
      v13 = ecl_list1(ECL_NIL);
      v14 = v13;
      v15used_forms = ECL_NIL;
      if (!(ecl_endp(v7))){
       goto L18;
      }
      goto L17;
L18:;
      v6var = ECL_CONS_CAR(v7);
      {
       cl_object v16;
       v16 = ECL_CONS_CDR(v7);
       if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v7 = v16;
      }
L16:;
      if (!(ECL_ATOM(v8rest_forms))){
       goto L26;
      }
      goto L17;
L26:;
      v9form = ecl_car(v8rest_forms);
      if (L3889c2let_replaceable_var_ref_p(v6var, v9form, v8rest_forms)!=ECL_NIL) {
       goto L30;
      }
      {
       cl_object v16;
       v16 = v11;
       if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v16;
      }
      v11 = ecl_list1(v6var);
      (ECL_CONS_CDR(T0)=v11,T0);
      v12used_vars = ecl_cdr(v10);
      {
       cl_object v16;
       v16 = v14;
       if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v16;
      }
      v14 = ecl_list1(v9form);
      (ECL_CONS_CDR(T0)=v14,T0);
      v15used_forms = ecl_cdr(v13);
L30:;
      if (!(ecl_endp(v7))){
       goto L45;
      }
      goto L17;
L45:;
      v6var = ECL_CONS_CAR(v7);
      {
       cl_object v16;
       v16 = ECL_CONS_CDR(v7);
       if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v7 = v16;
      }
      v8rest_forms = ECL_CONS_CDR(v8rest_forms);
      goto L16;
L17:;
      v2vars = v12used_vars;
      v3forms = v15used_forms;
     }
    }
   }
  }
 }
 {
  cl_object v5;
  cl_object v6var;
  cl_object v7;
  {
   cl_object v8;
   v8 = v2vars;
   if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v5 = v8;
  }
  v6var = ECL_NIL;
  v7 = v5;
  {
   cl_object v8kind;
   v8kind = ECL_NIL;
L67:;
   if (!(ecl_endp(v7))){
    goto L69;
   }
   goto L68;
L69:;
   v6var = ECL_CONS_CAR(v7);
   {
    cl_object v9;
    v9 = ECL_CONS_CDR(v7);
    if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v7 = v9;
   }
   v8kind = (cl_env_copy->function=ecl_fdefinition(VV[3]))->cfun.entry(1, v6var) /*  LOCAL-VAR-P */;
   if (Null(v8kind)){
    goto L79;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(0) /*  MAYBE-OPEN-INLINE-BLOCK */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(1, v6var) /*  VAR-NAME */;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[58]))->cfun.entry(1, T0) /*  NEXT-LCL */;
   L3900bind(T1, v6var);
   T0 = ecl_cmp_symbol_value(cl_env_copy,VV[47]);
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v8kind) /*  HOST-TYPE->C-NAME */;
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(5, T0, T1, VV[60], v6var, VV[61]) /*  WT-NL */;
L79:;
   goto L67;
L68:;
  }
 }
 T0 = ecl_fdefinition(VV[62]);
 if (Null(cl_some(2, T0, v2vars))){
  goto L85;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(0) /*  MAYBE-OPEN-INLINE-BLOCK */;
 {
  cl_object v5env_lvl;
  v5env_lvl = ecl_cmp_symbol_value(cl_env_copy,VV[51]);
  T0 = ecl_cmp_symbol_value(cl_env_copy,VV[47]);
  T2 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[51]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[51],T2);
  T1 = ecl_cmp_symbol_value(cl_env_copy,VV[51]);
  (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(6, T0, VV[63], T1, VV[64], v5env_lvl, VV[61]) /*  WT-NL */;
 }
L85:;
 {
  cl_object v5;
  cl_object v6form;
  cl_object v7;
  {
   cl_object v8;
   v8 = v3forms;
   if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v5 = v8;
  }
  v6form = ECL_NIL;
  v7 = v5;
  {
   cl_object v8;
   cl_object v9var;
   cl_object v10;
   {
    cl_object v11;
    v11 = v2vars;
    if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v8 = v11;
   }
   v9var = ECL_NIL;
   v10 = v8;
L104:;
   if (!(ecl_endp(v7))){
    goto L106;
   }
   goto L105;
L106:;
   v6form = ECL_CONS_CAR(v7);
   {
    cl_object v11;
    v11 = ECL_CONS_CDR(v7);
    if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v7 = v11;
   }
   if (!(ecl_endp(v10))){
    goto L114;
   }
   goto L105;
L114:;
   v9var = ECL_CONS_CAR(v10);
   {
    cl_object v11;
    v11 = ECL_CONS_CDR(v10);
    if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v10 = v11;
   }
   {
    cl_object v11;
    v11 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v9var) /*  VAR-KIND */;
    if (!((v11)==(VV[66]))){
     goto L129;
    }
    goto L126;
L129:;
    goto L127;
L127:;
    if (!((v11)==(VV[67]))){
     goto L133;
    }
    goto L126;
L133:;
    goto L131;
L131:;
    if (!((v11)==(ECL_SYM("SPECIAL",792)))){
     goto L137;
    }
    goto L126;
L137:;
    goto L135;
L135:;
    if (!((v11)==(VV[70]))){
     goto L124;
    }
    goto L125;
L126:;
L125:;
    {
     cl_object v12;
     v12 = (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(1, v6form) /*  C1FORM-NAME */;
     if (!((v12)==(VV[72]))){
      goto L141;
     }
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(1, v6form) /*  C1FORM-ARGS */;
     T1 = ecl_car(T0);
     L3900bind(T1, v9var);
     goto L122;
L141:;
     if (!((v12)==(ECL_SYM("VARIABLE",901)))){
      goto L143;
     }
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(1, v6form) /*  C1FORM-ARGS */;
     T1 = ecl_car(T0);
     L3900bind(T1, v9var);
     goto L122;
L143:;
     L3901bind_init(v6form, v9var);
     goto L122;
    }
L124:;
    ecl_bds_bind(cl_env_copy,VV[74],v9var);       /*  *DESTINATION*           */
    (cl_env_copy->function=ecl_fdefinition(VV[75]))->cfun.entry(1, v6form) /*  C2EXPR* */;
    ecl_bds_unwind1(cl_env_copy);
   }
L122:;
   goto L104;
L105:;
  }
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[76]))->cfun.entry(0) /*  POLICY-DEBUG-VARIABLE-BINDINGS */)){
  goto L147;
 }
 ecl_bds_push(cl_env_copy,VV[49]);                /*  *UNWIND-EXIT*           */
 {
  cl_object v5;
  cl_object v6;
  v5 = ecl_cmp_symbol_value(cl_env_copy,VV[79]);
  v6 = ecl_cmp_symbol_value(cl_env_copy,VV[80]);
  ecl_bds_bind(cl_env_copy,VV[52],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*    */
  ecl_bds_bind(cl_env_copy,VV[79],v5);            /*  *TEMP*                  */
  ecl_bds_bind(cl_env_copy,VV[80],v6);            /*  *LCL*                   */
  (cl_env_copy->function=ecl_fdefinition(VV[81]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
  {
   cl_object v7env;
   v7env = L3891build_debug_lexical_env(1, v2vars);
   if (Null(v7env)){
    goto L154;
   }
   T0 = CONS(VV[82],ecl_cmp_symbol_value(cl_env_copy,VV[49]));
   ecl_cmp_setq(cl_env_copy,VV[49],T0);
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, v4body) /*  C2EXPR */;
   L3892pop_debug_lexical_env();
   goto L152;
L154:;
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, v4body) /*  C2EXPR */;
  }
L152:;
  (cl_env_copy->function=ecl_fdefinition(VV[84]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
  ecl_bds_unwind_n(cl_env_copy,4);
  goto L146;
 }
L147:;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, v4body) /*  C2EXPR */;
L146:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[84]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
 ecl_bds_unwind_n(cl_env_copy,5);
 return value0;
}
static cl_object L3893c2let__va(cl_narg narg, cl_object v5c1form, cl_object v6vars, cl_object v7forms, cl_object v8body, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[53]);
 {
  return L3893c2let_(v5c1form, v6vars, v7forms, v8body);
 }
}
/* function definition for C2MULTIPLE-VALUE-BIND                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3894c2multiple_value_bind(cl_object v1c1form, cl_object v2vars, cl_object v3init_form, cl_object v4body)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5env_grows;
  cl_object v6min_values;
  cl_object v7max_values;
  ecl_bds_push(cl_env_copy,VV[49]);               /*  *UNWIND-EXIT*           */
  ecl_bds_push(cl_env_copy,VV[51]);               /*  *ENV-LVL*               */
  ecl_bds_push(cl_env_copy,VV[50]);               /*  *ENV*                   */
  ecl_bds_push(cl_env_copy,VV[80]);               /*  *LCL*                   */
  v5env_grows = ECL_NIL;
  ecl_bds_bind(cl_env_copy,VV[52],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*    */
  v6min_values = ECL_NIL;
  v7max_values = ECL_NIL;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[87]))->cfun.entry(1, v3init_form) /*  C1FORM-VALUES-NUMBER */;
  {
   const int v8 = cl_env_copy->nvalues;
   v6min_values = value0;
   cl_object v9;
   v9 = (v8<=1)? ECL_NIL : cl_env_copy->values[1];
   v7max_values = v9;
  }
  {
   cl_object v8;
   v8 = v2vars;
   goto L11;
L10:;
   {
    cl_object v9var;
    {
     cl_object v10;
     v10 = ecl_car(v8);
     T0 = si_of_class_p(2, v10, VV[6]);
     if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[6],v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v9var = v10;
    }
    {
     cl_object v10kind;
     v10kind = (cl_env_copy->function=ecl_fdefinition(VV[3]))->cfun.entry(1, v9var) /*  LOCAL-VAR-P */;
     if (Null(v10kind)){
      goto L19;
     }
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v9var) /*  USEFUL-VAR-P */)){
      goto L17;
     }
     (cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(0) /*  MAYBE-OPEN-INLINE-BLOCK */;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[58]))->cfun.entry(0) /*  NEXT-LCL */;
     L3900bind(T0, v9var);
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v10kind) /*  HOST-TYPE->C-NAME */;
     (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(5, T0, VV[60], ecl_cmp_symbol_value(cl_env_copy,VV[47]), v9var, VV[61]) /*  WT-NL */;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(1, v9var) /*  VAR-NAME */;
     (cl_env_copy->function=ecl_fdefinition(VV[89]))->cfun.entry(1, T0) /*  WT-COMMENT */;
     goto L17;
L19:;
     if (v5env_grows!=ECL_NIL) {
      goto L17;
     }
     v5env_grows = (cl_env_copy->function=ecl_fdefinition(VV[62]))->cfun.entry(1, v9var) /*  VAR-REF-CCB */;
    }
L17:;
   }
   v8 = ecl_cdr(v8);
L11:;
   if (Null(v8)){
    goto L29;
   }
   goto L10;
L29:;
  }
  v5env_grows = (cl_env_copy->function=ecl_fdefinition(VV[90]))->cfun.entry(1, v5env_grows) /*  ENV-GROWS */;
  if (Null(v5env_grows)){
   goto L31;
  }
  {
   cl_object v8env_lvl;
   v8env_lvl = ecl_cmp_symbol_value(cl_env_copy,VV[51]);
   (cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(0) /*  MAYBE-OPEN-INLINE-BLOCK */;
   T1 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[51]),ecl_make_int8_t(1));
   ecl_cmp_setq(cl_env_copy,VV[51],T1);
   T0 = ecl_cmp_symbol_value(cl_env_copy,VV[51]);
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(5, VV[91], T0, VV[64], v8env_lvl, VV[61]) /*  WT-NL */;
  }
L31:;
  L3905do_m_v_setq(v2vars, v3init_form, ECL_T);
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, v4body) /*  C2EXPR */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[84]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
  ecl_bds_unwind_n(cl_env_copy,5);
  return value0;
 }
}
static cl_object L3894c2multiple_value_bind_va(cl_narg narg, cl_object v8c1form, cl_object v9vars, cl_object v10init_form, cl_object v11body, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[86]);
 {
  return L3894c2multiple_value_bind(v8c1form, v9vars, v10init_form, v11body);
 }
}
/* function definition for C2LOCATION                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3895c2location(cl_object v1c1form, cl_object v2loc)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[97]))->cfun.entry(1, v1c1form) /*  C1FORM-PRIMARY-TYPE */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[96]))->cfun.entry(2, v2loc, T0) /*  PRECISE-LOC-LISP-TYPE */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[95]))->cfun.entry(1, T1) /*  UNWIND-EXIT */;
 return value0;
}
static cl_object L3895c2location_va(cl_narg narg, cl_object v3c1form, cl_object v4loc, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[94]);
 {
  return L3895c2location(v3c1form, v4loc);
 }
}
/* function definition for C2VARIABLE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3896c2variable(cl_object v1c1form, cl_object v2var, cl_object v3loc)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v3loc)){
  goto L3;
 }
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[100]))->cfun.entry(1, v3loc) /*  VV-LOCATION */;
 if (ecl_numberp(T1)) {
  goto L3;
 }
 T0 = v3loc;
 goto L2;
L3:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, v2var) /*  TRY-CONST-C-INLINER */;
 if (value0!=ECL_NIL) {
  goto L7;
 }
 T0 = v2var;
 goto L2;
L7:;
 T0 = value0;
 goto L2;
L2:;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[97]))->cfun.entry(1, v1c1form) /*  C1FORM-PRIMARY-TYPE */;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[96]))->cfun.entry(2, T0, T1) /*  PRECISE-LOC-LISP-TYPE */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[95]))->cfun.entry(1, T2) /*  UNWIND-EXIT */;
 return value0;
}
static cl_object L3896c2variable_va(cl_narg narg, cl_object v4c1form, cl_object v5var, cl_object v6loc, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[99]);
 {
  return L3896c2variable(v4c1form, v5var, v6loc);
 }
}
/* function definition for C2SETQ                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3897c2setq(cl_object v1c1form, cl_object v2vref, cl_object v3form)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,VV[74],v2vref);         /*  *DESTINATION*           */
 (cl_env_copy->function=ecl_fdefinition(VV[75]))->cfun.entry(1, v3form) /*  C2EXPR* */;
 ecl_bds_unwind1(cl_env_copy);
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(1, v3form) /*  C1FORM-NAME */;
 if (!((T0)==(VV[72]))){
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(1, v3form) /*  C1FORM-ARGS */;
 T1 = ecl_car(T0);
 value0 = L3895c2location(v3form, T1);
 return value0;
L3:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[95]))->cfun.entry(1, v2vref) /*  UNWIND-EXIT */;
 return value0;
}
static cl_object L3897c2setq_va(cl_narg narg, cl_object v4c1form, cl_object v5vref, cl_object v6form, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[103]);
 {
  return L3897c2setq(v4c1form, v5vref, v6form);
 }
}
/* function definition for C2PROGV                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3898c2progv(cl_object v1c1form, cl_object v2symbols, cl_object v3values, cl_object v4body)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5lcl;
  cl_object v6sym_loc;
  cl_object v7val_loc;
  ecl_bds_push(cl_env_copy,VV[80]);               /*  *LCL*                   */
  v5lcl = (cl_env_copy->function=ecl_fdefinition(VV[58]))->cfun.entry(0) /*  NEXT-LCL */;
  v6sym_loc = (cl_env_copy->function=ecl_fdefinition(VV[106]))->cfun.entry(0) /*  MAKE-LCL-VAR */;
  v7val_loc = (cl_env_copy->function=ecl_fdefinition(VV[106]))->cfun.entry(0) /*  MAKE-LCL-VAR */;
  {
   cl_object v8;
   cl_object v9;
   v8 = ecl_cmp_symbol_value(cl_env_copy,VV[79]);
   v9 = ecl_cmp_symbol_value(cl_env_copy,VV[80]);
   ecl_bds_bind(cl_env_copy,VV[52],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*   */
   ecl_bds_bind(cl_env_copy,VV[79],v8);           /*  *TEMP*                  */
   ecl_bds_bind(cl_env_copy,VV[80],v9);           /*  *LCL*                   */
   (cl_env_copy->function=ecl_fdefinition(VV[81]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(7, VV[107], v6sym_loc, VV[108], v7val_loc, VV[109], v5lcl, VV[61]) /*  WT-NL */;
   ecl_bds_bind(cl_env_copy,VV[74],v6sym_loc);    /*  *DESTINATION*           */
   (cl_env_copy->function=ecl_fdefinition(VV[75]))->cfun.entry(1, v2symbols) /*  C2EXPR* */;
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_bind(cl_env_copy,VV[74],v7val_loc);    /*  *DESTINATION*           */
   (cl_env_copy->function=ecl_fdefinition(VV[75]))->cfun.entry(1, v3values) /*  C2EXPR* */;
   ecl_bds_unwind1(cl_env_copy);
   T0 = CONS(v5lcl,ecl_cmp_symbol_value(cl_env_copy,VV[49]));
   ecl_bds_bind(cl_env_copy,VV[49],T0);           /*  *UNWIND-EXIT*           */
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(6, v5lcl, VV[110], v6sym_loc, VV[108], v7val_loc, VV[111]) /*  WT-NL */;
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, v4body) /*  C2EXPR */;
   ecl_bds_unwind1(cl_env_copy);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[84]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
   ecl_bds_unwind_n(cl_env_copy,4);
   return value0;
  }
 }
}
static cl_object L3898c2progv_va(cl_narg narg, cl_object v10c1form, cl_object v11symbols, cl_object v12values, cl_object v13body, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[105]);
 {
  return L3898c2progv(v10c1form, v11symbols, v12values, v13body);
 }
}
/* function definition for C2PSETQ                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3899c2psetq(cl_object v1c1form, cl_object v2vrefs, cl_object v3forms)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4saves;
  v4saves = ECL_NIL;
  {
   cl_object v5;
   cl_object v6;
   v5 = ecl_cmp_symbol_value(cl_env_copy,VV[79]);
   v6 = ecl_cmp_symbol_value(cl_env_copy,VV[80]);
   ecl_bds_bind(cl_env_copy,VV[52],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*   */
   ecl_bds_bind(cl_env_copy,VV[79],v5);           /*  *TEMP*                  */
   ecl_bds_bind(cl_env_copy,VV[80],v6);           /*  *LCL*                   */
   {
    cl_object v7;
    cl_object v8var;
    cl_object v9;
    {
     cl_object v10;
     v10 = v2vrefs;
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v7 = v10;
    }
    v8var = ECL_NIL;
    v9 = v7;
    {
     cl_object v10;
     cl_object v11form;
     cl_object v12rest_forms;
     v10 = v3forms;
     v11form = ECL_NIL;
     v12rest_forms = ECL_NIL;
L15:;
     if (!(ecl_endp(v9))){
      goto L17;
     }
     goto L16;
L17:;
     v8var = ECL_CONS_CAR(v9);
     {
      cl_object v13;
      v13 = ECL_CONS_CDR(v9);
      if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v9 = v13;
     }
     if (!(ECL_ATOM(v10))){
      goto L25;
     }
     goto L16;
L25:;
     {
      cl_object v13;
      v13 = v10;
      v11form = ecl_car(v13);
      v13 = ecl_cdr(v13);
      v12rest_forms = v13;
     }
     v10 = ECL_CONS_CDR(v10);
     if ((cl_env_copy->function=ecl_fdefinition(VV[8]))->cfun.entry(2, v8var, v12rest_forms) /*  VAR-CHANGED-IN-FORM-LIST */!=ECL_NIL) {
      goto L39;
     }
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[114]))->cfun.entry(2, v8var, v12rest_forms) /*  VAR-REFERENCED-IN-FORM-LIST */)){
      goto L37;
     }
     goto L38;
L39:;
L38:;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(1, v11form) /*  C1FORM-NAME */;
     if (!((T0)==(VV[72]))){
      goto L41;
     }
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(1, v11form) /*  C1FORM-ARGS */;
     T1 = ecl_car(T0);
     T2 = CONS(v8var,T1);
     v4saves = CONS(T2,v4saves);
     goto L36;
L41:;
     {
      cl_object v13typ;
      cl_object v14rep;
      cl_object v15tmp;
      v13typ = (cl_env_copy->function=ecl_fdefinition(VV[97]))->cfun.entry(1, v11form) /*  C1FORM-PRIMARY-TYPE */;
      v14rep = (cl_env_copy->function=ecl_fdefinition(VV[115]))->cfun.entry(1, v8var) /*  VAR-HOST-TYPE */;
      v15tmp = (cl_env_copy->function=ecl_fdefinition(VV[116]))->cfun.entry(3, v11form, v13typ, v14rep) /*  EMIT-INLINED-TEMP-VAR */;
      T0 = CONS(v8var,v15tmp);
      v4saves = CONS(T0,v4saves);
      goto L36;
     }
L37:;
     ecl_bds_bind(cl_env_copy,VV[74],v8var);      /*  *DESTINATION*           */
     (cl_env_copy->function=ecl_fdefinition(VV[75]))->cfun.entry(1, v11form) /*  C2EXPR* */;
     ecl_bds_unwind1(cl_env_copy);
L36:;
     goto L15;
L16:;
    }
   }
   {
    cl_object v7;
    v7 = v4saves;
    goto L53;
L52:;
    {
     cl_object v8save;
     v8save = ecl_car(v7);
     T0 = ecl_cdr(v8save);
     T1 = ecl_car(v8save);
     L3908set_var(T0, T1);
    }
    v7 = ecl_cdr(v7);
L53:;
    if (Null(v7)){
     goto L60;
    }
    goto L52;
L60:;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[84]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[95]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[118])) /*  UNWIND-EXIT */;
  return value0;
 }
}
static cl_object L3899c2psetq_va(cl_narg narg, cl_object v5c1form, cl_object v6vrefs, cl_object v7forms, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[113]);
 {
  return L3899c2psetq(v5c1form, v6vrefs, v7forms);
 }
}
/* function definition for BIND                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3900bind(cl_object v1loc, cl_object v2var)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v2var) /*  VAR-KIND */;
  if (!((v3)==(VV[67]))){
   goto L3;
  }
  {
   cl_object v4var_loc;
   v4var_loc = (cl_env_copy->function=ecl_fdefinition(VV[23]))->cfun.entry(1, v2var) /*  VAR-LOC */;
   if (ECL_FIXNUMP(v4var_loc)) {
    goto L6;
   }
   v4var_loc = (cl_env_copy->function=ecl_fdefinition(VV[120]))->cfun.entry(0) /*  NEXT-ENV */;
   ecl_structure_set(v2var,VV[6],(cl_fixnum)(10),v4var_loc);
L6:;
   if (!(ecl_zerop(v4var_loc))){
    goto L10;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(3, VV[121], ecl_cmp_symbol_value(cl_env_copy,VV[51]), VV[122]) /*  WT-NL */;
L10:;
   T0 = ecl_cmp_symbol_value(cl_env_copy,VV[51]);
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[125]))->cfun.entry(2, ECL_SYM("OBJECT",1315), v1loc) /*  COERCE-LOC */;
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(9, VV[123], v4var_loc, VV[64], T0, VV[124], T1, VV[126], ecl_cmp_symbol_value(cl_env_copy,VV[51]), VV[111]) /*  WT-NL */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(1, v2var) /*  VAR-NAME */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[89]))->cfun.entry(1, T0) /*  WT-COMMENT */;
   return value0;
  }
L3:;
  if (!((v3)==(VV[66]))){
   goto L14;
  }
  {
   cl_object v5var_loc;
   v5var_loc = (cl_env_copy->function=ecl_fdefinition(VV[23]))->cfun.entry(1, v2var) /*  VAR-LOC */;
   if (ECL_CONSP(v5var_loc)) {
    goto L18;
   }
   v5var_loc = (cl_env_copy->function=ecl_fdefinition(VV[127]))->cfun.entry(0) /*  NEXT-LEX */;
   ecl_structure_set(v2var,VV[6],(cl_fixnum)(10),v5var_loc);
L18:;
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(0) /*  WT-NL   */;
   L3911wt_lex(v5var_loc);
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[125]))->cfun.entry(2, ECL_SYM("OBJECT",1315), v1loc) /*  COERCE-LOC */;
   (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(3, VV[129], T0, VV[61]) /*  WT */;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(1, v2var) /*  VAR-NAME */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[89]))->cfun.entry(1, T0) /*  WT-COMMENT */;
  return value0;
L14:;
  if (!((v3)==(ECL_SYM("SPECIAL",792)))){
   goto L29;
  }
  goto L26;
L29:;
  goto L27;
L27:;
  if (!((v3)==(VV[70]))){
   goto L24;
  }
  goto L25;
L26:;
L25:;
  value0 = L3902bds_bind(v1loc, v2var);
  return value0;
L24:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[23]))->cfun.entry(1, v2var) /*  VAR-LOC */;
  if ((T0)==(VV[131])) {
   goto L32;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[23]))->cfun.entry(1, v2var) /*  VAR-LOC */;
  if (ecl_equal(T0,v1loc)) {
   goto L34;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[115]))->cfun.entry(1, v2var) /*  VAR-HOST-TYPE */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[125]))->cfun.entry(2, T0, v1loc) /*  COERCE-LOC */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(4, v2var, VV[129], T1, VV[61]) /*  WT-NL */;
  return value0;
L34:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L32:;
  if (!(ECL_CONSP(v1loc))){
   goto L36;
  }
  T0 = ecl_car(v1loc);
  if (!((T0)==(VV[24]))){
   goto L36;
  }
  value0 = ecl_structure_set(v2var,VV[6],(cl_fixnum)(10),v1loc);
  cl_env_copy->nvalues = 1;
  return value0;
L36:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v2var) /*  VAR-KIND */;
  T1 = cl_list(2, T0, v1loc);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[132]))->cfun.entry(4, ECL_SYM("FORMAT-CONTROL",1272), VV[133], ECL_SYM("FORMAT-ARGUMENTS",1271), T1) /*  BABOON */;
  return value0;
 }
}
static cl_object L3900bind_va(cl_narg narg, cl_object v5loc, cl_object v6var, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[57]);
 {
  return L3900bind(v5loc, v6var);
 }
}
/* function definition for BIND-INIT                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3901bind_init(cl_object v1form, cl_object v2var)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3kind;
  v3kind = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v2var) /*  VAR-KIND */;
  if (!((v3kind)==(VV[67]))){
   goto L8;
  }
  goto L5;
L8:;
  goto L6;
L6:;
  if (!((v3kind)==(VV[66]))){
   goto L12;
  }
  goto L5;
L12:;
  goto L10;
L10:;
  if (!((v3kind)==(ECL_SYM("SPECIAL",792)))){
   goto L16;
  }
  goto L5;
L16:;
  goto L14;
L14:;
  if (!((v3kind)==(VV[70]))){
   goto L3;
  }
  goto L4;
L5:;
L4:;
  {
   cl_object v4;
   cl_object v5;
   v4 = ecl_cmp_symbol_value(cl_env_copy,VV[79]);
   v5 = ecl_cmp_symbol_value(cl_env_copy,VV[80]);
   ecl_bds_bind(cl_env_copy,VV[52],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*   */
   ecl_bds_bind(cl_env_copy,VV[79],v4);           /*  *TEMP*                  */
   ecl_bds_bind(cl_env_copy,VV[80],v5);           /*  *LCL*                   */
   {
    cl_object v6locs;
    T0 = ecl_list1(v1form);
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[138]))->cfun.entry(1, T0) /*  INLINE-ARGS */;
    v6locs = (cl_env_copy->function=ecl_fdefinition(VV[137]))->cfun.entry(1, T1) /*  COERCE-ARGS */;
    T0 = ecl_car(v6locs);
    L3900bind(T0, v2var);
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[84]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   return value0;
  }
L3:;
  T0 = cl_list(2, VV[57], v2var);
  ecl_bds_bind(cl_env_copy,VV[74],T0);            /*  *DESTINATION*           */
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[75]))->cfun.entry(1, v1form) /*  C2EXPR* */;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3901bind_init_va(cl_narg narg, cl_object v6form, cl_object v7var, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[73]);
 {
  return L3901bind_init(v6form, v7var);
 }
}
/* function definition for BDS-BIND                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3902bds_bind(cl_object v1loc, cl_object v2var)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[140]))->cfun.entry(1, v1loc) /*  VAR-P */)){
  goto L3;
 }
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v1loc) /*  VAR-KIND */;
  if (!((v3)==(VV[70]))){
   goto L11;
  }
  goto L8;
L11:;
  goto L9;
L9:;
  if (!((v3)==(ECL_SYM("SPECIAL",792)))){
   goto L3;
  }
  goto L6;
L8:;
 }
L6:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(1, v1loc) /*  VAR-NAME */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(1, v2var) /*  VAR-NAME */;
 if (!((T0)==(T1))){
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[23]))->cfun.entry(1, v2var) /*  VAR-LOC */;
 (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(3, VV[143], T0, VV[111]) /*  WT-NL */;
 goto L2;
L3:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[23]))->cfun.entry(1, v2var) /*  VAR-LOC */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[125]))->cfun.entry(2, ECL_SYM("OBJECT",1315), v1loc) /*  COERCE-LOC */;
 (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(5, VV[144], T0, VV[30], T1, VV[111]) /*  WT-NL */;
L2:;
 T0 = CONS(VV[130],ecl_cmp_symbol_value(cl_env_copy,VV[49]));
 ecl_cmp_setq(cl_env_copy,VV[49],T0);
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(1, v2var) /*  VAR-NAME */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[89]))->cfun.entry(1, T0) /*  WT-COMMENT */;
 return value0;
}
static cl_object L3902bds_bind_va(cl_narg narg, cl_object v3loc, cl_object v4var, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[130]);
 {
  return L3902bds_bind(v3loc, v4var);
 }
}
/* function definition for BIND-OR-SET                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3903bind_or_set(cl_object v1loc, cl_object v2v, cl_object v3use_bind)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (v3use_bind!=ECL_NIL) {
  goto L2;
 }
 value0 = L3908set_var(v1loc, v2v);
 return value0;
L2:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[147]))->cfun.entry(1, v2v) /*  VAR-REF */;
 if (ecl_plusp(T0)) {
  goto L6;
 }
 {
  cl_object v4;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v2v) /*  VAR-KIND */;
  if (!((v4)==(ECL_SYM("SPECIAL",792)))){
   goto L12;
  }
  goto L9;
L12:;
  goto L10;
L10:;
  if (!((v4)==(VV[70]))){
   goto L4;
  }
  goto L5;
L9:;
  goto L5;
 }
L6:;
L5:;
 value0 = L3900bind(v1loc, v2v);
 return value0;
L4:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for VALUES-LOC-OR-VALUE0                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3904values_loc_or_value0(cl_object v1i)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ecl_plusp(v1i))){
  goto L2;
 }
 value0 = cl_list(2, VV[149], v1i);
 return value0;
L2:;
 value0 = VV[150];
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for DO-M-V-SETQ                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3905do_m_v_setq(cl_object v1vars, cl_object v2form, cl_object v3use_bind)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_fixnum v4;
  v4 = ecl_length(v1vars);
  if (!((v4)==((cl_fixnum)(1)))){
   goto L2;
  }
 }
 T0 = ecl_car(v1vars);
 ecl_bds_bind(cl_env_copy,VV[74],T0);             /*  *DESTINATION*           */
 (cl_env_copy->function=ecl_fdefinition(VV[75]))->cfun.entry(1, v2form) /*  C2EXPR* */;
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[74]);
 cl_env_copy->nvalues = 1;
 ecl_bds_unwind1(cl_env_copy);
 return value0;
L2:;
 {
  cl_object v4;                                   /*  MIN-VALUES              */
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[87]))->cfun.entry(1, v2form) /*  C1FORM-VALUES-NUMBER */;
  {
   v4 = value0;
  }
  ecl_bds_bind(cl_env_copy,VV[74],VV[151]);       /*  *DESTINATION*           */
  (cl_env_copy->function=ecl_fdefinition(VV[75]))->cfun.entry(1, v2form) /*  C2EXPR* */;
  ecl_bds_unwind1(cl_env_copy);
  v4 = ((ecl_float_nan_p(v4) || ecl_greatereq(ecl_make_int8_t(1),v4))?ecl_make_int8_t(1):v4);
  {
   cl_object v5useful_extra_vars;
   cl_object v6nr;
   ecl_bds_push(cl_env_copy,VV[80]);              /*  *LCL*                   */
   T0 = ecl_fdefinition(VV[88]);
   T1 = ecl_nthcdr(ecl_to_size(v4),v1vars);
   v5useful_extra_vars = cl_some(2, T0, T1);
   v6nr = (cl_env_copy->function=ecl_fdefinition(VV[106]))->cfun.entry(2, ECL_SYM("TYPE",1356), ECL_SYM("INT",1411)) /*  MAKE-LCL-VAR */;
   {
    cl_object v7;
    cl_object v8;
    v7 = ecl_cmp_symbol_value(cl_env_copy,VV[79]);
    v8 = ecl_cmp_symbol_value(cl_env_copy,VV[80]);
    ecl_bds_bind(cl_env_copy,VV[52],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*  */
    ecl_bds_bind(cl_env_copy,VV[79],v7);          /*  *TEMP*                  */
    ecl_bds_bind(cl_env_copy,VV[80],v8);          /*  *LCL*                   */
    (cl_env_copy->function=ecl_fdefinition(VV[81]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
    if (Null(v5useful_extra_vars)){
     goto L16;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(3, VV[152], v6nr, VV[153]) /*  WT-NL */;
L16:;
    {
     cl_object v9i;
     v9i = ecl_make_int8_t(0);
     goto L21;
L20:;
     if (Null(v1vars)){
      goto L23;
     }
     {
      cl_object v10;
      cl_object v11;
      {
       cl_object v12;
       v12 = v1vars;
       {
        cl_object v13;
        v13 = v12;
        {
         bool v14;
         v14 = ECL_LISTP(v13);
         if (ecl_unlikely(!(v14)))
         FEwrong_type_argument(VV[156],v13);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
       }
       if (Null(v12)){
        goto L30;
       }
       {
        cl_object v13;
        v13 = ECL_CONS_CDR(v12);
        v1vars = v13;
        v12 = ECL_CONS_CAR(v12);
       }
L30:;
       v10 = v12;
      }
      v11 = L3904values_loc_or_value0(v9i);
      L3903bind_or_set(v11, v10, v3use_bind);
     }
L23:;
     v9i = ecl_one_plus(v9i);
L21:;
     if (!(ecl_lower(v9i,v4))){
      goto L39;
     }
     goto L20;
L39:;
    }
    if (Null(v5useful_extra_vars)){
     goto L41;
    }
    {
     cl_object v9tmp;
     v9tmp = (cl_env_copy->function=ecl_fdefinition(VV[106]))->cfun.entry(0) /*  MAKE-LCL-VAR */;
     (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(3, VV[107], v9tmp, VV[61]) /*  WT-NL */;
     {
      cl_object v10;
      cl_object v11v;
      cl_object v12;
      {
       cl_object v13;
       v13 = v1vars;
       if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v10 = v13;
      }
      v11v = ECL_NIL;
      v12 = v10;
      {
       cl_object v13i;
       {
        cl_object v14;
        v14 = v4;
        {
         bool v15;
         v15 = ecl_numberp(v14);
         if (ecl_unlikely(!(v15)))
         FEwrong_type_argument(ECL_SYM("NUMBER",608),v14);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
        v13i = v14;
       }
       {
        cl_object v14loc;
        v14loc = ECL_NIL;
        if (!(ecl_endp(v12))){
         goto L56;
        }
        goto L55;
L56:;
        v11v = ECL_CONS_CAR(v12);
        {
         cl_object v15;
         v15 = ECL_CONS_CDR(v12);
         if (ecl_unlikely(!ECL_LISTP(v15))) FEtype_error_list(v15);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         v12 = v15;
        }
L54:;
        v14loc = L3904values_loc_or_value0(v13i);
        if (Null((cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v11v) /*  USEFUL-VAR-P */)){
         goto L66;
        }
        (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(8, v9tmp, VV[157], v6nr, VV[158], v13i, VV[159], v14loc, VV[61]) /*  WT-NL */;
        L3903bind_or_set(v9tmp, v11v, v3use_bind);
L66:;
        if (!(ecl_endp(v12))){
         goto L69;
        }
        goto L55;
L69:;
        v11v = ECL_CONS_CAR(v12);
        {
         cl_object v15;
         v15 = ECL_CONS_CDR(v12);
         if (ecl_unlikely(!ECL_LISTP(v15))) FEtype_error_list(v15);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         v12 = v15;
        }
        v13i = ecl_one_plus(v13i);
        goto L54;
L55:;
       }
      }
     }
    }
L41:;
    (cl_env_copy->function=ecl_fdefinition(VV[84]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
    ecl_bds_unwind_n(cl_env_copy,4);
   }
  }
  value0 = VV[150];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for C2MULTIPLE-VALUE-SETQ                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3906c2multiple_value_setq(cl_object v1c1form, cl_object v2vars, cl_object v3form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = L3905do_m_v_setq(v2vars, v3form, ECL_NIL);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[95]))->cfun.entry(1, T0) /*  UNWIND-EXIT */;
 return value0;
}
static cl_object L3906c2multiple_value_setq_va(cl_narg narg, cl_object v4c1form, cl_object v5vars, cl_object v6form, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[160]);
 {
  return L3906c2multiple_value_setq(v4c1form, v5vars, v6form);
 }
}
/* function definition for WT-VAR                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3907wt_var(cl_object v1var)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2var_loc;
  v2var_loc = (cl_env_copy->function=ecl_fdefinition(VV[23]))->cfun.entry(1, v1var) /*  VAR-LOC */;
  {
   cl_object v3;
   v3 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v1var) /*  VAR-KIND */;
   if (!((v3)==(VV[67]))){
    goto L4;
   }
   value0 = L3913wt_env(v2var_loc);
   return value0;
L4:;
   if (!((v3)==(VV[66]))){
    goto L6;
   }
   value0 = L3911wt_lex(v2var_loc);
   return value0;
L6:;
   if (!((v3)==(ECL_SYM("SPECIAL",792)))){
    goto L13;
   }
   goto L10;
L13:;
   goto L11;
L11:;
   if (!((v3)==(VV[70]))){
    goto L8;
   }
   goto L9;
L10:;
L9:;
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(0) /*  SAFE-COMPILE */)){
    goto L16;
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(3, VV[165], v2var_loc, VV[40]) /*  WT */;
   return value0;
L16:;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(3, VV[166], v2var_loc, VV[40]) /*  WT */;
   return value0;
L8:;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(1, v2var_loc) /*  WT */;
   return value0;
  }
 }
}
static cl_object L3907wt_var_va(cl_narg narg, cl_object v4var, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[162]);
 {
  return L3907wt_var(v4var);
 }
}
/* function definition for SET-VAR                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3908set_var(cl_object v1loc, cl_object v2var)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3var_loc;
  v3var_loc = (cl_env_copy->function=ecl_fdefinition(VV[23]))->cfun.entry(1, v2var) /*  VAR-LOC */;
  if ((cl_env_copy->function=ecl_fdefinition(VV[140]))->cfun.entry(1, v2var) /*  VAR-P */!=ECL_NIL) {
   goto L3;
  }
  T0 = ecl_list1(v2var);
  (cl_env_copy->function=ecl_fdefinition(VV[132]))->cfun.entry(4, ECL_SYM("FORMAT-CONTROL",1272), VV[168], ECL_SYM("FORMAT-ARGUMENTS",1271), T0) /*  BABOON */;
L3:;
  {
   cl_object v4;
   v4 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v2var) /*  VAR-KIND */;
   if (!((v4)==(VV[67]))){
    goto L6;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(0) /*  WT-NL   */;
   L3913wt_env(v3var_loc);
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[115]))->cfun.entry(1, v2var) /*  VAR-HOST-TYPE */;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[125]))->cfun.entry(2, T0, v1loc) /*  COERCE-LOC */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(3, VV[129], T1, VV[61]) /*  WT */;
   return value0;
L6:;
   if (!((v4)==(VV[66]))){
    goto L10;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(0) /*  WT-NL   */;
   L3911wt_lex(v3var_loc);
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[115]))->cfun.entry(1, v2var) /*  VAR-HOST-TYPE */;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[125]))->cfun.entry(2, T0, v1loc) /*  COERCE-LOC */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(3, VV[129], T1, VV[61]) /*  WT */;
   return value0;
L10:;
   if (!((v4)==(ECL_SYM("SPECIAL",792)))){
    goto L19;
   }
   goto L16;
L19:;
   goto L17;
L17:;
   if (!((v4)==(VV[70]))){
    goto L14;
   }
   goto L15;
L16:;
L15:;
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[164]))->cfun.entry(0) /*  SAFE-COMPILE */)){
    goto L23;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(3, VV[169], v3var_loc, VV[30]) /*  WT-NL */;
   goto L22;
L23:;
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(3, VV[170], v3var_loc, VV[30]) /*  WT-NL */;
L22:;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[115]))->cfun.entry(1, v2var) /*  VAR-HOST-TYPE */;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[125]))->cfun.entry(2, T0, v1loc) /*  COERCE-LOC */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(2, T1, VV[111]) /*  WT */;
   return value0;
L14:;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[115]))->cfun.entry(1, v2var) /*  VAR-HOST-TYPE */;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[125]))->cfun.entry(2, T0, v1loc) /*  COERCE-LOC */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(4, v3var_loc, VV[129], T1, VV[61]) /*  WT-NL */;
   return value0;
  }
 }
}
static cl_object L3908set_var_va(cl_narg narg, cl_object v5loc, cl_object v6var, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[117]);
 {
  return L3908set_var(v5loc, v6var);
 }
}
/* function definition for WT-LCL                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3909wt_lcl(cl_object v1lcl)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (ecl_numberp(v1lcl)) {
  goto L2;
 }
 T0 = ecl_list1(v1lcl);
 (cl_env_copy->function=ecl_fdefinition(VV[132]))->cfun.entry(4, ECL_SYM("FORMAT-CONTROL",1272), VV[173], ECL_SYM("FORMAT-ARGUMENTS",1271), T0) /*  BABOON */;
L2:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(2, VV[174], v1lcl) /*  WT */;
 return value0;
}
static cl_object L3909wt_lcl_va(cl_narg narg, cl_object v2lcl, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[172]);
 {
  return L3909wt_lcl(v2lcl);
 }
}
/* function definition for WT-LCL-LOC                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3910wt_lcl_loc(cl_narg narg, cl_object v1lcl, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[176]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[176]);
 {
  cl_object v2type;
  cl_object v3name;
  va_list args; va_start(args,v1lcl);
  {
   int i = 1;
   if (i >= narg) {
    v2type = ECL_NIL;
   } else {
    i++;
    v2type = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v3name = ECL_NIL;
   } else {
    i++;
    v3name = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (ecl_numberp(v1lcl)) {
   goto L3;
  }
  T0 = ecl_list1(v1lcl);
  (cl_env_copy->function=ecl_fdefinition(VV[132]))->cfun.entry(4, ECL_SYM("FORMAT-CONTROL",1272), VV[177], ECL_SYM("FORMAT-ARGUMENTS",1271), T0) /*  BABOON */;
L3:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(3, VV[174], v1lcl, v3name) /*  WT */;
  return value0;
 }
}
/* function definition for WT-LEX                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3911wt_lex(cl_object v1lex)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_CONSP(v1lex))){
  goto L2;
 }
 T0 = ecl_car(v1lex);
 T1 = ecl_cdr(v1lex);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(5, VV[179], T0, VV[180], T1, VV[181]) /*  WT */;
 return value0;
L2:;
 value0 = L3909wt_lcl(v1lex);
 return value0;
}
static cl_object L3911wt_lex_va(cl_narg narg, cl_object v2lex, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[128]);
 {
  return L3911wt_lex(v2lex);
 }
}
/* function definition for WT-TEMP                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3912wt_temp(cl_object v1temp)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(2, VV[184], v1temp) /*  WT */;
 return value0;
}
static cl_object L3912wt_temp_va(cl_narg narg, cl_object v2temp, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[183]);
 {
  return L3912wt_temp(v2temp);
 }
}
/* function definition for WT-ENV                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3913wt_env(cl_object v1clv)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(3, VV[186], v1clv, VV[40]) /*  WT */;
 return value0;
}
static cl_object L3913wt_env_va(cl_narg narg, cl_object v2clv, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[163]);
 {
  return L3913wt_env(v2clv);
 }
}
#include "cmp/cmppass2-var.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclxRgWacM9v2Qi9_6Dc0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPBACKEND-CXX;CMPPASS2-VAR.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclxRgWacM9v2Qi9_6Dc0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(_ecl_static_0);
  ecl_cmp_defun(VV[188]);                         /*  C2LET-REPLACEABLE-VAR-REF-P */
  ecl_cmp_defun(VV[189]);                         /*  LOCATIVE-TYPE-FROM-VAR-KIND */
  ecl_cmp_defun(VV[190]);                         /*  BUILD-DEBUG-LEXICAL-ENV */
  ecl_cmp_defun(VV[191]);                         /*  POP-DEBUG-LEXICAL-ENV   */
  ecl_cmp_defun(VV[192]);                         /*  C2LET*                  */
  ecl_cmp_defun(VV[193]);                         /*  C2MULTIPLE-VALUE-BIND   */
  ecl_cmp_defun(VV[194]);                         /*  C2LOCATION              */
  ecl_cmp_defun(VV[195]);                         /*  C2VARIABLE              */
  ecl_cmp_defun(VV[196]);                         /*  C2SETQ                  */
  ecl_cmp_defun(VV[197]);                         /*  C2PROGV                 */
  ecl_cmp_defun(VV[198]);                         /*  C2PSETQ                 */
  ecl_cmp_defun(VV[199]);                         /*  BIND                    */
  ecl_cmp_defun(VV[200]);                         /*  BIND-INIT               */
  ecl_cmp_defun(VV[201]);                         /*  BDS-BIND                */
  (void)0; /* No entry created for BIND-OR-SET */
  (void)0; /* No entry created for VALUES-LOC-OR-VALUE0 */
  (void)0; /* No entry created for DO-M-V-SETQ */
  ecl_cmp_defun(VV[202]);                         /*  C2MULTIPLE-VALUE-SETQ   */
  ecl_cmp_defun(VV[203]);                         /*  WT-VAR                  */
  ecl_cmp_defun(VV[204]);                         /*  SET-VAR                 */
  ecl_cmp_defun(VV[205]);                         /*  WT-LCL                  */
  ecl_cmp_defun(VV[206]);                         /*  WT-LCL-LOC              */
  ecl_cmp_defun(VV[207]);                         /*  WT-LEX                  */
  ecl_cmp_defun(VV[208]);                         /*  WT-TEMP                 */
  ecl_cmp_defun(VV[209]);                         /*  WT-ENV                  */
}
