/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/lsp/export.lsp                      */
#include <ecl/ecl-cmp.h>
#include "lsp/export.eclh"
/* function definition for FILTER-DOLIST-DECLARATIONS                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2filter_dolist_declarations(cl_object v1declarations)
{
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(ECL_NIL,env1);               /*  A                       */
  {
   cl_object v2;
   {
    cl_object v3;
    v3 = ecl_make_cclosure_va((cl_objectfn)LC1__lambda5,env1,Cblock,1);
    v2 = v3;
   }
   {
    cl_object v3;
    cl_object v4;
    cl_object v5;
    {
     cl_object v6;
     v6 = v1declarations;
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v3 = v6;
    }
    v4 = ECL_NIL;
    v5 = v3;
L9:;
    if (!(ecl_endp(v5))){
     goto L11;
    }
    goto L10;
L11:;
    v4 = ECL_CONS_CAR(v5);
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v6;
    }
    ecl_function_dispatch(cl_env_copy,v2)(1, v4);
    goto L9;
L10:;
    goto L2;
   }
  }
L2:;
  value0 = cl_nreverse(ECL_CONS_CAR(CLV0));
  return value0;
 }
}
/* local function DOLIST                                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3dolist(cl_object v1whole, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3body;
  cl_object v4control;
  cl_object v5var;
  cl_object v6expr;
  cl_object v7exit;
  v3body = ECL_NIL;
  v4control = ECL_NIL;
  v5var = ECL_NIL;
  v6expr = ECL_NIL;
  v7exit = ECL_NIL;
  v3body = ecl_cdr(v1whole);
  if (!(ecl_endp(v3body))){
   goto L9;
  }
  si_simple_program_error(3, VV[6], ECL_SYM("DOLIST",315), v1whole);
L9:;
  v4control = ecl_car(v3body);
  v3body = ecl_cdr(v3body);
  if (!(ecl_endp(v4control))){
   goto L15;
  }
  si_simple_program_error(3, VV[6], ECL_SYM("DOLIST",315), v1whole);
L15:;
  v5var = ecl_car(v4control);
  v4control = ecl_cdr(v4control);
  {
   cl_fixnum v8;
   v8 = ecl_length(v4control);
   if (!((((cl_fixnum)(1))<=(v8) && (v8)<=((cl_fixnum)(2))))){
    goto L22;
   }
  }
  v6expr = ecl_car(v4control);
  v7exit = ecl_cdr(v4control);
  goto L21;
L22:;
  si_simple_program_error(3, VV[6], ECL_SYM("DOLIST",315), v1whole);
L21:;
  {
   cl_object v8;                                  /*  DECLARATIONS            */
   cl_object v9;                                  /*  BODY                    */
   value0 = si_process_declarations(2, v3body, ECL_NIL);
   {
    const int v10 = cl_env_copy->nvalues;
    v8 = value0;
    cl_object v11;
    v11 = (v10<=1)? ECL_NIL : cl_env_copy->values[1];
    v9 = v11;
   }
   T0 = cl_list(2, VV[7], v6expr);
   T1 = ecl_list1(T0);
   T2 = cl_list(2, v5var, VV[8]);
   T3 = ecl_list1(T2);
   T4 = CONS(ECL_SYM("DECLARE",276),v8);
   T5 = CONS(ECL_SYM("TAGBODY",853),v9);
   T6 = cl_list(5, ECL_SYM("LET",479), T3, T4, T5, VV[9]);
   T7 = cl_list(3, ECL_SYM("WHILE",1543), VV[7], T6);
   if (Null(v7exit)){
    goto L29;
   }
   T9 = cl_list(2, v5var, ECL_NIL);
   T10 = ecl_list1(T9);
   T11 = cl_list(2, ECL_SYM("IGNORABLE",429), v5var);
   T12 = L2filter_dolist_declarations(v8);
   T13 = cl_listX(3, ECL_SYM("DECLARE",276), T11, T12);
   T8 = cl_listX(4, ECL_SYM("LET",479), T10, T13, v7exit);
   goto L28;
L29:;
   T8 = ECL_NIL;
L28:;
   T9 = cl_list(4, ECL_SYM("LET*",480), T1, T7, T8);
   value0 = cl_list(3, ECL_SYM("BLOCK",139), ECL_NIL, T9);
   return value0;
  }
 }
}
static cl_object LC3dolist_va(cl_narg narg, cl_object v8whole, cl_object v9env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("DOLIST",315));
 {
  return LC3dolist(v8whole, v9env);
 }
}
/* local function DOTIMES                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4dotimes(cl_object v1whole, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3body;
  cl_object v4control;
  cl_object v5var;
  cl_object v6expr;
  cl_object v7exit;
  v3body = ECL_NIL;
  v4control = ECL_NIL;
  v5var = ECL_NIL;
  v6expr = ECL_NIL;
  v7exit = ECL_NIL;
  v3body = ecl_cdr(v1whole);
  if (!(ecl_endp(v3body))){
   goto L9;
  }
  si_simple_program_error(3, VV[6], ECL_SYM("DOTIMES",316), v1whole);
L9:;
  v4control = ecl_car(v3body);
  v3body = ecl_cdr(v3body);
  if (!(ecl_endp(v4control))){
   goto L15;
  }
  si_simple_program_error(3, VV[6], ECL_SYM("DOTIMES",316), v1whole);
L15:;
  v5var = ecl_car(v4control);
  v4control = ecl_cdr(v4control);
  {
   cl_fixnum v8;
   v8 = ecl_length(v4control);
   if (!((((cl_fixnum)(1))<=(v8) && (v8)<=((cl_fixnum)(2))))){
    goto L22;
   }
  }
  v6expr = ecl_car(v4control);
  v7exit = ecl_cdr(v4control);
  goto L21;
L22:;
  si_simple_program_error(3, VV[6], ECL_SYM("DOTIMES",316), v1whole);
L21:;
  {
   cl_object v8;                                  /*  DECLARATIONS            */
   cl_object v9;                                  /*  BODY                    */
   value0 = si_process_declarations(2, v3body, ECL_NIL);
   {
    const int v10 = cl_env_copy->nvalues;
    v8 = value0;
    cl_object v11;
    v11 = (v10<=1)? ECL_NIL : cl_env_copy->values[1];
    v9 = v11;
   }
   if (!(ECL_FIXNUMP(v6expr)||ECL_BIGNUMP(v6expr))){
    goto L28;
   }
   T0 = cl_list(3, ECL_SYM("INTEGER",439), ecl_make_int8_t(0), v6expr);
   T1 = cl_list(3, ECL_SYM("TYPE",872), T0, v5var);
   v8 = CONS(T1,v8);
L28:;
   T0 = cl_list(2, VV[10], v6expr);
   T1 = cl_list(2, v5var, ecl_make_int8_t(0));
   T2 = cl_list(2, T0, T1);
   T3 = CONS(ECL_SYM("DECLARE",276),v8);
   T4 = cl_list(3, ECL_SYM("<",74), v5var, VV[10]);
   T5 = cl_list(2, ECL_SYM("1+",72), v5var);
   T6 = cl_list(3, ECL_SYM("SETQ",754), v5var, T5);
   T7 = ecl_list1(T6);
   T8 = ecl_append(v9,T7);
   T9 = cl_listX(3, ECL_SYM("WHILE",1543), T4, T8);
   T10 = cl_listX(5, ECL_SYM("LET*",480), T2, T3, T9, v7exit);
   value0 = cl_list(3, ECL_SYM("BLOCK",139), ECL_NIL, T10);
   return value0;
  }
 }
}
static cl_object LC4dotimes_va(cl_narg narg, cl_object v8whole, cl_object v9env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("DOTIMES",316));
 {
  return LC4dotimes(v8whole, v9env);
 }
}
/* local function DO/DO*-EXPAND                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5do_do__expand(cl_object v1whole, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3do_do_;
  cl_object v4control;
  cl_object v5test;
  cl_object v6result;
  cl_object v7vl;
  cl_object v8step;
  cl_object v9let;
  cl_object v10psetq;
  cl_object v11body;
  v3do_do_ = ECL_NIL;
  v4control = ECL_NIL;
  v5test = ECL_NIL;
  v6result = ECL_NIL;
  v7vl = ECL_NIL;
  v8step = ECL_NIL;
  v9let = ECL_NIL;
  v10psetq = ECL_NIL;
  v11body = ECL_NIL;
  v3do_do_ = ecl_car(v1whole);
  v11body = ecl_cdr(v1whole);
  if (!((v3do_do_)==(ECL_SYM("DO",309)))){
   goto L16;
  }
  v9let = ECL_SYM("LET",479);
  v10psetq = ECL_SYM("PSETQ",679);
  goto L15;
L16:;
  v9let = ECL_SYM("LET*",480);
  v10psetq = ECL_SYM("SETQ",754);
L15:;
  if (!(ecl_endp(v11body))){
   goto L24;
  }
  si_simple_program_error(3, VV[6], v3do_do_, v1whole);
L24:;
  v4control = ecl_car(v11body);
  v11body = ecl_cdr(v11body);
  if (!(ecl_endp(v11body))){
   goto L30;
  }
  si_simple_program_error(3, VV[6], v3do_do_, v1whole);
L30:;
  v5test = ecl_car(v11body);
  v11body = ecl_cdr(v11body);
  if (!(ecl_endp(v5test))){
   goto L36;
  }
  si_simple_program_error(3, VV[6], v3do_do_, v1whole);
L36:;
  v6result = ecl_cdr(v5test);
  v5test = ecl_car(v5test);
  {
   cl_object v12;
   v12 = v4control;
   goto L46;
L45:;
   {
    cl_object v13c;
    v13c = ecl_car(v12);
    if (!(ECL_SYMBOLP(v13c))){
     goto L50;
    }
    v13c = ecl_list1(v13c);
L50:;
    {
     cl_object v14;
     v14 = ecl_make_fixnum(ecl_length(v13c));
     if (!((ecl_fixnum(v14))==((cl_fixnum)(1)))){
      goto L60;
     }
     goto L57;
L60:;
     goto L58;
L58:;
     if (!((ecl_fixnum(v14))==((cl_fixnum)(2)))){
      goto L55;
     }
     goto L56;
L57:;
L56:;
     v7vl = CONS(v13c,v7vl);
     goto L53;
L55:;
     if (!((ecl_fixnum(v14))==((cl_fixnum)(3)))){
      goto L64;
     }
     T0 = ecl_butlast(v13c,1);
     v7vl = CONS(T0,v7vl);
     T0 = ecl_caddr(v13c);
     T1 = ecl_car(v13c);
     v8step = cl_listX(3, T0, T1, v8step);
     goto L53;
L64:;
     si_simple_program_error(3, VV[6], v3do_do_, v1whole);
    }
L53:;
   }
   v12 = ecl_cdr(v12);
L46:;
   if (Null(v12)){
    goto L71;
   }
   goto L45;
L71:;
  }
  {
   cl_object v12;                                 /*  DECLARATIONS            */
   cl_object v13;                                 /*  REAL-BODY               */
   value0 = si_process_declarations(2, v11body, ECL_NIL);
   {
    const int v14 = cl_env_copy->nvalues;
    v12 = value0;
    cl_object v15;
    v15 = (v14<=1)? ECL_NIL : cl_env_copy->values[1];
    v13 = v15;
   }
   T0 = cl_nreverse(v7vl);
   T1 = CONS(ECL_SYM("DECLARE",276),v12);
   if (Null(v8step)){
    goto L75;
   }
   T3 = cl_nreverse(v8step);
   T4 = CONS(v10psetq,T3);
   T2 = ecl_list1(T4);
   goto L74;
L75:;
   T2 = ECL_NIL;
L74:;
   T3 = ecl_append(v13,T2);
   T4 = cl_listX(3, ECL_SYM("UNTIL",1544), v5test, T3);
   value0 = v6result;
   if (value0!=ECL_NIL) {
    goto L79;
   }
   T5 = VV[14];
   goto L77;
L79:;
   T5 = value0;
   goto L77;
L77:;
   T6 = cl_listX(5, v9let, T0, T1, T4, T5);
   value0 = cl_list(3, ECL_SYM("BLOCK",139), ECL_NIL, T6);
   return value0;
  }
 }
}
static cl_object LC5do_do__expand_va(cl_narg narg, cl_object v12whole, cl_object v13env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[11]);
 {
  return LC5do_do__expand(v12whole, v13env);
 }
}
/* function definition for EVAL-FEATURE                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L6eval_feature(cl_object v1x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2operator;
  v2operator = ECL_NIL;
  if (!(ECL_SYMBOLP(v1x))){
   goto L3;
  }
  {
   cl_object v3;
   cl_object v4;
   cl_object v5;
   cl_object v6;
   v3 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
   v4 = (ECL_SYM("EQ",335)->symbol.gfdef);
   v5 = v1x;
   v6 = v3;
   if (Null(si_memq(v5,v6))){
    goto L6;
   }
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (!(ECL_ATOM(v1x))){
   goto L12;
  }
  value0 = cl_error(2, VV[16], v1x);
  return value0;
L12:;
  v2operator = ecl_car(v1x);
  if (ECL_SYMBOLP(v2operator)) {
   goto L14;
  }
  value0 = cl_error(2, VV[17], v1x);
  return value0;
L14:;
  if (!((v2operator)==(VV[18]))){
   goto L17;
  }
  {
   cl_object v3;
   v3 = ecl_cdr(v1x);
   goto L22;
L21:;
   {
    cl_object v4x;
    v4x = ecl_car(v3);
    if (L6eval_feature(v4x)!=ECL_NIL) {
     goto L26;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L26:;
   }
   v3 = ecl_cdr(v3);
L22:;
   if (Null(v3)){
    goto L30;
   }
   goto L21;
L30:;
   value0 = ECL_T;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L17:;
  if (!((v2operator)==(VV[19]))){
   goto L32;
  }
  {
   cl_object v4;
   v4 = ecl_cdr(v1x);
   goto L37;
L36:;
   {
    cl_object v5x;
    v5x = ecl_car(v4);
    if (Null(L6eval_feature(v5x))){
     goto L41;
    }
    value0 = ECL_T;
    cl_env_copy->nvalues = 1;
    return value0;
L41:;
   }
   v4 = ecl_cdr(v4);
L37:;
   if (Null(v4)){
    goto L45;
   }
   goto L36;
L45:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L32:;
  if (!((v2operator)==(VV[20]))){
   goto L47;
  }
  T0 = ecl_cadr(v1x);
  T1 = L6eval_feature(T0);
  value0 = Null(T1)?ECL_T:ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L47:;
  value0 = cl_error(2, VV[17], v1x);
  return value0;
 }
}
/* function definition for DO-READ-FEATURE                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L7do_read_feature(cl_object v1stream, cl_object v2subchar, cl_object v3arg, cl_object v4test)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v3arg)){
  goto L2;
 }
 cl_error(3, VV[22], v1stream, v2subchar);
L2:;
 {
  cl_object v5feature;
  T0 = cl_find_package(VV[23]);
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T0); /*  *PACKAGE*         */
  v5feature = cl_read(4, v1stream, ECL_T, ECL_NIL, ECL_T);
  ecl_bds_unwind1(cl_env_copy);
  if (ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*READ-SUPPRESS*",66))!=ECL_NIL) {
   goto L5;
  }
  T0 = L6eval_feature(v5feature);
  if (!((T0)==(v4test))){
   goto L5;
  }
  value0 = cl_read(4, v1stream, ECL_T, ECL_NIL, ECL_T);
  return value0;
L5:;
  ecl_bds_bind(cl_env_copy,ECL_SYM("*READ-SUPPRESS*",66),ECL_T); /*  *READ-SUPPRESS* */
  cl_read(4, v1stream, ECL_T, ECL_NIL, ECL_T);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
/* function definition for SHARP-+-READER                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L8sharp___reader(cl_object v1stream, cl_object v2subchar, cl_object v3arg)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L7do_read_feature(v1stream, v2subchar, v3arg, ECL_T);
 return value0;
}
static cl_object L8sharp___reader_va(cl_narg narg, cl_object v4stream, cl_object v5subchar, cl_object v6arg, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[24]);
 {
  return L8sharp___reader(v4stream, v5subchar, v6arg);
 }
}
/* function definition for SHARP---READER                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L9sharp___reader(cl_object v1stream, cl_object v2subchar, cl_object v3arg)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L7do_read_feature(v1stream, v2subchar, v3arg, ECL_NIL);
 return value0;
}
static cl_object L9sharp___reader_va(cl_narg narg, cl_object v4stream, cl_object v5subchar, cl_object v6arg, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[26]);
 {
  return L9sharp___reader(v4stream, v5subchar, v6arg);
 }
}
/* closure LAMBDA5                                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC1__lambda5(cl_narg narg, cl_object v1clause, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  A                       */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[3]);
 {
L1:;
  if (!(ECL_CONSP(v1clause))){
   goto L5;
  }
  T0 = ecl_car(v1clause);
  if ((T0)==(ECL_SYM("TYPE",872))) {
   goto L2;
  }
  T0 = ecl_car(v1clause);
  if ((T0)==(ECL_SYM("IGNORE",430))) {
   goto L2;
  }
  goto L3;
L5:;
  goto L3;
L3:;
  ECL_CONS_CAR(CLV0) = CONS(v1clause,ECL_CONS_CAR(CLV0));
  value0 = ECL_CONS_CAR(CLV0);
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
#include "lsp/export.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecluw0h0bai4zfp9_oSazL881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:LSP;EXPORT.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecluw0h0bai4zfp9_oSazL881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  si_Xmake_special(VV[0]);
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[1]);
  T0 = ecl_cmp_symbol_value(cl_env_copy,VV[0]);
  ecl_cmp_setq(cl_env_copy,VV[1],T0);
  (void)0; /* No entry created for FILTER-DOLIST-DECLARATIONS */
  {
   cl_object v1f;
   {
    cl_object v2;
    v2 = ecl_make_cfun_va((cl_objectfn)LC3dolist_va,ECL_NIL,Cblock,2);
    v1f = v2;
   }
   si_fset(3, ECL_SYM("DOLIST",315), v1f, ECL_T);
  }
  {
   cl_object v2f;
   {
    cl_object v3;
    v3 = ecl_make_cfun_va((cl_objectfn)LC4dotimes_va,ECL_NIL,Cblock,2);
    v2f = v3;
   }
   si_fset(3, ECL_SYM("DOTIMES",316), v2f, ECL_T);
  }
  {
   cl_object v3f;
   {
    cl_object v4;
    v4 = ecl_make_cfun_va((cl_objectfn)LC5do_do__expand_va,ECL_NIL,Cblock,2);
    v3f = v4;
   }
   si_fset(3, ECL_SYM("DO",309), v3f, ECL_T);
   si_fset(3, ECL_SYM("DO*",310), v3f, ECL_T);
  }
  (void)0; /* No entry created for EVAL-FEATURE */
  (void)0; /* No entry created for DO-READ-FEATURE */
  ecl_cmp_defun(VV[28]);                          /*  SHARP-+-READER          */
  ecl_cmp_defun(VV[29]);                          /*  SHARP---READER          */
  T0 = si_standard_readtable();
  si_readtable_lock(2, T0, ECL_NIL);
  cl_set_dispatch_macro_character(3, ECL_CODE_CHAR(35), ECL_CODE_CHAR(43), VV[24]);
  T0 = si_standard_readtable();
  cl_set_dispatch_macro_character(4, ECL_CODE_CHAR(35), ECL_CODE_CHAR(43), VV[24], T0);
  cl_set_dispatch_macro_character(3, ECL_CODE_CHAR(35), ECL_CODE_CHAR(45), VV[26]);
  T0 = si_standard_readtable();
  cl_set_dispatch_macro_character(4, ECL_CODE_CHAR(35), ECL_CODE_CHAR(45), VV[26], T0);
  T0 = si_standard_readtable();
  si_readtable_lock(2, T0, ECL_T);
 }
}
