/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpname.lsp                     */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpname.eclh"
/* function definition for ENCODE-NUMBER-IN-NAME                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3996encode_number_in_name(cl_object v1number)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ecl_zerop(v1number))){
  goto L2;
 }
 value0 = VV[1];
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!(ecl_minusp(v1number))){
  goto L4;
 }
 v1number = ecl_negate(v1number);
 goto L1;
L4:;
 {
  cl_object v2base;
  cl_object v3output;
  cl_object v4digit;
  v2base = ecl_make_fixnum(ecl_length(VV[2]));
  v3output = ECL_NIL;
  v4digit = ecl_make_int8_t(0);
  goto L13;
L12:;
  value0 = ecl_floor2(v1number,v2base);
  {
   v1number = value0;
   v4digit = cl_env_copy->values[1];
  }
  T0 = cl_char(VV[2], v4digit);
  v3output = CONS(T0,v3output);
L13:;
  if (ecl_zerop(v1number)) {
   goto L19;
  }
  goto L12;
L19:;
  T0 = cl_nreverse(v3output);
  value0 = si_coerce_to_vector(T0, ECL_SYM("BASE-CHAR",122), ECL_SYM("*",20), ECL_NIL);
  return value0;
 }
}
/* function definition for UNIQUE-INIT-NAME                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3997unique_init_name(cl_object v1file)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2path;
  cl_object v3path_hash;
  cl_object v4seconds;
  cl_object v5ms;
  cl_object v6tag;
  v2path = cl_pathname(v1file);
  T0 = cl_sxhash(v2path);
  T1 = cl_ash(T0, ecl_make_int8_t(8));
  T2 = cl_pathname_directory(1, v2path);
  T3 = ecl_cddr(T2);
  T4 = cl_sxhash(T3);
  T5 = cl_ash(T4, ecl_make_int8_t(16));
  T6 = cl_pathname_name(1, v2path);
  T7 = cl_sxhash(T6);
  v3path_hash = cl_logxor(3, T1, T5, T7);
  v4seconds = cl_get_universal_time();
  T0 = ecl_times(v4seconds,ecl_make_fixnum(1000));
  T1 = cl_get_internal_real_time();
  T2 = ecl_times(ecl_make_fixnum(1000),T1);
  T3 = ecl_floor2(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("INTERNAL-TIME-UNITS-PER-SECOND",445)));
  T4 = (ecl_floor2(T3,ecl_make_fixnum(1000)),cl_env_copy->values[1]);
  v5ms = ecl_plus(T0,T4);
  T0 = L3996encode_number_in_name(v3path_hash);
  T1 = L3996encode_number_in_name(v5ms);
  v6tag = cl_concatenate(5, ECL_SYM("BASE-STRING",123), VV[5], T0, VV[6], T1);
  value0 = v6tag;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3997unique_init_name_va(cl_narg narg, cl_object v7file, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[4]);
 {
  return L3997unique_init_name(v7file);
 }
}
/* function definition for KIND->TAG                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3998kind__tag(cl_object v1kind)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v1kind)==(ECL_SYM("OBJECT",1315)))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v1kind)==(VV[10]))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = VV[12];
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!((v1kind)==(VV[14]))){
  goto L15;
 }
 goto L12;
L15:;
 goto L13;
L13:;
 if (!((v1kind)==(VV[15]))){
  goto L10;
 }
 goto L11;
L12:;
L11:;
 value0 = VV[17];
 cl_env_copy->nvalues = 1;
 return value0;
L10:;
 if (!((v1kind)==(VV[19]))){
  goto L23;
 }
 goto L20;
L23:;
 goto L21;
L21:;
 if (!((v1kind)==(VV[20]))){
  goto L18;
 }
 goto L19;
L20:;
L19:;
 value0 = VV[22];
 cl_env_copy->nvalues = 1;
 return value0;
L18:;
 if (!((v1kind)==(VV[24]))){
  goto L31;
 }
 goto L28;
L31:;
 goto L29;
L29:;
 if (!((v1kind)==(VV[25]))){
  goto L26;
 }
 goto L27;
L28:;
L27:;
 value0 = VV[27];
 cl_env_copy->nvalues = 1;
 return value0;
L26:;
 if (!((v1kind)==(VV[29]))){
  goto L34;
 }
 value0 = VV[30];
 cl_env_copy->nvalues = 1;
 return value0;
L34:;
 value0 = cl_error(2, VV[31], v1kind);
 return value0;
}
static cl_object L3998kind__tag_va(cl_narg narg, cl_object v2kind, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[8]);
 {
  return L3998kind__tag(v2kind);
 }
}
/* function definition for INIT-NAME-TAG                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3999init_name_tag(cl_narg narg, cl_object v1init_name, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[33]);
 {
  cl_object v2kind;
  ecl_va_list args; ecl_va_start(args,v1init_name,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L3999init_name_tagkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v2kind = ECL_SYM("OBJECT",1315);
   } else {
    v2kind = keyvars[0];
   }
  }
  T0 = L3998kind__tag(v2kind);
  value0 = cl_concatenate(5, ECL_SYM("BASE-STRING",123), T0, VV[34], v1init_name, VV[35]);
  return value0;
 }
}
/* function definition for SEARCH-TAG                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4000search_tag(cl_object v1stream, cl_object v2tag)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3key;
  cl_object v4string;
  v3key = cl_concatenate(3, ECL_SYM("LIST",483), v2tag, VV[34]);
  v4string = v3key;
  goto L6;
L5:;
  {
   cl_object v5c;
   v5c = cl_read_byte(3, v1stream, ECL_NIL, ECL_NIL);
   if (!(v5c==ECL_NIL)){
    goto L10;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L10:;
   {
    cl_object v6;
    v6 = v4string;
    {
     cl_object v7;
     v7 = v6;
     {
      bool v8;
      v8 = ECL_LISTP(v7);
      if (ecl_unlikely(!(v8)))
         FEwrong_type_argument(VV[40],v7);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v6)){
     goto L19;
    }
    {
     cl_object v7;
     v7 = ECL_CONS_CDR(v6);
     v4string = v7;
     v6 = ECL_CONS_CAR(v6);
    }
L19:;
    T0 = v6;
   }
   T1 = cl_char_code(T0);
   if (ecl_number_equalp(v5c,T1)) {
    goto L12;
   }
   v4string = v3key;
   goto L8;
L12:;
   if (!(v4string==ECL_NIL)){
    goto L8;
   }
   value0 = ECL_T;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L8:;
L6:;
  goto L5;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for READ-NAME                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4001read_name(cl_object v1stream)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2c;
  v2c = ECL_T;
  {
   cl_object v3;
   cl_object v4;
   v3 = ecl_list1(ECL_NIL);
   v4 = v3;
L6:;
   v2c = cl_read_byte(3, v1stream, ECL_NIL, ECL_NIL);
   if (v2c==ECL_NIL) {
    goto L10;
   }
   if (!(ecl_number_equalp(v2c,ecl_make_int8_t(64)))){
    goto L8;
   }
   goto L9;
L10:;
L9:;
   goto L7;
L8:;
   {
    cl_object v5;
    v5 = v4;
    if (ecl_unlikely(ECL_ATOM(v5))) FEtype_error_cons(v5);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T1 = v5;
   }
   T2 = cl_code_char(v2c);
   v4 = ecl_list1(T2);
   (ECL_CONS_CDR(T1)=v4,T1);
   goto L6;
L7:;
   T0 = ecl_cdr(v3);
   goto L2;
  }
 }
L2:;
 value0 = cl_concatenate(2, ECL_SYM("STRING",808), T0);
 return value0;
}
/* function definition for FIND-INIT-NAME                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4002find_init_name(volatile cl_narg narg, cl_object volatile v1file, ...)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[46]);
 {
  cl_object volatile v2tag;
  ecl_va_list args; ecl_va_start(args,v1file,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4002find_init_namekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v2tag = VV[12];
   } else {
    v2tag = keyvars[0];
   }
  }
  {
   volatile cl_object v3stream;
   v3stream = cl_open(5, v1file, ECL_SYM("DIRECTION",1249), ECL_SYM("INPUT",1289), ECL_SYM("ELEMENT-TYPE",1255), VV[47]);
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    volatile bool unwinding = FALSE;
    ecl_frame_ptr next_fr;
    {
     ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
     if (__ecl_frs_push_result!=0) {
       unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
     } else {
     {
      struct ecl_stack_frame _ecl_inner_frame_aux;
      volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
      if (Null(L4000search_tag(v3stream, v2tag))){
       goto L5;
      }
      {
       cl_object v4name;
       v4name = L4001read_name(v3stream);
       cl_env_copy->values[0] = v4name;
       cl_env_copy->nvalues = 1;
       goto L4;
      }
L5:;
      cl_env_copy->values[0] = ECL_NIL;
      cl_env_copy->nvalues = 1;
L4:;
      ecl_stack_frame_push_values(_ecl_inner_frame);
      if (Null(v3stream)){
       goto L8;
      }
      cl_close(1, v3stream);
L8:;
      ecl_stack_frame_pop_values(_ecl_inner_frame);
      ecl_stack_frame_close(_ecl_inner_frame);
     }
     }
    }
    ecl_frs_pop(cl_env_copy);
    ecl_stack_frame_push_values(_ecl_inner_frame);
    if (Null(v3stream)){
     goto L10;
    }
    cl_close(3, v3stream, ECL_SYM("ABORT",1225), ECL_T);
L10:;
    ecl_stack_frame_pop_values(_ecl_inner_frame);
    if (unwinding) ecl_unwind(cl_env_copy,next_fr);
    ecl_stack_frame_close(_ecl_inner_frame);
    return cl_env_copy->values[0];
   }
  }
 }
}
/* function definition for GUESS-INIT-NAME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4003guess_init_name(cl_object v1pathname, cl_object v2kind)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = v2kind;
  v4 = VV[50];
  if (Null(ecl_memql(v3,v4))){
   goto L2;
  }
 }
 if (Null(cl_probe_file(v1pathname))){
  goto L10;
 }
 T0 = L3998kind__tag(v2kind);
 value0 = L4002find_init_name(3, v1pathname, ECL_SYM("TAG",1352), T0);
 goto L8;
L10:;
 value0 = ECL_NIL;
 goto L8;
L8:;
 if (value0!=ECL_NIL) {
  goto L7;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[51]))->cfun.entry(2, VV[52], v1pathname) /*  CMPNOTE */;
 return value0;
L7:;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = L4004compute_init_name(3, v1pathname, VV[54], v2kind);
 return value0;
}
static cl_object L4003guess_init_name_va(cl_narg narg, cl_object v3pathname, cl_object v4kind, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[49]);
 {
  return L4003guess_init_name(v3pathname, v4kind);
 }
}
/* function definition for COMPUTE-INIT-NAME                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4004compute_init_name(cl_narg narg, cl_object v1pathname, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[53]);
 {
  cl_object v2kind;
  cl_object v3prefix;
  ecl_va_list args; ecl_va_start(args,v1pathname,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4004compute_init_namekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[2])) {
    v2kind = (cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(1, v1pathname) /*  GUESS-KIND */;
   } else {
    v2kind = keyvars[0];
   }
   v3prefix = keyvars[1];
  }
  {
   cl_object v4unique_name;
   v4unique_name = L3997unique_init_name(v1pathname);
   if (!((v2kind)==(ECL_SYM("OBJECT",1315)))){
    goto L8;
   }
   goto L5;
L8:;
   goto L6;
L6:;
   if (!((v2kind)==(VV[10]))){
    goto L3;
   }
   goto L4;
L5:;
L4:;
   value0 = v4unique_name;
   cl_env_copy->nvalues = 1;
   return value0;
L3:;
   if (!((v2kind)==(VV[14]))){
    goto L16;
   }
   goto L13;
L16:;
   goto L14;
L14:;
   if (!((v2kind)==(VV[15]))){
    goto L11;
   }
   goto L12;
L13:;
L12:;
   value0 = L4007init_function_name(5, VV[58], VV[54], VV[15], VV[59], v3prefix);
   return value0;
L11:;
   if (!((v2kind)==(VV[19]))){
    goto L24;
   }
   goto L21;
L24:;
   goto L22;
L22:;
   if (!((v2kind)==(VV[20]))){
    goto L19;
   }
   goto L20;
L21:;
L20:;
   value0 = L4007init_function_name(5, v4unique_name, VV[54], VV[20], VV[59], v3prefix);
   return value0;
L19:;
   if (!((v2kind)==(VV[24]))){
    goto L32;
   }
   goto L29;
L32:;
   goto L30;
L30:;
   if (!((v2kind)==(VV[25]))){
    goto L27;
   }
   goto L28;
L29:;
L28:;
   value0 = L4007init_function_name(5, v4unique_name, VV[54], VV[25], VV[59], v3prefix);
   return value0;
L27:;
   if (!((v2kind)==(VV[29]))){
    goto L35;
   }
   value0 = v3prefix;
   if (value0!=ECL_NIL) {
    goto L40;
   }
   T0 = VV[60];
   goto L38;
L40:;
   T0 = value0;
   goto L38;
L38:;
   value0 = cl_concatenate(3, ECL_SYM("STRING",808), T0, VV[61]);
   return value0;
L35:;
   value0 = cl_error(2, VV[31], v2kind);
   return value0;
  }
 }
}
/* function definition for INIT-FUNCTION-NAME                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4007init_function_name(cl_narg narg, cl_object v1s, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[57]);
 {
  cl_object v2kind;
  cl_object v3prefix;
  ecl_va_list args; ecl_va_start(args,v1s,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4007init_function_namekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[2])) {
    v2kind = ECL_SYM("OBJECT",1315);
   } else {
    v2kind = keyvars[0];
   }
   v3prefix = keyvars[1];
  }
  {
   cl_object v4;
   v4 = ecl_make_cfun_va((cl_objectfn)LC4005translate_char_va,ECL_NIL,Cblock,1);
   T0 = cl_string(v1s);
   v1s = cl_map(3, ECL_SYM("STRING",808), v4, T0);
   value0 = v3prefix;
   if (value0!=ECL_NIL) {
    goto L6;
   }
   T0 = VV[60];
   goto L4;
L6:;
   T0 = value0;
   goto L4;
L4:;
   T1 = LC4006disambiguation(v2kind);
   T2 = cl_string(v1s);
   T3 = cl_map(3, ECL_SYM("STRING",808), v4, T2);
   value0 = cl_concatenate(4, ECL_SYM("STRING",808), T0, T1, T3);
   return value0;
  }
 }
}
/* local function DISAMBIGUATION                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4006disambiguation(cl_object v1kind)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v1kind)==(ECL_SYM("OBJECT",1315)))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v1kind)==(VV[10]))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = VV[65];
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!((v1kind)==(VV[14]))){
  goto L15;
 }
 goto L12;
L15:;
 goto L13;
L13:;
 if (!((v1kind)==(VV[15]))){
  goto L10;
 }
 goto L11;
L12:;
L11:;
 value0 = VV[66];
 cl_env_copy->nvalues = 1;
 return value0;
L10:;
 if (!((v1kind)==(VV[68]))){
  goto L23;
 }
 goto L20;
L23:;
 goto L21;
L21:;
 if (!((v1kind)==(VV[19]))){
  goto L27;
 }
 goto L20;
L27:;
 goto L25;
L25:;
 if (!((v1kind)==(VV[20]))){
  goto L18;
 }
 goto L19;
L20:;
L19:;
 value0 = VV[69];
 cl_env_copy->nvalues = 1;
 return value0;
L18:;
 if (!((v1kind)==(VV[24]))){
  goto L35;
 }
 goto L32;
L35:;
 goto L33;
L33:;
 if (!((v1kind)==(VV[25]))){
  goto L30;
 }
 goto L31;
L32:;
L31:;
 value0 = VV[70];
 cl_env_copy->nvalues = 1;
 return value0;
L30:;
 if (!((v1kind)==(VV[29]))){
  goto L38;
 }
 value0 = VV[71];
 cl_env_copy->nvalues = 1;
 return value0;
L38:;
 value0 = cl_error(2, VV[72], v1kind);
 return value0;
}
static cl_object LC4006disambiguation_va(cl_narg narg, cl_object v2kind, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[64]);
 {
  return LC4006disambiguation(v2kind);
 }
}
/* local function TRANSLATE-CHAR                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4005translate_char(cl_object v1c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_charGE(2, v1c, ECL_CODE_CHAR(97)))){
  goto L2;
 }
 if (Null(cl_charLE(2, v1c, ECL_CODE_CHAR(122)))){
  goto L2;
 }
 value0 = cl_char_upcase(v1c);
 return value0;
L2:;
 if (Null(cl_charGE(2, v1c, ECL_CODE_CHAR(65)))){
  goto L5;
 }
 if (Null(cl_charLE(2, v1c, ECL_CODE_CHAR(90)))){
  goto L5;
 }
 value0 = v1c;
 cl_env_copy->nvalues = 1;
 return value0;
L5:;
 if ((v1c)==(ECL_CODE_CHAR(45))) {
  goto L10;
 }
 if (!((v1c)==(ECL_CODE_CHAR(95)))){
  goto L8;
 }
 goto L9;
L10:;
L9:;
 value0 = ECL_CODE_CHAR(95);
 cl_env_copy->nvalues = 1;
 return value0;
L8:;
 if (!((v1c)==(ECL_CODE_CHAR(42)))){
  goto L12;
 }
 value0 = ECL_CODE_CHAR(120);
 cl_env_copy->nvalues = 1;
 return value0;
L12:;
 if (!((v1c)==(ECL_CODE_CHAR(63)))){
  goto L14;
 }
 value0 = ECL_CODE_CHAR(97);
 cl_env_copy->nvalues = 1;
 return value0;
L14:;
 if (Null(cl_digit_char_p(1, v1c))){
  goto L16;
 }
 value0 = v1c;
 cl_env_copy->nvalues = 1;
 return value0;
L16:;
 value0 = ECL_CODE_CHAR(112);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4005translate_char_va(cl_narg narg, cl_object v2c, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[63]);
 {
  return LC4005translate_char(v2c);
 }
}
#include "cmp/cmpname.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecljtotsyjvU1xj9_a7e0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPNAME.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecljtotsyjvU1xj9_a7e0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  (void)0; /* No entry created for ENCODE-NUMBER-IN-NAME */
  ecl_cmp_defun(VV[74]);                          /*  UNIQUE-INIT-NAME        */
  ecl_cmp_defun(VV[75]);                          /*  KIND->TAG               */
  ecl_cmp_defun(VV[76]);                          /*  INIT-NAME-TAG           */
  (void)0; /* No entry created for SEARCH-TAG */
  (void)0; /* No entry created for READ-NAME */
  ecl_cmp_defun(VV[77]);                          /*  FIND-INIT-NAME          */
  ecl_cmp_defun(VV[78]);                          /*  GUESS-INIT-NAME         */
  ecl_cmp_defun(VV[79]);                          /*  COMPUTE-INIT-NAME       */
  ecl_cmp_defun(VV[80]);                          /*  INIT-FUNCTION-NAME      */
}
