/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/build/cmp/cmpdefs.lsp                   */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpdefs.eclh"
/* local function DEFCONFIG                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3007defconfig(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4name;
  cl_object v5value;
  cl_object v6docstring;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v7;
   v7 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4name = v7;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v7;
   v7 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5value = v7;
  }
  if (Null(v3)){
   goto L16;
  }
  {
   cl_object v7;
   v7 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v6docstring = v7;
   goto L15;
  }
L16:;
  v6docstring = ECL_NIL;
L15:;
  if (Null(v3)){
   goto L21;
  }
  si_dm_too_many_arguments(v1);
L21:;
  if (Null(v6docstring)){
   goto L24;
  }
  T0 = cl_list(4, ECL_SYM("DEFVAR",292), v4name, v5value, v6docstring);
  goto L23;
L24:;
  T0 = cl_list(3, ECL_SYM("DEFVAR",292), v4name, v5value);
L23:;
  T1 = cl_list(2, ECL_SYM("QUOTE",682), v4name);
  T2 = cl_list(3, ECL_SYM("PUSHNEW",681), T1, VV[0]);
  value0 = cl_list(3, ECL_SYM("PROGN",674), T0, T2);
  return value0;
 }
}
static cl_object LC3007defconfig_va(cl_narg narg, cl_object v7, cl_object v8, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2]);
 {
  return LC3007defconfig(v7, v8);
 }
}
#include "cmp/cmpdefs.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclkQUxLGamihUi9_O2M0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("BUILD:CMP;CMPDEFS.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclkQUxLGamihUi9_O2M0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  si_Xmake_special(VV[0]);
  if (ecl_boundp(cl_env_copy,VV[0])) {
   goto L3;
  }
  T0 = VVtemp[1];
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
L3:;
  ecl_cmp_defmacro(VV[33]);                       /*  DEFCONFIG               */
  si_Xmake_special(VV[5]);
  if (ecl_boundp(cl_env_copy,VV[5])) {
   goto L12;
  }
  T0 = VVtemp[2];
  ecl_cmp_setq(cl_env_copy,VV[5],T0);
L12:;
  T0 = cl_adjoin(2, VV[5], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[6]);
  if (ecl_boundp(cl_env_copy,VV[6])) {
   goto L21;
  }
  T0 = VVtemp[3];
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
L21:;
  T0 = cl_adjoin(2, VV[6], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[7]);
  if (ecl_boundp(cl_env_copy,VV[7])) {
   goto L30;
  }
  T0 = VVtemp[3];
  ecl_cmp_setq(cl_env_copy,VV[7],T0);
L30:;
  T0 = cl_adjoin(2, VV[7], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[8]);
  if (ecl_boundp(cl_env_copy,VV[8])) {
   goto L39;
  }
  T0 = VVtemp[4];
  ecl_cmp_setq(cl_env_copy,VV[8],T0);
L39:;
  T0 = cl_adjoin(2, VV[8], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[9]);
  if (ecl_boundp(cl_env_copy,VV[9])) {
   goto L48;
  }
  T0 = VVtemp[5];
  ecl_cmp_setq(cl_env_copy,VV[9],T0);
L48:;
  T0 = cl_adjoin(2, VV[9], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[10]);
  if (ecl_boundp(cl_env_copy,VV[10])) {
   goto L57;
  }
  T0 = VVtemp[6];
  ecl_cmp_setq(cl_env_copy,VV[10],T0);
L57:;
  T0 = cl_adjoin(2, VV[10], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[11]);
  if (ecl_boundp(cl_env_copy,VV[11])) {
   goto L66;
  }
  T0 = VVtemp[7];
  ecl_cmp_setq(cl_env_copy,VV[11],T0);
L66:;
  T0 = cl_adjoin(2, VV[11], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[12]);
  if (ecl_boundp(cl_env_copy,VV[12])) {
   goto L75;
  }
  T0 = VVtemp[8];
  ecl_cmp_setq(cl_env_copy,VV[12],T0);
L75:;
  T0 = cl_adjoin(2, VV[12], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[13]);
  if (ecl_boundp(cl_env_copy,VV[13])) {
   goto L84;
  }
  T0 = VVtemp[9];
  ecl_cmp_setq(cl_env_copy,VV[13],T0);
L84:;
  T0 = cl_adjoin(2, VV[13], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[14]);
  if (ecl_boundp(cl_env_copy,VV[14])) {
   goto L93;
  }
  T0 = VVtemp[10];
  ecl_cmp_setq(cl_env_copy,VV[14],T0);
L93:;
  T0 = cl_adjoin(2, VV[14], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[15]);
  if (ecl_boundp(cl_env_copy,VV[15])) {
   goto L102;
  }
  T0 = VVtemp[10];
  ecl_cmp_setq(cl_env_copy,VV[15],T0);
L102:;
  T0 = cl_adjoin(2, VV[15], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[16]);
  if (ecl_boundp(cl_env_copy,VV[16])) {
   goto L111;
  }
  T0 = VVtemp[11];
  ecl_cmp_setq(cl_env_copy,VV[16],T0);
L111:;
  T0 = cl_adjoin(2, VV[16], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[17]);
  if (ecl_boundp(cl_env_copy,VV[17])) {
   goto L120;
  }
  T0 = VVtemp[12];
  ecl_cmp_setq(cl_env_copy,VV[17],T0);
L120:;
  T0 = cl_adjoin(2, VV[17], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[18]);
  if (ecl_boundp(cl_env_copy,VV[18])) {
   goto L129;
  }
  T0 = VVtemp[13];
  ecl_cmp_setq(cl_env_copy,VV[18],T0);
L129:;
  T0 = cl_adjoin(2, VV[18], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[19]);
  if (ecl_boundp(cl_env_copy,VV[19])) {
   goto L138;
  }
  T0 = VVtemp[14];
  ecl_cmp_setq(cl_env_copy,VV[19],T0);
L138:;
  T0 = cl_adjoin(2, VV[19], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[20]);
  if (ecl_boundp(cl_env_copy,VV[20])) {
   goto L147;
  }
  T0 = VVtemp[12];
  ecl_cmp_setq(cl_env_copy,VV[20],T0);
L147:;
  T0 = cl_adjoin(2, VV[20], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[21]);
  if (ecl_boundp(cl_env_copy,VV[21])) {
   goto L156;
  }
  T0 = VVtemp[15];
  ecl_cmp_setq(cl_env_copy,VV[21],T0);
L156:;
  T0 = cl_adjoin(2, VV[21], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[22]);
  if (ecl_boundp(cl_env_copy,VV[22])) {
   goto L165;
  }
  T0 = VVtemp[16];
  ecl_cmp_setq(cl_env_copy,VV[22],T0);
L165:;
  T0 = cl_adjoin(2, VV[22], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[23]);
  if (ecl_boundp(cl_env_copy,VV[23])) {
   goto L174;
  }
  T0 = VVtemp[17];
  ecl_cmp_setq(cl_env_copy,VV[23],T0);
L174:;
  T0 = cl_adjoin(2, VV[23], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[24]);
  if (ecl_boundp(cl_env_copy,VV[24])) {
   goto L183;
  }
  T0 = VVtemp[18];
  ecl_cmp_setq(cl_env_copy,VV[24],T0);
L183:;
  T0 = cl_adjoin(2, VV[24], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[25]);
  if (ecl_boundp(cl_env_copy,VV[25])) {
   goto L192;
  }
  T0 = VVtemp[19];
  ecl_cmp_setq(cl_env_copy,VV[25],T0);
L192:;
  T0 = cl_adjoin(2, VV[25], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[26]);
  if (ecl_boundp(cl_env_copy,VV[26])) {
   goto L201;
  }
  T0 = VVtemp[20];
  ecl_cmp_setq(cl_env_copy,VV[26],T0);
L201:;
  T0 = cl_adjoin(2, VV[26], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[27]);
  if (ecl_boundp(cl_env_copy,VV[27])) {
   goto L210;
  }
  T0 = VVtemp[21];
  ecl_cmp_setq(cl_env_copy,VV[27],T0);
L210:;
  T0 = cl_adjoin(2, VV[27], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[28]);
  if (ecl_boundp(cl_env_copy,VV[28])) {
   goto L219;
  }
  {
   cl_fixnum v1;
   v1 = ecl_length(VVtemp[22]);
   if (!((v1)>0)){
    goto L223;
   }
  }
  T0 = cl_format(3, ECL_NIL, VVtemp[22], ecl_cmp_symbol_value(cl_env_copy,VV[26]));
  ecl_cmp_setq(cl_env_copy,VV[28],T0);
  goto L221;
L223:;
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[28],T0);
  goto L221;
L221:;
L219:;
  T0 = cl_adjoin(2, VV[28], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[29]);
  if (ecl_boundp(cl_env_copy,VV[29])) {
   goto L231;
  }
  T0 = VVtemp[23];
  ecl_cmp_setq(cl_env_copy,VV[29],T0);
L231:;
  T0 = cl_adjoin(2, VV[29], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[30]);
  if (ecl_boundp(cl_env_copy,VV[30])) {
   goto L240;
  }
  T0 = VVtemp[24];
  ecl_cmp_setq(cl_env_copy,VV[30],T0);
L240:;
  T0 = cl_adjoin(2, VV[30], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[31]);
  if (ecl_boundp(cl_env_copy,VV[31])) {
   goto L249;
  }
  T0 = VVtemp[25];
  ecl_cmp_setq(cl_env_copy,VV[31],T0);
L249:;
  T0 = cl_adjoin(2, VV[31], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  si_Xmake_special(VV[32]);
  if (ecl_boundp(cl_env_copy,VV[32])) {
   goto L258;
  }
  T0 = VVtemp[26];
  ecl_cmp_setq(cl_env_copy,VV[32],T0);
L258:;
  T0 = cl_adjoin(2, VV[32], ecl_cmp_symbol_value(cl_env_copy,VV[0]));
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
 }
}
