/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpbackend-cxx/cmpc-util.lsp    */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpc-util.eclh"
/* function definition for TMP-DESTINATION                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3615tmp_destination(cl_object v1loc)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v1loc)==(VV[25]))){
  goto L2;
 }
 value0 = VV[25];
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!((v1loc)==(VV[26]))){
  goto L4;
 }
 value0 = VV[26];
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 value0 = VV[27];
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3615tmp_destination_va(cl_narg narg, cl_object v2loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[24]);
 {
  return L3615tmp_destination(v2loc);
 }
}
/* local function WITH-CXX-ENV                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3616with_cxx_env(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v5;
  }
  if (Null(v4)){
   goto L9;
  }
  si_dm_too_many_arguments(v1);
L9:;
  value0 = cl_listX(3, ECL_SYM("LET",479), VV[39], v3);
  return value0;
 }
}
static cl_object LC3616with_cxx_env_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[37]);
 {
  return LC3616with_cxx_env(v5, v6);
 }
}
/* local function WITH-BIR-ENV                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3617with_bir_env(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6env;
  cl_object v7;
  cl_object v8level;
  cl_object v9;
  cl_object v10volatile;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v11;
   v11 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v11;
  }
  v5 = si_search_keyword(v4, VV[42]);
  if (!((v5)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L11;
  }
  v6env = ECL_NIL;
  goto L10;
L11:;
  v6env = v5;
L10:;
  v7 = si_search_keyword(v4, ECL_SYM("LEVEL",1299));
  if (!((v7)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L15;
  }
  v8level = ECL_NIL;
  goto L14;
L15:;
  v8level = v7;
L14:;
  v9 = si_search_keyword(v4, VV[43]);
  if (!((v9)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L19;
  }
  v10volatile = ECL_NIL;
  goto L18;
L19:;
  v10volatile = v9;
L18:;
  si_check_keyword(2, v4, VV[46]);
  T0 = cl_list(2, VV[13], v6env);
  T1 = cl_list(2, VV[10], v8level);
  T2 = cl_list(2, VV[55], v10volatile);
  T3 = cl_listX(12, VV[47], VV[48], VV[49], VV[50], VV[51], VV[52], T0, VV[53], T1, VV[54], T2, VV[56]);
  value0 = cl_listX(3, ECL_SYM("LET*",480), T3, v3);
  return value0;
 }
}
static cl_object LC3617with_bir_env_va(cl_narg narg, cl_object v11, cl_object v12, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[44]);
 {
  return LC3617with_bir_env(v11, v12);
 }
}
/* function definition for ENV-VAR-NAME-EMPTY-CACHE                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3618env_var_name_empty_cache()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = si_make_vector(ECL_T, ecl_make_fixnum(1024), ECL_NIL, ECL_NIL, ECL_NIL, ecl_make_int8_t(0));
 ecl_cmp_setq(cl_env_copy,VV[58],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[58]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3618env_var_name_empty_cache_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[59]);
 {
  return L3618env_var_name_empty_cache();
 }
}
/* function definition for ENV-VAR-NAME                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3620env_var_name(cl_object v1n)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_fixnum v2hash;
  cl_object v3cache;
  cl_object v4elt;
  {
   cl_object v5;
   T0 = si_hash_eql(1, v1n);
   v5 = ecl_boole(ECL_BOOLAND,(T0),(ecl_make_fixnum(1023)));
   {
    cl_fixnum v6;
    cl_fixnum v7;
    v6 = (cl_fixnum)(0);
    v7 = v6;
    if (!(ECL_FIXNUMP(v5))){
     goto L9;
    }
    v7 = ecl_fixnum(v5);
    if (!((v7)<=(1023))){
     goto L14;
    }
    T0 = ecl_make_bool((v7)>=((cl_fixnum)(0)));
    goto L5;
L14:;
    T0 = ECL_NIL;
    goto L5;
L9:;
    T0 = ECL_NIL;
    goto L5;
   }
L5:;
   if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[63],v5);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v2hash = ecl_fixnum(v5);
  }
  {
   cl_object v5;
   v5 = ecl_cmp_symbol_value(cl_env_copy,VV[58]);
   T0 = cl_typep(2, v5, VV[64]);
   if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[64],v5);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3cache = v5;
  }
  {
   cl_object v5;
   v5 = v3cache;
   T0 = v5;
   {
    cl_fixnum v6;
    v6 = v2hash;
    if (ecl_unlikely((v6)>=(v5)->vector.dim))
           FEwrong_index(ECL_NIL,v5,-1,ecl_make_fixnum(v6),(v5)->vector.dim);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T1 = ecl_make_fixnum(v6);
   }
   v4elt = ecl_aref_unsafe(T0,ecl_fixnum(T1));
  }
  if (Null(v4elt)){
   goto L26;
  }
  {
   cl_object v5;
   {
    cl_object v6;
    v6 = v4elt;
    if (ecl_unlikely(ECL_ATOM(v6))) FEtype_error_cons(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v6;
   }
   {
    cl_object v6;
    v6 = v5;
    {
     bool v7;
     v7 = ECL_LISTP(v6);
     if (ecl_unlikely(!(v7)))
         FEwrong_type_argument(VV[69],v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v5)){
    goto L36;
   }
   {
    cl_object v6;
    v6 = ECL_CONS_CDR(v5);
    {
     cl_object v7;
     v7 = v6;
     if (ecl_unlikely(ECL_ATOM(v7))) FEtype_error_cons(v7);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v4elt = v7;
    }
    v5 = ECL_CONS_CAR(v5);
   }
L36:;
   T0 = v5;
  }
  if (!(ecl_eql(T0,v1n))){
   goto L26;
  }
  value0 = ecl_car(v4elt);
  cl_env_copy->nvalues = 1;
  return value0;
L26:;
  {
   cl_object v5output;
   v5output = LC3619env_var_name(v1n);
   {
    cl_object v6;
    v6 = ecl_cmp_symbol_value(cl_env_copy,VV[58]);
    T0 = v6;
    {
     cl_fixnum v7;
     v7 = v2hash;
     if (ecl_unlikely((v7)>=(v6)->vector.dim))
           FEwrong_index(ECL_NIL,v6,-1,ecl_make_fixnum(v7),(v6)->vector.dim);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T1 = ecl_make_fixnum(v7);
    }
    T2 = cl_list(2, v1n, v5output);
    ecl_aset_unsafe(T0,ecl_fixnum(T1),T2);
   }
   value0 = v5output;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3620env_var_name_va(cl_narg narg, cl_object v6n, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[61]);
 {
  return L3620env_var_name(v6n);
 }
}
/* function definition for LEX-ENV-VAR-NAME-EMPTY-CACHE                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3621lex_env_var_name_empty_cache()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = si_make_vector(ECL_T, ecl_make_fixnum(1024), ECL_NIL, ECL_NIL, ECL_NIL, ecl_make_int8_t(0));
 ecl_cmp_setq(cl_env_copy,VV[71],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[71]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3621lex_env_var_name_empty_cache_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[72]);
 {
  return L3621lex_env_var_name_empty_cache();
 }
}
/* function definition for LEX-ENV-VAR-NAME                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3623lex_env_var_name(cl_object v1n)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_fixnum v2hash;
  cl_object v3cache;
  cl_object v4elt;
  {
   cl_object v5;
   T0 = si_hash_eql(1, v1n);
   v5 = ecl_boole(ECL_BOOLAND,(T0),(ecl_make_fixnum(1023)));
   {
    cl_fixnum v6;
    cl_fixnum v7;
    v6 = (cl_fixnum)(0);
    v7 = v6;
    if (!(ECL_FIXNUMP(v5))){
     goto L9;
    }
    v7 = ecl_fixnum(v5);
    if (!((v7)<=(1023))){
     goto L14;
    }
    T0 = ecl_make_bool((v7)>=((cl_fixnum)(0)));
    goto L5;
L14:;
    T0 = ECL_NIL;
    goto L5;
L9:;
    T0 = ECL_NIL;
    goto L5;
   }
L5:;
   if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[63],v5);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v2hash = ecl_fixnum(v5);
  }
  {
   cl_object v5;
   v5 = ecl_cmp_symbol_value(cl_env_copy,VV[71]);
   T0 = cl_typep(2, v5, VV[64]);
   if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[64],v5);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3cache = v5;
  }
  {
   cl_object v5;
   v5 = v3cache;
   T0 = v5;
   {
    cl_fixnum v6;
    v6 = v2hash;
    if (ecl_unlikely((v6)>=(v5)->vector.dim))
           FEwrong_index(ECL_NIL,v5,-1,ecl_make_fixnum(v6),(v5)->vector.dim);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T1 = ecl_make_fixnum(v6);
   }
   v4elt = ecl_aref_unsafe(T0,ecl_fixnum(T1));
  }
  if (Null(v4elt)){
   goto L26;
  }
  {
   cl_object v5;
   {
    cl_object v6;
    v6 = v4elt;
    if (ecl_unlikely(ECL_ATOM(v6))) FEtype_error_cons(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v6;
   }
   {
    cl_object v6;
    v6 = v5;
    {
     bool v7;
     v7 = ECL_LISTP(v6);
     if (ecl_unlikely(!(v7)))
         FEwrong_type_argument(VV[69],v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v5)){
    goto L36;
   }
   {
    cl_object v6;
    v6 = ECL_CONS_CDR(v5);
    {
     cl_object v7;
     v7 = v6;
     if (ecl_unlikely(ECL_ATOM(v7))) FEtype_error_cons(v7);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v4elt = v7;
    }
    v5 = ECL_CONS_CAR(v5);
   }
L36:;
   T0 = v5;
  }
  if (!(ecl_eql(T0,v1n))){
   goto L26;
  }
  value0 = ecl_car(v4elt);
  cl_env_copy->nvalues = 1;
  return value0;
L26:;
  {
   cl_object v5output;
   v5output = LC3622lex_env_var_name(v1n);
   {
    cl_object v6;
    v6 = ecl_cmp_symbol_value(cl_env_copy,VV[71]);
    T0 = v6;
    {
     cl_fixnum v7;
     v7 = v2hash;
     if (ecl_unlikely((v7)>=(v6)->vector.dim))
           FEwrong_index(ECL_NIL,v6,-1,ecl_make_fixnum(v7),(v6)->vector.dim);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T1 = ecl_make_fixnum(v7);
    }
    T2 = cl_list(2, v1n, v5output);
    ecl_aset_unsafe(T0,ecl_fixnum(T1),T2);
   }
   value0 = v5output;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3623lex_env_var_name_va(cl_narg narg, cl_object v6n, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[74]);
 {
  return L3623lex_env_var_name(v6n);
 }
}
/* function definition for NEXT-LCL                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3624next_lcl(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[77]);
 {
  cl_object v1name;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1name = ECL_NIL;
   } else {
    i++;
    v1name = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T1 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[7]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[7],T1);
  T0 = ecl_cmp_symbol_value(cl_env_copy,VV[7]);
  if (Null(v1name)){
   goto L5;
  }
  if (Null(cl_symbol_package(v1name))){
   goto L5;
  }
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[79]))->cfun.entry(1, v1name) /*  LISP-TO-C-NAME */;
  goto L4;
L5:;
  T1 = VV[80];
L4:;
  value0 = cl_list(4, VV[78], T0, ECL_T, T1);
  return value0;
 }
}
/* function definition for NEXT-TEMP                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3625next_temp()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_cmp_symbol_value(cl_env_copy,VV[8]);
  T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[8]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[8],T0);
  T0 = ((ecl_float_nan_p(ecl_cmp_symbol_value(cl_env_copy,VV[9])) || ecl_greatereq(ecl_cmp_symbol_value(cl_env_copy,VV[8]),ecl_cmp_symbol_value(cl_env_copy,VV[9])))?ecl_cmp_symbol_value(cl_env_copy,VV[8]):ecl_cmp_symbol_value(cl_env_copy,VV[9]));
  ecl_cmp_setq(cl_env_copy,VV[9],T0);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3625next_temp_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[82]);
 {
  return L3625next_temp();
 }
}
/* function definition for NEXT-LEX                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3626next_lex()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = CONS(ecl_cmp_symbol_value(cl_env_copy,VV[10]),ecl_cmp_symbol_value(cl_env_copy,VV[11]));
  T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[11]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[11],T0);
  T0 = ((ecl_float_nan_p(ecl_cmp_symbol_value(cl_env_copy,VV[12])) || ecl_greatereq(ecl_cmp_symbol_value(cl_env_copy,VV[11]),ecl_cmp_symbol_value(cl_env_copy,VV[12])))?ecl_cmp_symbol_value(cl_env_copy,VV[11]):ecl_cmp_symbol_value(cl_env_copy,VV[12]));
  ecl_cmp_setq(cl_env_copy,VV[12],T0);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3626next_lex_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[84]);
 {
  return L3626next_lex();
 }
}
/* function definition for NEXT-ENV                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3627next_env()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_cmp_symbol_value(cl_env_copy,VV[13]);
  T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[13]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[13],T0);
  T0 = ((ecl_float_nan_p(ecl_cmp_symbol_value(cl_env_copy,VV[14])) || ecl_greatereq(ecl_cmp_symbol_value(cl_env_copy,VV[13]),ecl_cmp_symbol_value(cl_env_copy,VV[14])))?ecl_cmp_symbol_value(cl_env_copy,VV[13]):ecl_cmp_symbol_value(cl_env_copy,VV[14]));
  ecl_cmp_setq(cl_env_copy,VV[14],T0);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3627next_env_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[86]);
 {
  return L3627next_env();
 }
}
/* function definition for ENV-GROWS                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3628env_grows(cl_object v1possibily)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1possibily)){
  goto L3;
 }
 if (!(ecl_plusp(ecl_cmp_symbol_value(cl_env_copy,VV[13])))){
  goto L3;
 }
 {
  cl_object v2;
  v2 = ecl_cmp_symbol_value(cl_env_copy,VV[22]);
  goto L9;
L8:;
  {
   cl_object v3exit;
   v3exit = ecl_car(v2);
   if (!((v3exit)==(VV[27]))){
    goto L14;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L14:;
   if ((v3exit)==(VV[89])) {
    goto L13;
   }
   value0 = ECL_T;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
  }
  v2 = ecl_cdr(v2);
L9:;
  if (Null(v2)){
   goto L19;
  }
  goto L8;
L19:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3628env_grows_va(cl_narg narg, cl_object v3possibily, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[88]);
 {
  return L3628env_grows(v3possibily);
 }
}
/* function definition for NEXT-CFUN                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3629next_cfun(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[92]);
 {
  cl_object v1prefix;
  cl_object v2lisp_name;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1prefix = VV[91];
   } else {
    i++;
    v1prefix = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v2lisp_name = ECL_NIL;
   } else {
    i++;
    v2lisp_name = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v3code;
   T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[18]),ecl_make_int8_t(1));
   ecl_cmp_setq(cl_env_copy,VV[18],T0);
   v3code = ecl_cmp_symbol_value(cl_env_copy,VV[18]);
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[79]))->cfun.entry(1, v2lisp_name) /*  LISP-TO-C-NAME */;
   value0 = cl_format(4, ECL_NIL, v1prefix, v3code, T0);
   return value0;
  }
 }
}
/* local function WITH-INLINE-BLOCKS                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3630with_inline_blocks(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v5;
  }
  if (Null(v4)){
   goto L9;
  }
  si_dm_too_many_arguments(v1);
L9:;
  T0 = ecl_append(v3,VV[96]);
  value0 = cl_listX(3, ECL_SYM("LET",479), VV[95], T0);
  return value0;
 }
}
static cl_object LC3630with_inline_blocks_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[94]);
 {
  return LC3630with_inline_blocks(v5, v6);
 }
}
/* local function WITH-LEXICAL-SCOPE                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3631with_lexical_scope(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v5;
  }
  if (Null(v4)){
   goto L9;
  }
  si_dm_too_many_arguments(v1);
L9:;
  value0 = cl_listX(4, VV[94], ECL_NIL, VV[99], v3);
  return value0;
 }
}
static cl_object LC3631with_lexical_scope_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[98]);
 {
  return LC3631with_lexical_scope(v5, v6);
 }
}
/* function definition for MAKE-LABEL                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3632make_label(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L3632make_labelkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1 = keyvars[0];
   v2 = keyvars[1];
   v3 = keyvars[2];
  }
  value0 = si_make_structure(4, VV[107], v1, v2, v3);
  return value0;
 }
}
/* local function LAMBDA177                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3633__lambda177(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[103]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[103]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3633__lambda177_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[111]);
 {
  return LC3633__lambda177(v5, v6si__x);
 }
}
/* local function LAMBDA182                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3634__lambda182(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[103]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[103]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3634__lambda182_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[113]);
 {
  return LC3634__lambda182(v5, v6si__x);
 }
}
/* local function LAMBDA187                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3635__lambda187(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[103]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[103]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3635__lambda187_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[115]);
 {
  return LC3635__lambda187(v5, v6si__x);
 }
}
/* function definition for NEXT-LABEL                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3636next_label(cl_object v1used_p)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T1 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[101]),ecl_make_int8_t(1));
 ecl_cmp_setq(cl_env_copy,VV[101],T1);
 T0 = ecl_cmp_symbol_value(cl_env_copy,VV[101]);
 value0 = L3632make_label(6, VV[117], T0, VV[118], ecl_cmp_symbol_value(cl_env_copy,VV[22]), VV[119], v1used_p);
 return value0;
}
static cl_object L3636next_label_va(cl_narg narg, cl_object v2used_p, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[116]);
 {
  return L3636next_label(v2used_p);
 }
}
/* local function WITH-EXIT-LABEL                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3637with_exit_label(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6var;
  cl_object v7exit;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v8;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6var = v8;
  }
  if (Null(v5)){
   goto L17;
  }
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7exit = v8;
   goto L16;
  }
L17:;
  v7exit = ECL_NIL;
L16:;
  if (Null(v5)){
   goto L22;
  }
  si_dm_too_many_arguments(v1);
L22:;
  {
   cl_object v8reuse;
   cl_object v9label;
   v8reuse = cl_gensym(1, _ecl_static_1);
   v9label = cl_gensym(1, _ecl_static_2);
   T0 = cl_list(2, v9label, v7exit);
   T1 = cl_list(2, VV[105], v9label);
   T2 = cl_list(2, v8reuse, T1);
   T3 = cl_list(4, ECL_SYM("IF",950), v8reuse, v9label, VV[122]);
   T4 = cl_list(2, v6var, T3);
   T5 = cl_list(3, ECL_SYM("ADJOIN",84), v6var, VV[22]);
   T6 = cl_list(2, VV[22], T5);
   T7 = cl_list(4, T0, T2, T4, T6);
   T8 = cl_list(2, VV[123], v6var);
   T9 = cl_list(3, ECL_SYM("UNLESS",886), v8reuse, T8);
   T10 = ecl_list1(T9);
   T11 = ecl_append(v3,T10);
   value0 = cl_listX(3, ECL_SYM("LET*",480), T7, T11);
   return value0;
  }
 }
}
static cl_object LC3637with_exit_label_va(cl_narg narg, cl_object v10, cl_object v11, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[121]);
 {
  return LC3637with_exit_label(v10, v11);
 }
}
/* local function WITH-UNWIND-FRAME                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3638with_unwind_frame(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6tag;
  cl_object v7handler_form;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v8;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6tag = v8;
  }
  if (!(v3==ECL_NIL)){
   goto L17;
  }
  si_dm_too_few_arguments(v1);
L17:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v7handler_form = v8;
  }
  if (Null(v5)){
   goto L22;
  }
  si_dm_too_many_arguments(v1);
L22:;
  T0 = cl_list(4, VV[127], VV[128], v6tag, VV[129]);
  if (Null(v3)){
   goto L25;
  }
  T1 = CONS(VV[131],v3);
  goto L24;
L25:;
  T1 = ECL_NIL;
L24:;
  T2 = ecl_append(T1,VV[132]);
  T3 = cl_listX(6, ECL_SYM("LET",479), VV[126], T0, VV[130], v7handler_form, T2);
  value0 = cl_list(3, VV[98], ECL_NIL, T3);
  return value0;
 }
}
static cl_object LC3638with_unwind_frame_va(cl_narg narg, cl_object v8, cl_object v9, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[125]);
 {
  return LC3638with_unwind_frame(v8, v9);
 }
}
/* local function WITH-STACK-FRAME                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3639with_stack_frame(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6var;
  cl_object v7loc;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v8;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6var = v8;
  }
  if (Null(v5)){
   goto L17;
  }
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7loc = v8;
   goto L16;
  }
L17:;
  v7loc = ECL_NIL;
L16:;
  if (Null(v5)){
   goto L22;
  }
  si_dm_too_many_arguments(v1);
L22:;
  {
   cl_object v8hlp;
   v8hlp = cl_gensym(1, _ecl_static_3);
   value0 = v7loc;
   if (value0!=ECL_NIL) {
    goto L27;
   }
   T0 = VV[135];
   goto L25;
L27:;
   T0 = value0;
   goto L25;
L25:;
   T1 = cl_list(2, v6var, T0);
   T2 = cl_list(2, v8hlp, VV[136]);
   T3 = cl_list(3, ECL_SYM("LIST",483), VV[137], v6var);
   T4 = cl_list(3, ECL_SYM("LIST*",484), T3, VV[22]);
   T5 = cl_list(2, VV[22], T4);
   T6 = cl_list(3, T1, T2, T5);
   T7 = cl_list(4, VV[127], VV[138], v8hlp, VV[139]);
   T8 = cl_list(7, VV[127], VV[55], VV[140], v6var, VV[141], v8hlp, VV[142]);
   T9 = cl_listX(5, ECL_SYM("LET*",480), T6, T7, T8, v3);
   value0 = cl_list(3, VV[98], ECL_NIL, T9);
   return value0;
  }
 }
}
static cl_object LC3639with_stack_frame_va(cl_narg narg, cl_object v9, cl_object v10, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[134]);
 {
  return LC3639with_stack_frame(v9, v10);
 }
}
/* local function ENV-VAR-NAME                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3619env_var_name(cl_object v1n)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(3, ECL_NIL, VV[62], v1n);
 return value0;
}
static cl_object LC3619env_var_name_va(cl_narg narg, cl_object v2n, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[61]);
 {
  return LC3619env_var_name(v2n);
 }
}
/* local function LEX-ENV-VAR-NAME                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3622lex_env_var_name(cl_object v1n)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(3, ECL_NIL, VV[75], v1n);
 return value0;
}
static cl_object LC3622lex_env_var_name_va(cl_narg narg, cl_object v2n, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[74]);
 {
  return LC3622lex_env_var_name(v2n);
 }
}
#include "cmp/cmpc-util.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclDhkOhmtKm59q9_MfW0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPBACKEND-CXX;CMPC-UTIL.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclDhkOhmtKm59q9_MfW0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  si_Xmake_special(VV[0]);
  if (ecl_boundp(cl_env_copy,VV[0])) {
   goto L3;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
L3:;
  si_Xmake_special(VV[1]);
  if (ecl_boundp(cl_env_copy,VV[1])) {
   goto L10;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[1],T0);
L10:;
  si_Xmake_special(VV[2]);
  if (ecl_boundp(cl_env_copy,VV[2])) {
   goto L17;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[2],T0);
L17:;
  si_Xmake_special(VV[3]);
  if (ecl_boundp(cl_env_copy,VV[3])) {
   goto L24;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[3],T0);
L24:;
  si_Xmake_special(VV[4]);
  if (ecl_boundp(cl_env_copy,VV[4])) {
   goto L31;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[4],T0);
L31:;
  T0 = cl_adjoin(2, VV[4], ecl_cmp_symbol_value(cl_env_copy,VV[5]));
  ecl_cmp_setq(cl_env_copy,VV[5],T0);
  si_Xmake_special(VV[6]);
  if (ecl_boundp(cl_env_copy,VV[6])) {
   goto L40;
  }
  T0 = ECL_T;
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
L40:;
  T0 = cl_adjoin(2, VV[6], ecl_cmp_symbol_value(cl_env_copy,VV[5]));
  ecl_cmp_setq(cl_env_copy,VV[5],T0);
  si_Xmake_special(VV[7]);
  if (ecl_boundp(cl_env_copy,VV[7])) {
   goto L49;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[7],T0);
L49:;
  si_Xmake_special(VV[8]);
  if (ecl_boundp(cl_env_copy,VV[8])) {
   goto L56;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[8],T0);
L56:;
  si_Xmake_special(VV[9]);
  if (ecl_boundp(cl_env_copy,VV[9])) {
   goto L63;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[9],T0);
L63:;
  si_Xmake_special(VV[10]);
  if (ecl_boundp(cl_env_copy,VV[10])) {
   goto L70;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[10],T0);
L70:;
  si_Xmake_special(VV[11]);
  if (ecl_boundp(cl_env_copy,VV[11])) {
   goto L77;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[11],T0);
L77:;
  si_Xmake_special(VV[12]);
  if (ecl_boundp(cl_env_copy,VV[12])) {
   goto L84;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[12],T0);
L84:;
  si_Xmake_special(VV[13]);
  if (ecl_boundp(cl_env_copy,VV[13])) {
   goto L91;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[13],T0);
L91:;
  si_Xmake_special(VV[14]);
  if (ecl_boundp(cl_env_copy,VV[14])) {
   goto L98;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[14],T0);
L98:;
  si_Xmake_special(VV[15]);
  if (ecl_boundp(cl_env_copy,VV[15])) {
   goto L105;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[15],T0);
L105:;
  si_Xmake_special(VV[16]);
  if (ecl_boundp(cl_env_copy,VV[16])) {
   goto L112;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[16],T0);
L112:;
  si_Xmake_special(VV[17]);
  if (ecl_boundp(cl_env_copy,VV[17])) {
   goto L119;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[17],T0);
L119:;
  si_Xmake_special(VV[18]);
  if (ecl_boundp(cl_env_copy,VV[18])) {
   goto L126;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[18],T0);
L126:;
  si_Xmake_special(VV[19]);
  if (ecl_boundp(cl_env_copy,VV[19])) {
   goto L133;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[19],T0);
L133:;
  si_Xmake_special(VV[20]);
  if (ecl_boundp(cl_env_copy,VV[20])) {
   goto L140;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[20],T0);
L140:;
  si_Xmake_special(VV[21]);
  si_Xmake_special(VV[22]);
  si_Xmake_special(VV[23]);
  ecl_cmp_defun(VV[144]);                         /*  TMP-DESTINATION         */
  si_Xmake_special(VV[29]);
  si_Xmake_special(VV[30]);
  si_Xmake_special(VV[31]);
  if (ecl_boundp(cl_env_copy,VV[31])) {
   goto L170;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[31],T0);
L170:;
  si_Xmake_special(VV[32]);
  si_Xmake_special(VV[33]);
  si_Xmake_special(VV[34]);
  si_Xmake_special(VV[35]);
  ecl_cmp_defmacro(VV[145]);                      /*  WITH-CXX-ENV            */
  ecl_cmp_defmacro(VV[146]);                      /*  WITH-BIR-ENV            */
  si_Xmake_special(VV[58]);
  if (ecl_boundp(cl_env_copy,VV[58])) {
   goto L197;
  }
  T0 = si_make_vector(ECL_T, ecl_make_fixnum(1024), ECL_NIL, ECL_NIL, ECL_NIL, ecl_make_int8_t(0));
  ecl_cmp_setq(cl_env_copy,VV[58],T0);
L197:;
  ecl_cmp_defun(VV[147]);                         /*  ENV-VAR-NAME-EMPTY-CACHE */
  ecl_cmp_defun(VV[148]);                         /*  ENV-VAR-NAME            */
  si_Xmake_special(VV[71]);
  if (ecl_boundp(cl_env_copy,VV[71])) {
   goto L210;
  }
  T0 = si_make_vector(ECL_T, ecl_make_fixnum(1024), ECL_NIL, ECL_NIL, ECL_NIL, ecl_make_int8_t(0));
  ecl_cmp_setq(cl_env_copy,VV[71],T0);
L210:;
  ecl_cmp_defun(VV[149]);                         /*  LEX-ENV-VAR-NAME-EMPTY-CACHE */
  ecl_cmp_defun(VV[150]);                         /*  LEX-ENV-VAR-NAME        */
  ecl_cmp_defun(VV[151]);                         /*  NEXT-LCL                */
  ecl_cmp_defun(VV[152]);                         /*  NEXT-TEMP               */
  ecl_cmp_defun(VV[153]);                         /*  NEXT-LEX                */
  ecl_cmp_defun(VV[154]);                         /*  NEXT-ENV                */
  ecl_cmp_defun(VV[155]);                         /*  ENV-GROWS               */
  ecl_cmp_defun(VV[156]);                         /*  NEXT-CFUN               */
  ecl_cmp_defmacro(VV[157]);                      /*  WITH-INLINE-BLOCKS      */
  ecl_cmp_defmacro(VV[158]);                      /*  WITH-LEXICAL-SCOPE      */
  si_Xmake_special(VV[101]);
  if (ecl_boundp(cl_env_copy,VV[101])) {
   goto L245;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[101],T0);
L245:;
  si_define_structure(VV[103], _ecl_static_0, ECL_NIL, ECL_NIL, VVtemp[1], VVtemp[2], VV[104], ECL_NIL, ECL_NIL, ECL_NIL, VVtemp[3], ecl_make_int8_t(3), ECL_NIL, ECL_NIL, VV[105]);
  VV[107]=cl_find_class(1, VV[103]);
  ecl_cmp_defun(VV[159]);                         /*  MAKE-LABEL              */
  {
   cl_object v1package;
   v1package = cl_symbol_package(VV[109]);
   if (Null(v1package)){
    goto L258;
   }
   if (Null(si_package_locked_p(v1package))){
    goto L258;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L258;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[4], VVtemp[5], VVtemp[6], ECL_SYM("PACKAGE",1321), v1package);
  }
L258:;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC3633__lambda177_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  si_put_sysprop(VV[109], VV[110], T0);
  {
   cl_object v2package;
   v2package = cl_symbol_package(VV[112]);
   if (Null(v2package)){
    goto L266;
   }
   if (Null(si_package_locked_p(v2package))){
    goto L266;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L266;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[4], VVtemp[5], VVtemp[7], ECL_SYM("PACKAGE",1321), v2package);
  }
L266:;
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC3634__lambda182_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  si_put_sysprop(VV[112], VV[110], T0);
  {
   cl_object v3package;
   v3package = cl_symbol_package(VV[114]);
   if (Null(v3package)){
    goto L274;
   }
   if (Null(si_package_locked_p(v3package))){
    goto L274;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L274;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[4], VVtemp[5], VVtemp[8], ECL_SYM("PACKAGE",1321), v3package);
  }
L274:;
  {
   cl_object volatile v4;
   v4 = ecl_make_cfun_va((cl_objectfn)LC3635__lambda187_va,ECL_NIL,Cblock,2);
   T0 = v4;
  }
  si_put_sysprop(VV[114], VV[110], T0);
  ecl_cmp_defun(VV[160]);                         /*  NEXT-LABEL              */
  ecl_cmp_defmacro(VV[161]);                      /*  WITH-EXIT-LABEL         */
  ecl_cmp_defmacro(VV[162]);                      /*  WITH-UNWIND-FRAME       */
  ecl_cmp_defmacro(VV[163]);                      /*  WITH-STACK-FRAME        */
 }
}
