/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpbackend-cxx/cmppass2-data.lsp */
#include <ecl/ecl-cmp.h>
#include "cmp/cmppass2-data.eclh"
/* function definition for DATA-PERMANENT-STORAGE-SIZE                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3754data_permanent_storage_size()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_make_fixnum(ecl_length(ecl_cmp_symbol_value(cl_env_copy,VV[1])));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3754data_permanent_storage_size_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[0]);
 {
  return L3754data_permanent_storage_size();
 }
}
/* function definition for DATA-TEMPORARY-STORAGE-SIZE                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3755data_temporary_storage_size()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_make_fixnum(ecl_length(ecl_cmp_symbol_value(cl_env_copy,VV[4])));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3755data_temporary_storage_size_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[3]);
 {
  return L3755data_temporary_storage_size();
 }
}
/* function definition for DATA-SIZE                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3756data_size()
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = L3754data_permanent_storage_size();
 T1 = L3755data_temporary_storage_size();
 value0 = ecl_plus(T0,T1);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3756data_size_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[6]);
 {
  return L3756data_size();
 }
}
/* function definition for DATA-GET-ALL-OBJECTS                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3757data_get_all_objects()
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2array;
  cl_object v3;
  v1 = cl_list(2, ecl_cmp_symbol_value(cl_env_copy,VV[1]), ecl_cmp_symbol_value(cl_env_copy,VV[4]));
  v2array = ECL_NIL;
  v3 = v1;
  {
   cl_object v4;
   cl_object v5;
   v4 = ecl_list1(ECL_NIL);
   v5 = v4;
L7:;
   if (!(ecl_endp(v3))){
    goto L9;
   }
   goto L8;
L9:;
   v2array = ECL_CONS_CAR(v3);
   {
    cl_object v6;
    v6 = ECL_CONS_CDR(v3);
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v6;
   }
   {
    cl_object v6;
    {
     cl_object v7;
     cl_fixnum v8;
     cl_fixnum v9;
     cl_object v10vv_record;
     cl_fixnum v11;
     cl_fixnum v12;
     {
      cl_object v13;
      v13 = v2array;
      if (ecl_unlikely(!ECL_VECTORP(v13))) FEtype_error_vector(v13);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v7 = v13;
     }
     v8 = (cl_fixnum)(0);
     v9 = (cl_fixnum)(0);
     v10vv_record = ECL_NIL;
     v11 = v8;
     v12 = v9;
     {
      cl_object v13object;
      v13object = ECL_NIL;
      {
       cl_object v14;
       cl_object v15;
       v14 = ecl_list1(ECL_NIL);
       v15 = v14;
       {
        cl_object v16;
        v16 = ecl_make_fixnum(ecl_length(v7));
        {
         bool v17;
         v17 = ECL_FIXNUMP(v16);
         if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v16);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
        v12 = ecl_fixnum(v16);
       }
L31:;
       if (!((v11)>=(v12))){
        goto L37;
       }
       goto L32;
L37:;
       {
        cl_object v16;
        v16 = v7;
        T0 = v16;
        {
         cl_fixnum v17;
         v17 = v11;
         if (ecl_unlikely((v17)>=(v16)->vector.dim))
           FEwrong_index(ECL_NIL,v16,-1,ecl_make_fixnum(v17),(v16)->vector.dim);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         T1 = ecl_make_fixnum(v17);
        }
        v10vv_record = ecl_aref_unsafe(T0,ecl_fixnum(T1));
       }
       {
        cl_object v16;
        v16 = ecl_make_integer((v11)+1);
        {
         bool v17;
         v17 = ECL_FIXNUMP(v16);
         if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v16);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
        v11 = ecl_fixnum(v16);
       }
       v13object = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(1, v10vv_record) /*  VV-VALUE */;
       {
        cl_object v16;
        v16 = v15;
        if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T0 = v16;
       }
       if (Null(ecl_gethash_safe(v13object,ecl_cmp_symbol_value(cl_env_copy,VV[16]),ECL_NIL))){
        goto L59;
       }
       T1 = ecl_make_int8_t(0);
       goto L58;
L59:;
       if (Null((cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, v10vv_record) /*  VV-USED-P */)){
        goto L61;
       }
       T1 = v13object;
       goto L58;
L61:;
       T1 = ecl_make_int8_t(0);
L58:;
       v15 = ecl_list1(T1);
       (ECL_CONS_CDR(T0)=v15,T0);
       goto L31;
L32:;
       v6 = ecl_cdr(v14);
       goto L19;
      }
     }
    }
L19:;
    {
     cl_object v7;
     v7 = v5;
     if (ecl_unlikely(ECL_ATOM(v7))) FEtype_error_cons(v7);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T0 = v7;
    }
    (ECL_CONS_CDR(T0)=v6,T0);
    if (Null(v6)){
     goto L17;
    }
   }
   T0 = ecl_cdr(v5);
   v5 = ecl_last(T0,1);
L17:;
   goto L7;
L8:;
   value0 = ecl_cdr(v4);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3757data_get_all_objects_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[8]);
 {
  return L3757data_get_all_objects();
 }
}
/* function definition for DATA-DUMP-ARRAY                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3758data_dump_array()
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*COMPILER-CONSTANTS*",1021)))){
  goto L2;
 }
 T0 = L3757data_get_all_objects();
 T1 = cl_concatenate(2, ECL_SYM("VECTOR",902), T0);
 ecl_cmp_setq(cl_env_copy,ECL_SYM("*COMPILER-CONSTANTS*",1021),T1);
 value0 = VV[21];
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 T0 = L3756data_size();
 if (!(ecl_plusp(T0))){
  goto L6;
 }
 {
  cl_object v1data;
  cl_object v2data_string;
  cl_object v3l;
  ecl_bds_bind(cl_env_copy,VV[22],ecl_make_int8_t(0)); /*  *WT-STRING-SIZE*   */
  v1data = L3757data_get_all_objects();
  {
   cl_object v4;
   v4 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("+ECL-SYNTAX-PROGV-LIST+",1806));
   {
    cl_object v6, v7; cl_index v5;
    v6 = ECL_CONS_CAR(v4);
    v7 = ECL_CONS_CDR(v4);
    v5 = ecl_progv(cl_env_copy, v6, v7);
    v2data_string = cl_prin1_to_string(v1data);
    ecl_bds_unwind(cl_env_copy,v5);
   }
  }
  v3l = ecl_make_fixnum(ecl_length(v2data_string));
  T0 = ecl_make_integer((ecl_fixnum(v3l))-1);
  value0 = cl_subseq(3, v2data_string, ecl_make_int8_t(1), T0);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
L6:;
 value0 = VV[21];
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3758data_dump_array_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[20]);
 {
  return L3758data_dump_array();
 }
}
/* function definition for DATA-C-DUMP                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3762data_c_dump(cl_object volatile v1filename)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v2stream;
  v2stream = cl_open(9, v1filename, ECL_SYM("DIRECTION",1249), ECL_SYM("OUTPUT",1319), ECL_SYM("IF-DOES-NOT-EXIST",1277), ECL_SYM("CREATE",1244), ECL_SYM("IF-EXISTS",1279), ECL_SYM("SUPERSEDE",1351), ECL_SYM("EXTERNAL-FORMAT",1267), ECL_SYM("DEFAULT",1246));
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    {
     struct ecl_stack_frame _ecl_inner_frame_aux;
     volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
     {
      cl_object v3strings;
      v3strings = LC3759produce_strings();
      if (Null(v3strings)){
       goto L7;
      }
      LC3761output_c_strings(v3strings, v2stream);
      goto L6;
L7:;
      ecl_princ(VV[34],v2stream);
L6:;
      cl_env_copy->values[0] = (ecl_terpri(v2stream));
      cl_env_copy->nvalues = 1;
     }
     ecl_stack_frame_push_values(_ecl_inner_frame);
     if (Null(v2stream)){
      goto L9;
     }
     cl_close(1, v2stream);
L9:;
     ecl_stack_frame_pop_values(_ecl_inner_frame);
     ecl_stack_frame_close(_ecl_inner_frame);
    }
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   if (Null(v2stream)){
    goto L11;
   }
   cl_close(3, v2stream, ECL_SYM("ABORT",1225), ECL_T);
L11:;
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
}
static cl_object L3762data_c_dump_va(cl_narg narg, cl_object v3filename, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[24]);
 {
  return L3762data_c_dump(v3filename);
 }
}
/* function definition for STATIC-BASE-STRING-BUILDER                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3763static_base_string_builder(cl_object v1name, cl_object v2value, cl_object v3stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 cl_format(3, v3stream, VV[37], v1name);
 (cl_env_copy->function=ecl_fdefinition(VV[29]))->cfun.entry(4, v2value, v3stream, VV[38], ECL_T) /*  WT-FILTERED-DATA */;
 {
  cl_fixnum v4;
  v4 = ecl_length(v2value);
  value0 = cl_format(3, v3stream, VV[39], ecl_make_fixnum(v4));
  return value0;
 }
}
static cl_object L3763static_base_string_builder_va(cl_narg narg, cl_object v4name, cl_object v5value, cl_object v6stream, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[36]);
 {
  return L3763static_base_string_builder(v4name, v5value, v6stream);
 }
}
/* function definition for STATIC-SINGLE-FLOAT-BUILDER                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3764static_single_float_builder(cl_object v1name, cl_object v2value, cl_object v3stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*READ-DEFAULT-FLOAT-FORMAT*",64),ECL_SYM("SINGLE-FLOAT",781)); /*  *READ-DEFAULT-FLOAT-FORMAT* */
 ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59),ECL_T); /*  *PRINT-READABLY* */
 value0 = cl_format(4, v3stream, VV[42], v1name, v2value);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L3764static_single_float_builder_va(cl_narg narg, cl_object v4name, cl_object v5value, cl_object v6stream, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[41]);
 {
  return L3764static_single_float_builder(v4name, v5value, v6stream);
 }
}
/* function definition for STATIC-DOUBLE-FLOAT-BUILDER                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3765static_double_float_builder(cl_object v1name, cl_object v2value, cl_object v3stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*READ-DEFAULT-FLOAT-FORMAT*",64),ECL_SYM("DOUBLE-FLOAT",317)); /*  *READ-DEFAULT-FLOAT-FORMAT* */
 ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59),ECL_T); /*  *PRINT-READABLY* */
 value0 = cl_format(4, v3stream, VV[45], v1name, v2value);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L3765static_double_float_builder_va(cl_narg narg, cl_object v4name, cl_object v5value, cl_object v6stream, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[44]);
 {
  return L3765static_double_float_builder(v4name, v5value, v6stream);
 }
}
/* function definition for STATIC-LONG-FLOAT-BUILDER                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3766static_long_float_builder(cl_object v1name, cl_object v2value, cl_object v3stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*READ-DEFAULT-FLOAT-FORMAT*",64),ECL_SYM("LONG-FLOAT",510)); /*  *READ-DEFAULT-FLOAT-FORMAT* */
 ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59),ECL_T); /*  *PRINT-READABLY* */
 value0 = cl_format(4, v3stream, VV[48], v1name, v2value);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L3766static_long_float_builder_va(cl_narg narg, cl_object v4name, cl_object v5value, cl_object v6stream, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[47]);
 {
  return L3766static_long_float_builder(v4name, v5value, v6stream);
 }
}
/* function definition for STATIC-RATIONAL-BUILDER                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3767static_rational_builder(cl_object v1name, cl_object v2value, cl_object v3stream)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*READ-DEFAULT-FLOAT-FORMAT*",64),ECL_SYM("DOUBLE-FLOAT",317)); /*  *READ-DEFAULT-FLOAT-FORMAT* */
 ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59),ECL_T); /*  *PRINT-READABLY* */
 T0 = cl_numerator(v2value);
 T1 = cl_denominator(v2value);
 value0 = cl_format(5, v3stream, VV[51], v1name, T0, T1);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L3767static_rational_builder_va(cl_narg narg, cl_object v4name, cl_object v5value, cl_object v6stream, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[50]);
 {
  return L3767static_rational_builder(v4name, v5value, v6stream);
 }
}
/* function definition for STATIC-CONSTANT-DELEGATE                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3768static_constant_delegate(cl_object v1name, cl_object v2value, cl_object v3stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = L3773static_constant_expression(v2value);
 value0 = ecl_function_dispatch(cl_env_copy,T0)(3, v1name, v2value, v3stream);
 return value0;
}
static cl_object L3768static_constant_delegate_va(cl_narg narg, cl_object v4name, cl_object v5value, cl_object v6stream, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[53]);
 {
  return L3768static_constant_delegate(v4name, v5value, v6stream);
 }
}
/* function definition for STATIC-COMPLEX-BUILDER                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3769static_complex_builder(cl_object v1name, cl_object v2value, cl_object v3stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4name_real;
  cl_object v5name_imag;
  ecl_bds_bind(cl_env_copy,ECL_SYM("*READ-DEFAULT-FLOAT-FORMAT*",64),ECL_SYM("DOUBLE-FLOAT",317)); /*  *READ-DEFAULT-FLOAT-FORMAT* */
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59),ECL_T); /*  *PRINT-READABLY* */
  v4name_real = cl_concatenate(3, ECL_SYM("STRING",808), v1name, VV[57]);
  v5name_imag = cl_concatenate(3, ECL_SYM("STRING",808), v1name, VV[58]);
  T0 = cl_realpart(v2value);
  L3768static_constant_delegate(v4name_real, T0, v3stream);
  (ecl_terpri(v3stream));
  T0 = cl_imagpart(v2value);
  L3768static_constant_delegate(v5name_imag, T0, v3stream);
  (ecl_terpri(v3stream));
  value0 = cl_format(5, v3stream, VV[59], v1name, v4name_real, v5name_imag);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3769static_complex_builder_va(cl_narg narg, cl_object v6name, cl_object v7value, cl_object v8stream, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[56]);
 {
  return L3769static_complex_builder(v6name, v7value, v8stream);
 }
}
/* function definition for STATIC-CSFLOAT-BUILDER                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3770static_csfloat_builder(cl_object v1name, cl_object v2value, cl_object v3stream)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*READ-DEFAULT-FLOAT-FORMAT*",64),ECL_SYM("SINGLE-FLOAT",781)); /*  *READ-DEFAULT-FLOAT-FORMAT* */
 ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59),ECL_T); /*  *PRINT-READABLY* */
 T0 = cl_realpart(v2value);
 T1 = cl_imagpart(v2value);
 value0 = cl_format(6, v3stream, VV[62], v1name, T0, T1, v3stream);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L3770static_csfloat_builder_va(cl_narg narg, cl_object v4name, cl_object v5value, cl_object v6stream, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[61]);
 {
  return L3770static_csfloat_builder(v4name, v5value, v6stream);
 }
}
/* function definition for STATIC-CDFLOAT-BUILDER                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3771static_cdfloat_builder(cl_object v1name, cl_object v2value, cl_object v3stream)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*READ-DEFAULT-FLOAT-FORMAT*",64),ECL_SYM("DOUBLE-FLOAT",317)); /*  *READ-DEFAULT-FLOAT-FORMAT* */
 ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59),ECL_T); /*  *PRINT-READABLY* */
 T0 = cl_realpart(v2value);
 T1 = cl_imagpart(v2value);
 value0 = cl_format(6, v3stream, VV[65], v1name, T0, T1, v3stream);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L3771static_cdfloat_builder_va(cl_narg narg, cl_object v4name, cl_object v5value, cl_object v6stream, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[64]);
 {
  return L3771static_cdfloat_builder(v4name, v5value, v6stream);
 }
}
/* function definition for STATIC-CLFLOAT-BUILDER                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3772static_clfloat_builder(cl_object v1name, cl_object v2value, cl_object v3stream)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*READ-DEFAULT-FLOAT-FORMAT*",64),ECL_SYM("LONG-FLOAT",510)); /*  *READ-DEFAULT-FLOAT-FORMAT* */
 ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59),ECL_T); /*  *PRINT-READABLY* */
 T0 = cl_realpart(v2value);
 T1 = cl_imagpart(v2value);
 value0 = cl_format(6, v3stream, VV[68], v1name, T0, T1, v3stream);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L3772static_clfloat_builder_va(cl_narg narg, cl_object v4name, cl_object v5value, cl_object v6stream, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[67]);
 {
  return L3772static_clfloat_builder(v4name, v5value, v6stream);
 }
}
/* function definition for STATIC-CONSTANT-EXPRESSION                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3773static_constant_expression(cl_object v1object)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_BASE_STRING_P(v1object))){
  goto L2;
 }
 value0 = ecl_fdefinition(VV[36]);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (Null(si_ratiop(v1object))){
  goto L4;
 }
 T0 = cl_numerator(v1object);
 if (Null(L3773static_constant_expression(T0))){
  goto L7;
 }
 T0 = cl_denominator(v1object);
 if (Null(L3773static_constant_expression(T0))){
  goto L7;
 }
 value0 = ecl_fdefinition(VV[50]);
 cl_env_copy->nvalues = 1;
 return value0;
L7:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 if (!(ECL_SINGLE_FLOAT_P(v1object))){
  goto L10;
 }
 if (si_float_nan_p(v1object)!=ECL_NIL) {
  goto L13;
 }
 if (si_float_infinity_p(v1object)!=ECL_NIL) {
  goto L13;
 }
 value0 = ecl_fdefinition(VV[41]);
 cl_env_copy->nvalues = 1;
 return value0;
L13:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L10:;
 if (!(ECL_DOUBLE_FLOAT_P(v1object))){
  goto L16;
 }
 if (si_float_nan_p(v1object)!=ECL_NIL) {
  goto L19;
 }
 if (si_float_infinity_p(v1object)!=ECL_NIL) {
  goto L19;
 }
 value0 = ecl_fdefinition(VV[44]);
 cl_env_copy->nvalues = 1;
 return value0;
L19:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L16:;
 if (!(ECL_LONG_FLOAT_P(v1object))){
  goto L22;
 }
 if (si_float_nan_p(v1object)!=ECL_NIL) {
  goto L25;
 }
 if (si_float_infinity_p(v1object)!=ECL_NIL) {
  goto L25;
 }
 value0 = ecl_fdefinition(VV[47]);
 cl_env_copy->nvalues = 1;
 return value0;
L25:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L22:;
 if (Null(cl_complexp(v1object))){
  goto L28;
 }
 T0 = cl_realpart(v1object);
 if (Null(L3773static_constant_expression(T0))){
  goto L30;
 }
 T0 = cl_imagpart(v1object);
 if (Null(L3773static_constant_expression(T0))){
  goto L30;
 }
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[70]))){
  goto L33;
 }
 {
  cl_object v2;
  v2 = cl_realpart(v1object);
  if (!(ECL_SINGLE_FLOAT_P(v2))){
   goto L36;
  }
  value0 = ecl_fdefinition(VV[61]);
  cl_env_copy->nvalues = 1;
  return value0;
L36:;
  if (!(ECL_DOUBLE_FLOAT_P(v2))){
   goto L38;
  }
  value0 = ecl_fdefinition(VV[64]);
  cl_env_copy->nvalues = 1;
  return value0;
L38:;
  if (!(ECL_LONG_FLOAT_P(v2))){
   goto L40;
  }
  value0 = ecl_fdefinition(VV[67]);
  cl_env_copy->nvalues = 1;
  return value0;
L40:;
  value0 = ecl_fdefinition(VV[56]);
  cl_env_copy->nvalues = 1;
  return value0;
 }
L33:;
 value0 = ecl_fdefinition(VV[56]);
 cl_env_copy->nvalues = 1;
 return value0;
L30:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L28:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3773static_constant_expression_va(cl_narg narg, cl_object v3object, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[54]);
 {
  return L3773static_constant_expression(v3object);
 }
}
/* function definition for ADD-STATIC-CONSTANT                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3774add_static_constant(cl_object v1object)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*COMPILER-CONSTANTS*",1021))!=ECL_NIL) {
  goto L2;
 }
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[73]))){
  goto L2;
 }
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,VV[74])))){
  goto L2;
 }
 {
  cl_object v2record;
  {
   cl_object v3;
   cl_object v4;
   cl_object v5;
   v3 = ecl_cmp_symbol_value(cl_env_copy,VV[74]);
   v4 = (ECL_SYM("FIRST",373)->symbol.gfdef);
   v5 = (ECL_SYM("EQUAL",337)->symbol.gfdef);
   {
    cl_object v6;
    v6 = si_make_seq_iterator(2, v3, ecl_make_int8_t(0));
L11:;
    if (v6!=ECL_NIL) {
     goto L13;
    }
    v2record = ECL_NIL;
    goto L6;
L13:;
    {
     cl_object v7;
     v7 = si_seq_iterator_ref(v3, v6);
     T0 = ecl_car(v7);
     if (!(ecl_equal(v1object,T0))){
      goto L15;
     }
     v2record = v7;
     goto L6;
    }
L15:;
    v6 = si_seq_iterator_next(v3, v6);
    goto L11;
   }
  }
L6:;
  if (Null(v2record)){
   goto L20;
  }
  value0 = ecl_cadr(v2record);
  cl_env_copy->nvalues = 1;
  return value0;
L20:;
  {
   cl_object v3builder;
   v3builder = L3773static_constant_expression(v1object);
   if (Null(v3builder)){
    goto L23;
   }
   {
    cl_object v4c_name;
    cl_object v5vv;
    {
     cl_fixnum v6;
     v6 = ecl_length(ecl_cmp_symbol_value(cl_env_copy,VV[74]));
     v4c_name = cl_format(3, ECL_NIL, VV[79], ecl_make_fixnum(v6));
    }
    v5vv = (cl_env_copy->function=ecl_fdefinition(VV[80]))->cfun.entry(4, ECL_SYM("LOCATION",1003), v4c_name, ECL_SYM("VALUE",2074), v1object) /*  MAKE-VV */;
    T0 = cl_list(3, v1object, v5vv, v3builder);
    T1 = CONS(T0,ecl_cmp_symbol_value(cl_env_copy,VV[74]));
    ecl_cmp_setq(cl_env_copy,VV[74],T1);
    value0 = v5vv;
    cl_env_copy->nvalues = 1;
    return value0;
   }
L23:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3774add_static_constant_va(cl_narg narg, cl_object v6object, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[72]);
 {
  return L3774add_static_constant(v6object);
 }
}
/* function definition for TRY-VALUE-C-INLINER                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3775try_value_c_inliner(cl_object v1value)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2x;
  {
   cl_object v3;
   cl_object v4;
   cl_object v5;
   v3 = ecl_cmp_symbol_value(cl_env_copy,VV[83]);
   v4 = v1value;
   v5 = v3;
   v2x = ecl_assql(v4,v5);
  }
  if (Null(v2x)){
   goto L6;
  }
  if (floatp(v1value)) {
   goto L10;
  }
  if (Null(cl_complexp(v1value))){
   goto L8;
  }
  T0 = cl_realpart(v1value);
  if (!(floatp(T0))){
   goto L8;
  }
  T0 = cl_imagpart(v1value);
  if (!(floatp(T0))){
   goto L8;
  }
  goto L9;
L10:;
L9:;
  T0 = cl_adjoin(2, VV[85], ecl_cmp_symbol_value(cl_env_copy,VV[84]));
  ecl_cmp_setq(cl_env_copy,VV[84],T0);
  T0 = cl_adjoin(2, VV[86], ecl_cmp_symbol_value(cl_env_copy,VV[84]));
  ecl_cmp_setq(cl_env_copy,VV[84],T0);
L8:;
  value0 = ecl_cdr(v2x);
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3775try_value_c_inliner_va(cl_narg narg, cl_object v3value, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[82]);
 {
  return L3775try_value_c_inliner(v3value);
 }
}
/* function definition for TRY-CONST-C-INLINER                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3776try_const_c_inliner(cl_object v1var)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = v1var;
  if (si_of_class_p(2, v2, VV[89])!=ECL_NIL) {
   goto L4;
  }
  v1var = si_do_check_type(v2, VV[89], ECL_NIL, VV[89]);
L4:;
 }
 {
  cl_object v2name;
  v2name = (cl_env_copy->function=ecl_fdefinition(VV[90]))->cfun.entry(1, v1var) /*  VAR-NAME */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[91]))->cfun.entry(1, v2name) /*  CONSTANT-VARIABLE-P */)){
   goto L8;
  }
  {
   cl_object v3x;
   {
    cl_object v4;
    cl_object v5;
    cl_object v6;
    v4 = ecl_cmp_symbol_value(cl_env_copy,VV[83]);
    v5 = v2name;
    v6 = v4;
    v3x = ecl_assql(v5,v6);
   }
   if (Null(v3x)){
    goto L14;
   }
   value0 = ecl_cdr(v3x);
   cl_env_copy->nvalues = 1;
   return value0;
L14:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L8:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3776try_const_c_inliner_va(cl_narg narg, cl_object v4var, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[88]);
 {
  return L3776try_const_c_inliner(v4var);
 }
}
/* function definition for TRY-INLINE-CORE-SYM                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3777try_inline_core_sym(cl_object v1object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_SYMBOLP(v1object))){
  goto L2;
 }
 {
  cl_object v2;                                   /*  FOUNDP                  */
  cl_object v3;                                   /*  CNAME                   */
  value0 = si_mangle_name(1, v1object);
  {
   const int v4 = cl_env_copy->nvalues;
   v2 = value0;
   cl_object v5;
   v5 = (v4<=1)? ECL_NIL : cl_env_copy->values[1];
   v3 = v5;
  }
  if (Null(v2)){
   goto L5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[80]))->cfun.entry(4, ECL_SYM("VALUE",2074), v1object, ECL_SYM("LOCATION",1003), v3) /*  MAKE-VV */;
  return value0;
L5:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3777try_inline_core_sym_va(cl_narg narg, cl_object v2object, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[93]);
 {
  return L3777try_inline_core_sym(v2object);
 }
}
/* function definition for TRY-IMMEDIATE-VALUE                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3778try_immediate_value(cl_object v1value)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (ECL_FIXNUMP(v1value)) {
  goto L4;
 }
 if (!(ECL_CHARACTERP(v1value))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 T0 = cl_type_of(v1value);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[97]))->cfun.entry(1, T0) /*  LISP-TYPE->HOST-TYPE */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[80]))->cfun.entry(6, ECL_SYM("VALUE",2074), v1value, ECL_SYM("LOCATION",1003), ECL_NIL, VV[96], T1) /*  MAKE-VV */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3778try_immediate_value_va(cl_narg narg, cl_object v2value, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[95]);
 {
  return L3778try_immediate_value(v2value);
 }
}
/* function definition for DATA-EMPTY-LOC*                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3779data_empty_loc_()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[80]))->cfun.entry(6, ECL_SYM("VALUE",2074), ecl_cmp_symbol_value(cl_env_copy,VV[101]), VV[102], ECL_T, VV[103], ECL_T) /*  MAKE-VV */;
 value0 = L3781insert_vv(T0);
 return value0;
}
static cl_object L3779data_empty_loc__va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[99]);
 {
  return L3779data_empty_loc_();
 }
}
/* function definition for UPDATE-VV                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3780update_vv(cl_object v1target, cl_object v2source)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 goto L4;
L3:;
 si_assert_failure(1, VV[106]);
L4:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(1, v1target) /*  VV-VALUE */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(1, v2source) /*  VV-VALUE */;
 if (ecl_eql(T0,T1)) {
  goto L7;
 }
 goto L3;
L7:;
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[107]))->cfun.entry(1, v2source) /*  VV-LOCATION */;
  ecl_structure_set(v1target,VV[108],(cl_fixnum)(0),v3);
 }
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[109]))->cfun.entry(1, v2source) /*  VV-HOST-TYPE */;
  value0 = ecl_structure_set(v1target,VV[108],(cl_fixnum)(6),v3);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3780update_vv_va(cl_narg narg, cl_object v4target, cl_object v5source, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[105]);
 {
  return L3780update_vv(v4target, v5source);
 }
}
/* function definition for INSERT-VV                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3781insert_vv(cl_object v1vv)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2arr;
  cl_object v3ndx;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[111]))->cfun.entry(1, v1vv) /*  VV-PERMANENT-P */)){
   goto L3;
  }
  v2arr = ecl_cmp_symbol_value(cl_env_copy,VV[1]);
  goto L2;
L3:;
  v2arr = ecl_cmp_symbol_value(cl_env_copy,VV[4]);
L2:;
  {
   cl_fixnum v4;
   cl_fixnum v5;
   v4 = ((v2arr)->vector.fillp);
   v5 = ((v2arr)->array.dim);
   if (!((v4)<(v5))){
    goto L9;
   }
   {
    cl_fixnum v6;
    v6 = ((cl_fixnum)1)+(v4);
    ((v2arr)->vector.fillp)=(v6);
   }
   ecl_aset_unsafe(v2arr,v4,v1vv);
   v3ndx = ecl_make_fixnum(v4);
   goto L5;
L9:;
   v3ndx = cl_vector_push_extend(2, v1vv, v2arr);
  }
L5:;
  ecl_structure_set(v1vv,VV[108],(cl_fixnum)(0),v3ndx);
  value0 = v1vv;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3781insert_vv_va(cl_narg narg, cl_object v4vv, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[100]);
 {
  return L3781insert_vv(v4vv);
 }
}
/* function definition for SEARCH-VV                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3782search_vv(cl_narg narg, cl_object v1object, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[113]);
 {
  cl_object v2permanent;
  cl_object v3errorp;
  cl_object v4test;
  ecl_va_list args; ecl_va_start(args,v1object,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L3782search_vvkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2permanent = keyvars[0];
   if (Null(keyvars[4])) {
    v3errorp = ECL_T;
   } else {
    v3errorp = keyvars[1];
   }
   v4test = keyvars[2];
  }
  {
   cl_object v5test;
   cl_object v6item;
   value0 = v4test;
   if (value0!=ECL_NIL) {
    goto L4;
   }
   if (Null(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*COMPILER-CONSTANTS*",1021)))){
    goto L6;
   }
   v5test = ECL_SYM("EQ",335);
   goto L2;
L6:;
   v5test = VV[114];
   goto L2;
L4:;
   v5test = value0;
   goto L2;
L2:;
   if (Null(v2permanent)){
    goto L9;
   }
   {
    cl_object v7;
    cl_object v8;
    v7 = ecl_cmp_symbol_value(cl_env_copy,VV[1]);
    v8 = ecl_fdefinition(VV[15]);
    {
     cl_object v9;
     v9 = si_make_seq_iterator(2, v7, ecl_make_int8_t(0));
L14:;
     if (v9!=ECL_NIL) {
      goto L16;
     }
     v6item = ECL_NIL;
     goto L8;
L16:;
     {
      cl_object v10;
      v10 = si_seq_iterator_ref(v7, v9);
      T0 = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(1, v10) /*  VV-VALUE */;
      if (Null(ecl_function_dispatch(cl_env_copy,v5test)(2, v1object, T0))){
       goto L18;
      }
      v6item = v10;
      goto L8;
     }
L18:;
     v9 = si_seq_iterator_next(v7, v9);
     goto L14;
    }
   }
L9:;
   {
    cl_object v10;
    cl_object v11;
    v10 = ecl_cmp_symbol_value(cl_env_copy,VV[1]);
    v11 = ecl_fdefinition(VV[15]);
    {
     cl_object v12;
     v12 = si_make_seq_iterator(2, v10, ecl_make_int8_t(0));
L29:;
     if (v12!=ECL_NIL) {
      goto L31;
     }
     value0 = ECL_NIL;
     goto L25;
L31:;
     {
      cl_object v13;
      v13 = si_seq_iterator_ref(v10, v12);
      T0 = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(1, v13) /*  VV-VALUE */;
      if (Null(ecl_function_dispatch(cl_env_copy,v5test)(2, v1object, T0))){
       goto L33;
      }
      value0 = v13;
      goto L25;
     }
L33:;
     v12 = si_seq_iterator_next(v10, v12);
     goto L29;
    }
   }
L25:;
   if (value0!=ECL_NIL) {
    goto L24;
   }
   {
    cl_object v10;
    cl_object v11;
    v10 = ecl_cmp_symbol_value(cl_env_copy,VV[4]);
    v11 = ecl_fdefinition(VV[15]);
    {
     cl_object v12;
     v12 = si_make_seq_iterator(2, v10, ecl_make_int8_t(0));
L41:;
     if (v12!=ECL_NIL) {
      goto L43;
     }
     v6item = ECL_NIL;
     goto L8;
L43:;
     {
      cl_object v13;
      v13 = si_seq_iterator_ref(v10, v12);
      T0 = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(1, v13) /*  VV-VALUE */;
      if (Null(ecl_function_dispatch(cl_env_copy,v5test)(2, v1object, T0))){
       goto L45;
      }
      v6item = v13;
      goto L8;
     }
L45:;
     v12 = si_seq_iterator_next(v10, v12);
     goto L41;
    }
   }
L24:;
   v6item = value0;
   goto L8;
L8:;
   if (!(v6item==ECL_NIL)){
    goto L50;
   }
   if (Null(v3errorp)){
    goto L50;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[115]))->cfun.entry(2, VV[116], v1object) /*  CMPERR */;
L50:;
   value0 = v6item;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for GET-OBJECT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3783get_object(cl_narg narg, cl_object v1object, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[118]);
 {
  cl_object v2permanent;
  cl_object v3errorp;
  cl_object v4test;
  ecl_va_list args; ecl_va_start(args,v1object,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L3783get_objectkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[3])) {
    v2permanent = ECL_T;
   } else {
    v2permanent = keyvars[0];
   }
   if (Null(keyvars[4])) {
    v3errorp = ECL_T;
   } else {
    v3errorp = keyvars[1];
   }
   v4test = keyvars[2];
  }
  value0 = L3782search_vv(7, v1object, VV[119], v2permanent, VV[120], ECL_NIL, ECL_SYM("TEST",1353), v4test);
  if (value0!=ECL_NIL) {
   goto L4;
  }
  value0 = L3777try_inline_core_sym(v1object);
  if (value0!=ECL_NIL) {
   goto L4;
  }
  if (Null(v3errorp)){
   goto L8;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[115]))->cfun.entry(2, VV[116], v1object) /*  CMPERR */;
  return value0;
L8:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for OPTIMIZE-CXX-DATA                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3785optimize_cxx_data(cl_object v1objects)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = ecl_make_cfun_va((cl_objectfn)LC3784optimize_vv_va,ECL_NIL,Cblock,1);
  value0 = cl_map(3, ECL_NIL, v2, v1objects);
  return value0;
 }
}
static cl_object L3785optimize_cxx_data_va(cl_narg narg, cl_object v3objects, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[122]);
 {
  return L3785optimize_cxx_data(v3objects);
 }
}
/* function definition for ADD-KEYWORDS                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3787add_keywords(cl_object v1keywords)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2x;
  {
   cl_object v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC3786__lambda212_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  v2x = cl_search(4, v1keywords, ecl_cmp_symbol_value(cl_env_copy,VV[1]), ECL_SYM("TEST",1353), T0);
  if (Null(v2x)){
   goto L4;
  }
  value0 = ecl_elt(ecl_cmp_symbol_value(cl_env_copy,VV[1]),ecl_to_size(v2x));
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  {
   cl_object v3;
   {
    cl_object v4;
    v4 = v1keywords;
    {
     cl_object v5;
     v5 = v4;
     {
      bool v6;
      v6 = ECL_LISTP(v5);
      if (ecl_unlikely(!(v6)))
         FEwrong_type_argument(VV[130],v5);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v4)){
     goto L12;
    }
    {
     cl_object v5;
     v5 = ECL_CONS_CDR(v4);
     v1keywords = v5;
     v4 = ECL_CONS_CAR(v4);
    }
L12:;
    T0 = v4;
   }
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[80]))->cfun.entry(6, ECL_SYM("VALUE",2074), T0, VV[131], ECL_T, VV[103], ECL_T) /*  MAKE-VV */;
   v3 = L3781insert_vv(T1);
   {
    cl_object v4;
    v4 = v1keywords;
    goto L22;
L21:;
    {
     cl_object v5k;
     v5k = ecl_car(v4);
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[80]))->cfun.entry(6, ECL_SYM("VALUE",2074), v5k, VV[131], ECL_T, VV[103], ECL_T) /*  MAKE-VV */;
     L3781insert_vv(T0);
    }
    v4 = ecl_cdr(v4);
L22:;
    if (Null(v4)){
     goto L29;
    }
    goto L21;
L29:;
   }
   value0 = v3;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3787add_keywords_va(cl_narg narg, cl_object v4keywords, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[126]);
 {
  return L3787add_keywords(v4keywords);
 }
}
/* function definition for WT-VV-INDEX                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3788wt_vv_index(cl_object v1index, cl_object v2permanent_p)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (ecl_numberp(v1index)) {
  goto L2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[134]))->cfun.entry(1, v1index) /*  WT */;
 return value0;
L2:;
 if (Null(v2permanent_p)){
  goto L4;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[134]))->cfun.entry(3, VV[135], v1index, VV[136]) /*  WT */;
 return value0;
L4:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[134]))->cfun.entry(3, VV[137], v1index, VV[136]) /*  WT */;
 return value0;
}
static cl_object L3788wt_vv_index_va(cl_narg narg, cl_object v3index, cl_object v4permanent_p, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[133]);
 {
  return L3788wt_vv_index(v3index, v4permanent_p);
 }
}
/* function definition for WT-VV-VALUE                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3789wt_vv_value(cl_object v1vv, cl_object v2value)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v2value)==(ECL_T))){
  goto L2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[134]))->cfun.entry(1, VV[140]) /*  WT */;
 return value0;
L2:;
 if (!((v2value)==(ECL_NIL))){
  goto L4;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[134]))->cfun.entry(1, VV[141]) /*  WT */;
 return value0;
L4:;
 if (!(ECL_FIXNUMP(v2value))){
  goto L6;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(2, v2value, v1vv) /*  WT-FIXNUM */;
 return value0;
L6:;
 if (!(ECL_CHARACTERP(v2value))){
  goto L8;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[143]))->cfun.entry(2, v2value, v1vv) /*  WT-CHARACTER */;
 return value0;
L8:;
 if (!(floatp(v2value))){
  goto L10;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[144]))->cfun.entry(2, v2value, v1vv) /*  WT-NUMBER */;
 return value0;
L10:;
 if (Null(cl_complexp(v2value))){
  goto L12;
 }
 T0 = cl_realpart(v2value);
 if (!(floatp(T0))){
  goto L12;
 }
 T0 = cl_imagpart(v2value);
 if (!(floatp(T0))){
  goto L12;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[144]))->cfun.entry(2, v2value, v1vv) /*  WT-NUMBER */;
 return value0;
L12:;
 T0 = ecl_list1(v2value);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[145]))->cfun.entry(4, ECL_SYM("FORMAT-CONTROL",1272), VV[146], ECL_SYM("FORMAT-ARGUMENTS",1271), T0) /*  BABOON */;
 return value0;
}
static cl_object L3789wt_vv_value_va(cl_narg narg, cl_object v3vv, cl_object v4value, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[139]);
 {
  return L3789wt_vv_value(v3vv, v4value);
 }
}
/* function definition for WT-VV                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3790wt_vv(cl_object v1vv_loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_structure_set(v1vv_loc,VV[108],(cl_fixnum)(1),ECL_T);
 {
  cl_object v2index;
  v2index = (cl_env_copy->function=ecl_fdefinition(VV[107]))->cfun.entry(1, v1vv_loc) /*  VV-LOCATION */;
  if (!(v2index==ECL_NIL)){
   goto L4;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(1, v1vv_loc) /*  VV-VALUE */;
  value0 = L3789wt_vv_value(v1vv_loc, T0);
  return value0;
L4:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[111]))->cfun.entry(1, v1vv_loc) /*  VV-PERMANENT-P */;
  value0 = L3788wt_vv_index(v2index, T0);
  return value0;
 }
}
static cl_object L3790wt_vv_va(cl_narg narg, cl_object v3vv_loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[148]);
 {
  return L3790wt_vv(v3vv_loc);
 }
}
/* function definition for SET-VV-INDEX                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3791set_vv_index(cl_object v1loc, cl_object v2index, cl_object v3permanent_p)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[151]))->cfun.entry(0) /*  WT-NL    */;
 L3788wt_vv_index(v2index, v3permanent_p);
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[153]))->cfun.entry(2, ECL_SYM("OBJECT",1315), v1loc) /*  COERCE-LOC */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[134]))->cfun.entry(3, VV[152], T0, VV[154]) /*  WT */;
 return value0;
}
static cl_object L3791set_vv_index_va(cl_narg narg, cl_object v4loc, cl_object v5index, cl_object v6permanent_p, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[150]);
 {
  return L3791set_vv_index(v4loc, v5index, v6permanent_p);
 }
}
/* function definition for SET-VV                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3792set_vv(cl_object v1loc, cl_object v2vv_loc)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_structure_set(v2vv_loc,VV[108],(cl_fixnum)(1),ECL_T);
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[107]))->cfun.entry(1, v2vv_loc) /*  VV-LOCATION */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[111]))->cfun.entry(1, v2vv_loc) /*  VV-PERMANENT-P */;
 value0 = L3791set_vv_index(v1loc, T0, T1);
 return value0;
}
static cl_object L3792set_vv_va(cl_narg narg, cl_object v3loc, cl_object v4vv_loc, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[156]);
 {
  return L3792set_vv(v3loc, v4vv_loc);
 }
}
/* local function OUTPUT-C-STRINGS                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3761output_c_strings(cl_object v1strings, cl_object v2stream)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4s;
  cl_object v5;
  {
   cl_object v6;
   v6 = v1strings;
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3 = v6;
  }
  v4s = ECL_NIL;
  v5 = v3;
  {
   cl_object v6i;
   v6i = ecl_make_int8_t(1);
   {
    cl_object v7name;
    v7name = ECL_NIL;
    {
     cl_object v8;
     cl_object v9;
     v8 = ecl_list1(ECL_NIL);
     v9 = v8;
     if (!(ecl_endp(v5))){
      goto L14;
     }
     goto L13;
L14:;
     v4s = ECL_CONS_CAR(v5);
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v5);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v5 = v10;
     }
L12:;
     v7name = cl_format(3, ECL_NIL, VV[33], v6i);
     {
      cl_object v10;
      v10 = v9;
      if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T1 = v10;
     }
     T2 = LC3760output_one_c_string(v7name, v4s, v2stream);
     v9 = ecl_list1(T2);
     (ECL_CONS_CDR(T1)=v9,T1);
     if (!(ecl_endp(v5))){
      goto L30;
     }
     goto L13;
L30:;
     v4s = ECL_CONS_CAR(v5);
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v5);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v5 = v10;
     }
     v6i = ecl_one_plus(v6i);
     goto L12;
L13:;
     T0 = ecl_cdr(v8);
     goto L2;
    }
   }
  }
 }
L2:;
 value0 = cl_format(3, v2stream, VV[32], T0);
 return value0;
}
static cl_object LC3761output_c_strings_va(cl_narg narg, cl_object v3strings, cl_object v4stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[31]);
 {
  return LC3761output_c_strings(v3strings, v4stream);
 }
}
/* local function OUTPUT-ONE-C-STRING                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3760output_one_c_string(cl_object volatile v1name, cl_object volatile v2string, cl_object volatile v3stream)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v4s;
  ecl_bds_bind(cl_env_copy,VV[22],ecl_make_int8_t(0)); /*  *WT-STRING-SIZE*   */
  {
   volatile cl_object v5stream;
   v5stream = cl_make_string_output_stream(0);
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    volatile bool unwinding = FALSE;
    ecl_frame_ptr next_fr;
    {
     ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
     if (__ecl_frs_push_result!=0) {
       unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
     } else {
     (cl_env_copy->function=ecl_fdefinition(VV[29]))->cfun.entry(2, v2string, v5stream) /*  WT-FILTERED-DATA */;
     cl_env_copy->values[0] = cl_get_output_stream_string(v5stream);
     }
    }
    ecl_frs_pop(cl_env_copy);
    ecl_stack_frame_push_values(_ecl_inner_frame);
    cl_close(1, v5stream);
    ecl_stack_frame_pop_values(_ecl_inner_frame);
    if (unwinding) ecl_unwind(cl_env_copy,next_fr);
    v4s = cl_env_copy->values[0];
    ecl_stack_frame_close(_ecl_inner_frame);
   }
  }
  cl_format(6, v3stream, VV[30], v1name, ecl_cmp_symbol_value(cl_env_copy,VV[22]), ecl_cmp_symbol_value(cl_env_copy,VV[22]), v4s);
  value0 = v1name;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object LC3760output_one_c_string_va(cl_narg narg, cl_object v5name, cl_object v6string, cl_object v7stream, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[28]);
 {
  return LC3760output_one_c_string(v5name, v6string, v7stream);
 }
}
/* local function PRODUCE-STRINGS                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3759produce_strings()
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  v1 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v2 = VV[26];
  v3 = v1;
  if (Null(ecl_memql(v2,v3))){
   goto L2;
  }
 }
 {
  cl_object v1string;
  v1string = L3758data_dump_array();
  {
   cl_object v2l;
   v2l = ecl_make_fixnum(ecl_length(v1string));
   {
    cl_object v3;
    cl_object v4;
    cl_object v5;
    cl_object v6i;
    v3 = ecl_make_int8_t(0);
    v4 = v2l;
    v5 = ecl_make_fixnum(65530);
    v6i = v3;
    {
     cl_object v7this_l;
     v7this_l = ECL_NIL;
     {
      cl_object v8;
      cl_object v9;
      v8 = ecl_list1(ECL_NIL);
      v9 = v8;
L16:;
      if (!(ecl_greatereq(v6i,v4))){
       goto L18;
      }
      goto L17;
L18:;
      T0 = ecl_minus(v2l,v6i);
      v7this_l = ((ecl_float_nan_p(ecl_make_fixnum(65530)) || ecl_lowereq(T0,ecl_make_fixnum(65530)))?T0:ecl_make_fixnum(65530));
      {
       cl_object v10;
       v10 = v9;
       if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v10;
      }
      {
       cl_object v10;
       v10 = cl_array_element_type(v1string);
       T1 = si_make_pure_array(v10, v7this_l, ECL_NIL, ECL_NIL, v1string, v6i);
      }
      v9 = ecl_list1(T1);
      (ECL_CONS_CDR(T0)=v9,T0);
      v6i = ecl_plus(v6i,v5);
      goto L16;
L17:;
      value0 = ecl_cdr(v8);
      cl_env_copy->nvalues = 1;
      return value0;
     }
    }
   }
  }
 }
L2:;
 {
  cl_object v10s;
  v10s = L3758data_dump_array();
  {
   cl_fixnum v11;
   v11 = ecl_length(v10s);
   if (!((v11)>0)){
    goto L34;
   }
  }
  value0 = ecl_list1(v10s);
  cl_env_copy->nvalues = 1;
  return value0;
L34:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC3759produce_strings_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[25]);
 {
  return LC3759produce_strings();
 }
}
/* local function OPTIMIZE-VV                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3784optimize_vv(cl_object v1object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2value;
  v2value = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(1, v1object) /*  VV-VALUE */;
  {
   cl_object v3vv;
   if ((cl_env_copy->function=ecl_fdefinition(VV[124]))->cfun.entry(1, v1object) /*  VV-ALWAYS */!=ECL_NIL) {
    goto L5;
   }
   value0 = L3777try_inline_core_sym(v2value);
   if (value0!=ECL_NIL) {
    goto L8;
   }
   value0 = L3775try_value_c_inliner(v2value);
   if (value0!=ECL_NIL) {
    goto L8;
   }
   value0 = L3774add_static_constant(v2value);
   if (value0!=ECL_NIL) {
    goto L8;
   }
   v3vv = L3778try_immediate_value(v2value);
   goto L3;
L8:;
   v3vv = value0;
   goto L3;
L5:;
   v3vv = ECL_NIL;
   goto L3;
L3:;
   if (Null(v3vv)){
    goto L12;
   }
   value0 = L3780update_vv(v1object, v3vv);
   return value0;
L12:;
   value0 = L3781insert_vv(v1object);
   return value0;
  }
 }
}
static cl_object LC3784optimize_vv_va(cl_narg narg, cl_object v4object, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[123]);
 {
  return LC3784optimize_vv(v4object);
 }
}
/* local function LAMBDA212                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3786__lambda212(cl_object v1k, cl_object v2record)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[124]))->cfun.entry(1, v2record) /*  VV-ALWAYS */)){
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(1, v2record) /*  VV-VALUE */;
 value0 = ecl_make_bool((v1k)==(T0));
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC3786__lambda212_va(cl_narg narg, cl_object v3k, cl_object v4record, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[127]);
 {
  return LC3786__lambda212(v3k, v4record);
 }
}
#include "cmp/cmppass2-data.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclAqiq9aSb3oUl9_nUZ0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPBACKEND-CXX;CMPPASS2-DATA.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclAqiq9aSb3oUl9_nUZ0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  ecl_cmp_defun(VV[158]);                         /*  DATA-PERMANENT-STORAGE-SIZE */
  ecl_cmp_defun(VV[159]);                         /*  DATA-TEMPORARY-STORAGE-SIZE */
  ecl_cmp_defun(VV[160]);                         /*  DATA-SIZE               */
  ecl_cmp_defun(VV[161]);                         /*  DATA-GET-ALL-OBJECTS    */
  ecl_cmp_defun(VV[162]);                         /*  DATA-DUMP-ARRAY         */
  ecl_cmp_defun(VV[163]);                         /*  DATA-C-DUMP             */
  ecl_cmp_defun(VV[164]);                         /*  STATIC-BASE-STRING-BUILDER */
  ecl_cmp_defun(VV[165]);                         /*  STATIC-SINGLE-FLOAT-BUILDER */
  ecl_cmp_defun(VV[166]);                         /*  STATIC-DOUBLE-FLOAT-BUILDER */
  ecl_cmp_defun(VV[167]);                         /*  STATIC-LONG-FLOAT-BUILDER */
  ecl_cmp_defun(VV[168]);                         /*  STATIC-RATIONAL-BUILDER */
  ecl_cmp_defun(VV[169]);                         /*  STATIC-CONSTANT-DELEGATE */
  ecl_cmp_defun(VV[170]);                         /*  STATIC-COMPLEX-BUILDER  */
  ecl_cmp_defun(VV[171]);                         /*  STATIC-CSFLOAT-BUILDER  */
  ecl_cmp_defun(VV[172]);                         /*  STATIC-CDFLOAT-BUILDER  */
  ecl_cmp_defun(VV[173]);                         /*  STATIC-CLFLOAT-BUILDER  */
  ecl_cmp_defun(VV[174]);                         /*  STATIC-CONSTANT-EXPRESSION */
  ecl_cmp_defun(VV[175]);                         /*  ADD-STATIC-CONSTANT     */
  ecl_cmp_defun(VV[176]);                         /*  TRY-VALUE-C-INLINER     */
  ecl_cmp_defun(VV[177]);                         /*  TRY-CONST-C-INLINER     */
  ecl_cmp_defun(VV[178]);                         /*  TRY-INLINE-CORE-SYM     */
  ecl_cmp_defun(VV[179]);                         /*  TRY-IMMEDIATE-VALUE     */
  ecl_cmp_defun(VV[180]);                         /*  DATA-EMPTY-LOC*         */
  ecl_cmp_defun(VV[181]);                         /*  UPDATE-VV               */
  ecl_cmp_defun(VV[182]);                         /*  INSERT-VV               */
  ecl_cmp_defun(VV[183]);                         /*  SEARCH-VV               */
  ecl_cmp_defun(VV[184]);                         /*  GET-OBJECT              */
  ecl_cmp_defun(VV[185]);                         /*  OPTIMIZE-CXX-DATA       */
  ecl_cmp_defun(VV[186]);                         /*  ADD-KEYWORDS            */
  ecl_cmp_defun(VV[187]);                         /*  WT-VV-INDEX             */
  ecl_cmp_defun(VV[188]);                         /*  WT-VV-VALUE             */
  ecl_cmp_defun(VV[189]);                         /*  WT-VV                   */
  ecl_cmp_defun(VV[190]);                         /*  SET-VV-INDEX            */
  ecl_cmp_defun(VV[191]);                         /*  SET-VV                  */
}
