/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/clos/boot.lsp                       */
#include <ecl/ecl-cmp.h>
#include "clos/boot.eclh"
/* function definition for MAKE-EMPTY-STANDARD-CLASS                          */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object L1345make_empty_standard_class(cl_narg narg, cl_object v1name, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object v2metaclass;
 cl_object v3direct_superclasses;
 cl_object v4direct_slots;
 cl_object v5index;
 ecl_va_list args; ecl_va_start(args,v1name,narg,1);
 {
  cl_object keyvars[8];
  cl_parse_key(args,4,L1345make_empty_standard_classkeys,keyvars,NULL,FALSE);
  ecl_va_end(args);
  if (Null(keyvars[4])) {
   v2metaclass = ECL_SYM("STANDARD-CLASS",977);
  } else {
   v2metaclass = keyvars[0];
  }
  v3direct_superclasses = keyvars[1];
  v4direct_slots = keyvars[2];
  v5index = keyvars[3];
 }
 {
  cl_object v6the_metaclass;
  cl_object v7class;
  if (Null(v2metaclass)){
   goto L4;
  }
  v6the_metaclass = ecl_gethash_safe(v2metaclass,ECL_SYM_VAL(cl_env_copy,ECL_SYM("*CLASS-NAME-HASH-TABLE*",1020)),ECL_NIL);
  goto L2;
L4:;
  v6the_metaclass = ECL_NIL;
  goto L2;
L2:;
  value0 = ecl_gethash_safe(v1name,ECL_SYM_VAL(cl_env_copy,ECL_SYM("*CLASS-NAME-HASH-TABLE*",1020)),ECL_NIL);
  if (value0!=ECL_NIL) {
   goto L8;
  }
  v7class = si_allocate_raw_instance(ECL_NIL, v6the_metaclass, ecl_make_int8_t(22));
  goto L6;
L8:;
  v7class = value0;
  goto L6;
L6:;
  if (!((v1name)==(ECL_SYM("STANDARD-CLASS",977)))){
   goto L10;
  }
  si_Xmake_constant(ECL_SYM("+THE-STANDARD-CLASS+",1556), v7class);
  si_instance_class_set(v7class, v7class);
L10:;
  ecl_instance_set((v7class),((cl_fixnum)(3)),(v1name));
  ecl_instance_set((v7class),((cl_fixnum)(5)),(ECL_NIL));
  ecl_instance_set((v7class),((cl_fixnum)(9)),(ECL_NIL));
  ecl_instance_set((v7class),((cl_fixnum)(10)),(ECL_NIL));
  ecl_instance_set((v7class),((cl_fixnum)(11)),(ECL_T));
  ecl_instance_set((v7class),((cl_fixnum)(0)),(ECL_NIL));
  {
   cl_object v8;
   v8 = CONS(ECL_NIL,ECL_NIL);
   ecl_instance_set((v7class),((cl_fixnum)(1)),(v8));
  }
  si_hash_set(v1name, ECL_SYM_VAL(cl_env_copy,ECL_SYM("*CLASS-NAME-HASH-TABLE*",1020)), v7class);
  ecl_instance_set((v7class),((cl_fixnum)(14)),(ECL_NIL));
  ecl_instance_set((v7class),((cl_fixnum)(16)),(ECL_NIL));
  ecl_instance_set((v7class),((cl_fixnum)(17)),(ECL_NIL));
  L1401add_slots(v7class, v4direct_slots);
  {
   cl_object v8superclasses;
   {
    cl_object v9name;
    cl_object v10;
    v9name = ECL_NIL;
    v10 = v3direct_superclasses;
    {
     cl_object v11parent;
     v11parent = ECL_NIL;
     {
      cl_object v12;
      cl_object v13;
      v12 = ecl_list1(ECL_NIL);
      v13 = v12;
L36:;
      if (!(v10==ECL_NIL)){
       goto L38;
      }
      goto L37;
L38:;
      v9name = ECL_CONS_CAR(v10);
      v10 = ECL_CONS_CDR(v10);
      v11parent = cl_find_class(1, v9name);
      {
       cl_object v14;
       T0 = ecl_instance_ref((v11parent),((cl_fixnum)(5)));
       v14 = CONS(v7class,T0);
       ecl_instance_set((v11parent),((cl_fixnum)(5)),(v14));
      }
      T0 = v13;
      v13 = ecl_list1(v11parent);
      (ECL_CONS_CDR(T0)=v13,T0);
      goto L36;
L37:;
      v8superclasses = _ecl_cdr(v12);
      goto L30;
     }
    }
   }
L30:;
   ecl_instance_set((v7class),((cl_fixnum)(4)),(v8superclasses));
   {
    cl_object v9;
    v9 = (cl_env_copy->function=(VV[29]->symbol.gfdef))->cfun.entry(2, v7class, v8superclasses) /*  COMPUTE-CLOS-CLASS-PRECEDENCE-LIST */;
    ecl_instance_set((v7class),((cl_fixnum)(7)),(v9));
   }
  }
  if (Null(v5index)){
   goto L56;
  }
  (VV[1])->vector.self.t[ecl_fixnum(v5index)]= v7class;
L56:;
  si_instance_new_stamp(v7class);
  value0 = v7class;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for REMOVE-ACCESSORS                                   */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object L1346remove_accessors(cl_object v1slotds)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v2i;
  cl_object v3;
  v2i = ECL_NIL;
  v3 = v1slotds;
  {
   cl_object v4j;
   v4j = ECL_NIL;
   {
    cl_object v5;
    cl_object v6;
    v5 = ecl_list1(ECL_NIL);
    v6 = v5;
L7:;
    if (!(v3==ECL_NIL)){
     goto L9;
    }
    goto L8;
L9:;
    v2i = ECL_CONS_CAR(v3);
    v3 = ECL_CONS_CDR(v3);
    v4j = cl_copy_list(v2i);
    {
     cl_object v7;
     v7 = v4j;
     {
      cl_object v8;
      cl_object v9;                               /*  FLAG                    */
      T0 = _ecl_cdr(v7);
      value0 = si_rem_f(T0, ECL_SYM("ACCESSOR",987));
      {
       v8 = value0;
       v9 = cl_env_copy->values[1];
      }
      (ECL_CONS_CDR(v7)=v8,v7);
     }
    }
    T0 = v6;
    v6 = ecl_list1(v4j);
    (ECL_CONS_CDR(T0)=v6,T0);
    goto L7;
L8:;
    value0 = _ecl_cdr(v5);
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
static cl_object L1346remove_accessors_va(cl_narg narg, cl_object v7slotds, ...)
{
 return L1346remove_accessors(v7slotds);
}
/* function definition for ADD-SLOTS                                          */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object L1401add_slots(cl_object v1class, cl_object v2slots)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3table;
  cl_object v4location_table;
  cl_object v5slots;
  cl_object v6direct_slots;
  cl_object v7effective_slots;
  if (Null(v2slots)){
   goto L4;
  }
  T0 = ecl_make_int8_t(24);
  goto L3;
L4:;
  T0 = ecl_make_int8_t(0);
L3:;
  v3table = cl_make_hash_table(2, ECL_SYM("SIZE",1345), T0);
  if (Null(v2slots)){
   goto L8;
  }
  T0 = ecl_make_int8_t(24);
  goto L7;
L8:;
  T0 = ecl_make_int8_t(0);
L7:;
  v4location_table = cl_make_hash_table(2, ECL_SYM("SIZE",1345), T0);
  v5slots = (cl_env_copy->function=(VV[35]->symbol.gfdef))->cfun.entry(1, v2slots) /*  PARSE-SLOTS */;
  {
   cl_object v8slotd;
   cl_object v9;
   v8slotd = ECL_NIL;
   v9 = v5slots;
   {
    cl_object v10;
    cl_object v11;
    v10 = ecl_list1(ECL_NIL);
    v11 = v10;
L16:;
    if (!(v9==ECL_NIL)){
     goto L18;
    }
    goto L17;
L18:;
    v8slotd = ECL_CONS_CAR(v9);
    v9 = ECL_CONS_CDR(v9);
    T0 = v11;
    T1 = (VV[36]->symbol.gfdef);
    T2 = cl_find_class(1, ECL_SYM("STANDARD-DIRECT-SLOT-DEFINITION",1636));
    T3 = cl_apply(3, T1, T2, v8slotd);
    v11 = ecl_list1(T3);
    (ECL_CONS_CDR(T0)=v11,T0);
    goto L16;
L17:;
    v6direct_slots = _ecl_cdr(v10);
    goto L11;
   }
  }
L11:;
  {
   cl_object v8i;
   v8i = ecl_make_int8_t(0);
   {
    cl_object v9slotd;
    cl_object v10;
    v9slotd = ECL_NIL;
    v10 = v5slots;
    {
     cl_object v11name;
     v11name = ECL_NIL;
     {
      cl_object v12s;
      v12s = ECL_NIL;
      {
       cl_object v13;
       cl_object v14;
       v13 = ecl_list1(ECL_NIL);
       v14 = v13;
L38:;
       if (!(v10==ECL_NIL)){
        goto L40;
       }
       goto L39;
L40:;
       v9slotd = ECL_CONS_CAR(v10);
       v10 = ECL_CONS_CDR(v10);
       v11name = cl_getf(2, v9slotd, ECL_SYM("NAME",1309));
       T0 = (VV[36]->symbol.gfdef);
       T1 = cl_find_class(1, ECL_SYM("STANDARD-EFFECTIVE-SLOT-DEFINITION",1637));
       v12s = cl_apply(3, T0, T1, v9slotd);
       ecl_instance_set((v12s),((cl_fixnum)(9)),(v8i));
       si_hash_set(v11name, v4location_table, v8i);
       si_hash_set(v11name, v3table, v12s);
       T0 = v14;
       v14 = ecl_list1(v12s);
       (ECL_CONS_CDR(T0)=v14,T0);
       v8i = ecl_one_plus(v8i);
       goto L38;
L39:;
       v7effective_slots = _ecl_cdr(v13);
       goto L30;
      }
     }
    }
   }
  }
L30:;
  ecl_instance_set((v1class),((cl_fixnum)(6)),(v7effective_slots));
  ecl_instance_set((v1class),((cl_fixnum)(8)),(v6direct_slots));
  {
   cl_object v8;
   v8 = ecl_make_fixnum(ecl_length(v5slots));
   ecl_instance_set((v1class),((cl_fixnum)(13)),(v8));
  }
  ecl_instance_set((v1class),((cl_fixnum)(18)),(v3table));
  value0 = ecl_instance_set((v1class),((cl_fixnum)(19)),(v4location_table));
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function CLASS-SLOTS                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC1425class_slots(cl_object v1object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_instance_ref((v1object),((cl_fixnum)(6)));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1425class_slots_va(cl_narg narg, cl_object v2object, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("CLASS-SLOTS",1570));
 {
  return LC1425class_slots(v2object);
 }
}
/* local function CLASS-DIRECT-SLOTS                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC1421class_direct_slots(cl_object v1object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_instance_ref((v1object),((cl_fixnum)(8)));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1421class_direct_slots_va(cl_narg narg, cl_object v2object, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("CLASS-DIRECT-SLOTS",1564));
 {
  return LC1421class_direct_slots(v2object);
 }
}
/* local function (SETF EQL-SPECIALIZER-FLAG)                                 */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1343_setf_eql_specializer_flag_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(0)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1343_setf_eql_specializer_flag__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1343_setf_eql_specializer_flag_(v3value, v4object);
}
/* local function (SETF SPECIALIZER-METHOD-HOLDER)                            */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1341_setf_specializer_method_holder_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(1)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1341_setf_specializer_method_holder__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1341_setf_specializer_method_holder_(v3value, v4object);
}
/* local function (SETF CLASS-ID)                                             */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1339_setf_class_id_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(3)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1339_setf_class_id__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1339_setf_class_id_(v3value, v4object);
}
/* local function (SETF CLASS-DIRECT-SUPERCLASSES)                            */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1337_setf_class_direct_superclasses_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(4)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1337_setf_class_direct_superclasses__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1337_setf_class_direct_superclasses_(v3value, v4object);
}
/* local function CLASS-DIRECT-SUBCLASSES                                     */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1336class_direct_subclasses(cl_object v1object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_ref((v1object),((cl_fixnum)(5)));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1336class_direct_subclasses_va(cl_narg narg, cl_object v2object, ...)
{
 return LC1336class_direct_subclasses(v2object);
}
/* local function (SETF CLASS-DIRECT-SUBCLASSES)                              */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1335_setf_class_direct_subclasses_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(5)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1335_setf_class_direct_subclasses__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1335_setf_class_direct_subclasses_(v3value, v4object);
}
/* local function (SETF CLASS-PRECEDENCE-LIST)                                */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1331_setf_class_precedence_list_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(7)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1331_setf_class_precedence_list__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1331_setf_class_precedence_list_(v3value, v4object);
}
/* local function (SETF CLASS-DIRECT-DEFAULT-INITARGS)                        */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1327_setf_class_direct_default_initargs_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(9)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1327_setf_class_direct_default_initargs__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1327_setf_class_direct_default_initargs_(v3value, v4object);
}
/* local function (SETF CLASS-DEFAULT-INITARGS)                               */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1325_setf_class_default_initargs_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(10)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1325_setf_class_default_initargs__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1325_setf_class_default_initargs_(v3value, v4object);
}
/* local function (SETF CLASS-FINALIZED-P)                                    */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1323_setf_class_finalized_p_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(11)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1323_setf_class_finalized_p__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1323_setf_class_finalized_p_(v3value, v4object);
}
/* local function (SETF CLASS-SEALEDP)                                        */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1319_setf_class_sealedp_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(14)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1319_setf_class_sealedp__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1319_setf_class_sealedp_(v3value, v4object);
}
/* local function (SETF CLASS-DEPENDENTS)                                     */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1317_setf_class_dependents_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(16)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1317_setf_class_dependents__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1317_setf_class_dependents_(v3value, v4object);
}
/* local function (SETF CLASS-VALID-INITARGS)                                 */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1315_setf_class_valid_initargs_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(17)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1315_setf_class_valid_initargs__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1315_setf_class_valid_initargs_(v3value, v4object);
}
/* local function (SETF CLASS-SLOTS)                                          */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1389_setf_class_slots_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(6)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1389_setf_class_slots__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1389_setf_class_slots_(v3value, v4object);
}
/* local function (SETF CLASS-DIRECT-SLOTS)                                   */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1385_setf_class_direct_slots_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(8)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1385_setf_class_direct_slots__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1385_setf_class_direct_slots_(v3value, v4object);
}
/* local function (SETF CLASS-SIZE)                                           */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1377_setf_class_size_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(13)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1377_setf_class_size__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1377_setf_class_size_(v3value, v4object);
}
/* local function (SETF SLOT-TABLE)                                           */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1369_setf_slot_table_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(18)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1369_setf_slot_table__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1369_setf_slot_table_(v3value, v4object);
}
/* local function (SETF CLASS-LOCATION-TABLE)                                 */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1367_setf_class_location_table_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(19)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1367_setf_class_location_table__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1367_setf_class_location_table_(v3value, v4object);
}
/* local function (SETF SLOT-DEFINITION-LOCATION)                             */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object LC1347_setf_slot_definition_location_(cl_object v1value, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_set((v2object),((cl_fixnum)(9)),(v1value));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC1347_setf_slot_definition_location__va(cl_narg narg, cl_object v3value, cl_object v4object, ...)
{
 return LC1347_setf_slot_definition_location_(v3value, v4object);
}
#include "clos/boot.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecl2IiCj6S8Bemj9_oZ10M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CLOS;BOOT.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecl2IiCj6S8Bemj9_oZ10M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0, T1;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  si_Xmake_constant(VV[0], VV[1]);
  ecl_cmp_defun(VV[47]);                          /*  MAKE-EMPTY-STANDARD-CLASS */
  ecl_cmp_defun(VV[48]);                          /*  REMOVE-ACCESSORS        */
  (void)0; /* No entry created for ADD-SLOTS */
  {
   cl_object v1all_classes;
   {
    cl_object v2;
    cl_object v3c;
    cl_object v4;
    v2 = VVtemp[1];
    v3c = ECL_NIL;
    v4 = v2;
    {
     cl_object v5class;
     v5class = ECL_NIL;
     {
      cl_object v6;
      cl_object v7;
      v6 = ecl_list1(ECL_NIL);
      v7 = v6;
L23:;
      if (!(ecl_endp(v4))){
       goto L25;
      }
      goto L24;
L25:;
      v3c = ECL_CONS_CAR(v4);
      {
       cl_object v8;
       v8 = ECL_CONS_CDR(v4);
       if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v4 = v8;
      }
      T0 = (VV[2]->symbol.gfdef);
      v5class = cl_apply(2, T0, v3c);
      {
       cl_object v8;
       v8 = v7;
       if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v8;
      }
      v7 = ecl_list1(v5class);
      (ECL_CONS_CDR(T0)=v7,T0);
      goto L23;
L24:;
      v1all_classes = ecl_cdr(v6);
      goto L16;
     }
    }
   }
L16:;
   T0 = cl_find_class(2, ECL_T, ECL_NIL);
   si_Xmake_constant(ECL_SYM("+THE-T-CLASS+",1553), T0);
   T0 = cl_find_class(2, ECL_SYM("CLASS",937), ECL_NIL);
   si_Xmake_constant(ECL_SYM("+THE-CLASS+",1554), T0);
   T0 = cl_find_class(2, VV[44], ECL_NIL);
   si_Xmake_constant(ECL_SYM("+THE-STD-CLASS+",1555), T0);
   T0 = cl_find_class(2, ECL_SYM("FUNCALLABLE-STANDARD-CLASS",1592), ECL_NIL);
   si_Xmake_constant(ECL_SYM("+THE-FUNCALLABLE-STANDARD-CLASS+",1557), T0);
   T0 = cl_find_class(1, ECL_T);
   T1 = cl_find_class(1, ECL_SYM("BUILT-IN-CLASS",933));
   si_instance_class_set(T0, T1);
   {
    cl_object v2;
    v2 = (ECL_SYM("INSTANCE-NEW-STAMP",1199)->symbol.gfdef);
    {
     cl_object v3;
     cl_object v4;
     cl_object v5;
     {
      cl_object v6;
      v6 = v1all_classes;
      if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v3 = v6;
     }
     v4 = ECL_NIL;
     v5 = v3;
L67:;
     if (!(ecl_endp(v5))){
      goto L69;
     }
     goto L68;
L69:;
     v4 = ECL_CONS_CAR(v5);
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v5 = v6;
     }
     ecl_function_dispatch(cl_env_copy,v2)(1, v4);
     goto L67;
L68:;
     goto L60;
    }
   }
L60:;
   {
    cl_object v2;
    v2 = (ECL_SYM("INSTANCE-SIG-SET",1202)->symbol.gfdef);
    {
     cl_object v3;
     cl_object v4;
     cl_object v5;
     {
      cl_object v6;
      v6 = v1all_classes;
      if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v3 = v6;
     }
     v4 = ECL_NIL;
     v5 = v3;
L87:;
     if (!(ecl_endp(v5))){
      goto L89;
     }
     goto L88;
L89:;
     v4 = ECL_CONS_CAR(v5);
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v5 = v6;
     }
     ecl_function_dispatch(cl_env_copy,v2)(1, v4);
     goto L87;
L88:;
     goto L80;
    }
   }
L80:;
   {
    cl_object v2;
    v2 = cl_find_class(1, ECL_SYM("METHOD-COMBINATION",960));
    (cl_env_copy->function=ECL_CONS_CAR(VV[49]))->cfun.entry(3, ECL_T, v2, VV[45]) /*  (SETF SLOT-VALUE) */;
   }
   {
    cl_object v2;
    cl_object v3c;
    cl_object v4;
    {
     cl_object v5;
     v5 = v1all_classes;
     if (ecl_unlikely(!ECL_LISTP(v5))) FEtype_error_list(v5);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v2 = v5;
    }
    v3c = ECL_NIL;
    v4 = v2;
L107:;
    if (!(ecl_endp(v4))){
     goto L109;
    }
    goto L108;
L109:;
    v3c = ECL_CONS_CAR(v4);
    {
     cl_object v5;
     v5 = ECL_CONS_CDR(v4);
     if (ecl_unlikely(!ECL_LISTP(v5))) FEtype_error_list(v5);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v4 = v5;
    }
    {
     cl_object v5;
     cl_object v6s;
     cl_object v7;
     {
      cl_object v8;
      v8 = ecl_instance_ref((v3c),((cl_fixnum)(8)));
      if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v5 = v8;
     }
     v6s = ECL_NIL;
     v7 = v5;
L123:;
     if (!(ecl_endp(v7))){
      goto L125;
     }
     goto L124;
L125:;
     v6s = ECL_CONS_CAR(v7);
     {
      cl_object v8;
      v8 = ECL_CONS_CDR(v7);
      if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v7 = v8;
     }
     si_instance_sig_set(v6s);
     goto L123;
L124:;
    }
    {
     cl_object v5;
     cl_object v6s;
     cl_object v7;
     {
      cl_object v8;
      v8 = ecl_instance_ref((v3c),((cl_fixnum)(6)));
      if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v5 = v8;
     }
     v6s = ECL_NIL;
     v7 = v5;
L141:;
     if (!(ecl_endp(v7))){
      goto L143;
     }
     goto L142;
L143:;
     v6s = ECL_CONS_CAR(v7);
     {
      cl_object v8;
      v8 = ECL_CONS_CDR(v7);
      if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v7 = v8;
     }
     si_instance_sig_set(v6s);
     goto L141;
L142:;
    }
    goto L107;
L108:;
   }
  }
 }
}
