/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpbackend-cxx/cmppass2-eval.lsp */
#include <ecl/ecl-cmp.h>
#include "cmp/cmppass2-eval.eclh"
/* function definition for C2EXPR                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3858c2expr(cl_object v1form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,VV[2],v1form);          /*  *CURRENT-C1FORM*        */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[3]))->cfun.entry(1, v1form) /*  C1FORM-FILE */;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*COMPILE-FILE-TRUENAME*",29),T0); /*  *COMPILE-FILE-TRUENAME* */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(1, v1form) /*  C1FORM-FILE-POSITION */;
 ecl_bds_bind(cl_env_copy,VV[4],T0);              /*  *COMPILE-FILE-POSITION* */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[7]))->cfun.entry(1, v1form) /*  C1FORM-TOPLEVEL-FORM */;
 ecl_bds_bind(cl_env_copy,VV[6],T0);              /*  *CURRENT-TOPLEVEL-FORM* */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[9]))->cfun.entry(1, v1form) /*  C1FORM-FORM */;
 ecl_bds_bind(cl_env_copy,VV[8],T0);              /*  *CURRENT-FORM*          */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(1, v1form) /*  C1FORM-ENV */;
 ecl_bds_bind(cl_env_copy,VV[10],T0);             /*  *CMP-ENV*               */
 {
  cl_object v2name;
  cl_object v3args;
  cl_object v4dispatch;
  v2name = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v1form) /*  C1FORM-NAME */;
  v3args = (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(1, v1form) /*  C1FORM-ARGS */;
  v4dispatch = ecl_gethash_safe(v2name,ecl_cmp_symbol_value(cl_env_copy,VV[14]),ECL_NIL);
  if (Null(v4dispatch)){
   goto L5;
  }
  value0 = cl_apply(3, v4dispatch, v1form, v3args);
  ecl_bds_unwind_n(cl_env_copy,6);
  return value0;
L5:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(2, VV[16], v1form) /*  CMPERR */;
  ecl_bds_unwind_n(cl_env_copy,6);
  return value0;
 }
}
static cl_object L3858c2expr_va(cl_narg narg, cl_object v5form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[0]);
 {
  return L3858c2expr(v5form);
 }
}
/* function definition for C2EXPR*                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3859c2expr_(cl_object v1form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, ECL_NIL) /*  LABELP */;
  if (Null(v2)){
   goto L4;
  }
  T0 = ECL_NIL;
  goto L3;
L4:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L3:;
  ecl_bds_bind(cl_env_copy,VV[21],T0);            /*  *EXIT*                  */
  T0 = cl_adjoin(2, ecl_cmp_symbol_value(cl_env_copy,VV[21]), ecl_cmp_symbol_value(cl_env_copy,VV[23]));
  ecl_bds_bind(cl_env_copy,VV[23],T0);            /*  *UNWIND-EXIT*           */
  {
   cl_object v3;
   cl_object v4;
   v3 = ecl_cmp_symbol_value(cl_env_copy,VV[24]);
   v4 = ecl_cmp_symbol_value(cl_env_copy,VV[25]);
   ecl_bds_bind(cl_env_copy,VV[24],v3);           /*  *LCL*                   */
   ecl_bds_bind(cl_env_copy,VV[25],v4);           /*  *TEMP*                  */
   L3858c2expr(v1form);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
  }
  if (v2!=ECL_NIL) {
   goto L9;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[21])) /*  WT-LABEL */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L9:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3859c2expr__va(cl_narg narg, cl_object v3form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[18]);
 {
  return L3859c2expr_(v3form);
 }
}
/* function definition for C2PROGN                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3860c2progn(cl_object v1c1form, cl_object v2forms)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3lex;
  v3lex = ecl_cmp_symbol_value(cl_env_copy,VV[29]);
  {
   cl_object v4;
   cl_object v5form;
   cl_object v6next;
   cl_object v7rest;
   v4 = v2forms;
   v5form = ECL_NIL;
   v6next = ECL_NIL;
   v7rest = ECL_NIL;
L7:;
   if (!(ECL_ATOM(v4))){
    goto L9;
   }
   goto L8;
L9:;
   {
    cl_object v8;
    v8 = v4;
    v5form = ecl_car(v8);
    v8 = ecl_cdr(v8);
    v6next = ecl_car(v8);
    v8 = ecl_cdr(v8);
    v7rest = v8;
   }
   v4 = ECL_CONS_CDR(v4);
   if (!(v6next==ECL_NIL)){
    goto L25;
   }
   L3858c2expr(v5form);
   goto L24;
L25:;
   ecl_bds_bind(cl_env_copy,VV[32],VV[33]);       /*  *DESTINATION*           */
   L3859c2expr_(v5form);
   T0 = v3lex;
   ecl_cmp_setq(cl_env_copy,VV[29],T0);
   ecl_bds_unwind1(cl_env_copy);
L24:;
   {
    cl_object v8;
    v8 = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v5form) /*  C1FORM-NAME */;
    if (!((v8)==(ECL_SYM("GO",416)))){
     goto L35;
    }
    goto L32;
L35:;
    goto L33;
L33:;
    if (!((v8)==(ECL_SYM("RETURN-FROM",728)))){
     goto L29;
    }
    goto L30;
L32:;
   }
L30:;
   goto L8;
L29:;
   goto L7;
L8:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3860c2progn_va(cl_narg narg, cl_object v8c1form, cl_object v9forms, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[28]);
 {
  return L3860c2progn(v8c1form, v9forms);
 }
}
/* function definition for C2IF                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3861c2if(cl_object v1c1form, cl_object v2fmla, cl_object v3form1, cl_object v4form2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[39]))->cfun.entry(1, v2fmla) /*  C1FORM-PRIMARY-TYPE */;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(2, T0, ecl_cmp_symbol_value(cl_env_copy,VV[10])) /*  TYPE-TRUE-P */)){
  goto L2;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(4, v4form2, v1c1form, VV[41], v2fmla) /*  WARN-DEAD-CODE */;
 ecl_bds_bind(cl_env_copy,VV[32],VV[33]);         /*  *DESTINATION*           */
 L3859c2expr_(v2fmla);
 ecl_bds_unwind1(cl_env_copy);
 value0 = L3858c2expr(v3form1);
 return value0;
L2:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[39]))->cfun.entry(1, v2fmla) /*  C1FORM-PRIMARY-TYPE */;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[42]))->cfun.entry(2, T0, ecl_cmp_symbol_value(cl_env_copy,VV[10])) /*  TYPE-FALSE-P */)){
  goto L6;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(4, v3form1, v1c1form, VV[43], v2fmla) /*  WARN-DEAD-CODE */;
 ecl_bds_bind(cl_env_copy,VV[32],VV[33]);         /*  *DESTINATION*           */
 L3859c2expr_(v2fmla);
 ecl_bds_unwind1(cl_env_copy);
 value0 = L3858c2expr(v4form2);
 return value0;
L6:;
 if (!((ecl_cmp_symbol_value(cl_env_copy,VV[32]))==(VV[33]))){
  goto L10;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v4form2) /*  C1FORM-NAME */;
 if (!((T0)==(VV[44]))){
  goto L10;
 }
 {
  cl_object v5;
  cl_object v6;
  cl_object v7false_label;
  v5 = ecl_cmp_symbol_value(cl_env_copy,VV[21]);
  v6 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, v5) /*  LABELP */;
  if (Null(v6)){
   goto L16;
  }
  v7false_label = v5;
  goto L15;
L16:;
  v7false_label = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L15:;
  T0 = cl_adjoin(2, v7false_label, ecl_cmp_symbol_value(cl_env_copy,VV[23]));
  ecl_bds_bind(cl_env_copy,VV[23],T0);            /*  *UNWIND-EXIT*           */
  T0 = cl_list(2, VV[45], v7false_label);
  ecl_bds_bind(cl_env_copy,VV[32],T0);            /*  *DESTINATION*           */
  L3859c2expr_(v2fmla);
  ecl_bds_unwind1(cl_env_copy);
  L3858c2expr(v3form1);
  if (v6!=ECL_NIL) {
   goto L20;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v7false_label) /*  WT-LABEL */;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L20:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
L10:;
 if (!((ecl_cmp_symbol_value(cl_env_copy,VV[32]))==(VV[33]))){
  goto L22;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v3form1) /*  C1FORM-NAME */;
 if (!((T0)==(VV[44]))){
  goto L22;
 }
 {
  cl_object v8;
  cl_object v9;
  cl_object v10true_label;
  v8 = ecl_cmp_symbol_value(cl_env_copy,VV[21]);
  v9 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, v8) /*  LABELP */;
  if (Null(v9)){
   goto L28;
  }
  v10true_label = v8;
  goto L27;
L28:;
  v10true_label = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L27:;
  T0 = cl_adjoin(2, v10true_label, ecl_cmp_symbol_value(cl_env_copy,VV[23]));
  ecl_bds_bind(cl_env_copy,VV[23],T0);            /*  *UNWIND-EXIT*           */
  T0 = cl_list(2, VV[46], v10true_label);
  ecl_bds_bind(cl_env_copy,VV[32],T0);            /*  *DESTINATION*           */
  L3859c2expr_(v2fmla);
  ecl_bds_unwind1(cl_env_copy);
  L3858c2expr(v4form2);
  if (v9!=ECL_NIL) {
   goto L32;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v10true_label) /*  WT-LABEL */;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L32:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
L22:;
 {
  cl_object v11;
  cl_object v12false_label;
  v11 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, ECL_NIL) /*  LABELP */;
  if (Null(v11)){
   goto L37;
  }
  v12false_label = ECL_NIL;
  goto L36;
L37:;
  v12false_label = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L36:;
  T0 = cl_adjoin(2, v12false_label, ecl_cmp_symbol_value(cl_env_copy,VV[23]));
  ecl_bds_bind(cl_env_copy,VV[23],T0);            /*  *UNWIND-EXIT*           */
  T0 = cl_list(2, VV[45], v12false_label);
  ecl_bds_bind(cl_env_copy,VV[32],T0);            /*  *DESTINATION*           */
  L3859c2expr_(v2fmla);
  ecl_bds_unwind1(cl_env_copy);
  L3858c2expr(v3form1);
  if (v11!=ECL_NIL) {
   ecl_bds_unwind1(cl_env_copy);
   goto L34;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v12false_label) /*  WT-LABEL */;
  ecl_bds_unwind1(cl_env_copy);
 }
L34:;
 value0 = L3858c2expr(v4form2);
 return value0;
}
static cl_object L3861c2if_va(cl_narg narg, cl_object v11c1form, cl_object v12fmla, cl_object v13form1, cl_object v14form2, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[37]);
 {
  return L3861c2if(v11c1form, v12fmla, v13form1, v14form2);
 }
}
/* function definition for JUMP-TRUE-DESTINATION-P                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3862jump_true_destination_p(cl_object v1dest)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_CONSP(v1dest))){
  goto L3;
 }
 T0 = ECL_CONS_CAR(v1dest);
 value0 = ecl_make_bool((T0)==(VV[46]));
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for JUMP-FALSE-DESTINATION-P                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3863jump_false_destination_p(cl_object v1dest)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_CONSP(v1dest))){
  goto L3;
 }
 T0 = ECL_CONS_CAR(v1dest);
 value0 = ecl_make_bool((T0)==(VV[45]));
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for C2FMLA-NOT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3864c2fmla_not(cl_object v1c1form, cl_object v2arg)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3dest;
  v3dest = ecl_cmp_symbol_value(cl_env_copy,VV[32]);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[39]))->cfun.entry(1, v2arg) /*  C1FORM-PRIMARY-TYPE */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(2, T0, ecl_cmp_symbol_value(cl_env_copy,VV[10])) /*  TYPE-TRUE-P */)){
   goto L3;
  }
  ecl_bds_bind(cl_env_copy,VV[32],VV[33]);        /*  *DESTINATION*           */
  L3859c2expr_(v2arg);
  ecl_bds_unwind1(cl_env_copy);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[51]))->cfun.entry(0) /*  C1NIL */;
  value0 = L3858c2expr(T0);
  return value0;
L3:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[39]))->cfun.entry(1, v2arg) /*  C1FORM-PRIMARY-TYPE */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[42]))->cfun.entry(2, T0, ecl_cmp_symbol_value(cl_env_copy,VV[10])) /*  TYPE-FALSE-P */)){
   goto L6;
  }
  ecl_bds_bind(cl_env_copy,VV[32],VV[33]);        /*  *DESTINATION*           */
  L3859c2expr_(v2arg);
  ecl_bds_unwind1(cl_env_copy);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[52]))->cfun.entry(0) /*  C1T */;
  value0 = L3858c2expr(T0);
  return value0;
L6:;
  if (Null(L3862jump_true_destination_p(v3dest))){
   goto L9;
  }
  T0 = ecl_cdr(v3dest);
  T1 = CONS(VV[45],T0);
  ecl_bds_bind(cl_env_copy,VV[32],T1);            /*  *DESTINATION*           */
  value0 = L3858c2expr(v2arg);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L9:;
  if (Null(L3863jump_false_destination_p(v3dest))){
   goto L11;
  }
  T0 = ecl_cdr(v3dest);
  T1 = CONS(VV[46],T0);
  ecl_bds_bind(cl_env_copy,VV[32],T1);            /*  *DESTINATION*           */
  value0 = L3858c2expr(v2arg);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L11:;
  {
   cl_object v4;
   cl_object v5;
   v4 = ecl_cmp_symbol_value(cl_env_copy,VV[25]);
   v5 = ecl_cmp_symbol_value(cl_env_copy,VV[24]);
   ecl_bds_bind(cl_env_copy,VV[54],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*   */
   ecl_bds_bind(cl_env_copy,VV[25],v4);           /*  *TEMP*                  */
   ecl_bds_bind(cl_env_copy,VV[24],v5);           /*  *LCL*                   */
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(2, v2arg, v3dest) /*  NEGATE-ARGUMENT */;
   (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, T0) /*  UNWIND-EXIT */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   return value0;
  }
 }
}
static cl_object L3864c2fmla_not_va(cl_narg narg, cl_object v6c1form, cl_object v7arg, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[50]);
 {
  return L3864c2fmla_not(v6c1form, v7arg);
 }
}
/* function definition for C2FMLA-AND                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3866c2fmla_and(cl_object v1c1form, cl_object v2butlast, cl_object v3last)
{
 cl_object T0;
 volatile cl_object lex0[3];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 lex0[0] = v1c1form;                              /*  C1FORM                  */
 lex0[1] = v2butlast;                             /*  BUTLAST                 */
 lex0[2] = v3last;                                /*  LAST                    */
L1:;
 if (Null(L3863jump_false_destination_p(ecl_cmp_symbol_value(cl_env_copy,VV[32])))){
  goto L2;
 }
 value0 = LC3865c2expr_and_arguments(lex0, ecl_cmp_symbol_value(cl_env_copy,VV[32]), ecl_cmp_symbol_value(cl_env_copy,VV[32]));
 return value0;
L2:;
 {
  cl_object v4;
  cl_object v5normal_exit;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, ECL_NIL) /*  LABELP */;
  if (Null(v4)){
   goto L6;
  }
  v5normal_exit = ECL_NIL;
  goto L5;
L6:;
  v5normal_exit = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L5:;
  T0 = cl_adjoin(2, v5normal_exit, ecl_cmp_symbol_value(cl_env_copy,VV[23]));
  ecl_bds_bind(cl_env_copy,VV[23],T0);            /*  *UNWIND-EXIT*           */
  {
   cl_object v6;
   cl_object v7false_label;
   v6 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, ECL_NIL) /*  LABELP */;
   if (Null(v6)){
    goto L11;
   }
   v7false_label = ECL_NIL;
   goto L10;
L11:;
   v7false_label = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L10:;
   T0 = cl_adjoin(2, v7false_label, ecl_cmp_symbol_value(cl_env_copy,VV[23]));
   ecl_bds_bind(cl_env_copy,VV[23],T0);           /*  *UNWIND-EXIT*           */
   T0 = cl_list(2, VV[45], v7false_label);
   LC3865c2expr_and_arguments(lex0, T0, ecl_cmp_symbol_value(cl_env_copy,VV[32]));
   if (v6!=ECL_NIL) {
    ecl_bds_unwind1(cl_env_copy);
    goto L8;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v7false_label) /*  WT-LABEL */;
   ecl_bds_unwind1(cl_env_copy);
  }
L8:;
  (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[61])) /*  UNWIND-EXIT */;
  if (v4!=ECL_NIL) {
   goto L16;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v5normal_exit) /*  WT-LABEL */;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L16:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3866c2fmla_and_va(cl_narg narg, cl_object v6c1form, cl_object v7butlast, cl_object v8last, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[59]);
 {
  return L3866c2fmla_and(v6c1form, v7butlast, v8last);
 }
}
/* function definition for C2FMLA-OR                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3869c2fmla_or(cl_object v1c1form, cl_object v2butlast, cl_object v3last)
{
 cl_object T0, T1, T2;
 volatile cl_object lex0[3];
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 lex0[0] = v1c1form;                              /*  C1FORM                  */
 lex0[1] = v2butlast;                             /*  BUTLAST                 */
 lex0[2] = v3last;                                /*  LAST                    */
L1:;
 if (Null(L3862jump_true_destination_p(ecl_cmp_symbol_value(cl_env_copy,VV[32])))){
  goto L2;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,VV[32]);
 T1 = ecl_cmp_symbol_value(cl_env_copy,VV[32]);
 T2 = ecl_fdefinition(VV[18]);
 value0 = LC3867c2expr_or_arguments(lex0, T0, T1, T2);
 return value0;
L2:;
 if (Null(L3863jump_false_destination_p(ecl_cmp_symbol_value(cl_env_copy,VV[32])))){
  goto L7;
 }
 {
  cl_object v4;
  cl_object v5true_label;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, ECL_NIL) /*  LABELP */;
  if (Null(v4)){
   goto L12;
  }
  v5true_label = ECL_NIL;
  goto L11;
L12:;
  v5true_label = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L11:;
  T0 = cl_adjoin(2, v5true_label, ecl_cmp_symbol_value(cl_env_copy,VV[23]));
  ecl_bds_bind(cl_env_copy,VV[23],T0);            /*  *UNWIND-EXIT*           */
  T0 = cl_list(2, VV[46], v5true_label);
  T1 = ecl_cmp_symbol_value(cl_env_copy,VV[32]);
  T2 = ecl_fdefinition(VV[18]);
  LC3867c2expr_or_arguments(lex0, T0, T1, T2);
  if (v4!=ECL_NIL) {
   ecl_bds_unwind1(cl_env_copy);
   goto L9;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v5true_label) /*  WT-LABEL */;
  ecl_bds_unwind1(cl_env_copy);
 }
L9:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[66])) /*  UNWIND-EXIT */;
 return value0;
L7:;
 {
  cl_object v4;
  cl_object v5common_exit;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, ECL_NIL) /*  LABELP */;
  if (Null(v4)){
   goto L20;
  }
  v5common_exit = ECL_NIL;
  goto L19;
L20:;
  v5common_exit = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L19:;
  T0 = cl_adjoin(2, v5common_exit, ecl_cmp_symbol_value(cl_env_copy,VV[23]));
  ecl_bds_bind(cl_env_copy,VV[23],T0);            /*  *UNWIND-EXIT*           */
  {
   cl_object v6;
   cl_object env1 = env0;
   v6 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, ECL_NIL) /*  LABELP */;
   if (Null(v6)){
    goto L25;
   }
   T0 = ECL_NIL;
   goto L24;
L25:;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L24:;
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(T0,env1);                   /*  NORMAL-EXIT             */
   T0 = cl_adjoin(2, ECL_CONS_CAR(CLV0), ecl_cmp_symbol_value(cl_env_copy,VV[23]));
   ecl_bds_bind(cl_env_copy,VV[23],T0);           /*  *UNWIND-EXIT*           */
   {
    cl_object v7;
    v7 = ecl_make_cclosure_va((cl_objectfn)LC3868__lambda55,env1,Cblock,1);
    T0 = v7;
   }
   LC3867c2expr_or_arguments(lex0, ecl_cmp_symbol_value(cl_env_copy,VV[32]), ecl_cmp_symbol_value(cl_env_copy,VV[32]), T0);
   if (v6!=ECL_NIL) {
    ecl_bds_unwind1(cl_env_copy);
    goto L22;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  WT-LABEL */;
   ecl_bds_unwind1(cl_env_copy);
  }
L22:;
  (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, VV[65]) /*  UNWIND-EXIT */;
  if (v4!=ECL_NIL) {
   goto L31;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v5common_exit) /*  WT-LABEL */;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L31:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3869c2fmla_or_va(cl_narg narg, cl_object v6c1form, cl_object v7butlast, cl_object v8last, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[63]);
 {
  return L3869c2fmla_or(v6c1form, v7butlast, v8last);
 }
}
/* function definition for C2MV-PROG1                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3870c2mv_prog1(cl_object v1c1form, cl_object v2form, cl_object v3body)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  cl_object v5;
  v4 = ecl_cmp_symbol_value(cl_env_copy,VV[25]);
  v5 = ecl_cmp_symbol_value(cl_env_copy,VV[24]);
  ecl_bds_bind(cl_env_copy,VV[54],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*    */
  ecl_bds_bind(cl_env_copy,VV[25],v4);            /*  *TEMP*                  */
  ecl_bds_bind(cl_env_copy,VV[24],v5);            /*  *LCL*                   */
  (cl_env_copy->function=ecl_fdefinition(VV[74]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
  T0 = cl_list(2, VV[77], VV[75]);
  T1 = CONS(T0,ecl_cmp_symbol_value(cl_env_copy,VV[23]));
  ecl_bds_bind(cl_env_copy,VV[23],T1);            /*  *UNWIND-EXIT*           */
  (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(3, VV[79], VV[76], VV[80]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(6, ecl_cmp_symbol_value(cl_env_copy,VV[81]), VV[82], VV[75], VV[83], VV[76], VV[84]) /*  WT-NL */;
  ecl_bds_bind(cl_env_copy,VV[32],VV[85]);        /*  *DESTINATION*           */
  L3859c2expr_(v2form);
  ecl_bds_unwind1(cl_env_copy);
  (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(3, VV[86], VV[75], VV[87]) /*  WT-NL */;
  ecl_bds_bind(cl_env_copy,VV[32],VV[33]);        /*  *DESTINATION*           */
  {
   cl_object v6;
   v6 = ecl_fdefinition(VV[18]);
   {
    cl_object v7;
    cl_object v8;
    cl_object v9;
    {
     cl_object v10;
     v10 = v3body;
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v7 = v10;
    }
    v8 = ECL_NIL;
    v9 = v7;
L17:;
    if (!(ecl_endp(v9))){
     goto L19;
    }
    goto L18;
L19:;
    v8 = ECL_CONS_CAR(v9);
    {
     cl_object v10;
     v10 = ECL_CONS_CDR(v9);
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v9 = v10;
    }
    ecl_function_dispatch(cl_env_copy,v6)(1, v8);
    goto L17;
L18:;
    ecl_bds_unwind1(cl_env_copy);
    goto L10;
   }
  }
L10:;
  (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(3, VV[88], VV[75], VV[87]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, VV[85]) /*  UNWIND-EXIT */;
  ecl_bds_unwind1(cl_env_copy);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3870c2mv_prog1_va(cl_narg narg, cl_object v6c1form, cl_object v7form, cl_object v8body, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[71]);
 {
  return L3870c2mv_prog1(v6c1form, v7form, v8body);
 }
}
/* function definition for C2VALUES                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3871c2values(cl_object v1c1form, cl_object v2forms)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((ecl_cmp_symbol_value(cl_env_copy,VV[32]))==(VV[33]))){
  goto L2;
 }
 {
  cl_object v3;
  v3 = ecl_fdefinition(VV[18]);
  {
   cl_object v4;
   cl_object v5;
   cl_object v6;
   {
    cl_object v7;
    v7 = v2forms;
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   v5 = ECL_NIL;
   v6 = v4;
L11:;
   if (!(ecl_endp(v6))){
    goto L13;
   }
   goto L12;
L13:;
   v5 = ECL_CONS_CAR(v6);
   {
    cl_object v7;
    v7 = ECL_CONS_CDR(v6);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v6 = v7;
   }
   ecl_function_dispatch(cl_env_copy,v3)(1, v5);
   goto L11;
L12:;
   goto L4;
  }
 }
L4:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, VV[65]) /*  UNWIND-EXIT */;
 return value0;
L2:;
 if (!(ecl_endp(v2forms))){
  goto L24;
 }
 {
  cl_object v3;
  v3 = ecl_cmp_symbol_value(cl_env_copy,VV[32]);
  if (!((v3)==(VV[85]))){
   goto L27;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, VV[91]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, VV[92]) /*  WT-NL */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, VV[85]) /*  UNWIND-EXIT */;
  return value0;
L27:;
  if (!((v3)==(VV[93]))){
   goto L31;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, VV[94]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, VV[92]) /*  WT-NL */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, VV[93]) /*  UNWIND-EXIT */;
  return value0;
L31:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[61])) /*  UNWIND-EXIT */;
  return value0;
 }
L24:;
 T0 = ecl_cdr(v2forms);
 if (!(ecl_endp(T0))){
  goto L35;
 }
 {
  cl_object v4form;
  v4form = ecl_car(v2forms);
  {
   cl_object v5;
   v5 = ecl_cmp_symbol_value(cl_env_copy,VV[32]);
   if (!((v5)==(VV[93]))){
    goto L46;
   }
   goto L43;
L46:;
   goto L44;
L44:;
   if (!((v5)==(VV[85]))){
    goto L40;
   }
   goto L41;
L43:;
  }
L41:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[97]))->cfun.entry(1, v4form) /*  C1FORM-SINGLE-VALUED-P */)){
   goto L38;
  }
  goto L39;
L40:;
L39:;
  value0 = L3858c2expr(v4form);
  return value0;
L38:;
  ecl_bds_bind(cl_env_copy,VV[32],VV[65]);        /*  *DESTINATION*           */
  L3859c2expr_(v4form);
  ecl_bds_unwind1(cl_env_copy);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, VV[65]) /*  UNWIND-EXIT */;
  return value0;
 }
L35:;
 {
  cl_object v5;
  cl_object v6;
  v5 = ecl_cmp_symbol_value(cl_env_copy,VV[25]);
  v6 = ecl_cmp_symbol_value(cl_env_copy,VV[24]);
  ecl_bds_bind(cl_env_copy,VV[54],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*    */
  ecl_bds_bind(cl_env_copy,VV[25],v5);            /*  *TEMP*                  */
  ecl_bds_bind(cl_env_copy,VV[24],v6);            /*  *LCL*                   */
  {
   cl_object v7nv;
   cl_object v8forms;
   v7nv = ecl_make_fixnum(ecl_length(v2forms));
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[99]))->cfun.entry(1, v2forms) /*  INLINE-ARGS */;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[98]))->cfun.entry(1, T0) /*  COERCE-ARGS */;
   v8forms = cl_nreverse(T1);
   (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(3, VV[100], v7nv, VV[80]) /*  WT-NL */;
   {
    cl_fixnum v9;
    cl_object v10vl;
    cl_fixnum v11i;
    {
     cl_object v12;
     {
      cl_fixnum v13;
      v13 = ecl_length(v8forms);
      v12 = ecl_make_integer((v13)-1);
     }
     {
      bool v13;
      v13 = ECL_FIXNUMP(v12);
      if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
     v9 = ecl_fixnum(v12);
    }
    v10vl = v8forms;
    v11i = v9;
    goto L64;
L63:;
    T0 = ecl_car(v10vl);
    (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(5, VV[101], ecl_make_fixnum(v11i), VV[102], T0, VV[80]) /*  WT-NL */;
    v10vl = ecl_cdr(v10vl);
    {
     cl_object v12;
     v12 = ecl_make_integer((v11i)-1);
     {
      bool v13;
      v13 = ECL_FIXNUMP(v12);
      if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
     v11i = ecl_fixnum(v12);
    }
L64:;
    if (v10vl==ECL_NIL) {
     goto L72;
    }
    goto L63;
L72:;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(1, VV[85]) /*  UNWIND-EXIT */;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3871c2values_va(cl_narg narg, cl_object v7c1form, cl_object v8forms, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[90]);
 {
  return L3871c2values(v7c1form, v8forms);
 }
}
/* local function C2EXPR-AND-ARGUMENTS                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3865c2expr_and_arguments(volatile cl_object *lex0, cl_object v1eval_dest, cl_object v2exit_dest)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,VV[32],v1eval_dest);    /*  *DESTINATION*           */
 {
  cl_object v3;
  cl_object v4expr;
  cl_object v5;
  {
   cl_object v6;
   v6 = lex0[1];
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3 = v6;
  }
  v4expr = ECL_NIL;
  v5 = v3;
  {
   cl_object v6remaining_exprs;
   v6remaining_exprs = lex0[1];
   {
    cl_object v7type;
    v7type = ECL_NIL;
    if (!(ecl_endp(v5))){
     goto L11;
    }
    goto L10;
L11:;
    v4expr = ECL_CONS_CAR(v5);
    {
     cl_object v8;
     v8 = ECL_CONS_CDR(v5);
     if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v8;
    }
L9:;
    if (!(ECL_ATOM(v6remaining_exprs))){
     goto L19;
    }
    goto L10;
L19:;
    v7type = (cl_env_copy->function=ecl_fdefinition(VV[39]))->cfun.entry(1, v4expr) /*  C1FORM-PRIMARY-TYPE */;
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[42]))->cfun.entry(2, v7type, ecl_cmp_symbol_value(cl_env_copy,VV[10])) /*  TYPE-FALSE-P */)){
     goto L24;
    }
    T0 = ecl_cdr(v6remaining_exprs);
    T1 = ecl_list1(lex0[2]);
    T2 = ecl_append(T0,T1);
    (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(4, T2, lex0[0], VV[43], v4expr) /*  WARN-DEAD-CODE */;
    ecl_bds_bind(cl_env_copy,VV[32],v2exit_dest); /*  *DESTINATION*           */
    L3859c2expr_(v4expr);
    ecl_bds_unwind1(cl_env_copy);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    ecl_bds_unwind1(cl_env_copy);
    return value0;
L24:;
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(2, v7type, ecl_cmp_symbol_value(cl_env_copy,VV[10])) /*  TYPE-TRUE-P */)){
     goto L28;
    }
    ecl_bds_bind(cl_env_copy,VV[32],VV[33]);      /*  *DESTINATION*           */
    L3859c2expr_(v4expr);
    ecl_bds_unwind1(cl_env_copy);
    goto L23;
L28:;
    L3859c2expr_(v4expr);
L23:;
    if (!(ecl_endp(v5))){
     goto L30;
    }
    goto L10;
L30:;
    v4expr = ECL_CONS_CAR(v5);
    {
     cl_object v8;
     v8 = ECL_CONS_CDR(v5);
     if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v8;
    }
    v6remaining_exprs = ECL_CONS_CDR(v6remaining_exprs);
    goto L9;
L10:;
    ecl_bds_bind(cl_env_copy,VV[32],v2exit_dest); /*  *DESTINATION*           */
    L3858c2expr(lex0[2]);
    ecl_bds_unwind1(cl_env_copy);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    ecl_bds_unwind1(cl_env_copy);
    return value0;
   }
  }
 }
}
/* local function C2EXPR-OR-ARGUMENTS                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3867c2expr_or_arguments(volatile cl_object *lex0, cl_object v1eval_dest, cl_object v2exit_dest, cl_object v3operation)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,VV[32],v1eval_dest);    /*  *DESTINATION*           */
 {
  cl_object v4;
  cl_object v5expr;
  cl_object v6;
  {
   cl_object v7;
   v7 = lex0[1];
   if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v4 = v7;
  }
  v5expr = ECL_NIL;
  v6 = v4;
  {
   cl_object v7remaining_exprs;
   v7remaining_exprs = lex0[1];
   {
    cl_object v8type;
    v8type = ECL_NIL;
    if (!(ecl_endp(v6))){
     goto L11;
    }
    goto L10;
L11:;
    v5expr = ECL_CONS_CAR(v6);
    {
     cl_object v9;
     v9 = ECL_CONS_CDR(v6);
     if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v6 = v9;
    }
L9:;
    if (!(ECL_ATOM(v7remaining_exprs))){
     goto L19;
    }
    goto L10;
L19:;
    v8type = (cl_env_copy->function=ecl_fdefinition(VV[39]))->cfun.entry(1, v5expr) /*  C1FORM-PRIMARY-TYPE */;
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(2, v8type, ecl_cmp_symbol_value(cl_env_copy,VV[10])) /*  TYPE-TRUE-P */)){
     goto L24;
    }
    T0 = ecl_cdr(v7remaining_exprs);
    T1 = ecl_list1(lex0[2]);
    T2 = ecl_append(T0,T1);
    (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(4, T2, lex0[0], VV[41], v5expr) /*  WARN-DEAD-CODE */;
    ecl_bds_bind(cl_env_copy,VV[32],VV[65]);      /*  *DESTINATION*           */
    L3859c2expr_(v5expr);
    ecl_bds_unwind1(cl_env_copy);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    ecl_bds_unwind1(cl_env_copy);
    return value0;
L24:;
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[42]))->cfun.entry(2, v8type, ecl_cmp_symbol_value(cl_env_copy,VV[10])) /*  TYPE-FALSE-P */)){
     goto L28;
    }
    ecl_bds_bind(cl_env_copy,VV[32],VV[33]);      /*  *DESTINATION*           */
    L3859c2expr_(v5expr);
    ecl_bds_unwind1(cl_env_copy);
    goto L23;
L28:;
    ecl_function_dispatch(cl_env_copy,v3operation)(1, v5expr);
L23:;
    if (!(ecl_endp(v6))){
     goto L30;
    }
    goto L10;
L30:;
    v5expr = ECL_CONS_CAR(v6);
    {
     cl_object v9;
     v9 = ECL_CONS_CDR(v6);
     if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v6 = v9;
    }
    v7remaining_exprs = ECL_CONS_CDR(v7remaining_exprs);
    goto L9;
L10:;
    ecl_bds_bind(cl_env_copy,VV[32],v2exit_dest); /*  *DESTINATION*           */
    L3858c2expr(lex0[2]);
    ecl_bds_unwind1(cl_env_copy);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    ecl_bds_unwind1(cl_env_copy);
    return value0;
   }
  }
 }
}
/* closure LAMBDA55                                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3868__lambda55(cl_narg narg, cl_object v1expr, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  NORMAL-EXIT             */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[67]);
 {
L1:;
  ecl_bds_bind(cl_env_copy,VV[32],VV[65]);        /*  *DESTINATION*           */
  L3859c2expr_(v1expr);
  ecl_bds_unwind1(cl_env_copy);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[68]))->cfun.entry(3, ECL_CONS_CAR(CLV0), VV[69], VV[65]) /*  UNWIND-COND */;
  return value0;
 }
 }
}
#include "cmp/cmppass2-eval.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclUMK7OZyOSwWo9_hTb0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPBACKEND-CXX;CMPPASS2-EVAL.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclUMK7OZyOSwWo9_hTb0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(_ecl_static_0);
  ecl_cmp_defun(VV[104]);                         /*  C2EXPR                  */
  ecl_cmp_defun(VV[105]);                         /*  C2EXPR*                 */
  ecl_cmp_defun(VV[106]);                         /*  C2PROGN                 */
  ecl_cmp_defun(VV[107]);                         /*  C2IF                    */
  (void)0; /* No entry created for JUMP-TRUE-DESTINATION-P */
  (void)0; /* No entry created for JUMP-FALSE-DESTINATION-P */
  ecl_cmp_defun(VV[108]);                         /*  C2FMLA-NOT              */
  ecl_cmp_defun(VV[109]);                         /*  C2FMLA-AND              */
  ecl_cmp_defun(VV[110]);                         /*  C2FMLA-OR               */
  ecl_cmp_defun(VV[111]);                         /*  C2MV-PROG1              */
  ecl_cmp_defun(VV[112]);                         /*  C2VALUES                */
}
