/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/lsp/unicode.lsp                     */
#include <ecl/ecl-cmp.h>
#include "clos/unicode.eclh"
/* local function LAMBDA0                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2887__lambda0()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC2886__lambda2_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC2887__lambda0_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[0]);
 {
  return LC2887__lambda0();
 }
}
/* local function LAMBDA6                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2889__lambda6()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC2888__lambda8_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC2889__lambda6_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[3]);
 {
  return LC2889__lambda6();
 }
}
/* function definition for ENCODING-ERROR                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2894encoding_error(cl_object volatile v1stream, cl_object volatile v2external_format, cl_object volatile v3code)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(ECL_NIL,env1);
  {
   volatile cl_object env2 = env1;
   CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY        */
   {
    ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
    if (__ecl_frs_push_result!=0) {
    if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
     goto L2;
    }
    if (cl_env_copy->values[0]==ecl_make_int8_t(1)) {
     goto L3;
    }
    ecl_internal_error("GO found an inexistent tag");
    } else {
    {
     cl_object v4;
     v4 = ecl_make_cclosure_va((cl_objectfn)LC2890__lambda18,env2,Cblock,0);
     T0 = v4;
    }
    {
     cl_object v4;
     v4 = ecl_make_cfun_va((cl_objectfn)LC2891__lambda20_va,ECL_NIL,Cblock,1);
     T1 = v4;
    }
    T2 = (cl_env_copy->function=(VV[7]->symbol.gfdef))->cfun.entry(6, ECL_SYM("NAME",1309), ECL_SYM("CONTINUE",252), ECL_SYM("FUNCTION",1273), T0, VV[9], T1) /*  MAKE-RESTART */;
    {
     cl_object v4;
     v4 = ecl_make_cclosure_va((cl_objectfn)LC2892__lambda22,env2,Cblock,0);
     T3 = v4;
    }
    {
     cl_object v4;
     v4 = ecl_make_cfun_va((cl_objectfn)LC2893__lambda24_va,ECL_NIL,Cblock,1);
     T4 = v4;
    }
    T5 = (cl_env_copy->function=(VV[7]->symbol.gfdef))->cfun.entry(6, ECL_SYM("NAME",1309), ECL_SYM("USE-VALUE",897), ECL_SYM("FUNCTION",1273), T3, VV[9], T4) /*  MAKE-RESTART */;
    T6 = cl_list(2, T2, T5);
    T7 = CONS(T6,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5)));
    ecl_bds_bind(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5),T7); /*  *RESTART-CLUSTERS* */
    {
     cl_object v4;
     T0 = cl_list(6, ECL_SYM("STREAM",1350), v1stream, ECL_SYM("EXTERNAL-FORMAT",1267), v2external_format, ECL_SYM("CODE",1914), v3code);
     v4 = (cl_env_copy->function=(VV[15]->symbol.gfdef))->cfun.entry(4, ECL_SYM("STREAM-ENCODING-ERROR",1938), T0, ECL_SYM("SIMPLE-ERROR",773), ECL_SYM("ERROR",339)) /*  COERCE-TO-CONDITION */;
     T0 = ecl_car(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5)));
     T1 = CONS(v4,T0);
     T2 = CONS(T1,ecl_cmp_symbol_value(cl_env_copy,VV[16]));
     ecl_bds_bind(cl_env_copy,VV[16],T2);         /*  *CONDITION-RESTARTS*    */
     value0 = cl_error(1, v4);
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     ecl_bds_unwind1(cl_env_copy);
     return value0;
    }
L2:;
    {
     cl_object v4;
     v4 = ECL_CONS_CAR(CLV0);
     if (Null(v4)){
      goto L12;
     }
     si_dm_too_many_arguments(ECL_NIL);
L12:;
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     ecl_frs_pop_n(cl_env_copy, 1);
     return value0;
    }
L3:;
    {
     cl_object v4;
     cl_object v5c;
     v4 = ECL_CONS_CAR(CLV0);
     if (Null(v4)){
      goto L17;
     }
     {
      cl_object v6;
      v6 = v4;
      {
       cl_object v7;
       v7 = v6;
       {
        bool v8;
        v8 = ECL_LISTP(v7);
        if (ecl_unlikely(!(v8)))
         FEwrong_type_argument(VV[20],v7);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v6)){
       goto L23;
      }
      {
       cl_object v7;
       v7 = ECL_CONS_CDR(v6);
       v4 = v7;
       v6 = ECL_CONS_CAR(v6);
      }
L23:;
      v5c = v6;
      goto L16;
     }
L17:;
     v5c = si_dm_too_few_arguments(ECL_NIL);
L16:;
     if (Null(v4)){
      goto L29;
     }
     si_dm_too_many_arguments(ECL_NIL);
L29:;
     if (!(ECL_CHARACTERP(v5c))){
      goto L31;
     }
     value0 = v5c;
     cl_env_copy->nvalues = 1;
     ecl_frs_pop_n(cl_env_copy, 1);
     return value0;
L31:;
     value0 = cl_code_char(v5c);
     ecl_frs_pop_n(cl_env_copy, 1);
     return value0;
    }
    }
   }
  }
 }
}
static cl_object L2894encoding_error_va(cl_narg narg, cl_object v4stream, cl_object v5external_format, cl_object v6code, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[22]);
 {
  return L2894encoding_error(v4stream, v5external_format, v6code);
 }
}
/* function definition for DECODING-ERROR                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2899decoding_error(cl_object volatile v1stream, cl_object volatile v2external_format, cl_object volatile v3octets)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(ECL_NIL,env1);
  {
   volatile cl_object env2 = env1;
   CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY        */
   {
    ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
    if (__ecl_frs_push_result!=0) {
    if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
     goto L2;
    }
    if (cl_env_copy->values[0]==ecl_make_int8_t(1)) {
     goto L3;
    }
    ecl_internal_error("GO found an inexistent tag");
    } else {
    {
     cl_object v4;
     v4 = ecl_make_cclosure_va((cl_objectfn)LC2895__lambda36,env2,Cblock,0);
     T0 = v4;
    }
    {
     cl_object v4;
     v4 = ecl_make_cfun_va((cl_objectfn)LC2896__lambda38_va,ECL_NIL,Cblock,1);
     T1 = v4;
    }
    T2 = (cl_env_copy->function=(VV[7]->symbol.gfdef))->cfun.entry(6, ECL_SYM("NAME",1309), ECL_SYM("CONTINUE",252), ECL_SYM("FUNCTION",1273), T0, VV[9], T1) /*  MAKE-RESTART */;
    {
     cl_object v4;
     v4 = ecl_make_cclosure_va((cl_objectfn)LC2897__lambda40,env2,Cblock,0);
     T3 = v4;
    }
    {
     cl_object v4;
     v4 = ecl_make_cfun_va((cl_objectfn)LC2898__lambda42_va,ECL_NIL,Cblock,1);
     T4 = v4;
    }
    T5 = (cl_env_copy->function=(VV[7]->symbol.gfdef))->cfun.entry(6, ECL_SYM("NAME",1309), ECL_SYM("USE-VALUE",897), ECL_SYM("FUNCTION",1273), T3, VV[9], T4) /*  MAKE-RESTART */;
    T6 = cl_list(2, T2, T5);
    T7 = CONS(T6,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5)));
    ecl_bds_bind(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5),T7); /*  *RESTART-CLUSTERS* */
    {
     cl_object v4;
     T0 = cl_list(6, ECL_SYM("STREAM",1350), v1stream, ECL_SYM("EXTERNAL-FORMAT",1267), v2external_format, ECL_SYM("OCTETS",1930), v3octets);
     v4 = (cl_env_copy->function=(VV[15]->symbol.gfdef))->cfun.entry(4, ECL_SYM("STREAM-DECODING-ERROR",1937), T0, ECL_SYM("SIMPLE-ERROR",773), ECL_SYM("ERROR",339)) /*  COERCE-TO-CONDITION */;
     T0 = ecl_car(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5)));
     T1 = CONS(v4,T0);
     T2 = CONS(T1,ecl_cmp_symbol_value(cl_env_copy,VV[16]));
     ecl_bds_bind(cl_env_copy,VV[16],T2);         /*  *CONDITION-RESTARTS*    */
     value0 = cl_error(1, v4);
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     ecl_bds_unwind1(cl_env_copy);
     return value0;
    }
L2:;
    {
     cl_object v4;
     v4 = ECL_CONS_CAR(CLV0);
     if (Null(v4)){
      goto L12;
     }
     si_dm_too_many_arguments(ECL_NIL);
L12:;
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     ecl_frs_pop_n(cl_env_copy, 1);
     return value0;
    }
L3:;
    {
     cl_object v4;
     cl_object v5c;
     v4 = ECL_CONS_CAR(CLV0);
     if (Null(v4)){
      goto L17;
     }
     {
      cl_object v6;
      v6 = v4;
      {
       cl_object v7;
       v7 = v6;
       {
        bool v8;
        v8 = ECL_LISTP(v7);
        if (ecl_unlikely(!(v8)))
         FEwrong_type_argument(VV[20],v7);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v6)){
       goto L23;
      }
      {
       cl_object v7;
       v7 = ECL_CONS_CDR(v6);
       v4 = v7;
       v6 = ECL_CONS_CAR(v6);
      }
L23:;
      v5c = v6;
      goto L16;
     }
L17:;
     v5c = si_dm_too_few_arguments(ECL_NIL);
L16:;
     if (Null(v4)){
      goto L29;
     }
     si_dm_too_many_arguments(ECL_NIL);
L29:;
     if (!(ECL_CHARACTERP(v5c))){
      goto L31;
     }
     value0 = v5c;
     cl_env_copy->nvalues = 1;
     ecl_frs_pop_n(cl_env_copy, 1);
     return value0;
L31:;
     value0 = cl_code_char(v5c);
     ecl_frs_pop_n(cl_env_copy, 1);
     return value0;
    }
    }
   }
  }
 }
}
static cl_object L2899decoding_error_va(cl_narg narg, cl_object v4stream, cl_object v5external_format, cl_object v6octets, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[30]);
 {
  return L2899decoding_error(v4stream, v5external_format, v6octets);
 }
}
/* local function LAMBDA2                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2886__lambda2(cl_object v1c, cl_object v2s)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = (cl_env_copy->function=(ECL_SYM("STREAM-ERROR-STREAM",805)->symbol.gfdef))->cfun.entry(1, v1c) /*  STREAM-ERROR-STREAM */;
  v4 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("CHARACTER-ENCODING-ERROR-CODE",1934)))->cfun.entry(1, v1c) /*  CHARACTER-ENCODING-ERROR-CODE */;
  T0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("CHARACTER-CODING-ERROR-EXTERNAL-FORMAT",1932)))->cfun.entry(1, v1c) /*  CHARACTER-CODING-ERROR-EXTERNAL-FORMAT */;
  value0 = cl_format(6, v2s, VV[2], v3, ECL_SYM("EXTERNAL-FORMAT",1267), T0, v4);
  return value0;
 }
}
static cl_object LC2886__lambda2_va(cl_narg narg, cl_object v5c, cl_object v6s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1]);
 {
  return LC2886__lambda2(v5c, v6s);
 }
}
/* local function LAMBDA8                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2888__lambda8(cl_object v1c, cl_object v2s)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = (cl_env_copy->function=(ECL_SYM("STREAM-ERROR-STREAM",805)->symbol.gfdef))->cfun.entry(1, v1c) /*  STREAM-ERROR-STREAM */;
  v4 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("CHARACTER-DECODING-ERROR-OCTETS",1936)))->cfun.entry(1, v1c) /*  CHARACTER-DECODING-ERROR-OCTETS */;
  T0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("CHARACTER-CODING-ERROR-EXTERNAL-FORMAT",1932)))->cfun.entry(1, v1c) /*  CHARACTER-CODING-ERROR-EXTERNAL-FORMAT */;
  value0 = cl_format(6, v2s, VV[5], v3, ECL_SYM("EXTERNAL-FORMAT",1267), T0, v4);
  return value0;
 }
}
static cl_object LC2888__lambda8_va(cl_narg narg, cl_object v5c, cl_object v6s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[4]);
 {
  return LC2888__lambda8(v5c, v6s);
 }
}
/* closure LAMBDA18                                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2890__lambda18(cl_narg narg, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV0) = v1temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* local function LAMBDA20                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2891__lambda20(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_write_string(2, VV[11], v1stream);
 return value0;
}
static cl_object LC2891__lambda20_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[10]);
 {
  return LC2891__lambda20(v2stream);
 }
}
/* closure LAMBDA22                                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2892__lambda22(cl_narg narg, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV0) = v1temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(1));
 }
 }
}
/* local function LAMBDA24                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2893__lambda24(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_write_string(2, VV[14], v1stream);
 return value0;
}
static cl_object LC2893__lambda24_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[13]);
 {
  return LC2893__lambda24(v2stream);
 }
}
/* closure LAMBDA36                                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2895__lambda36(cl_narg narg, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV0) = v1temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* local function LAMBDA38                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2896__lambda38(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_write_string(2, VV[26], v1stream);
 return value0;
}
static cl_object LC2896__lambda38_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[25]);
 {
  return LC2896__lambda38(v2stream);
 }
}
/* closure LAMBDA40                                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2897__lambda40(cl_narg narg, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV0) = v1temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(1));
 }
 }
}
/* local function LAMBDA42                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2898__lambda42(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_write_string(2, VV[29], v1stream);
 return value0;
}
static cl_object LC2898__lambda42_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[28]);
 {
  return LC2898__lambda42(v2stream);
 }
}
#include "clos/unicode.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclRDjENcSO3kDk9_a4I0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:LSP;UNICODE.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclRDjENcSO3kDk9_a4I0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0, T1, T2;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  clos_load_defclass(ECL_SYM("CHARACTER-CODING-ERROR",1931), VVtemp[1], VVtemp[2], ECL_NIL);
  clos_load_defclass(ECL_SYM("CHARACTER-ENCODING-ERROR",1933), VVtemp[3], VVtemp[4], ECL_NIL);
  clos_load_defclass(ECL_SYM("CHARACTER-DECODING-ERROR",1935), VVtemp[3], VVtemp[5], ECL_NIL);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2887__lambda0_va,ECL_NIL,Cblock,0);
   T0 = v1;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[7]);
  T2 = ecl_list1(T1);
  clos_load_defclass(ECL_SYM("STREAM-ENCODING-ERROR",1938), VVtemp[6], T2, ECL_NIL);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2889__lambda6_va,ECL_NIL,Cblock,0);
   T0 = v1;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[9]);
  T2 = ecl_list1(T1);
  clos_load_defclass(ECL_SYM("STREAM-DECODING-ERROR",1937), VVtemp[8], T2, ECL_NIL);
  ecl_cmp_defun(VV[31]);                          /*  ENCODING-ERROR          */
  ecl_cmp_defun(VV[32]);                          /*  DECODING-ERROR          */
 }
}
