/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmplocs.lsp                     */
#include <ecl/ecl-cmp.h>
#include "cmp/cmplocs.eclh"
/* function definition for %MAKE-VV                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3198_make_vv(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[14];
   cl_parse_key(args,7,L3198_make_vvkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1 = keyvars[0];
   v2 = keyvars[1];
   v3 = keyvars[2];
   if (Null(keyvars[10])) {
    v4 = ECL_T;
   } else {
    v4 = keyvars[3];
   }
   v5 = keyvars[4];
   v6 = keyvars[5];
   if (Null(keyvars[13])) {
    v7 = ECL_SYM("OBJECT",1315);
   } else {
    v7 = keyvars[6];
   }
  }
  value0 = si_make_structure(8, VV[5], v1, v2, v3, v4, v5, v6, v7);
  return value0;
 }
}
/* local function LAMBDA2                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3199__lambda2(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(6), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(6));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3199__lambda2_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[9]);
 {
  return LC3199__lambda2(v5, v6si__x);
 }
}
/* local function LAMBDA7                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3200__lambda7(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(5), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(5));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3200__lambda7_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[11]);
 {
  return LC3200__lambda7(v5, v6si__x);
 }
}
/* local function LAMBDA12                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3201__lambda12(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(4), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(4));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3201__lambda12_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[13]);
 {
  return LC3201__lambda12(v5, v6si__x);
 }
}
/* local function LAMBDA17                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3202__lambda17(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3202__lambda17_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[15]);
 {
  return LC3202__lambda17(v5, v6si__x);
 }
}
/* local function LAMBDA22                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3203__lambda22(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3203__lambda22_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[17]);
 {
  return LC3203__lambda22(v5, v6si__x);
 }
}
/* local function LAMBDA27                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3204__lambda27(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3204__lambda27_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[19]);
 {
  return LC3204__lambda27(v5, v6si__x);
 }
}
/* local function LAMBDA32                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3205__lambda32(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3205__lambda32_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[21]);
 {
  return LC3205__lambda32(v5, v6si__x);
 }
}
/* function definition for MAKE-VV                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3206make_vv(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1args;
  cl_object v2location;
  cl_object v3used_p;
  cl_object v4always;
  cl_object v5permanent_p;
  cl_object v6value;
  cl_object v7type;
  cl_object v8host_type;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[14];
   cl_parse_key(args,7,L3206make_vvkeys,keyvars,(cl_object*)&v1args,FALSE);
   ecl_va_end(args);
   v2location = keyvars[0];
   v3used_p = keyvars[1];
   v4always = keyvars[2];
   v5permanent_p = keyvars[3];
   v6value = keyvars[4];
   v7type = keyvars[5];
   v8host_type = keyvars[6];
  }
  if (v7type!=ECL_NIL) {
   goto L1;
  }
  if (!((v6value)==(ecl_cmp_symbol_value(cl_env_copy,VV[23])))){
   goto L4;
  }
  v7type = ECL_T;
  goto L3;
L4:;
  v7type = cl_type_of(v6value);
L3:;
L1:;
  T0 = ecl_fdefinition(VV[4]);
  value0 = cl_apply(4, T0, ECL_SYM("TYPE",1356), v7type, v1args);
  return value0;
 }
}
/* function definition for LOC-LISP-TYPE                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3207loc_lisp_type(cl_object v1loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_of_class_p(2, v1loc, VV[26]))){
  goto L2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[27]))->cfun.entry(1, v1loc) /*  VAR-TYPE */;
 return value0;
L2:;
 if (Null(si_of_class_p(2, v1loc, VV[1]))){
  goto L4;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[10]))->cfun.entry(1, v1loc) /*  VV-TYPE */;
 return value0;
L4:;
 if (!(ecl_numberp(v1loc))){
  goto L6;
 }
 value0 = cl_type_of(v1loc);
 return value0;
L6:;
 if (!(ECL_ATOM(v1loc))){
  goto L8;
 }
 if (!((v1loc)==(VV[28]))){
  goto L10;
 }
 value0 = ECL_SYM("FIXNUM",374);
 cl_env_copy->nvalues = 1;
 return value0;
L10:;
 {
  cl_object v2;
  cl_object v3;
  v2 = v1loc;
  v3 = VV[29];
  if (Null(ecl_memql(v2,v3))){
   goto L12;
  }
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L12:;
 (cl_env_copy->function=ecl_fdefinition(VV[30]))->cfun.entry(2, VV[31], v1loc) /*  CMPWARN */;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L8:;
 {
  cl_object v2;
  v2 = ecl_car(v1loc);
  if (!((v2)==(ECL_SYM("C-INLINE",2106)))){
   goto L18;
  }
  {
   cl_object v3type;
   T0 = ecl_cadr(v1loc);
   v3type = ecl_car(T0);
   if (!(ECL_CONSP(v3type))){
    goto L21;
   }
   T0 = ecl_car(v3type);
   if (!((T0)==(ECL_SYM("VALUES",899)))){
    goto L21;
   }
   value0 = ECL_T;
   cl_env_copy->nvalues = 1;
   return value0;
L21:;
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[32]))->cfun.entry(1, v3type) /*  LISP-TYPE-P */)){
    goto L24;
   }
   value0 = v3type;
   cl_env_copy->nvalues = 1;
   return value0;
L24:;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(1, v3type) /*  HOST-TYPE->LISP-TYPE */;
   return value0;
  }
L18:;
  if (!((v2)==(VV[34]))){
   goto L26;
  }
  T0 = ecl_cadr(v1loc);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[27]))->cfun.entry(1, T0) /*  VAR-TYPE */;
  return value0;
L26:;
  if (!((v2)==(VV[35]))){
   goto L28;
  }
  value0 = ecl_caddr(v1loc);
  if (value0!=ECL_NIL) {
   goto L31;
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L31:;
  cl_env_copy->nvalues = 1;
  return value0;
L28:;
  if (!((v2)==(ECL_SYM("THE",859)))){
   goto L33;
  }
  value0 = ecl_cadr(v1loc);
  cl_env_copy->nvalues = 1;
  return value0;
L33:;
  if (!((v2)==(VV[36]))){
   goto L35;
  }
  value0 = ecl_cadddr(v1loc);
  cl_env_copy->nvalues = 1;
  return value0;
L35:;
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3207loc_lisp_type_va(cl_narg narg, cl_object v4loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[25]);
 {
  return L3207loc_lisp_type(v4loc);
 }
}
/* function definition for LOC-HOST-TYPE                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3208loc_host_type(cl_object v1loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_of_class_p(2, v1loc, VV[26]))){
  goto L2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[39]))->cfun.entry(1, v1loc) /*  VAR-HOST-TYPE */;
 return value0;
L2:;
 if (Null(si_of_class_p(2, v1loc, VV[1]))){
  goto L4;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[7]))->cfun.entry(1, v1loc) /*  VV-HOST-TYPE */;
 return value0;
L4:;
 if (!(ecl_numberp(v1loc))){
  goto L6;
 }
 T0 = cl_type_of(v1loc);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(1, T0) /*  LISP-TYPE->HOST-TYPE */;
 return value0;
L6:;
 if (!(ECL_ATOM(v1loc))){
  goto L8;
 }
 if (!((v1loc)==(VV[41]))){
  goto L10;
 }
 value0 = ECL_SYM("VOID",1424);
 cl_env_copy->nvalues = 1;
 return value0;
L10:;
 {
  cl_object v2;
  cl_object v3;
  v2 = v1loc;
  v3 = VV[42];
  if (Null(ecl_memql(v2,v3))){
   goto L12;
  }
 }
 value0 = ECL_SYM("OBJECT",1315);
 cl_env_copy->nvalues = 1;
 return value0;
L12:;
 (cl_env_copy->function=ecl_fdefinition(VV[30]))->cfun.entry(2, VV[31], v1loc) /*  CMPWARN */;
 value0 = ECL_SYM("OBJECT",1315);
 cl_env_copy->nvalues = 1;
 return value0;
L8:;
 {
  cl_object v2;
  v2 = ecl_car(v1loc);
  if (!((v2)==(ECL_SYM("C-INLINE",2106)))){
   goto L18;
  }
  {
   cl_object v3type;
   T0 = ecl_cadr(v1loc);
   v3type = ecl_car(T0);
   if (!(ECL_CONSP(v3type))){
    goto L21;
   }
   T0 = ecl_car(v3type);
   if (!((T0)==(ECL_SYM("VALUES",899)))){
    goto L21;
   }
   value0 = ECL_SYM("OBJECT",1315);
   cl_env_copy->nvalues = 1;
   return value0;
L21:;
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[32]))->cfun.entry(1, v3type) /*  LISP-TYPE-P */)){
    goto L24;
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(1, v3type) /*  LISP-TYPE->HOST-TYPE */;
   return value0;
L24:;
   value0 = v3type;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L18:;
  if (!((v2)==(VV[34]))){
   goto L26;
  }
  T0 = ecl_cadr(v1loc);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[39]))->cfun.entry(1, T0) /*  VAR-HOST-TYPE */;
  return value0;
L26:;
  if (!((v2)==(VV[35]))){
   goto L28;
  }
  value0 = ecl_caddr(v1loc);
  if (value0!=ECL_NIL) {
   goto L32;
  }
  T0 = ECL_T;
  goto L30;
L32:;
  T0 = value0;
  goto L30;
L30:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(1, T0) /*  LISP-TYPE->HOST-TYPE */;
  return value0;
L28:;
  if (!((v2)==(VV[44]))){
   goto L39;
  }
  goto L36;
L39:;
  goto L37;
L37:;
  if (!((v2)==(VV[45]))){
   goto L34;
  }
  goto L35;
L36:;
L35:;
  value0 = VV[47];
  cl_env_copy->nvalues = 1;
  return value0;
L34:;
  if (!((v2)==(ECL_SYM("THE",859)))){
   goto L42;
  }
  v1loc = ecl_caddr(v1loc);
  goto L1;
L42:;
  value0 = ECL_SYM("OBJECT",1315);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3208loc_host_type_va(cl_narg narg, cl_object v4loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[38]);
 {
  return L3208loc_host_type(v4loc);
 }
}
/* function definition for LOC-MOVABLE-P                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3209loc_movable_p(cl_object v1loc)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_ATOM(v1loc))){
  goto L2;
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 {
  cl_object v2;
  v2 = ecl_car(v1loc);
  if (!((v2)==(VV[51]))){
   goto L10;
  }
  goto L7;
L10:;
  goto L8;
L8:;
  if (!((v2)==(VV[52]))){
   goto L5;
  }
  goto L6;
L7:;
L6:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L5:;
  if (!((v2)==(ECL_SYM("C-INLINE",2106)))){
   goto L13;
  }
  T0 = ecl_cddddr(v1loc);
  T1 = ecl_car(T0);
  value0 = Null(T1)?ECL_T:ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L13:;
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3209loc_movable_p_va(cl_narg narg, cl_object v3loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[49]);
 {
  return L3209loc_movable_p(v3loc);
 }
}
/* function definition for LOC-WITH-SIDE-EFFECTS-P                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3210loc_with_side_effects_p(cl_object v1loc)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_ATOM(v1loc))){
  goto L2;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(1, v1loc) /*  VAR-P */)){
  goto L5;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[58]))->cfun.entry(1, v1loc) /*  GLOBAL-VAR-P */)){
  goto L5;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(0) /*  POLICY-GLOBAL-VAR-CHECKING */;
 return value0;
L5:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 {
  cl_object v2;
  v2 = ecl_car(v1loc);
  {
   cl_object v3;
   cl_object v4;
   v3 = v2;
   v4 = VV[60];
   if (Null(ecl_memql(v3,v4))){
    goto L9;
   }
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L9:;
  if (!((v2)==(ECL_SYM("THE",859)))){
   goto L13;
  }
  v1loc = ecl_caddr(v1loc);
  goto L1;
L13:;
  if (!((v2)==(ECL_SYM("FDEFINITION",351)))){
   goto L17;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[61]))->cfun.entry(0) /*  POLICY-GLOBAL-FUNCTION-CHECKING */;
  return value0;
L17:;
  if (!((v2)==(ECL_SYM("C-INLINE",2106)))){
   goto L19;
  }
  T0 = ecl_cddddr(v1loc);
  T1 = ecl_cadr(T0);
  value0 = ecl_make_bool((T1)==(ECL_SYM("VALUES",899)));
  if (value0!=ECL_NIL) {
   goto L22;
  }
  T0 = ecl_cddddr(v1loc);
  value0 = ecl_car(T0);
  cl_env_copy->nvalues = 1;
  return value0;
L22:;
  cl_env_copy->nvalues = 1;
  return value0;
L19:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3210loc_with_side_effects_p_va(cl_narg narg, cl_object v3loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[56]);
 {
  return L3210loc_with_side_effects_p(v3loc);
 }
}
/* function definition for LOC-REFERS-TO-SPECIAL-P                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3212loc_refers_to_special_p(cl_object v1loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_ATOM(v1loc))){
  goto L2;
 }
 value0 = LC3211special_var_p(v1loc);
 return value0;
L2:;
 {
  cl_object v2;
  v2 = ecl_car(v1loc);
  if (!((v2)==(ECL_SYM("THE",859)))){
   goto L5;
  }
  v1loc = ecl_caddr(v1loc);
  goto L1;
L5:;
  if (!((v2)==(VV[34]))){
   goto L9;
  }
  T0 = ecl_cadr(v1loc);
  value0 = LC3211special_var_p(T0);
  return value0;
L9:;
  if (!((v2)==(ECL_SYM("C-INLINE",2106)))){
   goto L11;
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L11:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3212loc_refers_to_special_p_va(cl_narg narg, cl_object v3loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[63]);
 {
  return L3212loc_refers_to_special_p(v3loc);
 }
}
/* function definition for PRECISE-LOC-LISP-TYPE                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3213precise_loc_lisp_type(cl_object v1loc, cl_object v2new_type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3loc_type;
  v3loc_type = L3207loc_lisp_type(v1loc);
  if (Null(cl_subtypep(3, v3loc_type, v2new_type, ecl_cmp_symbol_value(cl_env_copy,VV[71])))){
   goto L3;
  }
  value0 = v1loc;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[72]))->cfun.entry(2, v3loc_type, v2new_type) /*  TYPE-AND */;
  value0 = cl_list(3, ECL_SYM("THE",859), T0, v1loc);
  return value0;
 }
}
static cl_object L3213precise_loc_lisp_type_va(cl_narg narg, cl_object v4loc, cl_object v5new_type, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[70]);
 {
  return L3213precise_loc_lisp_type(v4loc, v5new_type);
 }
}
/* function definition for LOC-IN-C1FORM-MOVABLE-P                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3214loc_in_c1form_movable_p(cl_object v1loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ecl_numberp(v1loc))){
  goto L2;
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!(ECL_STRINGP(v1loc))){
  goto L4;
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[3]))->cfun.entry(1, v1loc) /*  VV-P */)){
  goto L6;
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L6:;
 if (!((v1loc)==(VV[76]))){
  goto L13;
 }
 goto L10;
L13:;
 goto L11;
L11:;
 if (!((v1loc)==(VV[77]))){
  goto L17;
 }
 goto L10;
L17:;
 goto L15;
L15:;
 if (!((v1loc)==(VV[79]))){
  goto L21;
 }
 goto L10;
L21:;
 goto L19;
L19:;
 if (!((v1loc)==(VV[81]))){
  goto L8;
 }
 goto L9;
L10:;
L9:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L8:;
 if (!(ECL_ATOM(v1loc))){
  goto L24;
 }
 T0 = ecl_list1(v1loc);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(4, ECL_SYM("FORMAT-CONTROL",1272), VV[84], ECL_SYM("FORMAT-ARGUMENTS",1271), T0) /*  BABOON */;
 return value0;
L24:;
 T0 = ecl_car(v1loc);
 if (!((T0)==(ECL_SYM("THE",859)))){
  goto L26;
 }
 v1loc = ecl_caddr(v1loc);
 goto L1;
L26:;
 {
  cl_object v2;
  v1loc = ecl_car(v1loc);
  v2 = v1loc;
  if (!((v2)==(VV[1]))){
   goto L37;
  }
  goto L34;
L37:;
  goto L35;
L35:;
  if (!((v2)==(VV[86]))){
   goto L41;
  }
  goto L34;
L41:;
  goto L39;
L39:;
  if (!((v2)==(VV[88]))){
   goto L30;
  }
  goto L31;
L34:;
 }
L31:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L30:;
 T0 = ecl_list1(v1loc);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(4, ECL_SYM("FORMAT-CONTROL",1272), VV[84], ECL_SYM("FORMAT-ARGUMENTS",1271), T0) /*  BABOON */;
 return value0;
}
static cl_object L3214loc_in_c1form_movable_p_va(cl_narg narg, cl_object v2loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[74]);
 {
  return L3214loc_in_c1form_movable_p(v2loc);
 }
}
/* function definition for USES-VALUES                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3215uses_values(cl_object v1loc)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_CONSP(v1loc))){
  goto L3;
 }
 {
  cl_object v2;
  cl_object v3;
  v2 = ecl_car(v1loc);
  v3 = (ECL_SYM("EQ",335)->symbol.gfdef);
  if (!((v2)==(VV[36]))){
   goto L14;
  }
  value0 = VV[92];
  goto L12;
L14:;
  value0 = ECL_NIL;
  goto L12;
L12:;
  if (value0!=ECL_NIL) {
   goto L11;
  }
  if (!((v2)==(VV[93]))){
   goto L18;
  }
  value0 = VV[94];
  goto L16;
L18:;
  value0 = ECL_NIL;
  goto L16;
L16:;
  if (value0!=ECL_NIL) {
   goto L11;
  }
  if (!((v2)==(VV[95]))){
   goto L22;
  }
  value0 = VV[96];
  goto L20;
L22:;
  value0 = ECL_NIL;
  goto L20;
L20:;
  if (value0!=ECL_NIL) {
   goto L11;
  }
  if (!((v2)==(VV[97]))){
   goto L25;
  }
  value0 = VV[98];
  goto L7;
L25:;
  value0 = ECL_NIL;
  goto L7;
L11:;
  goto L7;
 }
L7:;
 if (value0!=ECL_NIL) {
  goto L6;
 }
 T0 = ecl_car(v1loc);
 if (!((T0)==(ECL_SYM("C-INLINE",2106)))){
  goto L28;
 }
 T0 = ecl_cddddr(v1loc);
 T1 = ecl_cadr(T0);
 value0 = ecl_make_bool((T1)==(ECL_SYM("VALUES",899)));
 cl_env_copy->nvalues = 1;
 return value0;
L28:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L6:;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3215uses_values_va(cl_narg narg, cl_object v2loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[91]);
 {
  return L3215uses_values(v2loc);
 }
}
/* function definition for LOC-IMMEDIATE-VALUE-P                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3216loc_immediate_value_p(cl_object v1loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ecl_numberp(v1loc))){
  goto L2;
 }
 cl_env_copy->nvalues = 2;
 cl_env_copy->values[1] = v1loc;
 cl_env_copy->values[0] = ECL_T;
 return cl_env_copy->values[0];
L2:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[3]))->cfun.entry(1, v1loc) /*  VV-P */)){
  goto L4;
 }
 {
  cl_object v2value;
  v2value = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v1loc) /*  VV-VALUE */;
  if (!((v2value)==(ecl_cmp_symbol_value(cl_env_copy,VV[23])))){
   goto L7;
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
L7:;
  if (!((v2value)==(ecl_cmp_symbol_value(cl_env_copy,VV[101])))){
   goto L9;
  }
  v1loc = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(1, v1loc) /*  VV-LOCATION */;
  goto L1;
L9:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2value;
  cl_env_copy->values[0] = ECL_T;
  return cl_env_copy->values[0];
 }
L4:;
 if (!(ECL_ATOM(v1loc))){
  goto L13;
 }
 cl_env_copy->nvalues = 2;
 cl_env_copy->values[1] = ECL_NIL;
 cl_env_copy->values[0] = ECL_NIL;
 return cl_env_copy->values[0];
L13:;
 T0 = ecl_car(v1loc);
 if (!((T0)==(ECL_SYM("THE",859)))){
  goto L15;
 }
 v1loc = ecl_caddr(v1loc);
 goto L1;
L15:;
 cl_env_copy->nvalues = 2;
 cl_env_copy->values[1] = ECL_NIL;
 cl_env_copy->values[0] = ECL_NIL;
 return cl_env_copy->values[0];
}
static cl_object L3216loc_immediate_value_p_va(cl_narg narg, cl_object v3loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[100]);
 {
  return L3216loc_immediate_value_p(v3loc);
 }
}
/* function definition for LOC-IMMEDIATE-VALUE                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3217loc_immediate_value(cl_object v1loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  struct ecl_stack_frame _ecl_inner_frame_aux;
  cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
  cl_env_copy->values[0] = L3216loc_immediate_value_p(v1loc);
  ecl_stack_frame_push_values(_ecl_inner_frame);
  T0 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
  ecl_stack_frame_close(_ecl_inner_frame);
 }
 value0 = ecl_cadr(T0);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3217loc_immediate_value_va(cl_narg narg, cl_object v2loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[103]);
 {
  return L3217loc_immediate_value(v2loc);
 }
}
/* function definition for UNKNOWN-LOCATION                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3218unknown_location(cl_object v1where, cl_object v2loc)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, v1where, v2loc);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(4, ECL_SYM("FORMAT-CONTROL",1272), VV[106], ECL_SYM("FORMAT-ARGUMENTS",1271), T0) /*  BABOON */;
 return value0;
}
static cl_object L3218unknown_location_va(cl_narg narg, cl_object v3where, cl_object v4loc, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[105]);
 {
  return L3218unknown_location(v3where, v4loc);
 }
}
/* local function SPECIAL-VAR-P                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3211special_var_p(cl_object v1loc)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(1, v1loc) /*  VAR-P */)){
  goto L3;
 }
 {
  cl_object v2;
  v2 = (cl_env_copy->function=ecl_fdefinition(VV[65]))->cfun.entry(1, v1loc) /*  VAR-KIND */;
  if (!((v2)==(ECL_SYM("SPECIAL",792)))){
   goto L10;
  }
  value0 = VV[66];
  goto L8;
L10:;
  value0 = ECL_NIL;
  goto L8;
L8:;
  if (value0!=ECL_NIL) {
   goto L7;
  }
  if (!((v2)==(VV[67]))){
   goto L13;
  }
  value0 = VV[68];
  cl_env_copy->nvalues = 1;
  return value0;
L13:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L7:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC3211special_var_p_va(cl_narg narg, cl_object v3loc, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[64]);
 {
  return LC3211special_var_p(v3loc);
 }
}
#include "cmp/cmplocs.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclbinP7MWZCsum9_PEP0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPLOCS.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclbinP7MWZCsum9_PEP0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(_ecl_static_0);
  si_define_structure(VV[1], _ecl_static_1, ECL_NIL, ECL_NIL, VVtemp[0], VVtemp[1], VV[2], ECL_NIL, ECL_NIL, ECL_NIL, VVtemp[2], ecl_make_int8_t(7), ECL_NIL, ECL_NIL, VV[3]);
  VV[5]=cl_find_class(1, VV[1]);
  ecl_cmp_defun(VV[108]);                         /*  %MAKE-VV                */
  {
   cl_object v1package;
   v1package = cl_symbol_package(VV[7]);
   if (Null(v1package)){
    goto L9;
   }
   if (Null(si_package_locked_p(v1package))){
    goto L9;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L9;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[5], ECL_SYM("PACKAGE",1321), v1package);
  }
L9:;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC3199__lambda2_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  si_put_sysprop(VV[7], VV[8], T0);
  {
   cl_object v2package;
   v2package = cl_symbol_package(VV[10]);
   if (Null(v2package)){
    goto L17;
   }
   if (Null(si_package_locked_p(v2package))){
    goto L17;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L17;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[6], ECL_SYM("PACKAGE",1321), v2package);
  }
L17:;
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC3200__lambda7_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  si_put_sysprop(VV[10], VV[8], T0);
  {
   cl_object v3package;
   v3package = cl_symbol_package(VV[12]);
   if (Null(v3package)){
    goto L25;
   }
   if (Null(si_package_locked_p(v3package))){
    goto L25;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L25;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[7], ECL_SYM("PACKAGE",1321), v3package);
  }
L25:;
  {
   cl_object volatile v4;
   v4 = ecl_make_cfun_va((cl_objectfn)LC3201__lambda12_va,ECL_NIL,Cblock,2);
   T0 = v4;
  }
  si_put_sysprop(VV[12], VV[8], T0);
  {
   cl_object v4package;
   v4package = cl_symbol_package(VV[14]);
   if (Null(v4package)){
    goto L33;
   }
   if (Null(si_package_locked_p(v4package))){
    goto L33;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L33;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[8], ECL_SYM("PACKAGE",1321), v4package);
  }
L33:;
  {
   cl_object volatile v5;
   v5 = ecl_make_cfun_va((cl_objectfn)LC3202__lambda17_va,ECL_NIL,Cblock,2);
   T0 = v5;
  }
  si_put_sysprop(VV[14], VV[8], T0);
  {
   cl_object v5package;
   v5package = cl_symbol_package(VV[16]);
   if (Null(v5package)){
    goto L41;
   }
   if (Null(si_package_locked_p(v5package))){
    goto L41;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L41;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[9], ECL_SYM("PACKAGE",1321), v5package);
  }
L41:;
  {
   cl_object volatile v6;
   v6 = ecl_make_cfun_va((cl_objectfn)LC3203__lambda22_va,ECL_NIL,Cblock,2);
   T0 = v6;
  }
  si_put_sysprop(VV[16], VV[8], T0);
  {
   cl_object v6package;
   v6package = cl_symbol_package(VV[18]);
   if (Null(v6package)){
    goto L49;
   }
   if (Null(si_package_locked_p(v6package))){
    goto L49;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L49;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[10], ECL_SYM("PACKAGE",1321), v6package);
  }
L49:;
  {
   cl_object volatile v7;
   v7 = ecl_make_cfun_va((cl_objectfn)LC3204__lambda27_va,ECL_NIL,Cblock,2);
   T0 = v7;
  }
  si_put_sysprop(VV[18], VV[8], T0);
  {
   cl_object v7package;
   v7package = cl_symbol_package(VV[20]);
   if (Null(v7package)){
    goto L57;
   }
   if (Null(si_package_locked_p(v7package))){
    goto L57;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L57;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[11], ECL_SYM("PACKAGE",1321), v7package);
  }
L57:;
  {
   cl_object volatile v8;
   v8 = ecl_make_cfun_va((cl_objectfn)LC3205__lambda32_va,ECL_NIL,Cblock,2);
   T0 = v8;
  }
  si_put_sysprop(VV[20], VV[8], T0);
  ecl_cmp_defun(VV[109]);                         /*  MAKE-VV                 */
  ecl_cmp_defun(VV[110]);                         /*  LOC-LISP-TYPE           */
  ecl_cmp_defun(VV[111]);                         /*  LOC-HOST-TYPE           */
  ecl_cmp_defun(VV[112]);                         /*  LOC-MOVABLE-P           */
  ecl_cmp_defun(VV[113]);                         /*  LOC-WITH-SIDE-EFFECTS-P */
  ecl_cmp_defun(VV[114]);                         /*  LOC-REFERS-TO-SPECIAL-P */
  ecl_cmp_defun(VV[115]);                         /*  PRECISE-LOC-LISP-TYPE   */
  ecl_cmp_defun(VV[116]);                         /*  LOC-IN-C1FORM-MOVABLE-P */
  ecl_cmp_defun(VV[117]);                         /*  USES-VALUES             */
  ecl_cmp_defun(VV[118]);                         /*  LOC-IMMEDIATE-VALUE-P   */
  ecl_cmp_defun(VV[119]);                         /*  LOC-IMMEDIATE-VALUE     */
  ecl_cmp_defun(VV[120]);                         /*  UNKNOWN-LOCATION        */
 }
}
