/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpbackend-cxx/cmpc-mach.lsp    */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpc-mach.eclh"
/* function definition for MAKE-MACHINE                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3640make_machine(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  cl_object v4;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L3640make_machinekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1 = keyvars[0];
   v2 = keyvars[1];
   v3 = keyvars[2];
   v4 = keyvars[3];
  }
  value0 = si_make_structure(5, VV[5], v1, v2, v3, v4);
  return value0;
 }
}
/* local function LAMBDA2                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3641__lambda2(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3641__lambda2_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[9]);
 {
  return LC3641__lambda2(v5, v6si__x);
 }
}
/* local function LAMBDA7                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3642__lambda7(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3642__lambda7_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[11]);
 {
  return LC3642__lambda7(v5, v6si__x);
 }
}
/* local function LAMBDA12                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3643__lambda12(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3643__lambda12_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[13]);
 {
  return LC3643__lambda12(v5, v6si__x);
 }
}
/* local function LAMBDA17                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3644__lambda17(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[1]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3644__lambda17_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[15]);
 {
  return LC3644__lambda17(v5, v6si__x);
 }
}
/* function definition for %MAKE-HOST-TYPE                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3645_make_host_type(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  cl_object v8;
  cl_object v9;
  cl_object v10;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[20];
   cl_parse_key(args,10,L3645_make_host_typekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[10])) {
    v1 = ecl_make_int8_t(0);
   } else {
    v1 = keyvars[0];
   }
   if (Null(keyvars[11])) {
    v2 = ECL_T;
   } else {
    v2 = keyvars[1];
   }
   if (Null(keyvars[12])) {
    v3 = ECL_T;
   } else {
    v3 = keyvars[2];
   }
   v4 = keyvars[3];
   v5 = keyvars[4];
   v6 = keyvars[5];
   v7 = keyvars[6];
   v8 = keyvars[7];
   v9 = keyvars[8];
   v10 = keyvars[9];
  }
  value0 = si_make_structure(11, VV[20], v1, v2, v3, v4, v5, v6, v7, v8, v9, v10);
  return value0;
 }
}
/* local function LAMBDA23                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3646__lambda23(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(9), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(9));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3646__lambda23_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[23]);
 {
  return LC3646__lambda23(v5, v6si__x);
 }
}
/* local function LAMBDA28                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3647__lambda28(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(8), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(8));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3647__lambda28_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[25]);
 {
  return LC3647__lambda28(v5, v6si__x);
 }
}
/* local function LAMBDA33                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3648__lambda33(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(7), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(7));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3648__lambda33_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[27]);
 {
  return LC3648__lambda33(v5, v6si__x);
 }
}
/* local function LAMBDA38                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3649__lambda38(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(6), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(6));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3649__lambda38_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[29]);
 {
  return LC3649__lambda38(v5, v6si__x);
 }
}
/* local function LAMBDA43                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3650__lambda43(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(5), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(5));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3650__lambda43_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[31]);
 {
  return LC3650__lambda43(v5, v6si__x);
 }
}
/* local function LAMBDA48                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3651__lambda48(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(4), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(4));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3651__lambda48_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[33]);
 {
  return LC3651__lambda48(v5, v6si__x);
 }
}
/* local function LAMBDA53                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3652__lambda53(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3652__lambda53_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[35]);
 {
  return LC3652__lambda53(v5, v6si__x);
 }
}
/* local function LAMBDA58                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3653__lambda58(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3653__lambda58_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[37]);
 {
  return LC3653__lambda58(v5, v6si__x);
 }
}
/* local function LAMBDA63                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3654__lambda63(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3654__lambda63_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[39]);
 {
  return LC3654__lambda63(v5, v6si__x);
 }
}
/* local function LAMBDA68                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3655__lambda68(cl_object v1, cl_object v2si__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2si__x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[16]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2si__x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC3655__lambda68_va(cl_narg narg, cl_object v5, cl_object v6si__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[41]);
 {
  return LC3655__lambda68(v5, v6si__x);
 }
}
/* function definition for LISP-TYPE-P                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3656lisp_type_p(cl_object v1type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_subtypep(3, v1type, ECL_T, ecl_cmp_symbol_value(cl_env_copy,VV[43]));
 return value0;
}
static cl_object L3656lisp_type_p_va(cl_narg narg, cl_object v2type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[42]);
 {
  return L3656lisp_type_p(v2type);
 }
}
/* function definition for HOST-TYPE-RECORD-UNSAFE                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3657host_type_record_unsafe(cl_object v1host_type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[46])) /*  MACHINE-HOST-TYPE-HASH */;
 value0 = cl_gethash(2, v1host_type, T0);
 return value0;
}
static cl_object L3657host_type_record_unsafe_va(cl_narg narg, cl_object v2host_type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[45]);
 {
  return L3657host_type_record_unsafe(v2host_type);
 }
}
/* function definition for HOST-TYPE-RECORD                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3658host_type_record(cl_object v1host_type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2record;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[46])) /*  MACHINE-HOST-TYPE-HASH */;
  v2record = ecl_gethash_safe(v1host_type,T0,ECL_NIL);
  if (Null(v2record)){
   goto L3;
  }
  value0 = v2record;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[49]))->cfun.entry(2, VV[50], v1host_type) /*  CMPERR */;
  return value0;
 }
}
static cl_object L3658host_type_record_va(cl_narg narg, cl_object v3host_type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[48]);
 {
  return L3658host_type_record(v3host_type);
 }
}
/* function definition for HOST-TYPE->LISP-TYPE                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3659host_type__lisp_type(cl_object v1name)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2output;
  v2output = L3657host_type_record_unsafe(v1name);
  if (Null(v2output)){
   goto L3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[36]))->cfun.entry(1, v2output) /*  HOST-TYPE-LISP-TYPE */;
  return value0;
L3:;
  if (Null(L3656lisp_type_p(v1name))){
   goto L5;
  }
  value0 = v1name;
  cl_env_copy->nvalues = 1;
  return value0;
L5:;
  value0 = cl_error(2, VV[53], v1name);
  return value0;
 }
}
static cl_object L3659host_type__lisp_type_va(cl_narg narg, cl_object v3name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[52]);
 {
  return L3659host_type__lisp_type(v3name);
 }
}
/* function definition for LISP-TYPE->HOST-TYPE                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3660lisp_type__host_type(cl_object v1type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(v1type==ECL_NIL)){
  goto L2;
 }
 value0 = ECL_SYM("OBJECT",1315);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 {
  cl_object v2;
  {
   cl_object v3r;
   v3r = L3657host_type_record_unsafe(v1type);
   if (Null(v3r)){
    goto L7;
   }
   v2 = (cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(1, v3r) /*  HOST-TYPE-NAME */;
   goto L4;
L7:;
   v2 = ECL_NIL;
   goto L4;
  }
L4:;
  if (Null(v2)){
   goto L9;
  }
  value0 = v2;
  cl_env_copy->nvalues = 1;
  return value0;
L9:;
  {
   cl_object v3;
   v3 = (cl_env_copy->function=ecl_fdefinition(VV[10]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[46])) /*  MACHINE-SORTED-TYPES */;
   goto L14;
L13:;
   {
    cl_object v4record;
    v4record = ecl_car(v3);
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[36]))->cfun.entry(1, v4record) /*  HOST-TYPE-LISP-TYPE */;
    if (Null(cl_subtypep(3, v1type, T0, ecl_cmp_symbol_value(cl_env_copy,VV[43])))){
     goto L18;
    }
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(1, v4record) /*  HOST-TYPE-NAME */;
    return value0;
L18:;
   }
   v3 = ecl_cdr(v3);
L14:;
   if (Null(v3)){
    goto L22;
   }
   goto L13;
L22:;
   value0 = ECL_SYM("OBJECT",1315);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3660lisp_type__host_type_va(cl_narg narg, cl_object v4type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[55]);
 {
  return L3660lisp_type__host_type(v4type);
 }
}
/* function definition for C-NUMBER-HOST-TYPE-P                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3661c_number_host_type_p(cl_object v1host_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2r;
  v2r = L3657host_type_record_unsafe(v1host_type);
  if (Null(v2r)){
   goto L4;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[32]))->cfun.entry(1, v2r) /*  HOST-TYPE-NUMBERP */;
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3661c_number_host_type_p_va(cl_narg narg, cl_object v3host_type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[57]);
 {
  return L3661c_number_host_type_p(v3host_type);
 }
}
/* function definition for C-INTEGER-HOST-TYPE-P                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3662c_integer_host_type_p(cl_object v1host_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2r;
  v2r = L3657host_type_record_unsafe(v1host_type);
  if (Null(v2r)){
   goto L4;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[30]))->cfun.entry(1, v2r) /*  HOST-TYPE-INTEGERP */;
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3662c_integer_host_type_p_va(cl_narg narg, cl_object v3host_type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[59]);
 {
  return L3662c_integer_host_type_p(v3host_type);
 }
}
/* function definition for C-INTEGER-HOST-TYPE-BITS                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3663c_integer_host_type_bits(cl_object v1host_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2r;
  v2r = L3657host_type_record_unsafe(v1host_type);
  if (Null(v2r)){
   goto L4;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[34]))->cfun.entry(1, v2r) /*  HOST-TYPE-BITS */;
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3663c_integer_host_type_bits_va(cl_narg narg, cl_object v3host_type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[61]);
 {
  return L3663c_integer_host_type_bits(v3host_type);
 }
}
/* function definition for C-NUMBER-TYPE-P                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3664c_number_type_p(cl_object v1type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = L3660lisp_type__host_type(v1type);
 value0 = L3661c_number_host_type_p(T0);
 return value0;
}
static cl_object L3664c_number_type_p_va(cl_narg narg, cl_object v2type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[63]);
 {
  return L3664c_number_type_p(v2type);
 }
}
/* function definition for C-INTEGER-TYPE-P                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3665c_integer_type_p(cl_object v1type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = L3660lisp_type__host_type(v1type);
 value0 = L3662c_integer_host_type_p(T0);
 return value0;
}
static cl_object L3665c_integer_type_p_va(cl_narg narg, cl_object v2type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[65]);
 {
  return L3665c_integer_type_p(v2type);
 }
}
/* function definition for C-INTEGER-TYPE-BITS                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3666c_integer_type_bits(cl_object v1type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = L3660lisp_type__host_type(v1type);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[68]))->cfun.entry(1, T0) /*  C-NUMBER-HOST-TYPE-BITS */;
 return value0;
}
static cl_object L3666c_integer_type_bits_va(cl_narg narg, cl_object v2type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[67]);
 {
  return L3666c_integer_type_bits(v2type);
 }
}
/* function definition for HOST-TYPE->C-NAME                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3667host_type__c_name(cl_object v1type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = L3658host_type_record(v1type);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[28]))->cfun.entry(1, T0) /*  HOST-TYPE-C-NAME */;
 return value0;
}
static cl_object L3667host_type__c_name_va(cl_narg narg, cl_object v2type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[70]);
 {
  return L3667host_type__c_name(v2type);
 }
}
/* function definition for MAKE-HOST-TYPE                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3668make_host_type(cl_narg narg, cl_object v1all_c_types, cl_object v2name, cl_object v3lisp_type, cl_object v4c_name, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<4)) FEwrong_num_arguments(VV[78]);
 if (ecl_unlikely(narg>7)) FEwrong_num_arguments(VV[78]);
 {
  cl_object v5to_lisp;
  cl_object v6from_lisp;
  cl_object v7from_lisp_unsafe;
  va_list args; va_start(args,v4c_name);
  {
   int i = 4;
   if (i >= narg) {
    v5to_lisp = ECL_NIL;
   } else {
    i++;
    v5to_lisp = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v6from_lisp = ECL_NIL;
   } else {
    i++;
    v6from_lisp = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v7from_lisp_unsafe = ECL_NIL;
   } else {
    i++;
    v7from_lisp_unsafe = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v8record;
   cl_object v9bits;
   {
    cl_object v10;
    cl_object v11;
    v10 = v2name;
    v11 = v1all_c_types;
    v8record = ecl_assql(v10,v11);
   }
   v9bits = ecl_cdr(v8record);
   if (Null(v8record)){
    goto L8;
   }
   if (Null(v9bits)){
    goto L10;
   }
   if (!(ecl_plusp(v9bits))){
    goto L12;
   }
   v3lisp_type = cl_list(2, ECL_SYM("UNSIGNED-BYTE",889), v9bits);
   goto L10;
L12:;
   v9bits = ecl_negate(v9bits);
   v3lisp_type = cl_list(2, ECL_SYM("SIGNED-BYTE",764), v9bits);
L10:;
   T0 = cl_subtypep(3, v3lisp_type, ECL_SYM("NUMBER",608), ecl_cmp_symbol_value(cl_env_copy,VV[43]));
   T1 = cl_subtypep(3, v3lisp_type, ECL_SYM("INTEGER",439), ecl_cmp_symbol_value(cl_env_copy,VV[43]));
   value0 = L3645_make_host_type(18, ECL_SYM("NAME",1309), v2name, VV[79], v3lisp_type, VV[80], v9bits, VV[81], T0, VV[82], T1, VV[83], v4c_name, VV[84], v5to_lisp, VV[85], v6from_lisp, VV[86], v7from_lisp_unsafe);
   return value0;
L8:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for DEFAULT-MACHINE                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3669default_machine()
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1all_c_types;
  cl_object v2table;
  cl_object v3sorted_host_types;
  v1all_c_types = ecl_append(ecl_cmp_symbol_value(cl_env_copy,VV[74]),ecl_cmp_symbol_value(cl_env_copy,VV[76]));
  v2table = cl_make_hash_table(4, ECL_SYM("SIZE",1345), ecl_make_uint8_t(128), ECL_SYM("TEST",1353), ECL_SYM("EQ",335));
  {
   cl_object v4i;
   v4i = ecl_make_int8_t(0);
   {
    cl_object v5;
    cl_object v6record;
    cl_object v7;
    v5 = ecl_cmp_symbol_value(cl_env_copy,VV[72]);
    v6record = ECL_NIL;
    v7 = v5;
    {
     cl_object v8host_type;
     v8host_type = ECL_NIL;
     {
      cl_object v9;
      cl_object v10;
      v9 = ecl_list1(ECL_NIL);
      v10 = v9;
L12:;
      v6record = ECL_CONS_CAR(v7);
      {
       cl_object v11;
       v11 = ECL_CONS_CDR(v7);
       value0 = ecl_make_bool(ECL_LISTP(v11));
       if (value0!=ECL_NIL) {
        goto L22;
       }
       T0 = ecl_make_bool(ECL_SYMBOLP(v11));
       goto L20;
L22:;
       T0 = value0;
       goto L20;
L20:;
       if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[92],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v7 = v11;
      }
      T0 = ecl_fdefinition(VV[78]);
      v8host_type = cl_apply(3, T0, v1all_c_types, v6record);
      if (Null(v8host_type)){
       goto L27;
      }
      ecl_structure_set(v8host_type,VV[16],(cl_fixnum)(0),v4i);
      {
       cl_object v11;
       v11 = v10;
       if (ecl_unlikely(ECL_ATOM(v11))) FEtype_error_cons(v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v11;
      }
      T1 = (cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(1, v8host_type) /*  HOST-TYPE-NAME */;
      T2 = si_hash_set(T1, v2table, v8host_type);
      v10 = ecl_list1(T2);
      (ECL_CONS_CDR(T0)=v10,T0);
L27:;
      v4i = ecl_one_plus(v4i);
      if (!(ecl_endp(v7))){
       goto L36;
      }
      goto L13;
L36:;
      goto L12;
L13:;
      v3sorted_host_types = ecl_cdr(v9);
      goto L4;
     }
    }
   }
  }
L4:;
  {
   cl_object v4r;
   v4r = ecl_gethash_safe(VV[96],v2table,ECL_NIL);
   if (Null(v4r)){
    goto L40;
   }
   ecl_structure_set(v4r,VV[16],(cl_fixnum)(0),ECL_SYM("INT-SSE-PACK",1907));
  }
L40:;
  {
   cl_object v4fixnum_host_type;
   v4fixnum_host_type = ecl_gethash_safe(ECL_SYM("FIXNUM",1409),v2table,ECL_NIL);
   {
    cl_object v5fixnum_lisp_type;
    v5fixnum_lisp_type = (cl_env_copy->function=ecl_fdefinition(VV[36]))->cfun.entry(1, v4fixnum_host_type) /*  HOST-TYPE-LISP-TYPE */;
    {
     cl_object v6;
     cl_object v7name;
     cl_object v8rest;
     cl_object v9;
     v6 = ecl_cmp_symbol_value(cl_env_copy,VV[72]);
     v7name = ECL_NIL;
     v8rest = ECL_NIL;
     v9 = v6;
     {
      cl_object v10r;
      v10r = ECL_NIL;
L51:;
      {
       cl_object v11;
       v11 = ECL_CONS_CAR(v9);
       v7name = ecl_car(v11);
       v11 = ecl_cdr(v11);
       v8rest = v11;
      }
      {
       cl_object v11;
       v11 = ECL_CONS_CDR(v9);
       value0 = ecl_make_bool(ECL_LISTP(v11));
       if (value0!=ECL_NIL) {
        goto L66;
       }
       T0 = ecl_make_bool(ECL_SYMBOLP(v11));
       goto L64;
L66:;
       T0 = value0;
       goto L64;
L64:;
       if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[92],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v9 = v11;
      }
      v10r = ecl_gethash_safe(v7name,v2table,ECL_NIL);
      if (Null(v10r)){
       goto L70;
      }
      T0 = (cl_env_copy->function=ecl_fdefinition(VV[36]))->cfun.entry(1, v10r) /*  HOST-TYPE-LISP-TYPE */;
      if (Null(cl_subtypep(3, T0, v5fixnum_lisp_type, ecl_cmp_symbol_value(cl_env_copy,VV[43])))){
       goto L70;
      }
      ecl_structure_set(v10r,VV[16],(cl_fixnum)(9),VV[97]);
L70:;
      if (!(ecl_endp(v9))){
       goto L73;
      }
      goto L52;
L73:;
      goto L51;
L52:;
     }
    }
   }
  }
  value0 = L3640make_machine(6, VV[98], v1all_c_types, VV[99], v2table, VV[100], v3sorted_host_types);
  return value0;
 }
}
static cl_object L3669default_machine_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[88]);
 {
  return L3669default_machine();
 }
}
/* function definition for MACHINE-C-TYPE-P                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3670machine_c_type_p(cl_object v1name)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[46])) /*  MACHINE-HOST-TYPE-HASH */;
 value0 = cl_gethash(2, v1name, T0);
 return value0;
}
static cl_object L3670machine_c_type_p_va(cl_narg narg, cl_object v2name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[102]);
 {
  return L3670machine_c_type_p(v2name);
 }
}
#include "cmp/cmpc-mach.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclzyDq6XRlAR3j9_N1X0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPBACKEND-CXX;CMPC-MACH.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclzyDq6XRlAR3j9_N1X0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(_ecl_static_0);
  si_define_structure(VV[1], _ecl_static_1, ECL_NIL, ECL_NIL, VVtemp[0], VVtemp[1], VV[2], ECL_NIL, ECL_NIL, ECL_NIL, VVtemp[2], ecl_make_int8_t(4), ECL_NIL, ECL_NIL, VV[3]);
  VV[5]=cl_find_class(1, VV[1]);
  ecl_cmp_defun(VV[105]);                         /*  MAKE-MACHINE            */
  {
   cl_object v1package;
   v1package = cl_symbol_package(VV[7]);
   if (Null(v1package)){
    goto L9;
   }
   if (Null(si_package_locked_p(v1package))){
    goto L9;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L9;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[5], ECL_SYM("PACKAGE",1321), v1package);
  }
L9:;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC3641__lambda2_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  si_put_sysprop(VV[7], VV[8], T0);
  {
   cl_object v2package;
   v2package = cl_symbol_package(VV[10]);
   if (Null(v2package)){
    goto L17;
   }
   if (Null(si_package_locked_p(v2package))){
    goto L17;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L17;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[6], ECL_SYM("PACKAGE",1321), v2package);
  }
L17:;
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC3642__lambda7_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  si_put_sysprop(VV[10], VV[8], T0);
  {
   cl_object v3package;
   v3package = cl_symbol_package(VV[12]);
   if (Null(v3package)){
    goto L25;
   }
   if (Null(si_package_locked_p(v3package))){
    goto L25;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L25;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[7], ECL_SYM("PACKAGE",1321), v3package);
  }
L25:;
  {
   cl_object volatile v4;
   v4 = ecl_make_cfun_va((cl_objectfn)LC3643__lambda12_va,ECL_NIL,Cblock,2);
   T0 = v4;
  }
  si_put_sysprop(VV[12], VV[8], T0);
  {
   cl_object v4package;
   v4package = cl_symbol_package(VV[14]);
   if (Null(v4package)){
    goto L33;
   }
   if (Null(si_package_locked_p(v4package))){
    goto L33;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L33;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[8], ECL_SYM("PACKAGE",1321), v4package);
  }
L33:;
  {
   cl_object volatile v5;
   v5 = ecl_make_cfun_va((cl_objectfn)LC3644__lambda17_va,ECL_NIL,Cblock,2);
   T0 = v5;
  }
  si_put_sysprop(VV[14], VV[8], T0);
  si_define_structure(VV[16], _ecl_static_2, ECL_NIL, ECL_NIL, VVtemp[9], VVtemp[10], VV[17], ECL_NIL, ECL_NIL, ECL_NIL, VVtemp[11], ecl_make_int8_t(10), ECL_NIL, ECL_NIL, VV[18]);
  VV[20]=cl_find_class(1, VV[16]);
  ecl_cmp_defun(VV[106]);                         /*  %MAKE-HOST-TYPE         */
  {
   cl_object v5package;
   v5package = cl_symbol_package(VV[22]);
   if (Null(v5package)){
    goto L49;
   }
   if (Null(si_package_locked_p(v5package))){
    goto L49;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L49;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[12], ECL_SYM("PACKAGE",1321), v5package);
  }
L49:;
  {
   cl_object volatile v6;
   v6 = ecl_make_cfun_va((cl_objectfn)LC3646__lambda23_va,ECL_NIL,Cblock,2);
   T0 = v6;
  }
  si_put_sysprop(VV[22], VV[8], T0);
  {
   cl_object v6package;
   v6package = cl_symbol_package(VV[24]);
   if (Null(v6package)){
    goto L57;
   }
   if (Null(si_package_locked_p(v6package))){
    goto L57;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L57;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[13], ECL_SYM("PACKAGE",1321), v6package);
  }
L57:;
  {
   cl_object volatile v7;
   v7 = ecl_make_cfun_va((cl_objectfn)LC3647__lambda28_va,ECL_NIL,Cblock,2);
   T0 = v7;
  }
  si_put_sysprop(VV[24], VV[8], T0);
  {
   cl_object v7package;
   v7package = cl_symbol_package(VV[26]);
   if (Null(v7package)){
    goto L65;
   }
   if (Null(si_package_locked_p(v7package))){
    goto L65;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L65;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[14], ECL_SYM("PACKAGE",1321), v7package);
  }
L65:;
  {
   cl_object volatile v8;
   v8 = ecl_make_cfun_va((cl_objectfn)LC3648__lambda33_va,ECL_NIL,Cblock,2);
   T0 = v8;
  }
  si_put_sysprop(VV[26], VV[8], T0);
  {
   cl_object v8package;
   v8package = cl_symbol_package(VV[28]);
   if (Null(v8package)){
    goto L73;
   }
   if (Null(si_package_locked_p(v8package))){
    goto L73;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L73;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[15], ECL_SYM("PACKAGE",1321), v8package);
  }
L73:;
  {
   cl_object volatile v9;
   v9 = ecl_make_cfun_va((cl_objectfn)LC3649__lambda38_va,ECL_NIL,Cblock,2);
   T0 = v9;
  }
  si_put_sysprop(VV[28], VV[8], T0);
  {
   cl_object v9package;
   v9package = cl_symbol_package(VV[30]);
   if (Null(v9package)){
    goto L81;
   }
   if (Null(si_package_locked_p(v9package))){
    goto L81;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L81;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[16], ECL_SYM("PACKAGE",1321), v9package);
  }
L81:;
  {
   cl_object volatile v10;
   v10 = ecl_make_cfun_va((cl_objectfn)LC3650__lambda43_va,ECL_NIL,Cblock,2);
   T0 = v10;
  }
  si_put_sysprop(VV[30], VV[8], T0);
  {
   cl_object v10package;
   v10package = cl_symbol_package(VV[32]);
   if (Null(v10package)){
    goto L89;
   }
   if (Null(si_package_locked_p(v10package))){
    goto L89;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L89;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[17], ECL_SYM("PACKAGE",1321), v10package);
  }
L89:;
  {
   cl_object volatile v11;
   v11 = ecl_make_cfun_va((cl_objectfn)LC3651__lambda48_va,ECL_NIL,Cblock,2);
   T0 = v11;
  }
  si_put_sysprop(VV[32], VV[8], T0);
  {
   cl_object v11package;
   v11package = cl_symbol_package(VV[34]);
   if (Null(v11package)){
    goto L97;
   }
   if (Null(si_package_locked_p(v11package))){
    goto L97;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L97;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[18], ECL_SYM("PACKAGE",1321), v11package);
  }
L97:;
  {
   cl_object volatile v12;
   v12 = ecl_make_cfun_va((cl_objectfn)LC3652__lambda53_va,ECL_NIL,Cblock,2);
   T0 = v12;
  }
  si_put_sysprop(VV[34], VV[8], T0);
  {
   cl_object v12package;
   v12package = cl_symbol_package(VV[36]);
   if (Null(v12package)){
    goto L105;
   }
   if (Null(si_package_locked_p(v12package))){
    goto L105;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L105;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[19], ECL_SYM("PACKAGE",1321), v12package);
  }
L105:;
  {
   cl_object volatile v13;
   v13 = ecl_make_cfun_va((cl_objectfn)LC3653__lambda58_va,ECL_NIL,Cblock,2);
   T0 = v13;
  }
  si_put_sysprop(VV[36], VV[8], T0);
  {
   cl_object v13package;
   v13package = cl_symbol_package(VV[38]);
   if (Null(v13package)){
    goto L113;
   }
   if (Null(si_package_locked_p(v13package))){
    goto L113;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L113;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[20], ECL_SYM("PACKAGE",1321), v13package);
  }
L113:;
  {
   cl_object volatile v14;
   v14 = ecl_make_cfun_va((cl_objectfn)LC3654__lambda63_va,ECL_NIL,Cblock,2);
   T0 = v14;
  }
  si_put_sysprop(VV[38], VV[8], T0);
  {
   cl_object v14package;
   v14package = cl_symbol_package(VV[40]);
   if (Null(v14package)){
    goto L121;
   }
   if (Null(si_package_locked_p(v14package))){
    goto L121;
   }
   if (!(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L121;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[3], VVtemp[4], VVtemp[21], ECL_SYM("PACKAGE",1321), v14package);
  }
L121:;
  {
   cl_object volatile v15;
   v15 = ecl_make_cfun_va((cl_objectfn)LC3655__lambda68_va,ECL_NIL,Cblock,2);
   T0 = v15;
  }
  si_put_sysprop(VV[40], VV[8], T0);
  ecl_cmp_defun(VV[107]);                         /*  LISP-TYPE-P             */
  ecl_cmp_defun(VV[108]);                         /*  HOST-TYPE-RECORD-UNSAFE */
  ecl_cmp_defun(VV[109]);                         /*  HOST-TYPE-RECORD        */
  ecl_cmp_defun(VV[110]);                         /*  HOST-TYPE->LISP-TYPE    */
  ecl_cmp_defun(VV[111]);                         /*  LISP-TYPE->HOST-TYPE    */
  ecl_cmp_defun(VV[112]);                         /*  C-NUMBER-HOST-TYPE-P    */
  ecl_cmp_defun(VV[113]);                         /*  C-INTEGER-HOST-TYPE-P   */
  ecl_cmp_defun(VV[114]);                         /*  C-INTEGER-HOST-TYPE-BITS */
  ecl_cmp_defun(VV[115]);                         /*  C-NUMBER-TYPE-P         */
  ecl_cmp_defun(VV[116]);                         /*  C-INTEGER-TYPE-P        */
  ecl_cmp_defun(VV[117]);                         /*  C-INTEGER-TYPE-BITS     */
  ecl_cmp_defun(VV[118]);                         /*  HOST-TYPE->C-NAME       */
  si_Xmake_constant(VV[72], VV[73]);
  si_Xmake_constant(VV[74], VV[75]);
  si_Xmake_constant(VV[76], VV[77]);
  ecl_cmp_defun(VV[119]);                         /*  MAKE-HOST-TYPE          */
  ecl_cmp_defun(VV[120]);                         /*  DEFAULT-MACHINE         */
  ecl_cmp_defun(VV[121]);                         /*  MACHINE-C-TYPE-P        */
  si_Xmake_special(VV[104]);
  if (ecl_boundp(cl_env_copy,VV[104])) {
   goto L188;
  }
  T0 = L3669default_machine();
  ecl_cmp_setq(cl_env_copy,VV[46],T0);
  T0 = ecl_cmp_symbol_value(cl_env_copy,VV[46]);
  ecl_cmp_setq(cl_env_copy,VV[104],T0);
L188:;
 }
}
