/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/lsp/autoload.lsp                    */
#include <ecl/ecl-cmp.h>
#include "lsp/autoload.eclh"
/* function definition for LISP-IMPLEMENTATION-TYPE                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object cl_lisp_implementation_type()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = VV[0];
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for AUTOLOAD                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L769autoload(cl_narg narg, cl_object v1pathname, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1]);
 {
  cl_object v2si__function_names;
  ecl_va_list args; ecl_va_start(args,v1pathname,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1pathname,env0);            /*  PATHNAME                */
  v2si__function_names = cl_grab_rest_args(args);
  ecl_va_end(args);
  {
   cl_object v3;
   v3 = v2si__function_names;
   goto L4;
L3:;
   {
    cl_object v4si__fname;
    v4si__fname = ecl_car(v3);
    {
     cl_object env1 = env0;
     CLV1 = env1 = CONS(v4si__fname,env1);        /*  THENAME                 */
     {
      cl_object v5;
      v5 = ecl_make_cclosure_va((cl_objectfn)LC768__lambda5,env1,Cblock,0);
      T0 = v5;
     }
     si_fset(2, v4si__fname, T0);
    }
   }
   v3 = ecl_cdr(v3);
L4:;
   if (Null(v3)){
    goto L12;
   }
   goto L3;
L12:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function PROCLAIM                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC770proclaim(cl_object v1si__d)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_car(v1si__d);
 if (!((T0)==(ECL_SYM("SPECIAL",792)))){
  goto L2;
 }
 {
  cl_object v2;
  v2 = (ECL_SYM("*MAKE-SPECIAL",1031)->symbol.gfdef);
  {
   cl_object v3;
   v3 = ecl_cdr(v1si__d);
   {
    cl_object v4;
    cl_object v5;
    cl_object v6;
    {
     cl_object v7;
     v7 = v3;
     if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v4 = v7;
    }
    v5 = ECL_NIL;
    v6 = v4;
L11:;
    if (!(ecl_endp(v6))){
     goto L13;
    }
    goto L12;
L13:;
    v5 = ECL_CONS_CAR(v6);
    {
     cl_object v7;
     v7 = ECL_CONS_CDR(v6);
     if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v6 = v7;
    }
    ecl_function_dispatch(cl_env_copy,v2)(1, v5);
    goto L11;
L12:;
    value0 = v3;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC770proclaim_va(cl_narg narg, cl_object v7si__d, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(ECL_SYM("PROCLAIM",669));
 {
  return LC770proclaim(v7si__d);
 }
}
/* function definition for DO-COMPILATION-UNIT                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L771do_compilation_unit(cl_narg narg, cl_object v1si__closure, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[6]);
 {
  va_list args; va_start(args,v1si__closure);
  va_end(args);
  value0 = ecl_function_dispatch(cl_env_copy,v1si__closure)(0);
  return value0;
 }
}
/* local function WITH-COMPILATION-UNIT                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC772with_compilation_unit(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4si__options;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4si__options = v5;
  }
  T0 = cl_listX(3, ECL_SYM("LAMBDA",454), ECL_NIL, v3);
  T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
  value0 = cl_listX(3, VV[6], T1, v4si__options);
  return value0;
 }
}
static cl_object LC772with_compilation_unit_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[9]);
 {
  return LC772with_compilation_unit(v5, v6);
 }
}
/* function definition for ED-EXTERNAL                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L773ed_external(cl_object v1si__x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (v1si__x==ECL_NIL) {
  goto L4;
 }
 if (cl_pathnamep(v1si__x)!=ECL_NIL) {
  goto L4;
 }
 if (!(ECL_STRINGP(v1si__x))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = si_getenv(VV[11]);
 if (value0!=ECL_NIL) {
  goto L10;
 }
 T0 = VV[12];
 goto L8;
L10:;
 T0 = value0;
 goto L8;
L8:;
 if (Null(v1si__x)){
  goto L14;
 }
 T1 = ecl_list1(v1si__x);
 goto L12;
L14:;
 T1 = ECL_NIL;
 goto L12;
L12:;
 si_run_program(2, T0, T1);
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L773ed_external_va(cl_narg narg, cl_object v2si__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[10]);
 {
  return L773ed_external(v2si__x);
 }
}
/* function definition for ED                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L774ed(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[15]);
 {
  cl_object v1si__x;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1si__x = ECL_NIL;
   } else {
    i++;
    v1si__x = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v2;
   v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*ED-FUNCTIONS*",1127));
   goto L5;
L4:;
   {
    cl_object v3si__fun;
    v3si__fun = ecl_car(v2);
    if (Null(ecl_function_dispatch(cl_env_copy,v3si__fun)(1, v1si__x))){
     goto L9;
    }
    value0 = ECL_T;
    cl_env_copy->nvalues = 1;
    return value0;
L9:;
   }
   v2 = ecl_cdr(v2);
L5:;
   if (Null(v2)){
    goto L13;
   }
   goto L4;
L13:;
   value0 = cl_error(2, VV[14], v1si__x);
   return value0;
  }
 }
}
/* function definition for ROOM                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L775room(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[17]);
 {
  cl_object v1si__x;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1si__x = ECL_NIL;
   } else {
    i++;
    v1si__x = va_arg(args,cl_object);
   }
  }
  va_end(args);
  cl_format(2, ECL_T, VV[16]);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
}
/* function definition for HELP                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L776help(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[20]);
 {
  cl_object v1symbol;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1symbol = VV[20];
   } else {
    i++;
    v1symbol = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = (cl_env_copy->function=(VV[21]->symbol.gfdef))->cfun.entry(1, v1symbol) /*  PRINT-DOC */;
  return value0;
 }
}
/* closure LAMBDA5                                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC768__lambda5(cl_narg narg, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  THENAME                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1si__args;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1si__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  cl_load(1, ECL_CONS_CAR(CLV0));
  value0 = cl_apply(2, ECL_CONS_CAR(CLV1), v1si__args);
  return value0;
 }
 }
}
#include "lsp/autoload.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecl3WFL2k0m36Hi9_OW00M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:LSP;AUTOLOAD.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecl3WFL2k0m36Hi9_OW00M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0, T1;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  (void)0; /* No entry created for LISP-IMPLEMENTATION-TYPE */
  ecl_cmp_defun(VV[23]);                          /*  AUTOLOAD                */
  if (cl_fboundp(ECL_SYM("COMPILE",235))!=ECL_NIL) {
   goto L8;
  }
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC770proclaim_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  si_fset(2, ECL_SYM("PROCLAIM",669), T0);
L8:;
  ecl_cmp_defun(VV[24]);                          /*  DO-COMPILATION-UNIT     */
  ecl_cmp_defmacro(VV[25]);                       /*  WITH-COMPILATION-UNIT   */
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1]) /*  MAPC */;
  ecl_cmp_defun(VV[26]);                          /*  ED-EXTERNAL             */
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[2]) /*  MAPC */;
  si_Xmake_special(ECL_SYM("*ED-FUNCTIONS*",1127));
  if (ecl_boundp(cl_env_copy,ECL_SYM("*ED-FUNCTIONS*",1127))) {
   goto L26;
  }
  T0 = (VV[10]->symbol.gfdef);
  T1 = ecl_list1(T0);
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*ED-FUNCTIONS*",1127),T1);
L26:;
  ecl_cmp_defun(VV[27]);                          /*  ED                      */
  ecl_cmp_defun(VV[28]);                          /*  ROOM                    */
  L769autoload(3, VVtemp[3], VV[18], VV[19]);
  ecl_cmp_defun(VV[29]);                          /*  HELP                    */
  si_select_package(VVtemp[4]);
  cl_import(1, VVtemp[5]);
 }
}
