/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpopt.lsp                      */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpopt.eclh"
/* function definition for EXPAND-IN-INTERVAL-P                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4008expand_in_interval_p(cl_object v1var, cl_object v2interval)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3forms;
  v3forms = ECL_NIL;
  {
   cl_object v4;
   cl_object v5lower_limit;
   cl_object v6upper_limit;
   v4 = v2interval;
   if (Null(v4)){
    goto L6;
   }
   {
    cl_object v7;
    v7 = ecl_car(v4);
    v4 = ecl_cdr(v4);
    v5lower_limit = v7;
    goto L5;
   }
L6:;
   v5lower_limit = ECL_SYM("*",20);
L5:;
   if (Null(v4)){
    goto L12;
   }
   {
    cl_object v7;
    v7 = ecl_car(v4);
    v4 = ecl_cdr(v4);
    v6upper_limit = v7;
    goto L11;
   }
L12:;
   v6upper_limit = ECL_SYM("*",20);
L11:;
   if (Null(v4)){
    goto L17;
   }
   si_dm_too_many_arguments(v2interval);
L17:;
   if ((v5lower_limit)==(ECL_SYM("*",20))) {
    goto L19;
   }
   if (!(ECL_CONSP(v5lower_limit))){
    goto L23;
   }
   T1 = ecl_car(v5lower_limit);
   T0 = cl_list(3, ECL_SYM(">",77), v1var, T1);
   goto L22;
L23:;
   T0 = cl_list(3, ECL_SYM(">=",78), v1var, v5lower_limit);
L22:;
   v3forms = CONS(T0,v3forms);
L19:;
   if ((v6upper_limit)==(ECL_SYM("*",20))) {
    goto L3;
   }
   if (!(ECL_CONSP(v6upper_limit))){
    goto L28;
   }
   T1 = ecl_car(v6upper_limit);
   T0 = cl_list(3, ECL_SYM("<",74), v1var, T1);
   goto L27;
L28:;
   T0 = cl_list(3, ECL_SYM("<=",75), v1var, v6upper_limit);
L27:;
   v3forms = CONS(T0,v3forms);
  }
L3:;
  value0 = v3forms;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for CONTAINS-COMPOUND-FUNCTION-TYPE                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4009contains_compound_function_type(cl_object v1type)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_CONSP(v1type))){
  goto L3;
 }
 T0 = ecl_car(v1type);
 value0 = ecl_make_bool((T0)==(ECL_SYM("FUNCTION",398)));
 if (value0!=ECL_NIL) {
  goto L6;
 }
 {
  cl_object v2;
  v2 = ecl_car(v1type);
  if (!((v2)==(ECL_SYM("NOT",586)))){
   goto L15;
  }
  goto L12;
L15:;
  goto L13;
L13:;
  if (!((v2)==(ECL_SYM("OR",616)))){
   goto L19;
  }
  goto L12;
L19:;
  goto L17;
L17:;
  if (!((v2)==(ECL_SYM("AND",89)))){
   goto L23;
  }
  goto L12;
L23:;
  goto L21;
L21:;
  if (!((v2)==(ECL_SYM("CONS",253)))){
   goto L9;
  }
  goto L10;
L12:;
 }
L10:;
 T0 = ecl_fdefinition(VV[2]);
 T1 = ecl_cdr(v1type);
 value0 = cl_some(2, T0, T1);
 return value0;
L9:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L6:;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4009contains_compound_function_type_va(cl_narg narg, cl_object v2type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2]);
 {
  return L4009contains_compound_function_type(v2type);
 }
}
/* function definition for EXPAND-TYPEP                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4010expand_typep(cl_object v1form, cl_object v2object, cl_object v3type, cl_object v4env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5aux;
  cl_object v6first;
  cl_object v7rest;
  cl_object v8function;
  v5aux = ECL_NIL;
  v6first = ECL_NIL;
  v7rest = ECL_NIL;
  v8function = ECL_NIL;
  if (Null(cl_constantp(2, v3type, v4env))){
   goto L7;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("CONSTANT-FORM-VALUE",2161)))->cfun.entry(2, v3type, v4env) /*  CONSTANT-FORM-VALUE */;
  v3type = (cl_env_copy->function=(VV[9]->symbol.gfdef))->cfun.entry(2, T0, v4env) /*  SEARCH-TYPE-IN-ENV */;
  goto L6;
L7:;
  value0 = v1form;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  if (Null(L4009contains_compound_function_type(v3type))){
   goto L10;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[10]))->cfun.entry(2, VV[11], v3type) /*  CMPWARN */;
  value0 = v1form;
  cl_env_copy->nvalues = 1;
  return value0;
L10:;
  if (!(ECL_SYMBOLP(v2object))){
   goto L13;
  }
  v5aux = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(2, v2object, v4env) /*  CMP-ENV-SEARCH-VAR */;
  if (Null(v5aux)){
   goto L13;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(1, v5aux) /*  VAR-TYPE */;
  if (Null(cl_subtypep(3, T0, v3type, ecl_cmp_symbol_value(cl_env_copy,VV[14])))){
   goto L13;
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L13:;
  if (Null(cl_subtypep(3, ECL_T, v3type, ecl_cmp_symbol_value(cl_env_copy,VV[14])))){
   goto L18;
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L18:;
  if (!((v3type)==(ECL_NIL))){
   goto L20;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L20:;
  if (Null(cl_subtypep(3, v3type, ECL_NIL, ecl_cmp_symbol_value(cl_env_copy,VV[14])))){
   goto L22;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[10]))->cfun.entry(2, VV[15], v3type) /*  CMPWARN */;
  value0 = v1form;
  cl_env_copy->nvalues = 1;
  return value0;
L22:;
  if (!(ECL_ATOM(v3type))){
   goto L29;
  }
  T0 = v3type;
  goto L28;
L29:;
  T0 = ecl_car(v3type);
L28:;
  v8function = si_get_sysprop(T0, VV[16]);
  if (Null(v8function)){
   goto L25;
  }
  if (!(ECL_ATOM(v3type))){
   goto L37;
  }
  T1 = ecl_list1(v3type);
  goto L36;
L37:;
  T1 = v3type;
L36:;
  T0 = ecl_function_dispatch(cl_env_copy,v8function)(2, T1, v4env);
  v3type = cl_list(2, ECL_SYM("QUOTE",682), T0);
  goto L1;
L25:;
  v8function = si_get_sysprop(v3type, VV[17]);
  if (Null(v8function)){
   goto L40;
  }
  value0 = cl_list(2, v8function, v2object);
  return value0;
L40:;
  {
   cl_object v9;
   {
    cl_object v10;
    cl_object v11a_type;
    cl_object v12function_name;
    cl_object v13;
    v10 = ecl_cmp_symbol_value(cl_env_copy,VV[19]);
    v11a_type = ECL_NIL;
    v12function_name = ECL_NIL;
    v13 = v10;
L48:;
    {
     cl_object v14;
     v14 = ECL_CONS_CAR(v13);
     v11a_type = ecl_car(v14);
     v14 = ecl_cdr(v14);
     v12function_name = v14;
    }
    {
     cl_object v14;
     v14 = ECL_CONS_CDR(v13);
     value0 = ecl_make_bool(ECL_LISTP(v14));
     if (value0!=ECL_NIL) {
      goto L63;
     }
     T0 = ecl_make_bool(ECL_SYMBOLP(v14));
     goto L61;
L63:;
     T0 = value0;
     goto L61;
L61:;
     if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[22],v14);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v13 = v14;
    }
    if (Null((cl_env_copy->function=(VV[23]->symbol.gfdef))->cfun.entry(3, v3type, v11a_type, ecl_cmp_symbol_value(cl_env_copy,VV[14])) /*  TYPE= */)){
     goto L65;
    }
    v9 = cl_list(2, v12function_name, v2object);
    goto L43;
L65:;
    if (!(ecl_endp(v13))){
     goto L67;
    }
    goto L49;
L67:;
    goto L48;
L49:;
    v9 = ECL_NIL;
   }
L43:;
   if (Null(v9)){
    goto L70;
   }
   value0 = v9;
   cl_env_copy->nvalues = 1;
   return value0;
L70:;
   if ((cl_env_copy->function=ecl_fdefinition(VV[24]))->cfun.entry(0) /*  POLICY-INLINE-TYPE-CHECKS */!=ECL_NIL) {
    goto L72;
   }
   value0 = v1form;
   cl_env_copy->nvalues = 1;
   return value0;
L72:;
   if (!(ECL_CONSP(v3type))){
    goto L74;
   }
   T0 = ecl_car(v3type);
   if (!((T0)==(ECL_SYM("CONS",253)))){
    goto L74;
   }
   value0 = v1form;
   cl_env_copy->nvalues = 1;
   return value0;
L74:;
   if (!(ECL_SYMBOLP(v3type))){
    goto L77;
   }
   v5aux = cl_find_class(2, v3type, ECL_NIL);
   if (Null(v5aux)){
    goto L77;
   }
   T0 = cl_list(2, ECL_SYM("QUOTE",682), v3type);
   value0 = cl_list(3, ECL_SYM("OF-CLASS-P",1209), v2object, T0);
   return value0;
L77:;
   if (!(ECL_ATOM(v3type))){
    goto L81;
   }
   value0 = v1form;
   cl_env_copy->nvalues = 1;
   return value0;
L81:;
   v7rest = ecl_cdr(v3type);
   v6first = ecl_car(v3type);
   if (!((v6first)==(ECL_SYM("NOT",586)))){
    goto L83;
   }
   T0 = ecl_car(v7rest);
   T1 = cl_list(2, ECL_SYM("QUOTE",682), T0);
   T2 = cl_list(3, ECL_SYM("TYPEP",878), v2object, T1);
   value0 = cl_list(2, ECL_SYM("NOT",586), T2);
   return value0;
L83:;
   if (!((v6first)==(ECL_SYM("OR",616)))){
    goto L94;
   }
   goto L91;
L94:;
   goto L92;
L92:;
   if (!((v6first)==(ECL_SYM("AND",89)))){
    goto L89;
   }
   goto L90;
L91:;
L90:;
   {
    cl_object v10var;
    v10var = cl_gensym(0);
    T0 = cl_list(2, v10var, v2object);
    T1 = ecl_list1(T0);
    T2 = cl_list(2, VV[27], v10var);
    T3 = cl_list(2, ECL_SYM("DECLARE",276), T2);
    {
     cl_object v11;
     cl_object v12type;
     cl_object v13;
     {
      cl_object v14;
      v14 = v7rest;
      if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v11 = v14;
     }
     v12type = ECL_NIL;
     v13 = v11;
     {
      cl_object v14;
      cl_object v15;
      v14 = ecl_list1(ECL_NIL);
      v15 = v14;
L106:;
      if (!(ecl_endp(v13))){
       goto L108;
      }
      goto L107;
L108:;
      v12type = ECL_CONS_CAR(v13);
      {
       cl_object v16;
       v16 = ECL_CONS_CDR(v13);
       if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v13 = v16;
      }
      {
       cl_object v16;
       v16 = v15;
       if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T5 = v16;
      }
      T6 = cl_list(2, ECL_SYM("QUOTE",682), v12type);
      T7 = cl_list(3, ECL_SYM("TYPEP",878), v10var, T6);
      v15 = ecl_list1(T7);
      (ECL_CONS_CDR(T5)=v15,T5);
      goto L106;
L107:;
      T4 = ecl_cdr(v14);
      goto L98;
     }
    }
L98:;
    T5 = CONS(v6first,T4);
    value0 = cl_list(4, ECL_SYM("LET",479), T1, T3, T5);
    return value0;
   }
L89:;
   if (!((v6first)==(ECL_SYM("MEMBER",554)))){
    goto L123;
   }
   T0 = cl_list(2, ECL_SYM("QUOTE",682), v7rest);
   value0 = cl_list(3, ECL_SYM("MEMBER",554), v2object, T0);
   return value0;
L123:;
   {
    cl_object v11;
    cl_object v12;
    v11 = v6first;
    v12 = VV[31];
    if (Null(ecl_memql(v11,v12))){
     goto L125;
    }
   }
   {
    cl_object v11;
    cl_object v12;
    v11 = cl_gensym(0);
    v12 = cl_gensym(0);
    if (!((v6first)==(ECL_SYM("INTEGER",439)))){
     goto L131;
    }
    if (Null(cl_subtypep(3, v3type, ECL_SYM("FIXNUM",374), ecl_cmp_symbol_value(cl_env_copy,VV[14])))){
     goto L131;
    }
    v6first = ECL_SYM("FIXNUM",374);
L131:;
    T0 = cl_list(2, v11, v2object);
    T1 = cl_coerce(ecl_make_int8_t(0), v6first);
    T2 = cl_list(2, v12, T1);
    T3 = cl_list(2, T0, T2);
    T4 = cl_list(2, VV[27], v11);
    T5 = cl_list(3, ECL_SYM("TYPE",872), v6first, v12);
    T6 = cl_list(3, ECL_SYM("DECLARE",276), T4, T5);
    T7 = cl_list(2, ECL_SYM("QUOTE",682), v6first);
    T8 = cl_list(3, ECL_SYM("TYPEP",878), v11, T7);
    T9 = cl_list(3, ECL_SYM("TRULY-THE",2081), v6first, v11);
    T10 = cl_list(3, ECL_SYM("SETF",753), v12, T9);
    T11 = L4008expand_in_interval_p(v12, v7rest);
    T12 = CONS(ECL_SYM("AND",89),T11);
    T13 = cl_list(4, ECL_SYM("LOCALLY",492), VV[32], T10, T12);
    T14 = cl_list(3, ECL_SYM("AND",89), T8, T13);
    value0 = cl_list(4, ECL_SYM("LET",479), T3, T6, T14);
    return value0;
   }
L125:;
   if (!((v6first)==(ECL_SYM("COMPLEX",243)))){
    goto L135;
   }
   T0 = cl_list_length(v3type);
   if (!(ecl_number_equalp(T0,ecl_make_int8_t(2)))){
    goto L135;
   }
   T0 = cl_list(2, ECL_SYM("COMPLEXP",244), v2object);
   T1 = cl_list(2, ECL_SYM("REALPART",708), v2object);
   T2 = ecl_cadr(v3type);
   T3 = cl_list(2, ECL_SYM("QUOTE",682), T2);
   T4 = cl_list(3, ECL_SYM("TYPEP",878), T1, T3);
   T5 = cl_list(2, ECL_SYM("IMAGPART",432), v2object);
   T6 = ecl_cadr(v3type);
   T7 = cl_list(2, ECL_SYM("QUOTE",682), T6);
   T8 = cl_list(3, ECL_SYM("TYPEP",878), T5, T7);
   value0 = cl_list(4, ECL_SYM("AND",89), T0, T4, T8);
   return value0;
L135:;
   if (!((v6first)==(ECL_SYM("SATISFIES",738)))){
    goto L138;
   }
   T0 = cl_list_length(v3type);
   if (!(ecl_number_equalp(T0,ecl_make_int8_t(2)))){
    goto L138;
   }
   v8function = ecl_cadr(v3type);
   if (!(ECL_SYMBOLP(v8function))){
    goto L138;
   }
   value0 = cl_list(2, v8function, v2object);
   return value0;
L138:;
   value0 = v1form;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4010expand_typep_va(cl_narg narg, cl_object v13form, cl_object v14object, cl_object v15type, cl_object v16env, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[8]);
 {
  return L4010expand_typep(v13form, v14object, v15type, v16env);
 }
}
/* local function LAMBDA62                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4011__lambda62(cl_object v1, cl_object v2env)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4object;
  cl_object v5type;
  cl_object v6e;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v7;
   v7 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4object = v7;
  }
  if (!(v3==ECL_NIL)){
   goto L13;
  }
  si_dm_too_few_arguments(v1);
L13:;
  {
   cl_object v7;
   v7 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5type = v7;
  }
  if (Null(v3)){
   goto L19;
  }
  {
   cl_object v7;
   v7 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v6e = v7;
   goto L18;
  }
L19:;
  v6e = ECL_NIL;
L18:;
  if (Null(v3)){
   goto L24;
  }
  si_dm_too_many_arguments(v1);
L24:;
  value0 = L4010expand_typep(v1, v4object, v5type, v2env);
  return value0;
 }
}
static cl_object LC4011__lambda62_va(cl_narg narg, cl_object v7, cl_object v8env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[35]);
 {
  return LC4011__lambda62(v7, v8env);
 }
}
/* local function LAMBDA71                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4013__lambda71(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6var;
  cl_object v7expression;
  cl_object v8output_form;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v9;
   v9 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v9;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L14;
  }
  si_dm_too_few_arguments(v1);
L14:;
  {
   cl_object v9;
   v9 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6var = v9;
  }
  if (!(v5==ECL_NIL)){
   goto L20;
  }
  si_dm_too_few_arguments(v1);
L20:;
  {
   cl_object v9;
   v9 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7expression = v9;
  }
  if (Null(v5)){
   goto L26;
  }
  {
   cl_object v9;
   v9 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v8output_form = v9;
   goto L25;
  }
L26:;
  v8output_form = ECL_NIL;
L25:;
  if (Null(v5)){
   goto L31;
  }
  si_dm_too_many_arguments(v1);
L31:;
  {
   cl_object v9;                                  /*  DECLARATIONS            */
   cl_object v10;                                 /*  BODY                    */
   value0 = si_process_declarations(2, v3, ECL_NIL);
   {
    const int v11 = cl_env_copy->nvalues;
    v9 = value0;
    cl_object v12;
    v12 = (v11<=1)? ECL_NIL : cl_env_copy->values[1];
    v10 = v12;
   }
   {
    cl_object v11filtered_declarations;
    cl_object v12list_var;
    cl_object v13typed_var;
    T0 = cl_list(2, ECL_SYM("IGNORABLE",429), v6var);
    {
     cl_object v14;
     v14 = ecl_make_cfun_va((cl_objectfn)LC4012__lambda77_va,ECL_NIL,Cblock,1);
     T1 = v14;
    }
    T2 = cl_remove_if(2, T1, v9);
    v11filtered_declarations = CONS(T0,T2);
    v12list_var = cl_gensym(0);
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(1, v2env) /*  POLICY-ASSUME-NO-ERRORS */)){
     goto L38;
    }
    v13typed_var = v12list_var;
    goto L37;
L38:;
    v13typed_var = cl_list(3, ECL_SYM("TRULY-THE",2081), ECL_SYM("CONS",253), v12list_var);
L37:;
    T0 = cl_list(2, v12list_var, v7expression);
    T1 = ecl_list1(T0);
    T2 = cl_list(2, ECL_SYM("FIRST",373), v13typed_var);
    T3 = cl_list(2, v6var, T2);
    T4 = ecl_list1(T3);
    T5 = CONS(ECL_SYM("DECLARE",276),v9);
    T6 = CONS(ECL_SYM("TAGBODY",853),v10);
    T7 = cl_list(4, ECL_SYM("LET",479), T4, T5, T6);
    T8 = cl_list(2, ECL_SYM("REST",722), v13typed_var);
    T9 = cl_list(3, ECL_SYM("SETQ",754), v12list_var, T8);
    T10 = cl_list(4, ECL_SYM("WHILE",1543), v12list_var, T7, T9);
    if (Null(v8output_form)){
     goto L41;
    }
    T12 = cl_list(2, v6var, ECL_NIL);
    T13 = ecl_list1(T12);
    T14 = CONS(ECL_SYM("DECLARE",276),v11filtered_declarations);
    T11 = cl_list(4, ECL_SYM("LET",479), T13, T14, v8output_form);
    goto L40;
L41:;
    T11 = ECL_NIL;
L40:;
    T12 = cl_list(4, ECL_SYM("LET*",480), T1, T10, T11);
    value0 = cl_list(3, ECL_SYM("BLOCK",139), ECL_NIL, T12);
    return value0;
   }
  }
 }
}
static cl_object LC4013__lambda71_va(cl_narg narg, cl_object v9, cl_object v10env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[36]);
 {
  return LC4013__lambda71(v9, v10env);
 }
}
/* function definition for EXPAND-COERCE                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4014expand_coerce(cl_object v1form, cl_object v2value, cl_object v3type, cl_object v4env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5first;
  cl_object v6rest;
  v5first = ECL_NIL;
  v6rest = ECL_NIL;
  if (Null(cl_constantp(2, v3type, v4env))){
   goto L5;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("CONSTANT-FORM-VALUE",2161)))->cfun.entry(2, v3type, v4env) /*  CONSTANT-FORM-VALUE */;
  v3type = (cl_env_copy->function=(VV[9]->symbol.gfdef))->cfun.entry(2, T0, v4env) /*  SEARCH-TYPE-IN-ENV */;
  goto L4;
L5:;
  value0 = v1form;
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  if (Null(cl_subtypep(3, ECL_T, v3type, ecl_cmp_symbol_value(cl_env_copy,VV[14])))){
   goto L8;
  }
  value0 = v2value;
  cl_env_copy->nvalues = 1;
  return value0;
L8:;
  if (Null(cl_subtypep(3, v3type, ECL_NIL, ecl_cmp_symbol_value(cl_env_copy,VV[14])))){
   goto L10;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, VV[42]) /*  CMPERR */;
  return value0;
L10:;
  if ((cl_env_copy->function=ecl_fdefinition(VV[24]))->cfun.entry(0) /*  POLICY-INLINE-TYPE-CHECKS */!=ECL_NIL) {
   goto L12;
  }
  value0 = v1form;
  cl_env_copy->nvalues = 1;
  return value0;
L12:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[43]))){
   goto L14;
  }
  if (!((v3type)==(ECL_SYM("COMPLEX-SINGLE-FLOAT",1899)))){
   goto L20;
  }
  goto L17;
L20:;
  goto L18;
L18:;
  if (!((v3type)==(ECL_SYM("COMPLEX-DOUBLE-FLOAT",1900)))){
   goto L24;
  }
  goto L17;
L24:;
  goto L22;
L22:;
  if (!((v3type)==(ECL_SYM("COMPLEX-LONG-FLOAT",1901)))){
   goto L14;
  }
  goto L15;
L17:;
L15:;
  {
   cl_object v7prototype;
   if (!((v3type)==(ECL_SYM("COMPLEX-SINGLE-FLOAT",1899)))){
    goto L28;
   }
   v7prototype = cl_core.singlefloat_zero;
   goto L27;
L28:;
   if (!((v3type)==(ECL_SYM("COMPLEX-DOUBLE-FLOAT",1900)))){
    goto L30;
   }
   v7prototype = cl_core.doublefloat_zero;
   goto L27;
L30:;
   if (!((v3type)==(ECL_SYM("COMPLEX-LONG-FLOAT",1901)))){
    goto L32;
   }
   v7prototype = cl_core.longfloat_zero;
   goto L27;
L32:;
   v7prototype = ECL_NIL;
L27:;
   T0 = cl_list(2, VV[47], v2value);
   T1 = ecl_list1(T0);
   T2 = cl_list(3, ECL_SYM("FLOAT",376), VV[49], v7prototype);
   T3 = cl_list(3, ECL_SYM("FLOAT",376), VV[50], v7prototype);
   T4 = cl_list(3, ECL_SYM("COMPLEX",243), T2, T3);
   value0 = cl_list(4, ECL_SYM("LET",479), T1, VV[48], T4);
   return value0;
  }
L14:;
  {
   cl_object v8;
   {
    cl_object v9;
    cl_object v10a_type;
    cl_object v11template;
    cl_object v12;
    {
     cl_object v13;
     v13 = ecl_cmp_symbol_value(cl_env_copy,VV[39]);
     if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v9 = v13;
    }
    v10a_type = ECL_NIL;
    v11template = ECL_NIL;
    v12 = v9;
L41:;
    if (!(ecl_endp(v12))){
     goto L43;
    }
    goto L42;
L43:;
    {
     cl_object v13;
     v13 = ECL_CONS_CAR(v12);
     v10a_type = ecl_car(v13);
     v13 = ecl_cdr(v13);
     v11template = v13;
    }
    {
     cl_object v13;
     v13 = ECL_CONS_CDR(v12);
     if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v12 = v13;
    }
    if (!((v3type)==(v10a_type))){
     goto L56;
    }
    v8 = cl_subst(3, v2value, VV[51], v11template);
    goto L34;
L56:;
    goto L41;
L42:;
    v8 = ECL_NIL;
   }
L34:;
   if (Null(v8)){
    goto L59;
   }
   value0 = v8;
   cl_env_copy->nvalues = 1;
   return value0;
L59:;
   if (!(ECL_ATOM(v3type))){
    goto L61;
   }
   v5first = si_get_sysprop(v3type, VV[16]);
   if (Null(v5first)){
    goto L61;
   }
   T1 = ecl_list1(v3type);
   T0 = ecl_function_dispatch(cl_env_copy,v5first)(2, T1, v4env);
   v3type = cl_list(2, ECL_SYM("QUOTE",682), T0);
   goto L1;
L61:;
   if (!(ECL_CONSP(v3type))){
    goto L71;
   }
   T0 = ecl_car(v3type);
   if (!((T0)==(ECL_SYM("CONS",253)))){
    goto L71;
   }
   value0 = v1form;
   cl_env_copy->nvalues = 1;
   return value0;
L71:;
   {
    cl_object v9;
    {
     cl_object v10;
     cl_object v11a_type;
     cl_object v12template;
     cl_object v13;
     {
      cl_object v14;
      v14 = ecl_cmp_symbol_value(cl_env_copy,VV[39]);
      if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v10 = v14;
     }
     v11a_type = ECL_NIL;
     v12template = ECL_NIL;
     v13 = v10;
L81:;
     if (!(ecl_endp(v13))){
      goto L83;
     }
     goto L82;
L83:;
     {
      cl_object v14;
      v14 = ECL_CONS_CAR(v13);
      v11a_type = ecl_car(v14);
      v14 = ecl_cdr(v14);
      v12template = v14;
     }
     {
      cl_object v14;
      v14 = ECL_CONS_CDR(v13);
      if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v13 = v14;
     }
     if (Null((cl_env_copy->function=(VV[23]->symbol.gfdef))->cfun.entry(3, v3type, v11a_type, ecl_cmp_symbol_value(cl_env_copy,VV[14])) /*  TYPE= */)){
      goto L96;
     }
     v9 = cl_subst(3, v2value, VV[51], v12template);
     goto L74;
L96:;
     goto L81;
L82:;
     v9 = ECL_NIL;
    }
L74:;
    if (Null(v9)){
     goto L99;
    }
    value0 = v9;
    cl_env_copy->nvalues = 1;
    return value0;
L99:;
    if (Null(cl_subtypep(3, v3type, ECL_SYM("SEQUENCE",744), ecl_cmp_symbol_value(cl_env_copy,VV[14])))){
     goto L101;
    }
    {
     cl_object v10;                               /*  ELT-TYPE                */
     cl_object v11;                               /*  LENGTH                  */
     value0 = (cl_env_copy->function=(VV[52]->symbol.gfdef))->cfun.entry(1, v3type) /*  CLOSEST-SEQUENCE-TYPE */;
     {
      const int v12 = cl_env_copy->nvalues;
      v10 = value0;
      cl_object v13;
      v13 = (v12<=1)? ECL_NIL : cl_env_copy->values[1];
      v11 = v13;
     }
     if ((v11)==(ECL_SYM("*",20))) {
      goto L106;
     }
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[53]))->cfun.entry(0) /*  POLICY-ASSUME-RIGHT-TYPE */)){
      goto L104;
     }
     goto L105;
L106:;
L105:;
     if (!((v10)==(ECL_SYM("LIST",483)))){
      goto L108;
     }
     value0 = cl_list(2, VV[54], v2value);
     return value0;
L108:;
     T0 = cl_list(2, ECL_SYM("QUOTE",682), v10);
     T1 = cl_list(2, ECL_SYM("QUOTE",682), v11);
     if (Null(cl_subtypep(3, v3type, ECL_SYM("SIMPLE-ARRAY",766), ecl_cmp_symbol_value(cl_env_copy,VV[14])))){
      goto L112;
     }
     T2 = ECL_T;
     goto L110;
L112:;
     T2 = ECL_NIL;
     goto L110;
L110:;
     value0 = cl_list(5, VV[55], v2value, T0, T1, T2);
     return value0;
L104:;
     value0 = v1form;
     cl_env_copy->nvalues = 1;
     return value0;
    }
L101:;
    if (!(ECL_ATOM(v3type))){
     goto L114;
    }
    value0 = v1form;
    cl_env_copy->nvalues = 1;
    return value0;
L114:;
    v6rest = ecl_cdr(v3type);
    v5first = ecl_car(v3type);
    if (!((v5first)==(ECL_SYM("AND",89)))){
     goto L116;
    }
    T0 = cl_list(2, VV[51], v2value);
    T1 = ecl_list1(T0);
    {
     cl_object v10;
     cl_object v11i;
     cl_object v12;
     {
      cl_object v13;
      v13 = v6rest;
      if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v10 = v13;
     }
     v11i = ECL_NIL;
     v12 = v10;
     {
      cl_object v13;
      cl_object v14;
      v13 = ecl_list1(ECL_NIL);
      v14 = v13;
L130:;
      if (!(ecl_endp(v12))){
       goto L132;
      }
      goto L131;
L132:;
      v11i = ECL_CONS_CAR(v12);
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v12);
       if (ecl_unlikely(!ECL_LISTP(v15))) FEtype_error_list(v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v12 = v15;
      }
      {
       cl_object v15;
       v15 = v14;
       if (ecl_unlikely(ECL_ATOM(v15))) FEtype_error_cons(v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T3 = v15;
      }
      T4 = cl_list(2, ECL_SYM("QUOTE",682), v11i);
      T5 = cl_list(3, ECL_SYM("COERCE",233), VV[51], T4);
      T6 = cl_list(3, ECL_SYM("SETF",753), VV[51], T5);
      v14 = ecl_list1(T6);
      (ECL_CONS_CDR(T3)=v14,T3);
      goto L130;
L131:;
      T2 = ecl_cdr(v13);
      goto L122;
     }
    }
L122:;
    T3 = ecl_append(T2,VV[56]);
    value0 = cl_listX(3, ECL_SYM("LET",479), T1, T3);
    return value0;
L116:;
    if (!((v5first)==(ECL_SYM("COMPLEX",243)))){
     goto L147;
    }
    {
     cl_fixnum v10;
     v10 = ecl_length(v6rest);
     if (!((v10)==((cl_fixnum)(1)))){
      goto L147;
     }
    }
    T0 = cl_list(2, VV[47], v2value);
    T1 = ecl_list1(T0);
    T2 = ecl_car(v6rest);
    T3 = cl_list(2, ECL_SYM("QUOTE",682), T2);
    T4 = cl_list(3, ECL_SYM("COERCE",233), VV[49], T3);
    T5 = ecl_car(v6rest);
    T6 = cl_list(2, ECL_SYM("QUOTE",682), T5);
    T7 = cl_list(3, ECL_SYM("COERCE",233), VV[50], T6);
    T8 = cl_list(3, ECL_SYM("COMPLEX",243), T4, T7);
    value0 = cl_list(4, ECL_SYM("LET",479), T1, VV[48], T8);
    return value0;
L147:;
    {
     cl_object v10;
     cl_object v11;
     v10 = v5first;
     v11 = VV[31];
     if (Null(ecl_memql(v10,v11))){
      goto L150;
     }
    }
    {
     cl_object v10unchecked;
     T0 = cl_list(2, ECL_SYM("QUOTE",682), v5first);
     v10unchecked = L4014expand_coerce(v1form, v2value, T0, v4env);
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(0) /*  POLICY-ASSUME-NO-ERRORS */)){
      goto L155;
     }
     value0 = v10unchecked;
     cl_env_copy->nvalues = 1;
     return value0;
L155:;
     T0 = cl_list(2, VV[51], v10unchecked);
     T1 = ecl_list1(T0);
     T2 = cl_list(2, v5first, VV[51]);
     T3 = cl_list(2, ECL_SYM("DECLARE",276), T2);
     T4 = ecl_cdr(v3type);
     T5 = L4008expand_in_interval_p(VV[51], T4);
     T6 = CONS(ECL_SYM("AND",89),T5);
     T7 = cl_list(2, ECL_SYM("QUOTE",682), v3type);
     T8 = cl_listX(4, ECL_SYM("DO-CHECK-TYPE",1893), VV[51], T7, VV[57]);
     T9 = cl_list(3, ECL_SYM("UNLESS",886), T6, T8);
     value0 = cl_list(5, ECL_SYM("LET",479), T1, T3, T9, VV[51]);
     return value0;
    }
L150:;
    value0 = v1form;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* local function LAMBDA121                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4015__lambda121(cl_object v1, cl_object v2env)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4value;
  cl_object v5type;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4value = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L13;
  }
  si_dm_too_few_arguments(v1);
L13:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5type = v6;
  }
  if (Null(v3)){
   goto L18;
  }
  si_dm_too_many_arguments(v1);
L18:;
  value0 = L4014expand_coerce(v1, v4value, v5type, v2env);
  return value0;
 }
}
static cl_object LC4015__lambda121_va(cl_narg narg, cl_object v6, cl_object v7env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[58]);
 {
  return LC4015__lambda121(v6, v7env);
 }
}
/* local function LAMBDA129                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4016__lambda129(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4expression;
  cl_object v5stream;
  T0 = ecl_car(v1);
  if (!((T0)==(ECL_SYM("FUNCALL",396)))){
   goto L3;
  }
  T0 = ecl_caadr(v1);
  if (!((T0)==(ECL_SYM("FUNCTION",398)))){
   goto L3;
  }
  v3 = ecl_cddr(v1);
  goto L2;
L3:;
  v3 = ecl_cdr(v1);
L2:;
  if (!(v3==ECL_NIL)){
   goto L7;
  }
  si_dm_too_few_arguments(v1);
L7:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4expression = v6;
  }
  if (Null(v3)){
   goto L13;
  }
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5stream = v6;
   goto L12;
  }
L13:;
  v5stream = ECL_NIL;
L12:;
  if (Null(v3)){
   goto L18;
  }
  si_dm_too_many_arguments(v1);
L18:;
  if (Null(cl_constantp(2, v4expression, v2env))){
   goto L20;
  }
  {
   cl_object v6value;
   v6value = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("CONSTANT-FORM-VALUE",2161)))->cfun.entry(2, v4expression, v2env) /*  CONSTANT-FORM-VALUE */;
   if (Null(cl_typep(2, v6value, VV[60]))){
    goto L23;
   }
   value0 = cl_list(2, ECL_SYM("TERPRI",858), v5stream);
   return value0;
L23:;
   if (cl_typep(2, v6value, VV[61])!=ECL_NIL) {
    goto L27;
   }
   if (Null(cl_typep(2, v6value, VV[62]))){
    goto L25;
   }
   goto L26;
L27:;
L26:;
   {
    cl_object v7;
    v7 = v6value;
    T1 = v7;
    if (ecl_unlikely(((cl_fixnum)(0))>=(v7)->vector.dim))
           FEwrong_index(ECL_NIL,v7,-1,ecl_make_fixnum((cl_fixnum)(0)),(v7)->vector.dim);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T2 = ecl_make_int8_t(0);
    T0 = ecl_aref_unsafe(T1,ecl_fixnum(T2));
   }
   value0 = cl_list(3, ECL_SYM("PRINC",663), T0, v5stream);
   return value0;
L25:;
   value0 = v1;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L20:;
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4016__lambda129_va(cl_narg narg, cl_object v7, cl_object v8env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[59]);
 {
  return LC4016__lambda129(v7, v8env);
 }
}
/* local function LAMBDA77                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4012__lambda77(cl_object v1clause)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_CONSP(v1clause))){
  goto L3;
 }
 T0 = ecl_car(v1clause);
 value0 = ecl_make_bool((T0)==(ECL_SYM("TYPE",872)));
 if (value0!=ECL_NIL) {
  goto L6;
 }
 T0 = ecl_car(v1clause);
 value0 = ecl_make_bool((T0)==(ECL_SYM("IGNORE",430)));
 cl_env_copy->nvalues = 1;
 return value0;
L6:;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4012__lambda77_va(cl_narg narg, cl_object v2clause, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[37]);
 {
  return LC4012__lambda77(v2clause);
 }
}
#include "cmp/cmpopt.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecldTaYBbKzxmFo9_3ke0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPOPT.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecldTaYBbKzxmFo9_3ke0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  (void)0; /* No entry created for EXPAND-IN-INTERVAL-P */
  ecl_cmp_defun(VV[65]);                          /*  CONTAINS-COMPOUND-FUNCTION-TYPE */
  ecl_cmp_defun(VV[66]);                          /*  EXPAND-TYPEP            */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4011__lambda62_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("TYPEP",878), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4013__lambda71_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("DOLIST",315), ECL_SYM("COMPILER-MACRO",240), T0);
  si_Xmake_special(VV[39]);
  T0 = VVtemp[1];
  ecl_cmp_setq(cl_env_copy,VV[39],T0);
  (void)0; /* No entry created for EXPAND-COERCE */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4015__lambda121_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("COERCE",233), ECL_SYM("COMPILER-MACRO",240), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4016__lambda129_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_put_sysprop(ECL_SYM("PRINC",663), ECL_SYM("COMPILER-MACRO",240), T0);
 }
}
