/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpbackend-cxx/cmppass2-top.lsp */
#include <ecl/ecl-cmp.h>
#include "cmp/cmppass2-top.eclh"
/* function definition for WT-PRINT-HEADER                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3793wt_print_header(cl_object v1source)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_lisp_implementation_type();
 T1 = cl_lisp_implementation_version();
 (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(3, VV[2], T0, T1) /*  WT-COMMENT-NL */;
 {
  cl_object v2;                                   /*  MINUTE                  */
  cl_object v3;                                   /*  HOUR                    */
  cl_object v4;                                   /*  DAY                     */
  cl_object v5;                                   /*  MONTH                   */
  cl_object v6;                                   /*  YEAR                    */
  value0 = cl_get_decoded_time();
  {
   v2 = cl_env_copy->values[1];
   v3 = cl_env_copy->values[2];
   v4 = cl_env_copy->values[3];
   v5 = cl_env_copy->values[4];
   v6 = cl_env_copy->values[5];
  }
  (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(6, VV[3], v6, v5, v4, v3, v2) /*  WT-COMMENT-NL */;
  T0 = cl_software_type();
  T1 = cl_software_version();
  T2 = cl_machine_type();
  (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(4, VV[4], T0, T1, T2) /*  WT-COMMENT-NL */;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(2, VV[5], v1source) /*  WT-COMMENT-NL */;
 return value0;
}
static cl_object L3793wt_print_header_va(cl_narg narg, cl_object v2source, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[0]);
 {
  return L3793wt_print_header(v2source);
 }
}
/* function definition for COMPILER-PASS/GENERATE-CXX                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3794compiler_pass_generate_cxx(cl_object volatile v1c_pathname, cl_object volatile v2h_pathname, cl_object volatile v3data_pathname, cl_object volatile v4init_name, cl_object volatile v5source)
{
 cl_object T0;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v6;
  volatile cl_object v7;
  volatile cl_object v8;
  volatile cl_object v9;
  volatile cl_object v10;
  {
   cl_object v11r;
   v11r = (cl_env_copy->function=ecl_fdefinition(VV[9]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[10])) /*  MACHINE-INLINE-INFORMATION */;
   if (Null(v11r)){
    goto L4;
   }
   v6 = si_copy_hash_table(v11r);
   goto L2;
L4:;
   v6 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[10])) /*  MAKE-INLINE-INFORMATION */;
  }
L2:;
  v7 = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[10])) /*  MAKE-OPTIMIZABLE-CONSTANTS */;
  v8 = si_make_vector(ECL_T, ecl_make_uint8_t(128), ECL_T, ecl_make_int8_t(0), ECL_NIL, ecl_make_int8_t(0));
  v9 = si_make_vector(ECL_T, ecl_make_uint8_t(128), ECL_T, ecl_make_int8_t(0), ECL_NIL, ecl_make_int8_t(0));
  v10 = cl_make_hash_table(0);
  ecl_bds_bind(cl_env_copy,VV[13],ecl_make_int8_t(0)); /*  *OPENED-C-BRACES*  */
  ecl_bds_bind(cl_env_copy,VV[14],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*    */
  ecl_bds_bind(cl_env_copy,VV[15],ecl_make_int8_t(0)); /*  *NEXT-CFUN*        */
  ecl_bds_bind(cl_env_copy,VV[16],v6);            /*  *INLINE-INFORMATION*    */
  ecl_bds_bind(cl_env_copy,VV[17],ECL_NIL);       /*  *SETF-DEFINITIONS*      */
  ecl_bds_bind(cl_env_copy,VV[18],ECL_NIL);       /*  *GLOBAL-CFUNS-ARRAY*    */
  ecl_bds_bind(cl_env_copy,VV[19],ECL_NIL);       /*  *STATIC-CONSTANTS*      */
  ecl_bds_bind(cl_env_copy,VV[20],v7);            /*  *OPTIMIZABLE-CONSTANTS* */
  ecl_bds_bind(cl_env_copy,VV[21],v8);            /*  *PERMANENT-OBJECTS*     */
  ecl_bds_bind(cl_env_copy,VV[22],v9);            /*  *TEMPORARY-OBJECTS*     */
  ecl_bds_bind(cl_env_copy,VV[23],v10);           /*  *COMPILER-DECLARED-GLOBALS* */
  (cl_env_copy->function=ecl_fdefinition(VV[24]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[25])) /*  OPTIMIZE-CXX-DATA */;
  T0 = VV[27];
  ecl_cmp_setq(cl_env_copy,VV[26],T0);
  T0 = cl_open(7, v1c_pathname, ECL_SYM("DIRECTION",1249), ECL_SYM("OUTPUT",1319), ECL_SYM("IF-DOES-NOT-EXIST",1277), ECL_SYM("CREATE",1244), ECL_SYM("IF-EXISTS",1279), ECL_SYM("SUPERSEDE",1351));
  ecl_bds_bind(cl_env_copy,VV[28],T0);            /*  *COMPILER-OUTPUT1*      */
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    {
     struct ecl_stack_frame _ecl_inner_frame_aux;
     volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
     T0 = cl_open(7, v2h_pathname, ECL_SYM("DIRECTION",1249), ECL_SYM("OUTPUT",1319), ECL_SYM("IF-DOES-NOT-EXIST",1277), ECL_SYM("CREATE",1244), ECL_SYM("IF-EXISTS",1279), ECL_SYM("SUPERSEDE",1351));
     ecl_bds_bind(cl_env_copy,VV[29],T0);         /*  *COMPILER-OUTPUT2*      */
     {
      struct ecl_stack_frame _ecl_inner_frame_aux;
      volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
      volatile bool unwinding = FALSE;
      ecl_frame_ptr next_fr;
      {
       ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
       if (__ecl_frs_push_result!=0) {
         unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
       } else {
       {
        struct ecl_stack_frame _ecl_inner_frame_aux;
        volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
        L3793wt_print_header(v5source);
        (cl_env_copy->function=ecl_fdefinition(VV[30]))->cfun.entry(2, VV[31], ecl_cmp_symbol_value(cl_env_copy,VV[32])) /*  WT-NL1 */;
        L3805ctop_write(v4init_name, v2h_pathname, v3data_pathname);
        (ecl_terpri(ecl_cmp_symbol_value(cl_env_copy,VV[28])));
        cl_env_copy->values[0] = (ecl_terpri(ecl_cmp_symbol_value(cl_env_copy,VV[29])));
        cl_env_copy->nvalues = 1;
        ecl_stack_frame_push_values(_ecl_inner_frame);
        if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[29]))){
         goto L22;
        }
        cl_close(1, ecl_cmp_symbol_value(cl_env_copy,VV[29]));
L22:;
        ecl_stack_frame_pop_values(_ecl_inner_frame);
        ecl_stack_frame_close(_ecl_inner_frame);
       }
       }
      }
      ecl_frs_pop(cl_env_copy);
      ecl_stack_frame_push_values(_ecl_inner_frame);
      if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[29]))){
       goto L24;
      }
      cl_close(3, ecl_cmp_symbol_value(cl_env_copy,VV[29]), ECL_SYM("ABORT",1225), ECL_T);
L24:;
      ecl_stack_frame_pop_values(_ecl_inner_frame);
      if (unwinding) ecl_unwind(cl_env_copy,next_fr);
      ecl_stack_frame_close(_ecl_inner_frame);
      ecl_bds_unwind1(cl_env_copy);
     }
     ecl_stack_frame_push_values(_ecl_inner_frame);
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[28]))){
      goto L26;
     }
     cl_close(1, ecl_cmp_symbol_value(cl_env_copy,VV[28]));
L26:;
     ecl_stack_frame_pop_values(_ecl_inner_frame);
     ecl_stack_frame_close(_ecl_inner_frame);
    }
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[28]))){
    goto L28;
   }
   cl_close(3, ecl_cmp_symbol_value(cl_env_copy,VV[28]), ECL_SYM("ABORT",1225), ECL_T);
L28:;
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   ecl_bds_unwind1(cl_env_copy);
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[34]))->cfun.entry(1, v3data_pathname) /*  DATA-C-DUMP */;
  ecl_bds_unwind_n(cl_env_copy,11);
  return value0;
 }
}
static cl_object L3794compiler_pass_generate_cxx_va(cl_narg narg, cl_object v11c_pathname, cl_object v12h_pathname, cl_object v13data_pathname, cl_object v14init_name, cl_object v15source, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[7]);
 {
  return L3794compiler_pass_generate_cxx(v11c_pathname, v12h_pathname, v13data_pathname, v14init_name, v15source);
 }
}
/* function definition for T2EXPR                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3795t2expr(cl_object v1form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = v1form;
  if (si_of_class_p(2, v2, VV[37])!=ECL_NIL) {
   goto L4;
  }
  v1form = si_do_check_type(v2, VV[37], ECL_NIL, VV[38]);
L4:;
 }
 ecl_bds_bind(cl_env_copy,VV[40],v1form);         /*  *CURRENT-C1FORM*        */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, v1form) /*  C1FORM-FILE */;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*COMPILE-FILE-TRUENAME*",29),T0); /*  *COMPILE-FILE-TRUENAME* */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[43]))->cfun.entry(1, v1form) /*  C1FORM-FILE-POSITION */;
 ecl_bds_bind(cl_env_copy,VV[42],T0);             /*  *COMPILE-FILE-POSITION* */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[45]))->cfun.entry(1, v1form) /*  C1FORM-TOPLEVEL-FORM */;
 ecl_bds_bind(cl_env_copy,VV[44],T0);             /*  *CURRENT-TOPLEVEL-FORM* */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[47]))->cfun.entry(1, v1form) /*  C1FORM-FORM */;
 ecl_bds_bind(cl_env_copy,VV[46],T0);             /*  *CURRENT-FORM*          */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[49]))->cfun.entry(1, v1form) /*  C1FORM-ENV */;
 ecl_bds_bind(cl_env_copy,VV[48],T0);             /*  *CMP-ENV*               */
 {
  cl_object v2name;
  cl_object v3args;
  cl_object v4dispatch;
  v2name = (cl_env_copy->function=ecl_fdefinition(VV[50]))->cfun.entry(1, v1form) /*  C1FORM-NAME */;
  v3args = (cl_env_copy->function=ecl_fdefinition(VV[51]))->cfun.entry(1, v1form) /*  C1FORM-ARGS */;
  v4dispatch = ecl_gethash_safe(v2name,ecl_cmp_symbol_value(cl_env_copy,VV[52]),ECL_NIL);
  if (Null(v4dispatch)){
   goto L10;
  }
  value0 = cl_apply(3, v4dispatch, v1form, v3args);
  ecl_bds_unwind_n(cl_env_copy,6);
  return value0;
L10:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[53]))->cfun.entry(2, VV[54], v1form) /*  CMPERR */;
  ecl_bds_unwind_n(cl_env_copy,6);
  return value0;
 }
}
static cl_object L3795t2expr_va(cl_narg narg, cl_object v5form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[36]);
 {
  return L3795t2expr(v5form);
 }
}
/* function definition for T2COMPILER-LET                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3796t2compiler_let(cl_object v1c1form, cl_object v2symbols, cl_object v3values, cl_object v4body)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6, v7; cl_index v5;
  v6 = v2symbols;
  v7 = v3values;
  v5 = ecl_progv(cl_env_copy, v6, v7);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(1, v4body) /*  C2EXPR */;
  ecl_bds_unwind(cl_env_copy,v5);
  return value0;
 }
}
static cl_object L3796t2compiler_let_va(cl_narg narg, cl_object v5c1form, cl_object v6symbols, cl_object v7values, cl_object v8body, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[56]);
 {
  return L3796t2compiler_let(v5c1form, v6symbols, v7values, v8body);
 }
}
/* function definition for T2PROGN                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3797t2progn(cl_object v1c1form, cl_object v2args)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_fdefinition(VV[36]);
  {
   cl_object v4;
   cl_object v5;
   cl_object v6;
   {
    cl_object v7;
    v7 = v2args;
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   v5 = ECL_NIL;
   v6 = v4;
L8:;
   if (!(ecl_endp(v6))){
    goto L10;
   }
   goto L9;
L10:;
   v5 = ECL_CONS_CAR(v6);
   {
    cl_object v7;
    v7 = ECL_CONS_CDR(v6);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v6 = v7;
   }
   ecl_function_dispatch(cl_env_copy,v3)(1, v5);
   goto L8;
L9:;
   value0 = v2args;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3797t2progn_va(cl_narg narg, cl_object v7c1form, cl_object v8args, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[59]);
 {
  return L3797t2progn(v7c1form, v8args);
 }
}
/* function definition for T2ORDINARY                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3798t2ordinary(cl_object v1c1form, cl_object v2form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[65]))->cfun.entry(1, ECL_NIL) /*  LABELP */;
  if (Null(v3)){
   goto L4;
  }
  T0 = ECL_NIL;
  goto L3;
L4:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[67]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L3:;
  ecl_bds_bind(cl_env_copy,VV[66],T0);            /*  *EXIT*                  */
  T0 = cl_adjoin(2, ecl_cmp_symbol_value(cl_env_copy,VV[66]), ecl_cmp_symbol_value(cl_env_copy,VV[68]));
  ecl_bds_bind(cl_env_copy,VV[68],T0);            /*  *UNWIND-EXIT*           */
  ecl_bds_bind(cl_env_copy,VV[69],VV[70]);        /*  *DESTINATION*           */
  (cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(1, v2form) /*  C2EXPR */;
  ecl_bds_unwind1(cl_env_copy);
  if (v3!=ECL_NIL) {
   goto L7;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[71]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[66])) /*  WT-LABEL */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L7:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3798t2ordinary_va(cl_narg narg, cl_object v4c1form, cl_object v5form, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[63]);
 {
  return L3798t2ordinary(v4c1form, v5form);
 }
}
/* function definition for T2LOAD-TIME-VALUE                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3799t2load_time_value(cl_object v1c1form, cl_object v2vv_loc, cl_object v3form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[65]))->cfun.entry(1, ECL_NIL) /*  LABELP */;
  if (Null(v4)){
   goto L4;
  }
  T0 = ECL_NIL;
  goto L3;
L4:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[67]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L3:;
  ecl_bds_bind(cl_env_copy,VV[66],T0);            /*  *EXIT*                  */
  T0 = cl_adjoin(2, ecl_cmp_symbol_value(cl_env_copy,VV[66]), ecl_cmp_symbol_value(cl_env_copy,VV[68]));
  ecl_bds_bind(cl_env_copy,VV[68],T0);            /*  *UNWIND-EXIT*           */
  ecl_bds_bind(cl_env_copy,VV[69],v2vv_loc);      /*  *DESTINATION*           */
  (cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(1, v3form) /*  C2EXPR */;
  ecl_bds_unwind1(cl_env_copy);
  if (v4!=ECL_NIL) {
   goto L7;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[71]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[66])) /*  WT-LABEL */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L7:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3799t2load_time_value_va(cl_narg narg, cl_object v5c1form, cl_object v6vv_loc, cl_object v7form, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[73]);
 {
  return L3799t2load_time_value(v5c1form, v6vv_loc, v7form);
 }
}
/* function definition for T2MAKE-FORM                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3800t2make_form(cl_object v1c1form, cl_object v2vv_loc, cl_object v3form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[65]))->cfun.entry(1, ECL_NIL) /*  LABELP */;
  if (Null(v4)){
   goto L4;
  }
  T0 = ECL_NIL;
  goto L3;
L4:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[67]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L3:;
  ecl_bds_bind(cl_env_copy,VV[66],T0);            /*  *EXIT*                  */
  T0 = cl_adjoin(2, ecl_cmp_symbol_value(cl_env_copy,VV[66]), ecl_cmp_symbol_value(cl_env_copy,VV[68]));
  ecl_bds_bind(cl_env_copy,VV[68],T0);            /*  *UNWIND-EXIT*           */
  ecl_bds_bind(cl_env_copy,VV[69],v2vv_loc);      /*  *DESTINATION*           */
  (cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(1, v3form) /*  C2EXPR */;
  ecl_bds_unwind1(cl_env_copy);
  if (v4!=ECL_NIL) {
   goto L7;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[71]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[66])) /*  WT-LABEL */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L7:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3800t2make_form_va(cl_narg narg, cl_object v5c1form, cl_object v6vv_loc, cl_object v7form, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[75]);
 {
  return L3800t2make_form(v5c1form, v6vv_loc, v7form);
 }
}
/* function definition for T2INIT-FORM                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3801t2init_form(cl_object v1c1form, cl_object v2vv_loc, cl_object v3form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[65]))->cfun.entry(1, ECL_NIL) /*  LABELP */;
  if (Null(v4)){
   goto L4;
  }
  T0 = ECL_NIL;
  goto L3;
L4:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[67]))->cfun.entry(1, ECL_NIL) /*  NEXT-LABEL */;
L3:;
  ecl_bds_bind(cl_env_copy,VV[66],T0);            /*  *EXIT*                  */
  T0 = cl_adjoin(2, ecl_cmp_symbol_value(cl_env_copy,VV[66]), ecl_cmp_symbol_value(cl_env_copy,VV[68]));
  ecl_bds_bind(cl_env_copy,VV[68],T0);            /*  *UNWIND-EXIT*           */
  ecl_bds_bind(cl_env_copy,VV[69],VV[70]);        /*  *DESTINATION*           */
  (cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(1, v3form) /*  C2EXPR */;
  ecl_bds_unwind1(cl_env_copy);
  if (v4!=ECL_NIL) {
   goto L7;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[71]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[66])) /*  WT-LABEL */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L7:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3801t2init_form_va(cl_narg narg, cl_object v5c1form, cl_object v6vv_loc, cl_object v7form, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[77]);
 {
  return L3801t2init_form(v5c1form, v6vv_loc, v7form);
 }
}
/* function definition for T2FSET                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3802t2fset(cl_narg narg, cl_object v1c1form, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[79]);
 {
  va_list args; va_start(args,v1c1form);
  va_end(args);
  value0 = L3798t2ordinary(v1c1form, v1c1form);
  return value0;
 }
}
/* function definition for C2FSET                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3803c2fset(cl_object v1c1form, cl_object v2fun, cl_object v3fname, cl_object v4macro_p, cl_object v5pprint, cl_object v6c1forms)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[82]))->cfun.entry(1, v2fun) /*  FUN-NO-ENTRY */)){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[86]))->cfun.entry(1, v2fun) /*  FUN-NAME */;
 T1 = cl_format(3, ECL_NIL, VV[85], T0);
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(2, VV[84], T1) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[87]))->cfun.entry(1, v2fun) /*  UPDATE-FUNCTION-ENV */;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if ((cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v2fun) /*  FUN-CLOSURE */!=ECL_NIL) {
  goto L6;
 }
 if (!((ecl_cmp_symbol_value(cl_env_copy,VV[69]))==(VV[70]))){
  goto L6;
 }
 value0 = L3823wt_install_function(v3fname, v2fun, v4macro_p);
 return value0;
L6:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[90]))->cfun.entry(3, v1c1form, ECL_SYM("FSET",1090), v6c1forms) /*  C2CALL-GLOBAL */;
 return value0;
}
static cl_object L3803c2fset_va(cl_narg narg, cl_object v7c1form, cl_object v8fun, cl_object v9fname, cl_object v10macro_p, cl_object v11pprint, cl_object v12c1forms, ...)
{
 if (ecl_unlikely(narg!=6)) FEwrong_num_arguments(VV[81]);
 {
  return L3803c2fset(v7c1form, v8fun, v9fname, v10macro_p, v11pprint, v12c1forms);
 }
}
/* function definition for EMIT-FUNCTIONS                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3804emit_functions(cl_object v1_compiler_output1_)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 ecl_bds_bind(cl_env_copy,VV[28],v1_compiler_output1_); /*  *COMPILER-OUTPUT1* */
L1:;
 ecl_bds_bind(cl_env_copy,VV[93],ECL_NIL);        /*  *COMPILE-TIME-TOO*      */
 ecl_bds_bind(cl_env_copy,VV[94],ECL_NIL);        /*  *COMPILE-TOPLEVEL*      */
 ecl_bds_bind(cl_env_copy,VV[95],ECL_NIL);        /*  *EMITTED-FUNCTIONS*     */
 goto L4;
L3:;
 {
  cl_object v2lfs;
  v2lfs = ecl_cmp_symbol_value(cl_env_copy,VV[96]);
  goto L10;
L9:;
  v2lfs = ecl_cdr(v2lfs);
L10:;
  T0 = ecl_cdr(v2lfs);
  if ((T0)==(ecl_cmp_symbol_value(cl_env_copy,VV[95]))) {
   goto L14;
  }
  goto L9;
L14:;
  T0 = v2lfs;
  ecl_cmp_setq(cl_env_copy,VV[95],T0);
  T0 = ecl_car(v2lfs);
  (cl_env_copy->function=ecl_fdefinition(VV[97]))->cfun.entry(1, T0) /*  T3FUNCTION */;
 }
L4:;
 if ((ecl_cmp_symbol_value(cl_env_copy,VV[95]))==(ecl_cmp_symbol_value(cl_env_copy,VV[96]))) {
  goto L18;
 }
 goto L3;
L18:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 ecl_bds_unwind_n(cl_env_copy,4);
 return value0;
}
/* function definition for CTOP-WRITE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3805ctop_write(cl_object v1init_name, cl_object v2h_pathname, cl_object v3data_pathname)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4top_output_string;
  v4top_output_string = ECL_NIL;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[99]))->cfun.entry(1, v2h_pathname) /*  BRIEF-NAMESTRING */;
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[98], T0, VV[100]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[102]) /*  WT-NL-H */;
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[103]) /*  WT-NL-H */;
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[104]) /*  WT-NL-H */;
  {
   cl_object v5output;
   v5output = cl_make_string_output_stream(0);
   L3807t3entry_fun(v1init_name, v5output);
   L3804emit_functions(ecl_cmp_symbol_value(cl_env_copy,VV[28]));
   v4top_output_string = cl_get_output_stream_string(v5output);
  }
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[106]) /*  WT-NL-H */;
  {
   cl_object v5num_objects;
   v5num_objects = (cl_env_copy->function=ecl_fdefinition(VV[107]))->cfun.entry(0) /*  DATA-SIZE */;
   if (!(ecl_zerop(v5num_objects))){
    goto L15;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[108]) /*  WT-NL-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[109]) /*  WT-NL-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[110]) /*  WT-NL-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[111]) /*  WT-NL-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[112]) /*  WT-NL-H */;
   goto L13;
L15:;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[114]))->cfun.entry(0) /*  DATA-PERMANENT-STORAGE-SIZE */;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(2, VV[113], T0) /*  WT-NL-H */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[116]))->cfun.entry(0) /*  DATA-TEMPORARY-STORAGE-SIZE */;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(2, VV[115], T0) /*  WT-NL-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[117]) /*  WT-NL-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[118]) /*  WT-NL-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[119]) /*  WT-NL-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[120]) /*  WT-NL-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[121]) /*  WT-NL-H */;
  }
L13:;
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[122]) /*  WT-NL-H */;
  {
   cl_object v5;
   cl_object v6name;
   cl_object v7setf_vv;
   cl_object v8name_vv;
   cl_object v9;
   {
    cl_object v10;
    v10 = ecl_cmp_symbol_value(cl_env_copy,VV[17]);
    if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v10;
   }
   v6name = ECL_NIL;
   v7setf_vv = ECL_NIL;
   v8name_vv = ECL_NIL;
   v9 = v5;
L36:;
   if (!(ecl_endp(v9))){
    goto L38;
   }
   goto L37;
L38:;
   {
    cl_object v10;
    v10 = ECL_CONS_CAR(v9);
    v6name = ecl_car(v10);
    v10 = ecl_cdr(v10);
    v7setf_vv = ecl_car(v10);
    v10 = ecl_cdr(v10);
    v8name_vv = ecl_car(v10);
   }
   {
    cl_object v10;
    v10 = ECL_CONS_CDR(v9);
    if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v9 = v10;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[123]))->cfun.entry(6, ECL_CODE_CHAR(92), ECL_CODE_CHAR(10), v7setf_vv, VV[124], v8name_vv, VV[125]) /*  WT-H */;
   goto L36;
L37:;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[102]) /*  WT-NL-H */;
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[126]) /*  WT-NL-H */;
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[104]) /*  WT-NL-H */;
  if (ecl_cmp_symbol_value(cl_env_copy,VV[19])==ECL_NIL) {
   goto L60;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[127]) /*  WT-NL-H */;
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[128]) /*  WT-NL-H */;
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[129]) /*  WT-NL-H */;
  {
   cl_object v5;
   cl_object v6value;
   cl_object v7vv;
   cl_object v8builder;
   cl_object v9;
   {
    cl_object v10;
    v10 = cl_reverse(ecl_cmp_symbol_value(cl_env_copy,VV[19]));
    if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v10;
   }
   v6value = ECL_NIL;
   v7vv = ECL_NIL;
   v8builder = ECL_NIL;
   v9 = v5;
L72:;
   if (!(ecl_endp(v9))){
    goto L74;
   }
   goto L73;
L74:;
   {
    cl_object v10;
    v10 = ECL_CONS_CAR(v9);
    v6value = ecl_car(v10);
    v10 = ecl_cdr(v10);
    v7vv = ecl_car(v10);
    v10 = ecl_cdr(v10);
    v8builder = ecl_car(v10);
   }
   {
    cl_object v10;
    v10 = ECL_CONS_CDR(v9);
    if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v9 = v10;
   }
   (ecl_terpri(ecl_cmp_symbol_value(cl_env_copy,VV[29])));
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[130]))->cfun.entry(1, v7vv) /*  VV-LOCATION */;
   ecl_function_dispatch(cl_env_copy,v8builder)(3, T0, v6value, ecl_cmp_symbol_value(cl_env_copy,VV[29]));
   goto L72;
L73:;
  }
L60:;
  L3822output_cfuns(ecl_cmp_symbol_value(cl_env_copy,VV[29]));
  (cl_env_copy->function=ecl_fdefinition(VV[132]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[29])) /*  OUTPUT-CLINES */;
  T0 = VV[133];
  ecl_cmp_setq(cl_env_copy,VV[26],T0);
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[134]))){
   goto L98;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[135]) /*  WT-NL-H */;
  {
   cl_object v5;
   v5 = ecl_cmp_symbol_value(cl_env_copy,VV[134]);
   goto L104;
L103:;
   {
    cl_object v6x;
    v6x = ecl_car(v5);
    T0 = ecl_fdefinition(VV[136]);
    cl_apply(2, T0, v6x);
   }
   v5 = ecl_cdr(v5);
L104:;
   if (Null(v5)){
    goto L112;
   }
   goto L103;
L112:;
  }
L98:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[99]))->cfun.entry(1, v3data_pathname) /*  BRIEF-NAMESTRING */;
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[98], T0, VV[100]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[102]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[137]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[104]) /*  WT-NL */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, v4top_output_string) /*  WT-NL */;
  return value0;
 }
}
static cl_object L3805ctop_write_va(cl_narg narg, cl_object v5init_name, cl_object v6h_pathname, cl_object v7data_pathname, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[33]);
 {
  return L3805ctop_write(v5init_name, v6h_pathname, v7data_pathname);
 }
}
/* function definition for WT-FUNCTION-LOCALS                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3806wt_function_locals(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[139]);
 {
  cl_object v1closure_type;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1closure_type = ECL_NIL;
   } else {
    i++;
    v1closure_type = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (!(ecl_plusp(ecl_cmp_symbol_value(cl_env_copy,VV[140])))){
   goto L2;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[141]) /*  WT-NL */;
  {
   cl_object v2;
   v2 = ecl_cmp_symbol_value(cl_env_copy,VV[140]);
   {
    cl_object v3i;
    v3i = ecl_make_int8_t(0);
    goto L9;
L8:;
    (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(2, VV[143], v3i) /*  WT */;
    T0 = ecl_one_plus(v3i);
    if (ecl_number_equalp(T0,ecl_cmp_symbol_value(cl_env_copy,VV[140]))) {
     goto L12;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(1, VV[144]) /*  WT */;
L12:;
    v3i = ecl_one_plus(v3i);
L9:;
    if (!(ecl_lower(v3i,v2))){
     goto L16;
    }
    goto L8;
L16:;
   }
  }
  (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(1, VV[145]) /*  WT */;
L2:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[146]))){
   goto L18;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[147]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[148]) /*  WT-NL */;
L18:;
  if (!(ecl_plusp(ecl_cmp_symbol_value(cl_env_copy,VV[149])))){
   goto L21;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(5, VV[150], ecl_cmp_symbol_value(cl_env_copy,VV[151]), VV[152], ecl_cmp_symbol_value(cl_env_copy,VV[149]), VV[153]) /*  WT-NL */;
L21:;
  if ((v1closure_type)==(VV[154])) {
   goto L23;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[141], ecl_cmp_symbol_value(cl_env_copy,VV[155]), VV[156]) /*  WT-NL */;
L23:;
  if (!(ecl_plusp(ecl_cmp_symbol_value(cl_env_copy,VV[157])))){
   goto L25;
  }
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[158]))){
   goto L27;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[159]) /*  WT-NL */;
L27:;
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(2, VV[141], ecl_cmp_symbol_value(cl_env_copy,VV[155])) /*  WT-NL */;
  {
   cl_object v2;
   cl_object v3i;
   {
    cl_object v4;
    v4 = ecl_cmp_symbol_value(cl_env_copy,VV[157]);
    {
     bool v5;
     v5 = ecl_numberp(v4);
     if (ecl_unlikely(!(v5)))
         FEwrong_type_argument(ECL_SYM("NUMBER",608),v4);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
    v2 = v4;
   }
   v3i = ecl_make_int8_t(0);
   {
    cl_object v4comma;
    v4comma = ECL_NIL;
    if (!(ecl_greatereq(v3i,v2))){
     goto L37;
    }
    goto L36;
L37:;
    v4comma = VV[160];
L35:;
    (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(3, v4comma, VV[161], v3i) /*  WT */;
    v3i = ecl_one_plus(v3i);
    if (!(ecl_greatereq(v3i,v2))){
     goto L44;
    }
    goto L36;
L44:;
    v4comma = VV[144];
    goto L35;
L36:;
    (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(1, VV[145]) /*  WT */;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
L25:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for T3ENTRY-FUN                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3807t3entry_fun(cl_object volatile v1name, cl_object volatile v2_compiler_output1_)
{
 cl_object T0, T1;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 ecl_bds_bind(cl_env_copy,VV[28],v2_compiler_output1_); /*  *COMPILER-OUTPUT1* */
L1:;
 ecl_bds_bind(cl_env_copy,VV[165],ecl_make_int8_t(0)); /*  *LCL*              */
 ecl_bds_bind(cl_env_copy,VV[166],ecl_make_int8_t(0)); /*  *TEMP*             */
 ecl_bds_bind(cl_env_copy,VV[140],ecl_make_int8_t(0)); /*  *MAX-TEMP*         */
 ecl_bds_bind(cl_env_copy,VV[167],ecl_make_int8_t(0)); /*  *LEX*              */
 ecl_bds_bind(cl_env_copy,VV[149],ecl_make_int8_t(0)); /*  *MAX-LEX*          */
 ecl_bds_bind(cl_env_copy,VV[168],ecl_make_int8_t(0)); /*  *ENV-LVL*          */
 ecl_bds_bind(cl_env_copy,VV[169],ecl_make_int8_t(0)); /*  *ENV*              */
 ecl_bds_bind(cl_env_copy,VV[157],ecl_cmp_symbol_value(cl_env_copy,VV[169])); /*  *MAX-ENV* */
 ecl_bds_bind(cl_env_copy,VV[151],ecl_make_int8_t(0)); /*  *LEVEL*            */
 ecl_bds_bind(cl_env_copy,VV[170],ecl_make_int8_t(0)); /*  *LAST-LABEL*       */
 ecl_bds_bind(cl_env_copy,VV[155],VV[171]);       /*  *VOLATILE*              */
 ecl_bds_bind(cl_env_copy,VV[146],ECL_NIL);       /*  *IHS-USED-P*            */
 ecl_bds_bind(cl_env_copy,VV[158],ECL_NIL);       /*  *AUX-CLOSURE*           */
 ecl_bds_bind(cl_env_copy,VV[66],VV[172]);        /*  *EXIT*                  */
 ecl_bds_bind(cl_env_copy,VV[68],VV[173]);        /*  *UNWIND-EXIT*           */
 ecl_bds_bind(cl_env_copy,VV[69],ecl_cmp_symbol_value(cl_env_copy,VV[66])); /*  *DESTINATION* */
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[174], v1name, VV[175]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[176]))->cfun.entry(0) /*  WT-NL-OPEN-BRACE */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[177]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[178]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[179]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[180]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[181]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[182]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[183]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[104]) /*  WT-NL */;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[184]))){
  goto L12;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[185]) /*  WT-NL */;
L12:;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[186]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[187]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[188]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[189]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[190]) /*  WT-NL */;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*SOURCE-LOCATION*",1210)))){
  goto L19;
 }
 T0 = ecl_car(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*SOURCE-LOCATION*",1210)));
 T1 = cl_namestring(T0);
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[191], T1, VV[192]) /*  WT-NL */;
L19:;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[193]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[194]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[195]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[104]) /*  WT-NL */;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[197]))->cfun.entry(1, v1name) /*  INIT-NAME-TAG */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[196], T0, VV[198]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[199]) /*  WT-NL */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[200]) /*  WT-NL */;
 {
  volatile cl_object v3body;
  T0 = ecl_one_plus(ecl_cmp_symbol_value(cl_env_copy,VV[13]));
  ecl_bds_bind(cl_env_copy,VV[13],T0);            /*  *OPENED-C-BRACES*       */
  T0 = cl_make_string_output_stream(0);
  ecl_bds_bind(cl_env_copy,VV[28],T0);            /*  *COMPILER-OUTPUT1*      */
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    (ecl_terpri(ecl_cmp_symbol_value(cl_env_copy,VV[28])));
    (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(1, VV[201]) /*  WT-COMMENT-NL */;
    {
     cl_object v4;
     v4 = ecl_cmp_symbol_value(cl_env_copy,VV[202]);
     goto L37;
L36:;
     {
      cl_object v5form;
      v5form = ecl_car(v4);
      L3795t2expr(v5form);
     }
     v4 = ecl_cdr(v4);
L37:;
     if (Null(v4)){
      goto L44;
     }
     goto L36;
L44:;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(1, VV[203]) /*  WT-COMMENT-NL */;
    {
     cl_object v4;
     v4 = ecl_cmp_symbol_value(cl_env_copy,VV[204]);
     goto L51;
L50:;
     {
      cl_object v5form;
      v5form = ecl_car(v4);
      L3795t2expr(v5form);
     }
     v4 = ecl_cdr(v4);
L51:;
     if (Null(v4)){
      goto L58;
     }
     goto L50;
L58:;
    }
    cl_env_copy->values[0] = cl_get_output_stream_string(ecl_cmp_symbol_value(cl_env_copy,VV[28]));
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   cl_close(1, ecl_cmp_symbol_value(cl_env_copy,VV[28]));
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   v3body = cl_env_copy->values[0];
   ecl_stack_frame_close(_ecl_inner_frame);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
  }
  if (ecl_plusp(ecl_cmp_symbol_value(cl_env_copy,VV[149]))) {
   goto L63;
  }
  if (ecl_plusp(ecl_cmp_symbol_value(cl_env_copy,VV[140]))) {
   goto L63;
  }
  if (ecl_plusp(ecl_cmp_symbol_value(cl_env_copy,VV[157]))) {
   goto L63;
  }
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[146]))){
   goto L61;
  }
  goto L62;
L63:;
L62:;
  {
   cl_object v4;
   cl_object v5;
   v4 = ecl_cmp_symbol_value(cl_env_copy,VV[166]);
   v5 = ecl_cmp_symbol_value(cl_env_copy,VV[165]);
   ecl_bds_bind(cl_env_copy,VV[14],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*   */
   ecl_bds_bind(cl_env_copy,VV[166],v4);          /*  *TEMP*                  */
   ecl_bds_bind(cl_env_copy,VV[165],v5);          /*  *LCL*                   */
   (cl_env_copy->function=ecl_fdefinition(VV[207]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
   L3806wt_function_locals(0);
   cl_write_sequence(2, v3body, ecl_cmp_symbol_value(cl_env_copy,VV[28]));
   (cl_env_copy->function=ecl_fdefinition(VV[208]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   goto L28;
  }
L61:;
  cl_write_sequence(2, v3body, ecl_cmp_symbol_value(cl_env_copy,VV[28]));
 }
L28:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[209]))->cfun.entry(1, ecl_make_int8_t(0)) /*  WT-NL-CLOSE-MANY-BRACES */;
 ecl_bds_unwind_n(cl_env_copy,17);
 return value0;
}
static cl_object L3807t3entry_fun_va(cl_narg narg, cl_object v3name, cl_object v4_compiler_output1_, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[105]);
 {
  return L3807t3entry_fun(v3name, v4_compiler_output1_);
 }
}
/* function definition for T3CALLBACK                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3808t3callback(cl_object v1lisp_name, cl_object v2c_name, cl_object v3c_name_constant, cl_object v4return_type, cl_object v5return_type_code, cl_object v6arg_types, cl_object v7arg_type_constants, cl_object v8call_type)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v9return_p;
  v9return_p = ECL_T;
  ecl_bds_bind(cl_env_copy,VV[165],ecl_make_int8_t(0)); /*  *LCL*             */
  ecl_bds_bind(cl_env_copy,VV[166],ecl_make_int8_t(0)); /*  *TEMP*            */
  ecl_bds_bind(cl_env_copy,VV[140],ecl_make_int8_t(0)); /*  *MAX-TEMP*        */
  ecl_bds_bind(cl_env_copy,VV[167],ecl_make_int8_t(0)); /*  *LEX*             */
  ecl_bds_bind(cl_env_copy,VV[149],ecl_make_int8_t(0)); /*  *MAX-LEX*         */
  ecl_bds_bind(cl_env_copy,VV[168],ecl_make_int8_t(0)); /*  *ENV-LVL*         */
  ecl_bds_bind(cl_env_copy,VV[169],ecl_make_int8_t(0)); /*  *ENV*             */
  ecl_bds_bind(cl_env_copy,VV[157],ecl_cmp_symbol_value(cl_env_copy,VV[169])); /*  *MAX-ENV* */
  ecl_bds_bind(cl_env_copy,VV[151],ecl_make_int8_t(0)); /*  *LEVEL*           */
  ecl_bds_bind(cl_env_copy,VV[170],ecl_make_int8_t(0)); /*  *LAST-LABEL*      */
  ecl_bds_bind(cl_env_copy,VV[155],VV[171]);      /*  *VOLATILE*              */
  ecl_bds_bind(cl_env_copy,VV[146],ECL_NIL);      /*  *IHS-USED-P*            */
  ecl_bds_bind(cl_env_copy,VV[158],ECL_NIL);      /*  *AUX-CLOSURE*           */
  ecl_bds_bind(cl_env_copy,VV[66],VV[172]);       /*  *EXIT*                  */
  ecl_bds_bind(cl_env_copy,VV[68],VV[173]);       /*  *UNWIND-EXIT*           */
  ecl_bds_bind(cl_env_copy,VV[69],ecl_cmp_symbol_value(cl_env_copy,VV[66])); /*  *DESTINATION* */
  if (!((v4return_type)==(ECL_SYM("VOID",1424)))){
   goto L3;
  }
  v9return_p = ECL_NIL;
L3:;
  {
   cl_object v10;
   cl_object v11;
   cl_object v12;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[212]))->cfun.entry(1, v4return_type) /*  %CONVERT-TO-ARG-TYPE */;
   v10 = (cl_env_copy->function=ecl_fdefinition(VV[211]))->cfun.entry(1, T0) /*  HOST-TYPE->C-NAME */;
   {
    cl_object v13;
    cl_object v14n;
    v13 = ecl_make_fixnum(ecl_length(v6arg_types));
    v14n = ecl_make_int8_t(0);
    {
     cl_object v15;
     cl_object v16;
     v15 = ecl_list1(ECL_NIL);
     v16 = v15;
L12:;
     if (!(ecl_greatereq(v14n,v13))){
      goto L14;
     }
     goto L13;
L14:;
     {
      cl_object v17;
      v17 = v16;
      if (ecl_unlikely(ECL_ATOM(v17))) FEtype_error_cons(v17);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v17;
     }
     T1 = cl_format(3, ECL_NIL, VV[215], v14n);
     v16 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v16,T0);
     v14n = ecl_one_plus(v14n);
     goto L12;
L13:;
     v11 = ecl_cdr(v15);
     goto L7;
    }
   }
L7:;
   if (!((v8call_type)==(ECL_SYM("CDECL",1809)))){
    goto L31;
   }
   goto L28;
L31:;
   goto L29;
L29:;
   if (!((v8call_type)==(ECL_SYM("DEFAULT",1246)))){
    goto L26;
   }
   goto L27;
L28:;
L27:;
   v12 = VV[160];
   goto L25;
L26:;
   if (!((v8call_type)==(ECL_SYM("STDCALL",1812)))){
    goto L34;
   }
   v12 = VV[219];
   goto L25;
L34:;
   v12 = (cl_env_copy->function=ecl_fdefinition(VV[53]))->cfun.entry(2, VV[220], v8call_type) /*  CMPERR */;
L25:;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(6, VV[221], v10, VV[222], v12, v2c_name, VV[223]) /*  WT-NL-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[30]))->cfun.entry(6, VV[221], v10, VV[222], v12, v2c_name, VV[223]) /*  WT-NL1 */;
   {
    cl_object v13comma;
    v13comma = VV[160];
    {
     cl_object v14;
     cl_object v15var;
     cl_object v16;
     {
      cl_object v17;
      v17 = v11;
      if (ecl_unlikely(!ECL_LISTP(v17))) FEtype_error_list(v17);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v14 = v17;
     }
     v15var = ECL_NIL;
     v16 = v14;
     {
      cl_object v17;
      cl_object v18type;
      cl_object v19;
      {
       cl_object v20;
       v20 = v6arg_types;
       if (ecl_unlikely(!ECL_LISTP(v20))) FEtype_error_list(v20);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v17 = v20;
      }
      v18type = ECL_NIL;
      v19 = v17;
      {
       cl_object v20arg_type_name;
       v20arg_type_name = ECL_NIL;
L51:;
       if (!(ecl_endp(v16))){
        goto L53;
       }
       goto L52;
L53:;
       v15var = ECL_CONS_CAR(v16);
       {
        cl_object v21;
        v21 = ECL_CONS_CDR(v16);
        if (ecl_unlikely(!ECL_LISTP(v21))) FEtype_error_list(v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v16 = v21;
       }
       if (!(ecl_endp(v19))){
        goto L61;
       }
       goto L52;
L61:;
       v18type = ECL_CONS_CAR(v19);
       {
        cl_object v21;
        v21 = ECL_CONS_CDR(v19);
        if (ecl_unlikely(!ECL_LISTP(v21))) FEtype_error_list(v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v19 = v21;
       }
       T0 = (cl_env_copy->function=ecl_fdefinition(VV[212]))->cfun.entry(1, v18type) /*  %CONVERT-TO-ARG-TYPE */;
       v20arg_type_name = (cl_env_copy->function=ecl_fdefinition(VV[211]))->cfun.entry(1, T0) /*  HOST-TYPE->C-NAME */;
       (cl_env_copy->function=ecl_fdefinition(VV[123]))->cfun.entry(4, v13comma, v20arg_type_name, VV[222], v15var) /*  WT-H */;
       (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(4, v13comma, v20arg_type_name, VV[222], v15var) /*  WT */;
       v13comma = VV[224];
       goto L51;
L52:;
      }
     }
    }
   }
   (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(1, VV[225]) /*  WT */;
   (cl_env_copy->function=ecl_fdefinition(VV[123]))->cfun.entry(1, VV[226]) /*  WT-H */;
   {
    cl_object v13;
    cl_object v14;
    v13 = ecl_cmp_symbol_value(cl_env_copy,VV[166]);
    v14 = ecl_cmp_symbol_value(cl_env_copy,VV[165]);
    ecl_bds_bind(cl_env_copy,VV[14],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*  */
    ecl_bds_bind(cl_env_copy,VV[166],v13);        /*  *TEMP*                  */
    ecl_bds_bind(cl_env_copy,VV[165],v14);        /*  *LCL*                   */
    (cl_env_copy->function=ecl_fdefinition(VV[207]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
    if (Null(v9return_p)){
     goto L81;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(2, v10, VV[227]) /*  WT-NL */;
L81:;
    (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[177]) /*  WT-NL */;
    (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[228]) /*  WT-NL */;
    {
     cl_object v15;
     cl_object v16;
     v15 = ecl_cmp_symbol_value(cl_env_copy,VV[166]);
     v16 = ecl_cmp_symbol_value(cl_env_copy,VV[165]);
     ecl_bds_bind(cl_env_copy,VV[14],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS* */
     ecl_bds_bind(cl_env_copy,VV[166],v15);       /*  *TEMP*                  */
     ecl_bds_bind(cl_env_copy,VV[165],v16);       /*  *LCL*                   */
     (cl_env_copy->function=ecl_fdefinition(VV[207]))->cfun.entry(0) /*  OPEN-INLINE-BLOCK */;
     T0 = cl_list(2, VV[232], VV[230]);
     T1 = CONS(T0,ecl_cmp_symbol_value(cl_env_copy,VV[68]));
     ecl_bds_bind(cl_env_copy,VV[68],T1);         /*  *UNWIND-EXIT*           */
     (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[233], VV[231], VV[145]) /*  WT-NL */;
     (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(6, ecl_cmp_symbol_value(cl_env_copy,VV[155]), VV[141], VV[230], VV[234], VV[231], VV[235]) /*  WT-NL */;
     {
      cl_object v17;
      cl_object v18;
      cl_object v19;
      cl_object v20var;
      cl_object v21;
      cl_object v22type;
      cl_object v23;
      cl_object v24ct;
      cl_object v25;
      {
       cl_object v26;
       v26 = v11;
       if (ecl_unlikely(!ECL_LISTP(v26))) FEtype_error_list(v26);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v17 = v26;
      }
      {
       cl_object v26;
       v26 = v6arg_types;
       if (ecl_unlikely(!ECL_LISTP(v26))) FEtype_error_list(v26);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v18 = v26;
      }
      {
       cl_object v26;
       v26 = v7arg_type_constants;
       if (ecl_unlikely(!ECL_LISTP(v26))) FEtype_error_list(v26);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v19 = v26;
      }
      v20var = ECL_NIL;
      v21 = v17;
      v22type = ECL_NIL;
      v23 = v18;
      v24ct = ECL_NIL;
      v25 = v19;
L108:;
      if (ecl_endp(v21)) {
       goto L112;
      }
      if (ecl_endp(v23)) {
       goto L112;
      }
      if (!(ecl_endp(v25))){
       goto L110;
      }
      goto L111;
L112:;
L111:;
      goto L109;
L110:;
      {
       cl_object v26;
       v26 = ECL_CONS_CAR(v21);
       {
        cl_object v27;
        v27 = ECL_CONS_CAR(v23);
        v24ct = ECL_CONS_CAR(v25);
        v22type = v27;
       }
       v20var = v26;
      }
      {
       cl_object v26;
       v26 = ECL_CONS_CDR(v21);
       if (ecl_unlikely(!ECL_LISTP(v26))) FEtype_error_list(v26);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v21 = v26;
      }
      {
       cl_object v26;
       v26 = ECL_CONS_CDR(v23);
       if (ecl_unlikely(!ECL_LISTP(v26))) FEtype_error_list(v26);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v23 = v26;
      }
      {
       cl_object v26;
       v26 = ECL_CONS_CDR(v25);
       if (ecl_unlikely(!ECL_LISTP(v26))) FEtype_error_list(v26);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v25 = v26;
      }
      T0 = cl_list(3, VV[237], v20var, v24ct);
      (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(5, VV[236], VV[230], VV[224], T0, VV[226]) /*  WT-NL */;
      goto L108;
L109:;
     }
     (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(6, VV[238], VV[230], VV[224], VV[239], v3c_name_constant, VV[240]) /*  WT-NL */;
     (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[241], VV[230], VV[226]) /*  WT-NL */;
     ecl_bds_unwind1(cl_env_copy);
     (cl_env_copy->function=ecl_fdefinition(VV[208]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
     ecl_bds_unwind1(cl_env_copy);
     ecl_bds_unwind1(cl_env_copy);
     ecl_bds_unwind1(cl_env_copy);
    }
    if (Null(v9return_p)){
     goto L138;
    }
    T0 = cl_list(3, VV[237], VV[243], v5return_type_code);
    (cl_env_copy->function=ecl_fdefinition(VV[242]))->cfun.entry(2, T0, VV[244]) /*  SET-LOC */;
    (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[245]) /*  WT-NL */;
L138:;
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[208]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
    ecl_bds_unwind_n(cl_env_copy,19);
    return value0;
   }
  }
 }
}
static cl_object L3808t3callback_va(cl_narg narg, cl_object v15lisp_name, cl_object v16c_name, cl_object v17c_name_constant, cl_object v18return_type, cl_object v19return_type_code, cl_object v20arg_types, cl_object v21arg_type_constants, cl_object v22call_type, ...)
{
 if (ecl_unlikely(narg!=8)) FEwrong_num_arguments(VV[136]);
 {
  return L3808t3callback(v15lisp_name, v16c_name, v17c_name_constant, v18return_type, v19return_type_code, v20arg_types, v21arg_type_constants, v22call_type);
 }
}
/* function definition for T3FUNCTION                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3809t3function(cl_object v1fun)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*COMPILE-PRINT*",30)))){
  goto L2;
 }
 {
  cl_object v2name;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[86]))->cfun.entry(1, v1fun) /*  FUN-NAME */;
  if (value0!=ECL_NIL) {
   goto L6;
  }
  v2name = (cl_env_copy->function=ecl_fdefinition(VV[247]))->cfun.entry(1, v1fun) /*  FUN-DESCRIPTION */;
  goto L4;
L6:;
  v2name = value0;
  goto L4;
L4:;
  if (Null(v2name)){
   goto L2;
  }
  cl_format(3, ECL_T, VV[248], v2name);
 }
L2:;
 {
  cl_object v2lambda_expr;
  v2lambda_expr = (cl_env_copy->function=ecl_fdefinition(VV[249]))->cfun.entry(1, v1fun) /*  FUN-LAMBDA */;
  ecl_bds_bind(cl_env_copy,VV[40],v2lambda_expr); /*  *CURRENT-C1FORM*        */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, v2lambda_expr) /*  C1FORM-FILE */;
  ecl_bds_bind(cl_env_copy,ECL_SYM("*COMPILE-FILE-TRUENAME*",29),T0); /*  *COMPILE-FILE-TRUENAME* */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[43]))->cfun.entry(1, v2lambda_expr) /*  C1FORM-FILE-POSITION */;
  ecl_bds_bind(cl_env_copy,VV[42],T0);            /*  *COMPILE-FILE-POSITION* */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[45]))->cfun.entry(1, v2lambda_expr) /*  C1FORM-TOPLEVEL-FORM */;
  ecl_bds_bind(cl_env_copy,VV[44],T0);            /*  *CURRENT-TOPLEVEL-FORM* */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[47]))->cfun.entry(1, v2lambda_expr) /*  C1FORM-FORM */;
  ecl_bds_bind(cl_env_copy,VV[46],T0);            /*  *CURRENT-FORM*          */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[49]))->cfun.entry(1, v2lambda_expr) /*  C1FORM-ENV */;
  ecl_bds_bind(cl_env_copy,VV[48],T0);            /*  *CMP-ENV*               */
  ecl_bds_bind(cl_env_copy,VV[250],v1fun);        /*  *TAIL-RECURSION-INFO*   */
  ecl_bds_bind(cl_env_copy,VV[251],ECL_NIL);      /*  *TAIL-RECURSION-MARK*   */
  ecl_bds_bind(cl_env_copy,VV[165],ecl_make_int8_t(0)); /*  *LCL*             */
  ecl_bds_bind(cl_env_copy,VV[166],ecl_make_int8_t(0)); /*  *TEMP*            */
  ecl_bds_bind(cl_env_copy,VV[140],ecl_make_int8_t(0)); /*  *MAX-TEMP*        */
  ecl_bds_bind(cl_env_copy,VV[167],ecl_make_int8_t(0)); /*  *LEX*             */
  ecl_bds_bind(cl_env_copy,VV[149],ecl_make_int8_t(0)); /*  *MAX-LEX*         */
  ecl_bds_bind(cl_env_copy,VV[168],ecl_make_int8_t(0)); /*  *ENV-LVL*         */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[252]))->cfun.entry(1, v1fun) /*  FUN-ENV */;
  ecl_bds_bind(cl_env_copy,VV[169],T0);           /*  *ENV*                   */
  ecl_bds_bind(cl_env_copy,VV[157],ecl_cmp_symbol_value(cl_env_copy,VV[169])); /*  *MAX-ENV* */
  T0 = L3820fun_lexical_levels(v1fun);
  ecl_bds_bind(cl_env_copy,VV[151],T0);           /*  *LEVEL*                 */
  ecl_bds_bind(cl_env_copy,VV[170],ecl_make_int8_t(0)); /*  *LAST-LABEL*      */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[254]))->cfun.entry(1, v2lambda_expr) /*  C1FORM-VOLATILE* */;
  ecl_bds_bind(cl_env_copy,VV[155],T0);           /*  *VOLATILE*              */
  ecl_bds_bind(cl_env_copy,VV[146],ECL_NIL);      /*  *IHS-USED-P*            */
  ecl_bds_bind(cl_env_copy,VV[158],ECL_NIL);      /*  *AUX-CLOSURE*           */
  ecl_bds_bind(cl_env_copy,VV[66],VV[172]);       /*  *EXIT*                  */
  ecl_bds_bind(cl_env_copy,VV[68],VV[173]);       /*  *UNWIND-EXIT*           */
  ecl_bds_bind(cl_env_copy,VV[69],ecl_cmp_symbol_value(cl_env_copy,VV[66])); /*  *DESTINATION* */
  L3817t3function_declaration(v1fun);
  (cl_env_copy->function=ecl_fdefinition(VV[176]))->cfun.entry(0) /*  WT-NL-OPEN-BRACE */;
  {
   cl_object v3body;
   v3body = L3810t3function_body(v1fun);
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v1fun) /*  FUN-CLOSURE */;
   L3806wt_function_locals(1, T0);
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[177]) /*  WT-NL */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v1fun) /*  FUN-CLOSURE */;
   if (!((T0)==(VV[154]))){
    goto L16;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[141], ecl_cmp_symbol_value(cl_env_copy,VV[155]), VV[257]) /*  WT-NL */;
L16:;
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[141], ecl_cmp_symbol_value(cl_env_copy,VV[155]), VV[258]) /*  WT-NL */;
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[259]))->cfun.entry(0) /*  POLICY-CHECK-STACK-OVERFLOW */)){
    goto L19;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[260]) /*  WT-NL */;
L19:;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v1fun) /*  FUN-CLOSURE */;
   if (!((T0)==(VV[154]))){
    goto L21;
   }
   L3821t3function_closure_scan(v1fun);
L21:;
   cl_write_sequence(2, v3body, ecl_cmp_symbol_value(cl_env_copy,VV[28]));
   (cl_env_copy->function=ecl_fdefinition(VV[209]))->cfun.entry(1, ecl_make_int8_t(0)) /*  WT-NL-CLOSE-MANY-BRACES */;
  }
  if (Null(L3812fun_variadic_entrypoint(v1fun))){
   goto L24;
  }
  value0 = L3814t3function_variadic_entrypoint(v1fun);
  ecl_bds_unwind_n(cl_env_copy,24);
  return value0;
L24:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind_n(cl_env_copy,24);
  return value0;
 }
}
static cl_object L3809t3function_va(cl_narg narg, cl_object v3fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[97]);
 {
  return L3809t3function(v3fun);
 }
}
/* function definition for T3FUNCTION-BODY                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3810t3function_body(cl_object volatile v1fun)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v2string;
  v2string = si_make_vector(ECL_SYM("CHARACTER",224), ecl_make_fixnum(2048), ECL_T, ecl_make_int8_t(0), ECL_NIL, ecl_make_int8_t(0));
  {
   volatile cl_object v3;
   v3 = si_make_string_output_stream_from_string(v2string);
   ecl_bds_bind(cl_env_copy,VV[28],v3);           /*  *COMPILER-OUTPUT1*      */
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    volatile bool unwinding = FALSE;
    ecl_frame_ptr next_fr;
    {
     ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
     if (__ecl_frs_push_result!=0) {
       unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
     } else {
     {
      cl_object v4lambda_expr;
      v4lambda_expr = (cl_env_copy->function=ecl_fdefinition(VV[249]))->cfun.entry(1, v1fun) /*  FUN-LAMBDA */;
      T0 = (cl_env_copy->function=ecl_fdefinition(VV[51]))->cfun.entry(1, v4lambda_expr) /*  C1FORM-ARGS */;
      T1 = ecl_car(T0);
      T2 = (cl_env_copy->function=ecl_fdefinition(VV[51]))->cfun.entry(1, v4lambda_expr) /*  C1FORM-ARGS */;
      T3 = ecl_caddr(T2);
      T4 = (cl_env_copy->function=ecl_fdefinition(VV[267]))->cfun.entry(1, v1fun) /*  FUN-CFUN */;
      T5 = (cl_env_copy->function=ecl_fdefinition(VV[86]))->cfun.entry(1, v1fun) /*  FUN-NAME */;
      T6 = (cl_env_copy->function=ecl_fdefinition(VV[247]))->cfun.entry(1, v1fun) /*  FUN-DESCRIPTION */;
      T7 = (cl_env_copy->function=ecl_fdefinition(VV[268]))->cfun.entry(1, v1fun) /*  FUN-NEEDS-NARG */;
      T8 = (cl_env_copy->function=ecl_fdefinition(VV[269]))->cfun.entry(1, v1fun) /*  FUN-REQUIRED-LCLS */;
      T9 = (cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v1fun) /*  FUN-CLOSURE */;
      T10 = (cl_env_copy->function=ecl_fdefinition(VV[270]))->cfun.entry(1, v1fun) /*  FUN-OPTIONAL-TYPE-CHECK-FORMS */;
      T11 = (cl_env_copy->function=ecl_fdefinition(VV[271]))->cfun.entry(1, v1fun) /*  FUN-KEYWORD-TYPE-CHECK-FORMS */;
      T12 = L3811fun_c_compatible_variadic_signature(v1fun);
      cl_env_copy->values[0] = (cl_env_copy->function=ecl_fdefinition(VV[265]))->cfun.entry(11, T1, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12) /*  C2LAMBDA-EXPR */;
     }
     }
    }
    ecl_frs_pop(cl_env_copy);
    ecl_stack_frame_push_values(_ecl_inner_frame);
    cl_close(1, ecl_cmp_symbol_value(cl_env_copy,VV[28]));
    ecl_stack_frame_pop_values(_ecl_inner_frame);
    if (unwinding) ecl_unwind(cl_env_copy,next_fr);
    ecl_stack_frame_close(_ecl_inner_frame);
    ecl_bds_unwind1(cl_env_copy);
   }
  }
  value0 = v2string;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3810t3function_body_va(cl_narg narg, cl_object v3fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[256]);
 {
  return L3810t3function_body(v3fun);
 }
}
/* function definition for FUN-C-COMPATIBLE-VARIADIC-SIGNATURE                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3811fun_c_compatible_variadic_signature(cl_object v1fun)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[274]))){
  goto L3;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[268]))->cfun.entry(1, v1fun) /*  FUN-NEEDS-NARG */)){
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v1fun) /*  FUN-CLOSURE */;
 if ((T0)==(VV[275])) {
  goto L3;
 }
 if ((cl_env_copy->function=ecl_fdefinition(VV[82]))->cfun.entry(1, v1fun) /*  FUN-NO-ENTRY */!=ECL_NIL) {
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[276]))->cfun.entry(1, v1fun) /*  FUN-EXPORTED */;
 value0 = Null(T0)?ECL_T:ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3811fun_c_compatible_variadic_signature_va(cl_narg narg, cl_object v2fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[272]);
 {
  return L3811fun_c_compatible_variadic_signature(v2fun);
 }
}
/* function definition for FUN-VARIADIC-ENTRYPOINT                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3812fun_variadic_entrypoint(cl_object v1fun)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2result;
  v2result = (cl_env_copy->function=ecl_fdefinition(VV[278]))->cfun.entry(1, v1fun) /*  FUN-VARIADIC-ENTRYPOINT-CFUN */;
  if ((v2result)==(VV[279])) {
   goto L3;
  }
  value0 = v2result;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  {
   cl_object v3;
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[280]))->cfun.entry(0) /*  POLICY-INLINE-NARGS-CHECK */)){
    goto L7;
   }
   if ((cl_env_copy->function=ecl_fdefinition(VV[82]))->cfun.entry(1, v1fun) /*  FUN-NO-ENTRY */!=ECL_NIL) {
    goto L7;
   }
   if ((cl_env_copy->function=ecl_fdefinition(VV[268]))->cfun.entry(1, v1fun) /*  FUN-NEEDS-NARG */!=ECL_NIL) {
    goto L7;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v1fun) /*  FUN-CLOSURE */;
   if ((T0)==(VV[275])) {
    goto L7;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[267]))->cfun.entry(1, v1fun) /*  FUN-CFUN */;
   v3 = cl_concatenate(3, ECL_SYM("STRING",808), T0, VV[281]);
   goto L5;
L7:;
   v3 = ECL_NIL;
   goto L5;
L5:;
   value0 = ecl_structure_set(v1fun,VV[282],(cl_fixnum)(6),v3);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3812fun_variadic_entrypoint_va(cl_narg narg, cl_object v4fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[262]);
 {
  return L3812fun_variadic_entrypoint(v4fun);
 }
}
/* function definition for T3FUNCTION-VARIADIC-ENTRYPOINT                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3814t3function_variadic_entrypoint(cl_object v1fun)
{
 cl_object T0, T1, T2;
 volatile cl_object lex0[1];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 lex0[0] = v1fun;                                 /*  FUN                     */
L1:;
 ecl_bds_bind(cl_env_copy,VV[155],VV[160]);       /*  *VOLATILE*              */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[278]))->cfun.entry(1, lex0[0]) /*  FUN-VARIADIC-ENTRYPOINT-CFUN */;
 L3816t3function_header(4, lex0[0], T0, ECL_T, ecl_cmp_symbol_value(cl_env_copy,VV[274]));
 ecl_bds_unwind1(cl_env_copy);
 (cl_env_copy->function=ecl_fdefinition(VV[176]))->cfun.entry(0) /*  WT-NL-OPEN-BRACE */;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[289]))->cfun.entry(1, lex0[0]) /*  FUN-MINARG */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[290]))->cfun.entry(1, lex0[0]) /*  FUN-MAXARG */;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[86]))->cfun.entry(1, lex0[0]) /*  FUN-NAME */;
 (cl_env_copy->function=ecl_fdefinition(VV[288]))->cfun.entry(4, ECL_T, T0, T1, T2) /*  WT-MAYBE-CHECK-NUM-ARGUMENTS */;
 if (ecl_cmp_symbol_value(cl_env_copy,VV[274])!=ECL_NIL) {
  goto L5;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[269]))->cfun.entry(1, lex0[0]) /*  FUN-REQUIRED-LCLS */;
 value0 = LC3813wt_return(lex0, T0);
 return value0;
L5:;
 {
  cl_object v2maxargs;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[290]))->cfun.entry(1, lex0[0]) /*  FUN-MAXARG */;
  T1 = ecl_make_integer((ecl_fixnum(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("C-ARGUMENTS-LIMIT",1056))))+1);
  v2maxargs = ((ecl_float_nan_p(T1) || ecl_lowereq(T0,T1))?T0:T1);
  if (!(ecl_plusp(v2maxargs))){
   goto L8;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[291], v2maxargs, VV[153]) /*  WT-NL */;
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[292]) /*  WT-NL */;
  {
   cl_object v3;
   cl_object v4i;
   v3 = v2maxargs;
   v4i = ecl_make_int8_t(0);
L15:;
   if (!(ecl_greatereq(v4i,v3))){
    goto L17;
   }
   goto L16;
L17:;
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[293], v4i, VV[294]) /*  WT-NL */;
   (cl_env_copy->function=ecl_fdefinition(VV[295]))->cfun.entry(2, ECL_SYM("OBJECT",1315), VV[296]) /*  WT-COERCE-LOC */;
   (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(1, VV[145]) /*  WT */;
   v4i = ecl_one_plus(v4i);
   goto L15;
L16:;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[297]) /*  WT-NL */;
L8:;
  {
   cl_object v3args;
   {
    cl_object v4;
    cl_object v5i;
    v4 = v2maxargs;
    v5i = ecl_make_int8_t(0);
    {
     cl_object v6;
     cl_object v7;
     v6 = ecl_list1(ECL_NIL);
     v7 = v6;
L30:;
     if (!(ecl_greatereq(v5i,v4))){
      goto L32;
     }
     goto L31;
L32:;
     {
      cl_object v8;
      v8 = v7;
      if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v8;
     }
     T1 = cl_write_to_string(1, v5i);
     T2 = cl_concatenate(4, ECL_SYM("STRING",808), VV[293], T1, VV[298]);
     v7 = ecl_list1(T2);
     (ECL_CONS_CDR(T0)=v7,T0);
     v5i = ecl_one_plus(v5i);
     goto L30;
L31:;
     v3args = ecl_cdr(v6);
     goto L25;
    }
   }
L25:;
   value0 = LC3813wt_return(lex0, v3args);
   return value0;
  }
 }
}
static cl_object L3814t3function_variadic_entrypoint_va(cl_narg narg, cl_object v4fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[263]);
 {
  return L3814t3function_variadic_entrypoint(v4fun);
 }
}
/* function definition for FUN-FIXED-NARG-MAIN-ENTRYPOINT                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3815fun_fixed_narg_main_entrypoint(cl_object v1fun)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[274]))){
  goto L2;
 }
 if (L3812fun_variadic_entrypoint(v1fun)!=ECL_NIL) {
  goto L5;
 }
 if (Null(L3811fun_c_compatible_variadic_signature(v1fun))){
  goto L2;
 }
 goto L3;
L5:;
L3:;
 value0 = ecl_make_int8_t(0);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[289]))->cfun.entry(1, v1fun) /*  FUN-MINARG */;
 value0 = ((ecl_float_nan_p(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("C-ARGUMENTS-LIMIT",1056))) || ecl_lowereq(T0,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("C-ARGUMENTS-LIMIT",1056))))?T0:ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("C-ARGUMENTS-LIMIT",1056)));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3815fun_fixed_narg_main_entrypoint_va(cl_narg narg, cl_object v2fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[300]);
 {
  return L3815fun_fixed_narg_main_entrypoint(v2fun);
 }
}
/* function definition for T3FUNCTION-HEADER                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3816t3function_header(cl_narg narg, cl_object v1fun, cl_object v2cfun, cl_object v3needs_narg, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[287]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[287]);
 {
  cl_object v4omit_requireds;
  va_list args; va_start(args,v3needs_narg);
  {
   int i = 3;
   if (i >= narg) {
    v4omit_requireds = ECL_NIL;
   } else {
    i++;
    v4omit_requireds = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v5comma;
   cl_object v6lambda_expr;
   cl_object v7lambda_list;
   cl_object v8requireds;
   v5comma = VV[160];
   v6lambda_expr = (cl_env_copy->function=ecl_fdefinition(VV[249]))->cfun.entry(1, v1fun) /*  FUN-LAMBDA */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[51]))->cfun.entry(1, v6lambda_expr) /*  C1FORM-ARGS */;
   v7lambda_list = ecl_car(T0);
   {
    cl_object v9;
    cl_object v10;
    cl_object v11;
    cl_object v12arg;
    cl_object v13;
    v9 = ecl_make_int8_t(63);
    {
     cl_object v14;
     v14 = ecl_car(v7lambda_list);
     if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v10 = v14;
    }
    v11 = v9;
    v12arg = ECL_NIL;
    v13 = v10;
    {
     cl_object v14;
     cl_object v15;
     v14 = ecl_list1(ECL_NIL);
     v15 = v14;
L15:;
     v11 = ecl_minus(v11,ecl_make_int8_t(1));
     T0 = v11;
     if (!(ecl_minusp(T0))){
      goto L17;
     }
     goto L16;
L17:;
     if (!(ecl_endp(v13))){
      goto L21;
     }
     goto L16;
L21:;
     v12arg = ECL_CONS_CAR(v13);
     {
      cl_object v16;
      v16 = ECL_CONS_CDR(v13);
      if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v13 = v16;
     }
     {
      cl_object v16;
      v16 = v15;
      if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v16;
     }
     T1 = (cl_env_copy->function=ecl_fdefinition(VV[303]))->cfun.entry(1, v12arg) /*  VAR-NAME */;
     T2 = (cl_env_copy->function=ecl_fdefinition(VV[302]))->cfun.entry(1, T1) /*  NEXT-LCL */;
     v15 = ecl_list1(T2);
     (ECL_CONS_CDR(T0)=v15,T0);
     goto L15;
L16:;
     v8requireds = ecl_cdr(v14);
     goto L5;
    }
   }
L5:;
   ecl_structure_set(v1fun,VV[282],(cl_fixnum)(29),v8requireds);
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[276]))->cfun.entry(1, v1fun) /*  FUN-EXPORTED */)){
    goto L38;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(3, VV[304], v2cfun, VV[223]) /*  WT-NL-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[141], v2cfun, VV[223]) /*  WT-NL */;
   goto L37;
L38:;
   (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(3, VV[305], v2cfun, VV[223]) /*  WT-NL-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[305], v2cfun, VV[223]) /*  WT-NL */;
L37:;
   if (Null(v3needs_narg)){
    goto L42;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[123]))->cfun.entry(2, ecl_cmp_symbol_value(cl_env_copy,VV[155]), VV[306]) /*  WT-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(2, ecl_cmp_symbol_value(cl_env_copy,VV[155]), VV[307]) /*  WT */;
   v5comma = VV[144];
L42:;
   {
    cl_object v9;
    v9 = L3820fun_lexical_levels(v1fun);
    {
     cl_object v10n;
     v10n = ecl_make_int8_t(0);
     goto L51;
L50:;
     (cl_env_copy->function=ecl_fdefinition(VV[123]))->cfun.entry(2, v5comma, VV[308]) /*  WT-H */;
     (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(3, v5comma, VV[309], v10n) /*  WT */;
     v5comma = VV[144];
     v10n = ecl_one_plus(v10n);
L51:;
     if (!(ecl_lower(v10n,v9))){
      goto L59;
     }
     goto L50;
L59:;
    }
   }
   if (v4omit_requireds!=ECL_NIL) {
    goto L61;
   }
   {
    cl_object v9;
    cl_object v10lcl;
    cl_object v11;
    {
     cl_object v12;
     v12 = v8requireds;
     if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v9 = v12;
    }
    v10lcl = ECL_NIL;
    v11 = v9;
L68:;
    if (!(ecl_endp(v11))){
     goto L70;
    }
    goto L69;
L70:;
    v10lcl = ECL_CONS_CAR(v11);
    {
     cl_object v12;
     v12 = ECL_CONS_CDR(v11);
     if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v11 = v12;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[123]))->cfun.entry(3, v5comma, VV[141], ecl_cmp_symbol_value(cl_env_copy,VV[155])) /*  WT-H */;
    (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(4, v5comma, VV[141], ecl_cmp_symbol_value(cl_env_copy,VV[155]), v10lcl) /*  WT */;
    v5comma = VV[144];
    goto L68;
L69:;
   }
L61:;
   if (Null(v3needs_narg)){
    goto L83;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[123]))->cfun.entry(1, VV[310]) /*  WT-H */;
   (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(1, VV[310]) /*  WT */;
L83:;
   (cl_env_copy->function=ecl_fdefinition(VV[123]))->cfun.entry(1, VV[226]) /*  WT-H */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(1, VV[225]) /*  WT */;
   return value0;
  }
 }
}
/* function definition for T3FUNCTION-DECLARATION                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3817t3function_declaration(cl_object v1fun)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[312]))->cfun.entry(1, v1fun) /*  FUN-GLOBAL */)){
  goto L4;
 }
 T0 = VV[313];
 goto L3;
L4:;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v1fun) /*  FUN-CLOSURE */;
 if (!((T1)==(VV[154]))){
  goto L6;
 }
 T0 = VV[314];
 goto L3;
L6:;
 T0 = VV[315];
L3:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[86]))->cfun.entry(1, v1fun) /*  FUN-NAME */;
 if (value0!=ECL_NIL) {
  goto L10;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[247]))->cfun.entry(1, v1fun) /*  FUN-DESCRIPTION */;
 if (value0!=ECL_NIL) {
  goto L10;
 }
 T1 = VV[154];
 goto L8;
L10:;
 T1 = value0;
 goto L8;
L8:;
 (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(2, T0, T1) /*  WT-COMMENT-NL */;
 {
  cl_object v2lambda_expr;
  cl_object v3cmp_env;
  v2lambda_expr = (cl_env_copy->function=ecl_fdefinition(VV[249]))->cfun.entry(1, v1fun) /*  FUN-LAMBDA */;
  v3cmp_env = (cl_env_copy->function=ecl_fdefinition(VV[49]))->cfun.entry(1, v2lambda_expr) /*  C1FORM-ENV */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[317]))->cfun.entry(2, ECL_SYM("SPEED",794), v3cmp_env) /*  CMP-ENV-OPTIMIZATION */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[317]))->cfun.entry(2, ECL_SYM("DEBUG",272), v3cmp_env) /*  CMP-ENV-OPTIMIZATION */;
  T2 = (cl_env_copy->function=ecl_fdefinition(VV[317]))->cfun.entry(2, ECL_SYM("SPACE",791), v3cmp_env) /*  CMP-ENV-OPTIMIZATION */;
  T3 = (cl_env_copy->function=ecl_fdefinition(VV[317]))->cfun.entry(2, ECL_SYM("SAFETY",737), v3cmp_env) /*  CMP-ENV-OPTIMIZATION */;
  (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(5, VV[316], T0, T1, T2, T3) /*  WT-COMMENT-NL */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[267]))->cfun.entry(1, v1fun) /*  FUN-CFUN */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[268]))->cfun.entry(1, v1fun) /*  FUN-NEEDS-NARG */;
  T2 = L3811fun_c_compatible_variadic_signature(v1fun);
  L3816t3function_header(4, v1fun, T0, T1, T2);
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3817t3function_declaration_va(cl_narg narg, cl_object v2fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[255]);
 {
  return L3817t3function_declaration(v2fun);
 }
}
/* function definition for FUN-CLOSURE-VARIABLES                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3819fun_closure_variables(cl_object v1fun)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1fun,env0);                  /*  FUN                     */
 {
  cl_object v2;
  v2 = ecl_make_cclosure_va((cl_objectfn)LC3818__lambda221,env0,Cblock,1);
  T0 = v2;
 }
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[327]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  FUN-REFERENCED-VARS */;
 T2 = cl_remove_if(2, T0, T1);
 T3 = (ECL_SYM(">",77)->symbol.gfdef);
 T4 = ecl_fdefinition(VV[325]);
 value0 = cl_sort(4, T2, T3, ECL_SYM("KEY",1297), T4);
 return value0;
}
static cl_object L3819fun_closure_variables_va(cl_narg narg, cl_object v2fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[319]);
 {
  return L3819fun_closure_variables(v2fun);
 }
}
/* function definition for FUN-LEXICAL-LEVELS                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3820fun_lexical_levels(cl_object v1fun)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[88]))->cfun.entry(1, v1fun) /*  FUN-CLOSURE */;
 if (!((T0)==(VV[275]))){
  goto L2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[329]))->cfun.entry(1, v1fun) /*  FUN-LEVEL */;
 return value0;
L2:;
 value0 = ecl_make_int8_t(0);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3820fun_lexical_levels_va(cl_narg narg, cl_object v2fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[253]);
 {
  return L3820fun_lexical_levels(v2fun);
 }
}
/* function definition for T3FUNCTION-CLOSURE-SCAN                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3821t3function_closure_scan(cl_object v1fun)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2clv_used;
  v2clv_used = L3819fun_closure_variables(v1fun);
  (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[331]) /*  WT-NL */;
  {
   cl_object v3;
   cl_object v4;
   cl_object v5n;
   cl_object v6first;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[252]))->cfun.entry(1, v1fun) /*  FUN-ENV */;
   v3 = ecl_one_minus(T0);
   v4 = v2clv_used;
   v5n = v3;
   v6first = ECL_T;
   goto L11;
L10:;
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(2, VV[161], v5n) /*  WT-NL */;
   if (Null(v6first)){
    goto L15;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(1, VV[332]) /*  WT */;
   v6first = ECL_NIL;
   goto L14;
L15:;
   T0 = ecl_one_plus(v5n);
   (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(3, VV[333], T0, VV[226]) /*  WT */;
L14:;
   T0 = ecl_car(v4);
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[325]))->cfun.entry(1, T0) /*  VAR-LOC */;
   if (!(ecl_number_equalp(v5n,T1))){
    goto L19;
   }
   T0 = ecl_car(v2clv_used);
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[303]))->cfun.entry(1, T0) /*  VAR-NAME */;
   (cl_env_copy->function=ecl_fdefinition(VV[334]))->cfun.entry(1, T1) /*  WT-COMMENT */;
   {
    cl_object v7;
    v7 = v2clv_used;
    {
     cl_object v8;
     v8 = v7;
     {
      bool v9;
      v9 = ECL_LISTP(v8);
      if (ecl_unlikely(!(v9)))
         FEwrong_type_argument(VV[337],v8);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v7)){
     goto L26;
    }
    {
     cl_object v8;
     v8 = ECL_CONS_CDR(v7);
     v2clv_used = v8;
     v7 = ECL_CONS_CAR(v7);
    }
L26:;
   }
L19:;
   v5n = ecl_one_minus(v5n);
L11:;
   if (ecl_minusp(v5n)) {
    goto L34;
   }
   if (v4==ECL_NIL) {
    goto L34;
   }
   goto L10;
L34:;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[176]))->cfun.entry(0) /*  WT-NL-OPEN-BRACE */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(1, VV[338]) /*  WT */;
  return value0;
 }
}
static cl_object L3821t3function_closure_scan_va(cl_narg narg, cl_object v3fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[261]);
 {
  return L3821t3function_closure_scan(v3fun);
 }
}
/* function definition for OUTPUT-CFUNS                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3822output_cfuns(cl_object v1stream)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2n_cfuns;
  v2n_cfuns = ecl_make_fixnum(ecl_length(ecl_cmp_symbol_value(cl_env_copy,VV[18])));
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[127]) /*  WT-NL-H */;
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[340]) /*  WT-NL-H */;
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[129]) /*  WT-NL-H */;
  (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(2, VV[341], v2n_cfuns) /*  WT-NL-H */;
  if (!((ecl_fixnum(v2n_cfuns))==0)){
   goto L7;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[101]))->cfun.entry(1, VV[342]) /*  WT-NL-H */;
  return value0;
L7:;
  cl_format(2, v1stream, VV[343]);
  {
   cl_object v3;
   cl_object v4loc;
   cl_object v5fname_loc;
   cl_object v6fun;
   cl_object v7;
   {
    cl_object v8;
    v8 = cl_nreverse(ecl_cmp_symbol_value(cl_env_copy,VV[18]));
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v8;
   }
   v4loc = ECL_NIL;
   v5fname_loc = ECL_NIL;
   v6fun = ECL_NIL;
   v7 = v3;
L18:;
   if (!(ecl_endp(v7))){
    goto L20;
   }
   goto L19;
L20:;
   {
    cl_object v8;
    v8 = ECL_CONS_CAR(v7);
    v4loc = ecl_car(v8);
    v8 = ecl_cdr(v8);
    v5fname_loc = ecl_car(v8);
    v8 = ecl_cdr(v8);
    v6fun = ecl_car(v8);
   }
   {
    cl_object v8;
    v8 = ECL_CONS_CDR(v7);
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v7 = v8;
   }
   {
    cl_object v8variadic_entrypoint;
    cl_object v9cfun;
    cl_object v10needs_narg;
    cl_object v11narg;
    v8variadic_entrypoint = (cl_env_copy->function=ecl_fdefinition(VV[278]))->cfun.entry(1, v6fun) /*  FUN-VARIADIC-ENTRYPOINT-CFUN */;
    value0 = v8variadic_entrypoint;
    if (value0!=ECL_NIL) {
     goto L41;
    }
    v9cfun = (cl_env_copy->function=ecl_fdefinition(VV[267]))->cfun.entry(1, v6fun) /*  FUN-CFUN */;
    goto L39;
L41:;
    v9cfun = value0;
    goto L39;
L39:;
    value0 = v8variadic_entrypoint;
    if (value0!=ECL_NIL) {
     goto L45;
    }
    v10needs_narg = (cl_env_copy->function=ecl_fdefinition(VV[268]))->cfun.entry(1, v6fun) /*  FUN-NEEDS-NARG */;
    goto L43;
L45:;
    v10needs_narg = value0;
    goto L43;
L43:;
    v11narg = L3815fun_fixed_narg_main_entrypoint(v6fun);
    if (Null(v10needs_narg)){
     goto L49;
    }
    T0 = VV[345];
    goto L48;
L49:;
    T0 = VV[346];
L48:;
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[130]))->cfun.entry(1, v4loc) /*  VV-LOCATION */;
    T2 = (cl_env_copy->function=ecl_fdefinition(VV[130]))->cfun.entry(1, v5fname_loc) /*  VV-LOCATION */;
    T3 = (cl_env_copy->function=ecl_fdefinition(VV[347]))->cfun.entry(1, v6fun) /*  FUN-FILE-POSITION */;
    cl_format(8, v1stream, VV[344], T0, v11narg, T1, T2, v9cfun, T3);
   }
   goto L18;
L19:;
  }
  value0 = cl_format(2, v1stream, VV[348]);
  return value0;
 }
}
static cl_object L3822output_cfuns_va(cl_narg narg, cl_object v3stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[131]);
 {
  return L3822output_cfuns(v3stream);
 }
}
/* function definition for WT-INSTALL-FUNCTION                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3823wt_install_function(cl_object v1fname, cl_object v2fun, cl_object v3macro_p)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  cl_object v5;
  v4 = ecl_cmp_symbol_value(cl_env_copy,VV[166]);
  v5 = ecl_cmp_symbol_value(cl_env_copy,VV[165]);
  ecl_bds_bind(cl_env_copy,VV[14],ecl_make_int8_t(0)); /*  *INLINE-BLOCKS*    */
  ecl_bds_bind(cl_env_copy,VV[166],v4);           /*  *TEMP*                  */
  ecl_bds_bind(cl_env_copy,VV[165],v5);           /*  *LCL*                   */
  {
   cl_object v6loc;
   v6loc = (cl_env_copy->function=ecl_fdefinition(VV[350]))->cfun.entry(0) /*  DATA-EMPTY-LOC* */;
   T0 = cl_list(3, v6loc, v1fname, v2fun);
   T1 = CONS(T0,ecl_cmp_symbol_value(cl_env_copy,VV[18]));
   ecl_cmp_setq(cl_env_copy,VV[18],T1);
   (cl_env_copy->function=ecl_fdefinition(VV[87]))->cfun.entry(1, v2fun) /*  UPDATE-FUNCTION-ENV */;
   if (Null(v3macro_p)){
    goto L10;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[351], v6loc, VV[226]) /*  WT-NL */;
   goto L9;
L10:;
   (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(3, VV[352], v6loc, VV[226]) /*  WT-NL */;
L9:;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[353]))->cfun.entry(1, v1fname) /*  LOC-IMMEDIATE-VALUE */;
   (cl_env_copy->function=ecl_fdefinition(VV[334]))->cfun.entry(1, T0) /*  WT-COMMENT */;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[208]))->cfun.entry(0) /*  CLOSE-INLINE-BLOCKS */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3823wt_install_function_va(cl_narg narg, cl_object v6fname, cl_object v7fun, cl_object v8macro_p, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[89]);
 {
  return L3823wt_install_function(v6fname, v7fun, v8macro_p);
 }
}
/* local function WT-RETURN                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3813wt_return(volatile cl_object *lex0, cl_object v1args)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(1, VV[285]) /*  WT-NL */;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[267]))->cfun.entry(1, lex0[0]) /*  FUN-CFUN */;
 (cl_env_copy->function=ecl_fdefinition(VV[286]))->cfun.entry(2, T0, v1args) /*  WT-CALL */;
 (cl_env_copy->function=ecl_fdefinition(VV[142]))->cfun.entry(1, VV[145]) /*  WT */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[209]))->cfun.entry(1, ecl_make_int8_t(0)) /*  WT-NL-CLOSE-MANY-BRACES */;
 return value0;
}
/* closure LAMBDA221                                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3818__lambda221(cl_narg narg, cl_object v1x, ...)
{
 cl_object T0, T1;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  FUN                     */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[320]);
 {
L1:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[321]))->cfun.entry(1, v1x) /*  REF-REF-CCB */;
  value0 = Null(T0)?ECL_T:ECL_NIL;
  if (value0!=ECL_NIL) {
   goto L3;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[322]))->cfun.entry(1, v1x) /*  VAR-KIND */;
  value0 = ecl_make_bool((T0)==(ECL_SYM("SPECIAL",792)));
  if (value0!=ECL_NIL) {
   goto L3;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[249]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  FUN-LAMBDA */;
  if ((cl_env_copy->function=ecl_fdefinition(VV[323]))->cfun.entry(2, v1x, T0) /*  VAR-REFERENCED-IN-FORM */!=ECL_NIL) {
   goto L8;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[249]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  FUN-LAMBDA */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[324]))->cfun.entry(2, v1x, T0) /*  VAR-CHANGED-IN-FORM */;
  value0 = Null(T1)?ECL_T:ECL_NIL;
  goto L6;
L8:;
  value0 = ECL_NIL;
  goto L6;
L6:;
  if (value0!=ECL_NIL) {
   goto L3;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[325]))->cfun.entry(1, v1x) /*  VAR-LOC */;
  value0 = ecl_make_bool((T0)==(VV[326]));
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
#include "cmp/cmppass2-top.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclDYjuXZXDw9do9_T8a0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPBACKEND-CXX;CMPPASS2-TOP.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclDYjuXZXDw9do9_T8a0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(_ecl_static_0);
  ecl_cmp_defun(VV[355]);                         /*  WT-PRINT-HEADER         */
  ecl_cmp_defun(VV[356]);                         /*  COMPILER-PASS/GENERATE-CXX */
  ecl_cmp_defun(VV[357]);                         /*  T2EXPR                  */
  ecl_cmp_defun(VV[358]);                         /*  T2COMPILER-LET          */
  ecl_cmp_defun(VV[359]);                         /*  T2PROGN                 */
  ecl_cmp_defun(VV[360]);                         /*  T2ORDINARY              */
  ecl_cmp_defun(VV[361]);                         /*  T2LOAD-TIME-VALUE       */
  ecl_cmp_defun(VV[362]);                         /*  T2MAKE-FORM             */
  ecl_cmp_defun(VV[363]);                         /*  T2INIT-FORM             */
  ecl_cmp_defun(VV[364]);                         /*  T2FSET                  */
  ecl_cmp_defun(VV[365]);                         /*  C2FSET                  */
  (void)0; /* No entry created for EMIT-FUNCTIONS */
  ecl_cmp_defun(VV[366]);                         /*  CTOP-WRITE              */
  ecl_cmp_defun(VV[367]);                         /*  WT-FUNCTION-LOCALS      */
  ecl_cmp_defun(VV[368]);                         /*  T3ENTRY-FUN             */
  ecl_cmp_defun(VV[369]);                         /*  T3CALLBACK              */
  ecl_cmp_defun(VV[370]);                         /*  T3FUNCTION              */
  ecl_cmp_defun(VV[371]);                         /*  T3FUNCTION-BODY         */
  ecl_cmp_defun(VV[372]);                         /*  FUN-C-COMPATIBLE-VARIADIC-SIGNATURE */
  ecl_cmp_defun(VV[373]);                         /*  FUN-VARIADIC-ENTRYPOINT */
  ecl_cmp_defun(VV[374]);                         /*  T3FUNCTION-VARIADIC-ENTRYPOINT */
  ecl_cmp_defun(VV[375]);                         /*  FUN-FIXED-NARG-MAIN-ENTRYPOINT */
  ecl_cmp_defun(VV[376]);                         /*  T3FUNCTION-HEADER       */
  ecl_cmp_defun(VV[377]);                         /*  T3FUNCTION-DECLARATION  */
  ecl_cmp_defun(VV[378]);                         /*  FUN-CLOSURE-VARIABLES   */
  ecl_cmp_defun(VV[379]);                         /*  FUN-LEXICAL-LEVELS      */
  ecl_cmp_defun(VV[380]);                         /*  T3FUNCTION-CLOSURE-SCAN */
  ecl_cmp_defun(VV[381]);                         /*  OUTPUT-CFUNS            */
  ecl_cmp_defun(VV[382]);                         /*  WT-INSTALL-FUNCTION     */
}
