/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpvar.lsp                      */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpvar.eclh"
/* function definition for REPLACEABLE                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3378replaceable(cl_object volatile v1var, cl_object volatile v2form)
{
 cl_object T0, T1;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1var,env0);                  /*  VAR                     */
 {
  CLV1 = env0 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env0); /*  REPLACEABLE     */
  {
   ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
   if (__ecl_frs_push_result!=0) {
   ecl_frs_pop_n(cl_env_copy, 1);
   return cl_env_copy->values[0];
   } else {
   {
    cl_object volatile v3;
    v3 = ecl_make_cclosure_va((cl_objectfn)LC3377abort_on_side_effects,env0,Cblock,1);
    (cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(2, v2form, v3) /*  TRAVERSE-C1FORM-TREE */;
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[8]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  VAR-NAME */;
    T1 = cl_list(2, T0, ecl_cmp_symbol_value(cl_env_copy,VV[9]));
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[6]))->cfun.entry(4, ECL_SYM("FORMAT-CONTROL",1272), VV[7], ECL_SYM("FORMAT-ARGUMENTS",1271), T1) /*  BABOON */;
    ecl_frs_pop_n(cl_env_copy, 1);
    return value0;
   }
   }
  }
 }
}
static cl_object L3378replaceable_va(cl_narg narg, cl_object v3var, cl_object v4form, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[0]);
 {
  return L3378replaceable(v3var, v4form);
 }
}
/* function definition for NSUBST-VAR                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3379nsubst_var(cl_object v1var, cl_object v2form)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v1var) /*  VAR-SET-NODES */)){
  goto L2;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[6]))->cfun.entry(2, ECL_SYM("FORMAT-CONTROL",1272), VV[13]) /*  BABOON */;
L2:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[14]))->cfun.entry(1, v1var) /*  VAR-FUNCTIONS-READING */)){
  goto L4;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[6]))->cfun.entry(2, ECL_SYM("FORMAT-CONTROL",1272), VV[15]) /*  BABOON */;
L4:;
 {
  cl_object v3;
  v3 = L3389var_read_forms(v1var);
  goto L10;
L9:;
  {
   cl_object v4where;
   v4where = ecl_car(v3);
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(1, v4where) /*  C1FORM-NAME */;
   if (!((T0)==(ECL_SYM("VARIABLE",901)))){
    goto L17;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[3]))->cfun.entry(1, v4where) /*  C1FORM-ARGS */;
   T1 = ecl_car(T0);
   if (ecl_eql(T1,v1var)) {
    goto L14;
   }
   goto L15;
L17:;
   goto L15;
L15:;
   (cl_env_copy->function=ecl_fdefinition(VV[6]))->cfun.entry(2, ECL_SYM("FORMAT-CONTROL",1272), VV[18]) /*  BABOON */;
L14:;
   L3392delete_from_read_nodes(v1var, v4where);
   (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(2, v4where, v2form) /*  C1FORM-REPLACE-WITH */;
  }
  v3 = ecl_cdr(v3);
L10:;
  if (Null(v3)){
   goto L23;
  }
  goto L9;
L23:;
 }
 value0 = ecl_structure_set(v1var,VV[21],(cl_fixnum)(12),ecl_make_int8_t(0));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3379nsubst_var_va(cl_narg narg, cl_object v3var, cl_object v4form, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[11]);
 {
  return L3379nsubst_var(v3var, v4form);
 }
}
/* function definition for MAKE-VAR                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3380make_var(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1args;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1args = cl_grab_rest_args(args);
  ecl_va_end(args);
  {
   cl_object v2var;
   T0 = ecl_fdefinition(VV[24]);
   v2var = cl_apply(2, T0, v1args);
   {
    cl_object v3;
    v3 = (cl_env_copy->function=ecl_fdefinition(VV[25]))->cfun.entry(1, v2var) /*  VAR-KIND */;
    if (!((v3)==(ECL_SYM("SPECIAL",792)))){
     goto L8;
    }
    goto L3;
L8:;
    goto L6;
L6:;
    if (!((v3)==(VV[27]))){
     goto L11;
    }
    goto L3;
L11:;
    goto L4;
   }
L4:;
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[29]))){
    goto L3;
   }
   {
    cl_object v3;
    cl_object v4;
    v3 = ecl_cmp_symbol_value(cl_env_copy,VV[29]);
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[30]))->cfun.entry(1, v3) /*  FUN-LOCAL-VARS */;
    v4 = CONS(v2var,T0);
    ecl_structure_set(v3,VV[31],(cl_fixnum)(21),v4);
   }
L3:;
   value0 = v2var;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for MAKE-LCL-VAR                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3381make_lcl_var(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1host_type;
  cl_object v2type;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L3381make_lcl_varkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1host_type = keyvars[0];
   if (Null(keyvars[3])) {
    v2type = ECL_T;
   } else {
    v2type = keyvars[1];
   }
  }
  if (v1host_type!=ECL_NIL) {
   goto L2;
  }
  if (Null(v2type)){
   goto L5;
  }
  v1host_type = (cl_env_copy->function=ecl_fdefinition(VV[34]))->cfun.entry(1, v2type) /*  LISP-TYPE->HOST-TYPE */;
  goto L4;
L5:;
  v1host_type = ECL_SYM("OBJECT",1315);
L4:;
L2:;
  if (v2type!=ECL_NIL) {
   goto L7;
  }
  v2type = ECL_T;
L7:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[37]))->cfun.entry(0) /*  NEXT-LCL */;
  value0 = L3380make_var(6, VV[35], v1host_type, ECL_SYM("TYPE",1356), v2type, VV[36], T0);
  return value0;
 }
}
/* function definition for MAKE-GLOBAL-VAR                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3382make_global_var(cl_narg narg, cl_object v1name, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[40]);
 {
  cl_object v2type;
  cl_object v3kind;
  cl_object v4warn;
  ecl_va_list args; ecl_va_start(args,v1name,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L3382make_global_varkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[3])) {
    value0 = si_get_sysprop(v1name, VV[39]);
    if (value0!=ECL_NIL) {
     goto L3;
    }
    v2type = ECL_T;
    goto L1;
L3:;
    v2type = value0;
    goto L1;
L1:;
   } else {
    v2type = keyvars[0];
   }
   if (Null(keyvars[4])) {
    v3kind = VV[27];
   } else {
    v3kind = keyvars[1];
   }
   v4warn = keyvars[2];
  }
  {
   cl_object v5var;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, v1name) /*  ADD-SYMBOL */;
   v5var = L3380make_var(8, ECL_SYM("NAME",1309), v1name, VV[35], v3kind, ECL_SYM("TYPE",1356), v2type, VV[36], T0);
   if (Null(v4warn)){
    goto L7;
   }
   if (cl_constantp(1, v1name)!=ECL_NIL) {
    goto L7;
   }
   if ((cl_env_copy->function=ecl_fdefinition(VV[42]))->cfun.entry(1, v1name) /*  SPECIAL-VARIABLE-P */!=ECL_NIL) {
    goto L7;
   }
   {
    cl_object v6;
    cl_object v7;
    cl_object v8;
    v6 = ecl_cmp_symbol_value(cl_env_copy,VV[43]);
    v7 = v1name;
    v8 = v6;
    if (ecl_memql(v7,v8)!=ECL_NIL) {
     goto L7;
    }
   }
   (cl_env_copy->function=ecl_fdefinition(VV[44]))->cfun.entry(1, v1name) /*  UNDEFINED-VARIABLE */;
   T0 = CONS(v1name,ecl_cmp_symbol_value(cl_env_copy,VV[43]));
   ecl_cmp_setq(cl_env_copy,VV[43],T0);
L7:;
   value0 = v5var;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for MAKE-TEMP-VAR                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3383make_temp_var(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[46]);
 {
  cl_object v1type;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1type = ECL_T;
   } else {
    i++;
    v1type = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[48]))->cfun.entry(0) /*  NEXT-TEMP */;
  T1 = cl_list(2, VV[47], T0);
  value0 = L3380make_var(6, VV[35], ECL_SYM("OBJECT",1315), ECL_SYM("TYPE",1356), v1type, VV[36], T1);
  return value0;
 }
}
/* function definition for VAR-REFERENCED-IN-FORM-LIST                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3384var_referenced_in_form_list(cl_object v1var, cl_object v2form_list)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4f;
  cl_object v5;
  {
   cl_object v6;
   v6 = v2form_list;
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3 = v6;
  }
  v4f = ECL_NIL;
  v5 = v3;
  {
   cl_object v6;
   v6 = ECL_NIL;
L8:;
   if (!(ecl_endp(v5))){
    goto L10;
   }
   goto L9;
L10:;
   v4f = ECL_CONS_CAR(v5);
   {
    cl_object v7;
    v7 = ECL_CONS_CDR(v5);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v7;
   }
   v6 = L3386var_referenced_in_form(v1var, v4f);
   if (Null(v6)){
    goto L18;
   }
   value0 = v6;
   cl_env_copy->nvalues = 1;
   return value0;
L18:;
   goto L8;
L9:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3384var_referenced_in_form_list_va(cl_narg narg, cl_object v7var, cl_object v8form_list, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[50]);
 {
  return L3384var_referenced_in_form_list(v7var, v8form_list);
 }
}
/* function definition for VAR-CHANGED-IN-FORM-LIST                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3385var_changed_in_form_list(cl_object v1var, cl_object v2form_list)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4f;
  cl_object v5;
  {
   cl_object v6;
   v6 = v2form_list;
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3 = v6;
  }
  v4f = ECL_NIL;
  v5 = v3;
  {
   cl_object v6;
   v6 = ECL_NIL;
L8:;
   if (!(ecl_endp(v5))){
    goto L10;
   }
   goto L9;
L10:;
   v4f = ECL_CONS_CAR(v5);
   {
    cl_object v7;
    v7 = ECL_CONS_CDR(v5);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v7;
   }
   v6 = L3387var_changed_in_form(v1var, v4f);
   if (Null(v6)){
    goto L18;
   }
   value0 = v6;
   cl_env_copy->nvalues = 1;
   return value0;
L18:;
   goto L8;
L9:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3385var_changed_in_form_list_va(cl_narg narg, cl_object v7var, cl_object v8form_list, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[55]);
 {
  return L3385var_changed_in_form_list(v7var, v8form_list);
 }
}
/* function definition for VAR-REFERENCED-IN-FORM                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3386var_referenced_in_form(cl_object v1var, cl_object v2form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v1var) /*  VAR-READ-NODES */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[58]))->cfun.entry(2, v2form, T0) /*  FIND-FORM-IN-NODE-LIST */;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[14]))->cfun.entry(1, v1var) /*  VAR-FUNCTIONS-READING */;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3386var_referenced_in_form_va(cl_narg narg, cl_object v3var, cl_object v4form, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[53]);
 {
  return L3386var_referenced_in_form(v3var, v4form);
 }
}
/* function definition for VAR-CHANGED-IN-FORM                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3387var_changed_in_form(cl_object v1var, cl_object v2form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v1var) /*  VAR-SET-NODES */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[58]))->cfun.entry(2, v2form, T0) /*  FIND-FORM-IN-NODE-LIST */;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 {
  cl_object v3kind;
  v3kind = (cl_env_copy->function=ecl_fdefinition(VV[25]))->cfun.entry(1, v1var) /*  VAR-KIND */;
  if ((v3kind)==(ECL_SYM("SPECIAL",792))) {
   goto L8;
  }
  if (!((v3kind)==(VV[27]))){
   goto L6;
  }
  goto L7;
L8:;
L7:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[61]))->cfun.entry(1, v2form) /*  C1FORM-SP-CHANGE */;
  return value0;
L6:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[62]))->cfun.entry(1, v1var) /*  VAR-FUNCTIONS-SETTING */;
  return value0;
 }
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3387var_changed_in_form_va(cl_narg narg, cl_object v4var, cl_object v5form, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[56]);
 {
  return L3387var_changed_in_form(v4var, v5form);
 }
}
/* function definition for UPDATE-VARIABLE-TYPE                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3388update_variable_type(cl_object v1var, cl_object v2orig_type)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v1var) /*  VAR-SET-NODES */)){
  goto L2;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 {
  cl_object v3type;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[66]))->cfun.entry(1, v1var) /*  VAR-TYPE */;
  v3type = (cl_env_copy->function=ecl_fdefinition(VV[65]))->cfun.entry(2, T0, v2orig_type) /*  TYPE-AND */;
  if (!(v3type==ECL_NIL)){
   goto L5;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[8]))->cfun.entry(1, v1var) /*  VAR-NAME */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[66]))->cfun.entry(1, v1var) /*  VAR-TYPE */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[67]))->cfun.entry(4, VV[68], T0, T1, v2orig_type) /*  CMPWARN */;
  return value0;
L5:;
  {
   cl_object v4;
   cl_object v5form;
   cl_object v6;
   {
    cl_object v7;
    v7 = L3389var_read_forms(v1var);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   v5form = ECL_NIL;
   v6 = v4;
L12:;
   if (!(ecl_endp(v6))){
    goto L14;
   }
   goto L13;
L14:;
   v5form = ECL_CONS_CAR(v6);
   {
    cl_object v7;
    v7 = ECL_CONS_CDR(v6);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v6 = v7;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(1, v5form) /*  C1FORM-NAME */;
   if (!((T0)==(ECL_SYM("VARIABLE",901)))){
    goto L22;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[3]))->cfun.entry(1, v5form) /*  C1FORM-ARGS */;
   T1 = ecl_car(T0);
   if (!((v1var)==(T1))){
    goto L22;
   }
   {
    cl_object v7;
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[69]))->cfun.entry(1, v5form) /*  C1FORM-PRIMARY-TYPE */;
    v7 = (cl_env_copy->function=ecl_fdefinition(VV[65]))->cfun.entry(2, v3type, T0) /*  TYPE-AND */;
    ecl_structure_set(v5form,VV[70],(cl_fixnum)(1),v7);
   }
L22:;
   goto L12;
L13:;
   ecl_structure_set(v1var,VV[21],(cl_fixnum)(11),v3type);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3388update_variable_type_va(cl_narg narg, cl_object v7var, cl_object v8orig_type, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[64]);
 {
  return L3388update_variable_type(v7var, v8orig_type);
 }
}
/* function definition for VAR-READ-FORMS                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3389var_read_forms(cl_object v1var)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = (ECL_SYM("FIRST",373)->symbol.gfdef);
  {
   cl_object v3;
   cl_object v4;
   cl_object v5;
   {
    cl_object v6;
    v6 = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v1var) /*  VAR-READ-NODES */;
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v6;
   }
   v4 = ECL_NIL;
   v5 = v3;
   {
    cl_object v6;
    cl_object v7;
    v6 = ecl_list1(ECL_NIL);
    v7 = v6;
L10:;
    if (!(ecl_endp(v5))){
     goto L12;
    }
    goto L11;
L12:;
    v4 = ECL_CONS_CAR(v5);
    {
     cl_object v8;
     v8 = ECL_CONS_CDR(v5);
     if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v8;
    }
    {
     cl_object v8;
     v8 = v7;
     if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T0 = v8;
    }
    T1 = ecl_function_dispatch(cl_env_copy,v2)(1, v4);
    v7 = ecl_list1(T1);
    (ECL_CONS_CDR(T0)=v7,T0);
    goto L10;
L11:;
    value0 = ecl_cdr(v6);
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
static cl_object L3389var_read_forms_va(cl_narg narg, cl_object v8var, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[16]);
 {
  return L3389var_read_forms(v8var);
 }
}
/* function definition for ASSERT-VAR-REF-VALUE                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3390assert_var_ref_value(cl_object v1var)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[77]))){
  goto L2;
 }
 {
  cl_object v2ref;
  v2ref = (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, v1var) /*  VAR-REF */;
  T0 = ecl_divide(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("MOST-POSITIVE-FIXNUM",569)),ecl_make_int8_t(2));
  if (ecl_greater(v2ref,T0)) {
   goto L4;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, v1var) /*  VAR-REF */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v1var) /*  VAR-READ-NODES */;
  {
   cl_fixnum v3;
   v3 = ecl_length(T1);
   T2 = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v1var) /*  VAR-SET-NODES */;
   {
    cl_fixnum v4;
    v4 = ecl_length(T2);
    T3 = ecl_plus(ecl_make_fixnum(v3),ecl_make_fixnum(v4));
    if (ecl_number_equalp(T0,T3)) {
     goto L4;
    }
   }
  }
 }
 T0 = ecl_list1(v1var);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[6]))->cfun.entry(4, ECL_SYM("FORMAT-CONTROL",1272), VV[79], ECL_SYM("FORMAT-ARGUMENTS",1271), T0) /*  BABOON */;
 return value0;
L4:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3390assert_var_ref_value_va(cl_narg narg, cl_object v2var, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[76]);
 {
  return L3390assert_var_ref_value(v2var);
 }
}
/* function definition for ASSERT-VAR-NOT-IGNORED                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3391assert_var_not_ignored(cl_object v1var)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2x;
  v2x = (cl_env_copy->function=ecl_fdefinition(VV[82]))->cfun.entry(1, v1var) /*  VAR-IGNORABLE */;
  if (Null(v2x)){
   goto L2;
  }
  if (!(ecl_minusp(v2x))){
   goto L2;
  }
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[8]))->cfun.entry(1, v1var) /*  VAR-NAME */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(2, VV[84], T0) /*  CMPWARN-STYLE */;
 value0 = ecl_structure_set(v1var,VV[21],(cl_fixnum)(12),ECL_NIL);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3391assert_var_not_ignored_va(cl_narg narg, cl_object v2var, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[81]);
 {
  return L3391assert_var_not_ignored(v2var);
 }
}
/* function definition for DELETE-FROM-READ-NODES                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3392delete_from_read_nodes(cl_object v1var, cl_object v2form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 L3390assert_var_ref_value(v1var);
 {
  cl_object v3;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, v1var) /*  VAR-REF */;
  v3 = ecl_one_minus(T0);
  ecl_structure_set(v1var,VV[21],(cl_fixnum)(1),v3);
 }
 {
  cl_object v3;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v1var) /*  VAR-READ-NODES */;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[86]))->cfun.entry(2, v2form, T0) /*  DELETE-FORM-FROM-NODE-LIST */;
  value0 = ecl_structure_set(v1var,VV[21],(cl_fixnum)(4),v3);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3392delete_from_read_nodes_va(cl_narg narg, cl_object v4var, cl_object v5form, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[19]);
 {
  return L3392delete_from_read_nodes(v4var, v5form);
 }
}
/* function definition for ADD-TO-READ-NODES                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3393add_to_read_nodes(cl_object v1var, cl_object v2form)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 L3390assert_var_ref_value(v1var);
 L3391assert_var_not_ignored(v1var);
 {
  cl_object v3;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, v1var) /*  VAR-REF */;
  v3 = ecl_one_plus(T0);
  ecl_structure_set(v1var,VV[21],(cl_fixnum)(1),v3);
 }
 {
  cl_object v3;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, v1var) /*  VAR-READ-NODES */;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[89]))->cfun.entry(2, v2form, T0) /*  ADD-FORM-TO-NODE-LIST */;
  ecl_structure_set(v1var,VV[21],(cl_fixnum)(4),v3);
 }
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[29]))){
  goto L8;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,VV[29]);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[90]))->cfun.entry(1, v1var) /*  VAR-FUNCTION */;
 if ((T0)==(T1)) {
  goto L8;
 }
 {
  cl_object v3;
  cl_object v4;
  v3 = ecl_cmp_symbol_value(cl_env_copy,VV[29]);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[14]))->cfun.entry(1, v1var) /*  VAR-FUNCTIONS-READING */;
  v4 = cl_adjoin(2, v3, T0);
  ecl_structure_set(v1var,VV[21],(cl_fixnum)(9),v4);
 }
 {
  cl_object v3;
  cl_object v4;
  v3 = ecl_cmp_symbol_value(cl_env_copy,VV[29]);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[91]))->cfun.entry(1, v3) /*  FUN-REFERENCED-VARS */;
  v4 = cl_adjoin(2, v1var, T0);
  ecl_structure_set(v3,VV[31],(cl_fixnum)(22),v4);
 }
L8:;
 value0 = v2form;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3393add_to_read_nodes_va(cl_narg narg, cl_object v3var, cl_object v4form, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[88]);
 {
  return L3393add_to_read_nodes(v3var, v4form);
 }
}
/* function definition for ADD-TO-SET-NODES                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3394add_to_set_nodes(cl_object v1var, cl_object v2form)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 L3390assert_var_ref_value(v1var);
 L3391assert_var_not_ignored(v1var);
 {
  cl_object v3;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, v1var) /*  VAR-REF */;
  v3 = ecl_one_plus(T0);
  ecl_structure_set(v1var,VV[21],(cl_fixnum)(1),v3);
 }
 {
  cl_object v3;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v1var) /*  VAR-SET-NODES */;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[89]))->cfun.entry(2, v2form, T0) /*  ADD-FORM-TO-NODE-LIST */;
  ecl_structure_set(v1var,VV[21],(cl_fixnum)(5),v3);
 }
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[29]))){
  goto L8;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,VV[29]);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[90]))->cfun.entry(1, v1var) /*  VAR-FUNCTION */;
 if ((T0)==(T1)) {
  goto L8;
 }
 {
  cl_object v3;
  cl_object v4;
  v3 = ecl_cmp_symbol_value(cl_env_copy,VV[29]);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[62]))->cfun.entry(1, v1var) /*  VAR-FUNCTIONS-SETTING */;
  v4 = cl_adjoin(2, v3, T0);
  ecl_structure_set(v1var,VV[21],(cl_fixnum)(8),v4);
 }
 {
  cl_object v3;
  cl_object v4;
  v3 = ecl_cmp_symbol_value(cl_env_copy,VV[29]);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[91]))->cfun.entry(1, v3) /*  FUN-REFERENCED-VARS */;
  v4 = cl_adjoin(2, v1var, T0);
  ecl_structure_set(v3,VV[31],(cl_fixnum)(22),v4);
 }
L8:;
 value0 = v2form;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3394add_to_set_nodes_va(cl_narg narg, cl_object v3var, cl_object v4form, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[93]);
 {
  return L3394add_to_set_nodes(v3var, v4form);
 }
}
/* function definition for ADD-TO-SET-NODES-OF-VAR-LIST                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3395add_to_set_nodes_of_var_list(cl_object v1var_list, cl_object v2form)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = v1var_list;
  goto L6;
L5:;
  {
   cl_object v4v;
   v4v = ecl_car(v3);
   L3394add_to_set_nodes(v4v, v2form);
  }
  v3 = ecl_cdr(v3);
L6:;
  if (Null(v3)){
   goto L13;
  }
  goto L5;
L13:;
 }
 value0 = v2form;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3395add_to_set_nodes_of_var_list_va(cl_narg narg, cl_object v3var_list, cl_object v4form, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[95]);
 {
  return L3395add_to_set_nodes_of_var_list(v3var_list, v4form);
 }
}
/* function definition for VAR-HOST-TYPE                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3396var_host_type(cl_object v1var)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = (cl_env_copy->function=ecl_fdefinition(VV[25]))->cfun.entry(1, v1var) /*  VAR-KIND */;
  if (!((v2)==(VV[99]))){
   goto L8;
  }
  goto L5;
L8:;
  goto L6;
L6:;
  if (!((v2)==(VV[100]))){
   goto L12;
  }
  goto L5;
L12:;
  goto L10;
L10:;
  if (!((v2)==(ECL_SYM("SPECIAL",792)))){
   goto L16;
  }
  goto L5;
L16:;
  goto L14;
L14:;
  if (!((v2)==(VV[27]))){
   goto L3;
  }
  goto L4;
L5:;
L4:;
  value0 = ECL_SYM("OBJECT",1315);
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[25]))->cfun.entry(1, v1var) /*  VAR-KIND */;
  return value0;
 }
}
static cl_object L3396var_host_type_va(cl_narg narg, cl_object v3var, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[97]);
 {
  return L3396var_host_type(v3var);
 }
}
/* function definition for CHECK-VREF                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3397check_vref(cl_object v1var)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[25]))->cfun.entry(1, v1var) /*  VAR-KIND */;
 if (!((T0)==(VV[99]))){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, v1var) /*  VAR-REF */;
 if (!(ecl_zerop(T0))){
  goto L4;
 }
 if ((cl_env_copy->function=ecl_fdefinition(VV[82]))->cfun.entry(1, v1var) /*  VAR-IGNORABLE */!=ECL_NIL) {
  goto L4;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[8]))->cfun.entry(1, v1var) /*  VAR-NAME */;
 (cl_env_copy->function=ecl_fdefinition(VV[83]))->cfun.entry(2, VV[104], T0) /*  CMPWARN-STYLE */;
L4:;
 if ((cl_env_copy->function=ecl_fdefinition(VV[105]))->cfun.entry(1, v1var) /*  VAR-REF-CLB */!=ECL_NIL) {
  goto L7;
 }
 {
  cl_object v2;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, v1var) /*  VAR-REF */;
  if (!(ecl_plusp(T0))){
   goto L10;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[66]))->cfun.entry(1, v1var) /*  VAR-TYPE */;
  v2 = (cl_env_copy->function=ecl_fdefinition(VV[34]))->cfun.entry(1, T0) /*  LISP-TYPE->HOST-TYPE */;
  goto L9;
L10:;
  v2 = ECL_SYM("OBJECT",1315);
L9:;
  value0 = ecl_structure_set(v1var,VV[21],(cl_fixnum)(6),v2);
  cl_env_copy->nvalues = 1;
  return value0;
 }
L7:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3397check_vref_va(cl_narg narg, cl_object v3var, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[103]);
 {
  return L3397check_vref(v3var);
 }
}
/* function definition for UNBOXED-VAR-P                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3398unboxed_var_p(cl_object v1var)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = L3396var_host_type(v1var);
 {
  bool v2;
  v2 = (T0)==(ECL_SYM("OBJECT",1315));
  value0 = (v2)?ECL_NIL:ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3398unboxed_var_p_va(cl_narg narg, cl_object v2var, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[107]);
 {
  return L3398unboxed_var_p(v2var);
 }
}
/* function definition for LOCAL-VAR-P                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3399local_var_p(cl_object v1var)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = (cl_env_copy->function=ecl_fdefinition(VV[25]))->cfun.entry(1, v1var) /*  VAR-KIND */;
  if (!((v2)==(VV[99]))){
   goto L8;
  }
  goto L3;
L8:;
  goto L6;
L6:;
  if (!((v2)==(VV[100]))){
   goto L12;
  }
  goto L3;
L12:;
  goto L10;
L10:;
  if (!((v2)==(ECL_SYM("SPECIAL",792)))){
   goto L16;
  }
  goto L3;
L16:;
  goto L14;
L14:;
  if (!((v2)==(VV[27]))){
   goto L19;
  }
  goto L3;
L19:;
  goto L4;
 }
L4:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[25]))->cfun.entry(1, v1var) /*  VAR-KIND */;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3399local_var_p_va(cl_narg narg, cl_object v2var, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[109]);
 {
  return L3399local_var_p(v2var);
 }
}
/* function definition for GLOBAL-VAR-P                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3400global_var_p(cl_object v1var)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2kind;
  v2kind = (cl_env_copy->function=ecl_fdefinition(VV[25]))->cfun.entry(1, v1var) /*  VAR-KIND */;
  value0 = ecl_make_bool((v2kind)==(VV[27]));
  if (value0!=ECL_NIL) {
   goto L4;
  }
  value0 = ecl_make_bool((v2kind)==(ECL_SYM("SPECIAL",792)));
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3400global_var_p_va(cl_narg narg, cl_object v3var, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[111]);
 {
  return L3400global_var_p(v3var);
 }
}
/* function definition for USEFUL-VAR-P                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3401useful_var_p(cl_object v1var)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(1, v1var) /*  VAR-REF */;
 value0 = ecl_make_bool(ecl_plusp(T0));
 if (value0!=ECL_NIL) {
  goto L3;
 }
 value0 = L3400global_var_p(v1var);
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3401useful_var_p_va(cl_narg narg, cl_object v2var, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[113]);
 {
  return L3401useful_var_p(v2var);
 }
}
/* closure ABORT-ON-SIDE-EFFECTS                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3377abort_on_side_effects(cl_narg narg, cl_object v1form, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  REPLACEABLE             */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1]);
 {
L1:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(1, v1form) /*  C1FORM-NAME */;
  if (!((T0)==(ECL_SYM("VARIABLE",901)))){
   goto L2;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[3]))->cfun.entry(1, v1form) /*  C1FORM-ARGS */;
  T1 = ecl_car(T0);
  if (!((ECL_CONS_CAR(CLV0))==(T1))){
   goto L4;
  }
  cl_env_copy->values[0] = ECL_T;
  cl_env_copy->nvalues = 1;
  cl_return_from(ECL_CONS_CAR(CLV1),VV[0]);
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, v1form) /*  C1FORM-SIDE-EFFECTS */)){
   goto L7;
  }
  cl_env_copy->values[0] = ECL_NIL;
  cl_env_copy->nvalues = 1;
  cl_return_from(ECL_CONS_CAR(CLV1),VV[0]);
L7:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
#include "cmp/cmpvar.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclpFN7nDATYm3p9_OjR0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPVAR.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclpFN7nDATYm3p9_OjR0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(_ecl_static_0);
  ecl_cmp_defun(VV[115]);                         /*  REPLACEABLE             */
  ecl_cmp_defun(VV[116]);                         /*  NSUBST-VAR              */
  ecl_cmp_defun(VV[117]);                         /*  MAKE-VAR                */
  ecl_cmp_defun(VV[118]);                         /*  MAKE-LCL-VAR            */
  ecl_cmp_defun(VV[119]);                         /*  MAKE-GLOBAL-VAR         */
  ecl_cmp_defun(VV[120]);                         /*  MAKE-TEMP-VAR           */
  ecl_cmp_defun(VV[121]);                         /*  VAR-REFERENCED-IN-FORM-LIST */
  ecl_cmp_defun(VV[122]);                         /*  VAR-CHANGED-IN-FORM-LIST */
  ecl_cmp_defun(VV[123]);                         /*  VAR-REFERENCED-IN-FORM  */
  ecl_cmp_defun(VV[124]);                         /*  VAR-CHANGED-IN-FORM     */
  ecl_cmp_defun(VV[125]);                         /*  UPDATE-VARIABLE-TYPE    */
  ecl_cmp_defun(VV[126]);                         /*  VAR-READ-FORMS          */
  ecl_cmp_defun(VV[127]);                         /*  ASSERT-VAR-REF-VALUE    */
  ecl_cmp_defun(VV[128]);                         /*  ASSERT-VAR-NOT-IGNORED  */
  ecl_cmp_defun(VV[129]);                         /*  DELETE-FROM-READ-NODES  */
  ecl_cmp_defun(VV[130]);                         /*  ADD-TO-READ-NODES       */
  ecl_cmp_defun(VV[131]);                         /*  ADD-TO-SET-NODES        */
  ecl_cmp_defun(VV[132]);                         /*  ADD-TO-SET-NODES-OF-VAR-LIST */
  ecl_cmp_defun(VV[133]);                         /*  VAR-HOST-TYPE           */
  ecl_cmp_defun(VV[134]);                         /*  CHECK-VREF              */
  ecl_cmp_defun(VV[135]);                         /*  UNBOXED-VAR-P           */
  ecl_cmp_defun(VV[136]);                         /*  LOCAL-VAR-P             */
  ecl_cmp_defun(VV[137]);                         /*  GLOBAL-VAR-P            */
  ecl_cmp_defun(VV[138]);                         /*  USEFUL-VAR-P            */
}
