/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpglobals.lsp                  */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpglobals.eclh"
#include "cmp/cmpglobals.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclXM15AMbFTaMi9_etL0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPGLOBALS.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclXM15AMbFTaMi9_etL0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0, T1, T2;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  si_Xmake_special(VV[0]);
  if (ecl_boundp(cl_env_copy,VV[0])) {
   goto L3;
  }
  T0 = ecl_make_int8_t(3);
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
L3:;
  si_Xmake_special(VV[1]);
  if (ecl_boundp(cl_env_copy,VV[1])) {
   goto L10;
  }
  T0 = VV[2];
  ecl_cmp_setq(cl_env_copy,VV[1],T0);
L10:;
  si_Xmake_special(VV[3]);
  si_Xmake_special(VV[4]);
  if (ecl_boundp(cl_env_copy,VV[4])) {
   goto L21;
  }
  T0 = VV[2];
  ecl_cmp_setq(cl_env_copy,VV[4],T0);
L21:;
  si_Xmake_special(VV[5]);
  if (ecl_boundp(cl_env_copy,VV[5])) {
   goto L28;
  }
  T0 = ecl_make_int8_t(-1);
  ecl_cmp_setq(cl_env_copy,VV[5],T0);
L28:;
  si_Xmake_special(VV[6]);
  if (ecl_boundp(cl_env_copy,VV[6])) {
   goto L35;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
L35:;
  si_Xmake_special(VV[7]);
  if (ecl_boundp(cl_env_copy,VV[7])) {
   goto L42;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[7],T0);
L42:;
  si_Xmake_special(VV[8]);
  if (ecl_boundp(cl_env_copy,VV[8])) {
   goto L49;
  }
  T0 = cl_gensym(0);
  ecl_cmp_setq(cl_env_copy,VV[8],T0);
L49:;
  si_Xmake_special(VV[9]);
  if (ecl_boundp(cl_env_copy,VV[9])) {
   goto L56;
  }
  T0 = cl_gensym(0);
  ecl_cmp_setq(cl_env_copy,VV[9],T0);
L56:;
  si_Xmake_special(VV[10]);
  if (ecl_boundp(cl_env_copy,VV[10])) {
   goto L63;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[10],T0);
L63:;
  si_Xmake_special(ECL_SYM("*COMPILE-PRINT*",30));
  if (ecl_boundp(cl_env_copy,ECL_SYM("*COMPILE-PRINT*",30))) {
   goto L70;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*COMPILE-PRINT*",30),T0);
L70:;
  si_Xmake_special(ECL_SYM("*COMPILE-VERBOSE*",31));
  if (ecl_boundp(cl_env_copy,ECL_SYM("*COMPILE-VERBOSE*",31))) {
   goto L77;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*COMPILE-VERBOSE*",31),T0);
L77:;
  si_Xmake_special(VV[11]);
  if (ecl_boundp(cl_env_copy,VV[11])) {
   goto L84;
  }
  T0 = VVtemp[1];
  ecl_cmp_setq(cl_env_copy,VV[11],T0);
L84:;
  si_Xmake_special(VV[12]);
  if (ecl_boundp(cl_env_copy,VV[12])) {
   goto L91;
  }
  T0 = VV[13];
  ecl_cmp_setq(cl_env_copy,VV[12],T0);
L91:;
  si_Xmake_special(VV[14]);
  if (ecl_boundp(cl_env_copy,VV[14])) {
   goto L98;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[14],T0);
L98:;
  si_Xmake_special(VV[15]);
  if (ecl_boundp(cl_env_copy,VV[15])) {
   goto L105;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[15],T0);
L105:;
  si_Xmake_special(VV[16]);
  si_Xmake_special(VV[17]);
  si_Xmake_special(VV[18]);
  if (ecl_boundp(cl_env_copy,VV[18])) {
   goto L120;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[18],T0);
L120:;
  si_Xmake_special(VV[19]);
  if (ecl_boundp(cl_env_copy,VV[19])) {
   goto L127;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[19],T0);
L127:;
  si_Xmake_special(VV[20]);
  if (ecl_boundp(cl_env_copy,VV[20])) {
   goto L134;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[20],T0);
L134:;
  T0 = cl_adjoin(2, VV[20], ecl_cmp_symbol_value(cl_env_copy,VV[21]));
  ecl_cmp_setq(cl_env_copy,VV[21],T0);
  si_Xmake_special(VV[22]);
  si_Xmake_special(VV[23]);
  if (ecl_boundp(cl_env_copy,VV[23])) {
   goto L147;
  }
  T0 = ecl_make_int8_t(2);
  ecl_cmp_setq(cl_env_copy,VV[23],T0);
L147:;
  si_Xmake_special(VV[24]);
  if (ecl_boundp(cl_env_copy,VV[24])) {
   goto L154;
  }
  T0 = ecl_make_int8_t(3);
  ecl_cmp_setq(cl_env_copy,VV[24],T0);
L154:;
  si_Xmake_special(VV[25]);
  if (ecl_boundp(cl_env_copy,VV[25])) {
   goto L161;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[25],T0);
L161:;
  si_Xmake_special(VV[26]);
  if (ecl_boundp(cl_env_copy,VV[26])) {
   goto L168;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[26],T0);
L168:;
  si_Xmake_special(VV[27]);
  if (ecl_boundp(cl_env_copy,VV[27])) {
   goto L175;
  }
  T0 = ecl_make_int8_t(2);
  ecl_cmp_setq(cl_env_copy,VV[27],T0);
L175:;
  si_Xmake_special(VV[28]);
  if (ecl_boundp(cl_env_copy,VV[28])) {
   goto L182;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[28],T0);
L182:;
  si_Xmake_special(VV[29]);
  if (ecl_boundp(cl_env_copy,VV[29])) {
   goto L189;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[29],T0);
L189:;
  si_Xmake_special(VV[30]);
  if (ecl_boundp(cl_env_copy,VV[30])) {
   goto L196;
  }
  T0 = cl_list(3, VV[31], ECL_SYM("MACRO",1113), ECL_SYM("CONSTANTLY-NIL",1763));
  T1 = ecl_list1(T0);
  T2 = CONS(ECL_NIL,T1);
  ecl_cmp_setq(cl_env_copy,VV[30],T2);
L196:;
  T0 = cl_adjoin(2, VV[30], ecl_cmp_symbol_value(cl_env_copy,VV[21]));
  ecl_cmp_setq(cl_env_copy,VV[21],T0);
  si_Xmake_special(VV[32]);
  if (ecl_boundp(cl_env_copy,VV[32])) {
   goto L205;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[32],T0);
L205:;
  si_Xmake_special(VV[33]);
  if (ecl_boundp(cl_env_copy,VV[33])) {
   goto L212;
  }
  T0 = ECL_T;
  ecl_cmp_setq(cl_env_copy,VV[33],T0);
L212:;
  si_Xmake_special(VV[34]);
  if (ecl_boundp(cl_env_copy,VV[34])) {
   goto L219;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[34],T0);
L219:;
  si_Xmake_special(VV[35]);
  if (ecl_boundp(cl_env_copy,VV[35])) {
   goto L226;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[35],T0);
L226:;
  si_Xmake_special(VV[36]);
  if (ecl_boundp(cl_env_copy,VV[36])) {
   goto L233;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[36],T0);
L233:;
  si_Xmake_special(VV[37]);
  if (ecl_boundp(cl_env_copy,VV[37])) {
   goto L240;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[37],T0);
L240:;
  si_Xmake_special(VV[38]);
  if (ecl_boundp(cl_env_copy,VV[38])) {
   goto L247;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[38],T0);
L247:;
  si_Xmake_special(VV[39]);
  if (ecl_boundp(cl_env_copy,VV[39])) {
   goto L254;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[39],T0);
L254:;
  si_Xmake_special(VV[40]);
  if (ecl_boundp(cl_env_copy,VV[40])) {
   goto L261;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[40],T0);
L261:;
  si_Xmake_special(VV[41]);
  if (ecl_boundp(cl_env_copy,VV[41])) {
   goto L268;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[41],T0);
L268:;
  si_Xmake_special(VV[42]);
  if (ecl_boundp(cl_env_copy,VV[42])) {
   goto L275;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[42],T0);
L275:;
  si_Xmake_special(VV[43]);
  if (ecl_boundp(cl_env_copy,VV[43])) {
   goto L282;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[43],T0);
L282:;
  si_Xmake_special(VV[44]);
  if (ecl_boundp(cl_env_copy,VV[44])) {
   goto L289;
  }
  T0 = ECL_T;
  ecl_cmp_setq(cl_env_copy,VV[44],T0);
L289:;
  si_Xmake_special(VV[45]);
  if (ecl_boundp(cl_env_copy,VV[45])) {
   goto L296;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[45],T0);
L296:;
  si_Xmake_special(VV[46]);
  si_Xmake_special(VV[47]);
  if (ecl_boundp(cl_env_copy,VV[47])) {
   goto L307;
  }
  T0 = ecl_make_int8_t(0);
  ecl_cmp_setq(cl_env_copy,VV[47],T0);
L307:;
  si_Xmake_special(VV[48]);
  if (ecl_boundp(cl_env_copy,VV[48])) {
   goto L314;
  }
  T0 = ECL_T;
  ecl_cmp_setq(cl_env_copy,VV[48],T0);
L314:;
  si_Xmake_special(VV[49]);
  if (ecl_boundp(cl_env_copy,VV[49])) {
   goto L321;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[49],T0);
L321:;
  si_Xmake_special(VV[50]);
  if (ecl_boundp(cl_env_copy,VV[50])) {
   goto L328;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[50],T0);
L328:;
  si_Xmake_special(VV[51]);
  if (ecl_boundp(cl_env_copy,VV[51])) {
   goto L335;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[51],T0);
L335:;
  si_Xmake_special(VV[52]);
  if (ecl_boundp(cl_env_copy,VV[52])) {
   goto L342;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[52],T0);
L342:;
  si_Xmake_special(VV[53]);
  if (ecl_boundp(cl_env_copy,VV[53])) {
   goto L349;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[53],T0);
L349:;
  si_Xmake_special(VV[54]);
  if (ecl_boundp(cl_env_copy,VV[54])) {
   goto L356;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[54],T0);
L356:;
  si_Xmake_special(VV[55]);
  if (ecl_boundp(cl_env_copy,VV[55])) {
   goto L363;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[55],T0);
L363:;
  si_Xmake_special(ECL_SYM("*COMPILER-CONSTANTS*",1021));
  if (ecl_boundp(cl_env_copy,ECL_SYM("*COMPILER-CONSTANTS*",1021))) {
   goto L370;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*COMPILER-CONSTANTS*",1021),T0);
L370:;
  si_Xmake_special(VV[56]);
  if (ecl_boundp(cl_env_copy,VV[56])) {
   goto L377;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[56],T0);
L377:;
  si_Xmake_special(VV[57]);
  if (ecl_boundp(cl_env_copy,VV[57])) {
   goto L384;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[57],T0);
L384:;
  si_Xmake_special(VV[58]);
  if (ecl_boundp(cl_env_copy,VV[58])) {
   goto L391;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[58],T0);
L391:;
  si_Xmake_special(VV[59]);
  if (ecl_boundp(cl_env_copy,VV[59])) {
   goto L398;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[59],T0);
L398:;
  si_Xmake_special(VV[60]);
  if (ecl_boundp(cl_env_copy,VV[60])) {
   goto L405;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[60],T0);
L405:;
  si_Xmake_special(VV[61]);
  if (ecl_boundp(cl_env_copy,VV[61])) {
   goto L412;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[61],T0);
L412:;
  si_Xmake_special(VV[62]);
  if (ecl_boundp(cl_env_copy,VV[62])) {
   goto L419;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[62],T0);
L419:;
  si_Xmake_special(VV[63]);
  if (ecl_boundp(cl_env_copy,VV[63])) {
   goto L426;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[63],T0);
L426:;
  si_Xmake_special(VV[64]);
  if (ecl_boundp(cl_env_copy,VV[64])) {
   goto L433;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[64],T0);
L433:;
  si_Xmake_special(VV[65]);
  if (ecl_boundp(cl_env_copy,VV[65])) {
   goto L440;
  }
  T0 = VVtemp[2];
  ecl_cmp_setq(cl_env_copy,VV[65],T0);
L440:;
 }
}
