/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmppass1-cont.lsp               */
#include <ecl/ecl-cmp.h>
#include "cmp/cmppass1-cont.eclh"
/* function definition for C1BLOCK                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3467c1block(cl_object v1args)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(3, ECL_SYM("BLOCK",139), v1args, ecl_make_int8_t(1)) /*  CHECK-ARGS-NUMBER */;
 {
  cl_object v2block_name;
  v2block_name = ecl_car(v1args);
  if (ECL_SYMBOLP(v2block_name)) {
   goto L4;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(2, VV[3], v2block_name) /*  CMPERR */;
L4:;
  (cl_env_copy->function=ecl_fdefinition(VV[4]))->cfun.entry(1, v2block_name) /*  ADD-SYMBOL */;
  {
   cl_object v3blk_var;
   cl_object v4blk;
   cl_object v5body;
   v3blk_var = (cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(4, ECL_SYM("NAME",1309), v2block_name, VV[6], VV[7]) /*  MAKE-VAR */;
   v4blk = (cl_env_copy->function=ecl_fdefinition(VV[8]))->cfun.entry(4, VV[9], v3blk_var, ECL_SYM("NAME",1309), v2block_name) /*  MAKE-BLK */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(0) /*  CMP-ENV-COPY */;
   ecl_bds_bind(cl_env_copy,VV[10],T0);           /*  *CMP-ENV*               */
   (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v4blk) /*  CMP-ENV-REGISTER-BLOCK */;
   T0 = ecl_cdr(v1args);
   v5body = (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(1, T0) /*  C1PROGN */;
   ecl_bds_unwind1(cl_env_copy);
   if ((cl_env_copy->function=ecl_fdefinition(VV[14]))->cfun.entry(1, v3blk_var) /*  VAR-REF-CCB */!=ECL_NIL) {
    goto L13;
   }
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(1, v3blk_var) /*  VAR-REF-CLB */)){
    goto L11;
   }
   goto L12;
L13:;
L12:;
   T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[16]),ecl_make_int8_t(1));
   ecl_cmp_setq(cl_env_copy,VV[16],T0);
L11:;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, v4blk) /*  BLK-REF */;
   if (!(ecl_plusp(T0))){
    goto L16;
   }
   T0 = ecl_list1(v3blk_var);
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(1, v4blk) /*  BLK-TYPE */;
   T2 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v5body) /*  C1FORM-TYPE */;
   T3 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(2, T1, T2) /*  VALUES-TYPE-OR */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(8, ECL_SYM("BLOCK",139), VV[19], T0, ECL_SYM("TYPE",1356), T3, VV[23], v4blk, v5body) /*  MAKE-C1FORM* */;
   return value0;
L16:;
   value0 = v5body;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3467c1block_va(cl_narg narg, cl_object v6args, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[0]);
 {
  return L3467c1block(v6args);
 }
}
/* function definition for C1RETURN-FROM                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3468c1return_from(cl_object v1args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(4, ECL_SYM("RETURN-FROM",728), v1args, ecl_make_int8_t(1), ecl_make_int8_t(2)) /*  CHECK-ARGS-NUMBER */;
 {
  cl_object v2name;
  v2name = ecl_car(v1args);
  if (ECL_SYMBOLP(v2name)) {
   goto L4;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(2, VV[3], v2name) /*  CMPERR */;
L4:;
  {
   cl_object v3;                                  /*  BLK                     */
   cl_object v4;                                  /*  CFB                     */
   cl_object v5;                                  /*  UNW                     */
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(1, v2name) /*  CMP-ENV-SEARCH-BLOCK */;
   {
    const int v6 = cl_env_copy->nvalues;
    v3 = value0;
    cl_object v7;
    v7 = (v6<=1)? ECL_NIL : cl_env_copy->values[1];
    v4 = v7;
    v7 = (v6<=2)? ECL_NIL : cl_env_copy->values[2];
    v5 = v7;
   }
   if (v3!=ECL_NIL) {
    goto L7;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(2, VV[27], v2name) /*  CMPERR */;
L7:;
   {
    cl_object v6val;
    cl_object v7var;
    cl_object v8nonlocal;
    T0 = ecl_cadr(v1args);
    v6val = (cl_env_copy->function=ecl_fdefinition(VV[28]))->cfun.entry(1, T0) /*  C1EXPR */;
    v7var = (cl_env_copy->function=ecl_fdefinition(VV[29]))->cfun.entry(1, v3) /*  BLK-VAR */;
    value0 = v4;
    if (value0!=ECL_NIL) {
     goto L13;
    }
    v8nonlocal = v5;
    goto L11;
L13:;
    v8nonlocal = value0;
    goto L11;
L11:;
    if (Null(v4)){
     goto L15;
    }
    ecl_structure_set(v7var,VV[30],(cl_fixnum)(2),ECL_T);
L15:;
    {
     cl_object v9;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[17]))->cfun.entry(1, v3) /*  BLK-REF */;
     v9 = ecl_plus(T0,ecl_make_int8_t(1));
     ecl_structure_set(v3,VV[31],(cl_fixnum)(1),v9);
    }
    {
     cl_object v9;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[21]))->cfun.entry(1, v3) /*  BLK-TYPE */;
     T1 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v6val) /*  C1FORM-TYPE */;
     v9 = (cl_env_copy->function=ecl_fdefinition(VV[20]))->cfun.entry(2, T0, T1) /*  VALUES-TYPE-OR */;
     ecl_structure_set(v3,VV[31],(cl_fixnum)(8),v9);
    }
    {
     cl_object v9output;
     v9output = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(7, ECL_SYM("RETURN-FROM",728), ECL_SYM("TYPE",1356), ECL_T, VV[23], v3, v8nonlocal, v6val) /*  MAKE-C1FORM* */;
     if (v4!=ECL_NIL) {
      goto L24;
     }
     if (Null(v5)){
      goto L22;
     }
     goto L23;
L24:;
L23:;
     (cl_env_copy->function=ecl_fdefinition(VV[32]))->cfun.entry(2, v7var, v9output) /*  ADD-TO-READ-NODES */;
L22:;
     value0 = v9output;
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
}
static cl_object L3468c1return_from_va(cl_narg narg, cl_object v3args, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[25]);
 {
  return L3468c1return_from(v3args);
 }
}
/* function definition for ADD-LOOP-REGISTERS                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3471add_loop_registers(cl_object v1tagbody)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2v;
  cl_object v3end;
  cl_object v4first;
  v2v = v1tagbody;
  v3end = ECL_NIL;
  v4first = ECL_NIL;
  goto L7;
L6:;
  T0 = ecl_car(v2v);
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[43]))->cfun.entry(1, T0) /*  TAG-P */)){
   goto L9;
  }
  if (v4first!=ECL_NIL) {
   goto L11;
  }
  v4first = v2v;
L11:;
  {
   cl_object v5;
   cl_object v6;
   cl_object v7w;
   v5 = ecl_cdr(v2v);
   T0 = ecl_car(v2v);
   v6 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, T0) /*  TAG-NAME */;
   v7w = v5;
   goto L19;
L18:;
   T0 = ecl_car(v7w);
   if (Null(LC3470jumps_to_p(T0, v6))){
    goto L21;
   }
   v3end = v7w;
L21:;
   v7w = ecl_cdr(v7w);
L19:;
   if (v7w==ECL_NIL) {
    goto L26;
   }
   goto L18;
L26:;
  }
L9:;
  v2v = ecl_cdr(v2v);
L7:;
  if (v2v==ECL_NIL) {
   goto L30;
  }
  goto L6;
L30:;
  {
   cl_object v5ww;
   v5ww = v4first;
   goto L35;
L34:;
   T0 = ecl_car(v5ww);
   LC3469add_reg1(T0);
   v5ww = ecl_cdr(v5ww);
L35:;
   if ((v5ww)==(v3end)) {
    goto L40;
   }
   goto L34;
L40:;
   T0 = ecl_car(v5ww);
   value0 = LC3469add_reg1(T0);
   return value0;
  }
 }
}
static cl_object L3471add_loop_registers_va(cl_narg narg, cl_object v6tagbody, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[34]);
 {
  return L3471add_loop_registers(v6tagbody);
 }
}
/* function definition for C1TAGBODY                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3472c1tagbody(cl_object v1orig_body)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2tag_var;
  cl_object v3tag_index;
  cl_object v4body;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(0) /*  CMP-ENV-COPY */;
  ecl_bds_bind(cl_env_copy,VV[10],T0);            /*  *CMP-ENV*               */
  v2tag_var = (cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(4, ECL_SYM("NAME",1309), ECL_SYM("TAGBODY",853), VV[6], ECL_NIL) /*  MAKE-VAR */;
  v3tag_index = ecl_make_int8_t(0);
  v4body = ECL_NIL;
  {
   cl_object v5;
   cl_object v6x;
   cl_object v7;
   {
    cl_object v8;
    v8 = v1orig_body;
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v8;
   }
   v6x = ECL_NIL;
   v7 = v5;
   {
    cl_object v8;
    cl_object v9;
    v8 = ecl_list1(ECL_NIL);
    v9 = v8;
L14:;
    if (!(ecl_endp(v7))){
     goto L16;
    }
    goto L15;
L16:;
    v6x = ECL_CONS_CAR(v7);
    {
     cl_object v10;
     v10 = ECL_CONS_CDR(v7);
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v7 = v10;
    }
    {
     cl_object v10;
     v10 = v9;
     if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T0 = v10;
    }
    if (!(ECL_CONSP(v6x))){
     goto L30;
    }
    T1 = v6x;
    goto L29;
L30:;
    {
     cl_object v10tag;
     v10tag = (cl_env_copy->function=ecl_fdefinition(VV[50]))->cfun.entry(6, ECL_SYM("NAME",1309), v6x, VV[9], v2tag_var, VV[51], v3tag_index) /*  MAKE-TAG */;
     T2 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, v10tag) /*  TAG-NAME */;
     (cl_env_copy->function=ecl_fdefinition(VV[52]))->cfun.entry(2, T2, v10tag) /*  CMP-ENV-REGISTER-TAG */;
     v3tag_index = ecl_plus(v3tag_index,ecl_make_int8_t(1));
     T1 = v10tag;
    }
L29:;
    v9 = ecl_list1(T1);
    (ECL_CONS_CDR(T0)=v9,T0);
    goto L14;
L15:;
    v4body = ecl_cdr(v8);
    goto L6;
   }
  }
L6:;
  (cl_env_copy->function=ecl_fdefinition(VV[5]))->cfun.entry(4, ECL_SYM("NAME",1309), VV[54], VV[6], ECL_NIL) /*  MAKE-VAR */;
  {
   cl_object v5output;
   v5output = ECL_NIL;
   {
    cl_object v6tag_body;
    v6tag_body = ECL_NIL;
    {
     cl_object v7;
     cl_object v8form;
     cl_object v9;
     {
      cl_object v10;
      v10 = v4body;
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v7 = v10;
     }
     v8form = ECL_NIL;
     v9 = v7;
L47:;
     if (!(ecl_endp(v9))){
      goto L49;
     }
     goto L48;
L49:;
     v8form = ECL_CONS_CAR(v9);
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v9);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v9 = v10;
     }
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[43]))->cfun.entry(1, v8form) /*  TAG-P */)){
      goto L58;
     }
     if (Null(v6tag_body)){
      goto L60;
     }
     T0 = cl_nreconc(v6tag_body, VV[55]);
     T1 = (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(1, T0) /*  C1PROGN */;
     v5output = CONS(T1,v5output);
     v6tag_body = ECL_NIL;
L60:;
     v5output = CONS(v8form,v5output);
     goto L57;
L58:;
     v6tag_body = CONS(v8form,v6tag_body);
L57:;
     goto L47;
L48:;
     if (Null(v6tag_body)){
      goto L70;
     }
     T0 = cl_nreconc(v6tag_body, VV[55]);
     T1 = (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(1, T0) /*  C1PROGN */;
     v4body = CONS(T1,v5output);
     goto L69;
L70:;
     v4body = v5output;
L69:;
    }
   }
  }
  {
   cl_object v5;
   cl_object v6form;
   cl_object v7;
   {
    cl_object v8;
    v8 = v4body;
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v8;
   }
   v6form = ECL_NIL;
   v7 = v5;
   {
    cl_object v8output;
    v8output = ECL_NIL;
L79:;
    if (!(ecl_endp(v7))){
     goto L81;
    }
    goto L80;
L81:;
    v6form = ECL_CONS_CAR(v7);
    {
     cl_object v9;
     v9 = ECL_CONS_CDR(v7);
     if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v7 = v9;
    }
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[43]))->cfun.entry(1, v6form) /*  TAG-P */)){
     goto L91;
    }
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(1, v6form) /*  TAG-REF */;
    if (!(ecl_plusp(T0))){
     goto L89;
    }
    goto L90;
L91:;
L90:;
    v8output = CONS(v6form,v8output);
L89:;
    goto L79;
L80:;
    v4body = v8output;
   }
  }
  if (!(v4body==ECL_NIL)){
   goto L97;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(1, ECL_NIL) /*  C1PROGN */;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L97:;
  T0 = ecl_last(v4body,1);
  T1 = ecl_car(T0);
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[43]))->cfun.entry(1, T1) /*  TAG-P */)){
   goto L99;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[28]))->cfun.entry(1, ECL_NIL) /*  C1EXPR */;
  T1 = ecl_list1(T0);
  v4body = ecl_nconc(v4body,T1);
L99:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[57]))->cfun.entry(1, v2tag_var) /*  VAR-REF */;
  if (!(ecl_zerop(T0))){
   goto L102;
  }
  T0 = ecl_fdefinition(VV[43]);
  T1 = cl_delete_if(2, T0, v4body);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(3, ECL_SYM("PROGN",674), VV[23], T1) /*  MAKE-C1FORM* */;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L102:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[14]))->cfun.entry(1, v2tag_var) /*  VAR-REF-CCB */)){
   goto L105;
  }
  T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[16]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[16],T0);
L105:;
  L3471add_loop_registers(v4body);
  T0 = ecl_list1(v2tag_var);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(6, ECL_SYM("TAGBODY",853), VV[19], T0, VV[23], v2tag_var, v4body) /*  MAKE-C1FORM* */;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L3472c1tagbody_va(cl_narg narg, cl_object v5orig_body, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[45]);
 {
  return L3472c1tagbody(v5orig_body);
 }
}
/* function definition for C1GO                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3473c1go(cl_object v1args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(4, ECL_SYM("GO",416), v1args, ecl_make_int8_t(1), ecl_make_int8_t(1)) /*  CHECK-ARGS-NUMBER */;
 {
  cl_object v2name;
  v2name = ecl_car(v1args);
  if (ECL_SYMBOLP(v2name)) {
   goto L4;
  }
  if (ECL_FIXNUMP(v2name)||ECL_BIGNUMP(v2name)) {
   goto L4;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(2, VV[60], v2name) /*  CMPERR */;
L4:;
  {
   cl_object v3;                                  /*  TAG                     */
   cl_object v4;                                  /*  CFB                     */
   cl_object v5;                                  /*  UNW                     */
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[61]))->cfun.entry(1, v2name) /*  CMP-ENV-SEARCH-TAG */;
   {
    const int v6 = cl_env_copy->nvalues;
    v3 = value0;
    cl_object v7;
    v7 = (v6<=1)? ECL_NIL : cl_env_copy->values[1];
    v4 = v7;
    v7 = (v6<=2)? ECL_NIL : cl_env_copy->values[2];
    v5 = v7;
   }
   if (v3!=ECL_NIL) {
    goto L8;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[2]))->cfun.entry(2, VV[62], v2name) /*  CMPERR */;
L8:;
   {
    cl_object v6var;
    v6var = (cl_env_copy->function=ecl_fdefinition(VV[63]))->cfun.entry(1, v3) /*  TAG-VAR */;
    if (Null(v4)){
     goto L12;
    }
    ecl_structure_set(v6var,VV[30],(cl_fixnum)(3),ECL_T);
    ecl_structure_set(v6var,VV[30],(cl_fixnum)(6),VV[7]);
    goto L11;
L12:;
    if (Null(v5)){
     goto L11;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[64]))->cfun.entry(1, v6var) /*  VAR-KIND */!=ECL_NIL) {
     goto L11;
    }
    ecl_structure_set(v6var,VV[30],(cl_fixnum)(6),ECL_SYM("OBJECT",1315));
L11:;
    {
     cl_object v7;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[56]))->cfun.entry(1, v3) /*  TAG-REF */;
     v7 = ecl_plus(T0,ecl_make_int8_t(1));
     ecl_structure_set(v3,VV[65],(cl_fixnum)(1),v7);
    }
    value0 = v4;
    if (value0!=ECL_NIL) {
     goto L21;
    }
    T0 = v5;
    goto L19;
L21:;
    T0 = value0;
    goto L19;
L19:;
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(4, ECL_SYM("GO",416), VV[23], v3, T0) /*  MAKE-C1FORM* */;
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[32]))->cfun.entry(2, v6var, T1) /*  ADD-TO-READ-NODES */;
    return value0;
   }
  }
 }
}
static cl_object L3473c1go_va(cl_narg narg, cl_object v3args, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[59]);
 {
  return L3473c1go(v3args);
 }
}
/* function definition for C1THROW                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3474c1throw(cl_object v1args)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(4, ECL_SYM("THROW",861), v1args, ecl_make_int8_t(2), ecl_make_int8_t(2)) /*  CHECK-ARGS-NUMBER */;
 T0 = ecl_car(v1args);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[28]))->cfun.entry(1, T0) /*  C1EXPR */;
 T2 = ecl_cadr(v1args);
 T3 = (cl_env_copy->function=ecl_fdefinition(VV[28]))->cfun.entry(1, T2) /*  C1EXPR */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(4, ECL_SYM("THROW",861), VV[23], T1, T3) /*  MAKE-C1FORM* */;
 return value0;
}
static cl_object L3474c1throw_va(cl_narg narg, cl_object v2args, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[67]);
 {
  return L3474c1throw(v2args);
 }
}
/* function definition for C1CATCH                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3475c1catch(cl_object v1args)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(3, ECL_SYM("CATCH",184), v1args, ecl_make_int8_t(1)) /*  CHECK-ARGS-NUMBER */;
 T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[16]),ecl_make_int8_t(1));
 ecl_cmp_setq(cl_env_copy,VV[16],T0);
 T0 = ecl_car(v1args);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[28]))->cfun.entry(1, T0) /*  C1EXPR */;
 T2 = ecl_cdr(v1args);
 T3 = (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(1, T2) /*  C1PROGN */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(8, ECL_SYM("CATCH",184), VV[70], ECL_T, ECL_SYM("TYPE",1356), ECL_T, VV[23], T1, T3) /*  MAKE-C1FORM* */;
 return value0;
}
static cl_object L3475c1catch_va(cl_narg narg, cl_object v2args, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[69]);
 {
  return L3475c1catch(v2args);
 }
}
/* function definition for C1UNWIND-PROTECT                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3476c1unwind_protect(cl_object v1args)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[1]))->cfun.entry(3, ECL_SYM("UNWIND-PROTECT",892), v1args, ecl_make_int8_t(1)) /*  CHECK-ARGS-NUMBER */;
 T0 = ecl_cdr(v1args);
 if (!(T0==ECL_NIL)){
  goto L3;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[73]))->cfun.entry(1, VV[74]) /*  CMPDEBUG */;
 T0 = ecl_car(v1args);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[28]))->cfun.entry(1, T0) /*  C1EXPR */;
 return value0;
L3:;
 T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[16]),ecl_make_int8_t(1));
 ecl_cmp_setq(cl_env_copy,VV[16],T0);
 {
  cl_object v2form;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[75]))->cfun.entry(1, ECL_SYM("UNWIND-PROTECT-BOUNDARY",1948)) /*  CMP-ENV-MARK */;
  ecl_bds_bind(cl_env_copy,VV[10],T0);            /*  *CMP-ENV*               */
  T0 = ecl_car(v1args);
  v2form = (cl_env_copy->function=ecl_fdefinition(VV[28]))->cfun.entry(1, T0) /*  C1EXPR */;
  ecl_bds_unwind1(cl_env_copy);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v2form) /*  C1FORM-TYPE */;
  T1 = ecl_cdr(v1args);
  T2 = (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(1, T1) /*  C1PROGN */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(8, ECL_SYM("UNWIND-PROTECT",892), ECL_SYM("TYPE",1356), T0, VV[70], ECL_T, VV[23], v2form, T2) /*  MAKE-C1FORM* */;
  return value0;
 }
}
static cl_object L3476c1unwind_protect_va(cl_narg narg, cl_object v3args, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[72]);
 {
  return L3476c1unwind_protect(v3args);
 }
}
/* local function JUMPS-TO-P                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3470jumps_to_p(cl_object v1clause, cl_object v2tag_name)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[36]))->cfun.entry(1, v1clause) /*  C1FORM-P */)){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[40]))->cfun.entry(1, v1clause) /*  C1FORM-NAME */;
 if (!((T0)==(ECL_SYM("GO",416)))){
  goto L5;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[37]))->cfun.entry(1, v1clause) /*  C1FORM-ARGS */;
 T1 = ecl_car(T0);
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, T1) /*  TAG-NAME */;
 value0 = ecl_make_bool((T2)==(v2tag_name));
 cl_env_copy->nvalues = 1;
 return value0;
L5:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!(ECL_ATOM(v1clause))){
  goto L7;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L7:;
 T0 = ecl_car(v1clause);
 value0 = LC3470jumps_to_p(T0, v2tag_name);
 if (value0!=ECL_NIL) {
  goto L10;
 }
 v1clause = ecl_cdr(v1clause);
 goto L1;
L10:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC3470jumps_to_p_va(cl_narg narg, cl_object v3clause, cl_object v4tag_name, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[39]);
 {
  return LC3470jumps_to_p(v3clause, v4tag_name);
 }
}
/* local function ADD-REG1                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3469add_reg1(cl_object v1form)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[36]))->cfun.entry(1, v1form) /*  C1FORM-P */)){
  goto L2;
 }
 {
  cl_object v2;
  v2 = (cl_env_copy->function=ecl_fdefinition(VV[37]))->cfun.entry(1, v1form) /*  C1FORM-ARGS */;
  goto L7;
L6:;
  {
   cl_object v3v;
   v3v = ecl_car(v2);
   LC3469add_reg1(v3v);
  }
  v2 = ecl_cdr(v2);
L7:;
  if (Null(v2)){
   goto L14;
  }
  goto L6;
L14:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L2:;
 if (!(ECL_CONSP(v1form))){
  goto L16;
 }
 {
  cl_object v3;
  v3 = v1form;
  goto L21;
L20:;
  {
   cl_object v4v;
   v4v = ecl_car(v3);
   LC3469add_reg1(v4v);
  }
  v3 = ecl_cdr(v3);
L21:;
  if (Null(v3)){
   goto L28;
  }
  goto L20;
L28:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L16:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[38]))->cfun.entry(1, v1form) /*  VAR-P */)){
  goto L30;
 }
 {
  cl_object v4;
  v4 = ecl_make_fixnum(2305843009213693951);
  value0 = ecl_structure_set(v1form,VV[30],(cl_fixnum)(1),v4);
  cl_env_copy->nvalues = 1;
  return value0;
 }
L30:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC3469add_reg1_va(cl_narg narg, cl_object v5form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[35]);
 {
  return LC3469add_reg1(v5form);
 }
}
#include "cmp/cmppass1-cont.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclv5N98aIQjGjq9_WBT0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPPASS1-CONT.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclv5N98aIQjGjq9_WBT0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(_ecl_static_0);
  ecl_cmp_defun(VV[77]);                          /*  C1BLOCK                 */
  ecl_cmp_defun(VV[78]);                          /*  C1RETURN-FROM           */
  ecl_cmp_defun(VV[79]);                          /*  ADD-LOOP-REGISTERS      */
  ecl_cmp_defun(VV[80]);                          /*  C1TAGBODY               */
  ecl_cmp_defun(VV[81]);                          /*  C1GO                    */
  ecl_cmp_defun(VV[82]);                          /*  C1THROW                 */
  ecl_cmp_defun(VV[83]);                          /*  C1CATCH                 */
  ecl_cmp_defun(VV[84]);                          /*  C1UNWIND-PROTECT        */
}
