/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpbackend-cxx/cmpc-inl-sysfun.lsp */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpc-inl-sysfun.eclh"
/* function definition for INLINE-INFORMATION                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3735inline_information(cl_object v1name, cl_object v2safety)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, v1name, v2safety);
 value0 = cl_gethash(2, T0, ecl_cmp_symbol_value(cl_env_copy,VV[1]));
 return value0;
}
static cl_object L3735inline_information_va(cl_narg narg, cl_object v3name, cl_object v4safety, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[0]);
 {
  return L3735inline_information(v3name, v4safety);
 }
}
/* function definition for (SETF INLINE-INFORMATION)                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3736_setf_inline_information_(cl_object v1value, cl_object v2name, cl_object v3safety)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, v2name, v3safety);
 value0 = si_hash_set(T0, ecl_cmp_symbol_value(cl_env_copy,VV[1]), v1value);
 return value0;
}
static cl_object L3736_setf_inline_information__va(cl_narg narg, cl_object v4value, cl_object v5name, cl_object v6safety, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[3]);
 {
  return L3736_setf_inline_information_(v4value, v5name, v6safety);
 }
}
/* function definition for %DEF-INLINE                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3738_def_inline(cl_narg narg, cl_object v1name, cl_object v2safety, cl_object v3arg_types, cl_object v4return_host_type, cl_object v5expansion, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<5)) FEwrong_num_arguments(VV[5]);
 {
  cl_object v6one_liner;
  cl_object v7exact_return_type;
  cl_object v8multiple_values;
  ecl_va_list args; ecl_va_start(args,v5expansion,narg,5);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L3738_def_inlinekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[3])) {
    v6one_liner = ECL_T;
   } else {
    v6one_liner = keyvars[0];
   }
   v7exact_return_type = keyvars[1];
   if (Null(keyvars[5])) {
    v8multiple_values = ECL_T;
   } else {
    v8multiple_values = keyvars[2];
   }
  }
  {
   cl_object v9arg_host_types;
   v9arg_host_types = ECL_NIL;
   if (!((v2safety)==(VV[6]))){
    goto L6;
   }
   v2safety = VV[7];
   goto L5;
L6:;
   if (!((v2safety)==(VV[8]))){
    goto L8;
   }
   v2safety = VV[9];
   goto L5;
L8:;
   v2safety = cl_error(2, VV[10], v2safety);
L5:;
   {
    cl_object v10;
    cl_object v11type;
    cl_object v12;
    {
     cl_object v13;
     v13 = CONS(v4return_host_type,v3arg_types);
     if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v10 = v13;
    }
    v11type = ECL_NIL;
    v12 = v10;
L16:;
    if (!(ecl_endp(v12))){
     goto L18;
    }
    goto L17;
L18:;
    v11type = ECL_CONS_CAR(v12);
    {
     cl_object v13;
     v13 = ECL_CONS_CDR(v12);
     if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v12 = v13;
    }
    if ((v11type)==(VV[13])) {
     goto L26;
    }
    if (!(ECL_CONSP(v11type))){
     goto L31;
    }
    T0 = ecl_car(v11type);
    if ((T0)==(ECL_SYM("VALUES",899))) {
     goto L26;
    }
    goto L29;
L31:;
    goto L29;
L29:;
    if ((cl_env_copy->function=ecl_fdefinition(VV[14]))->cfun.entry(1, v11type) /*  LISP-TYPE-P */!=ECL_NIL) {
     goto L26;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(1, v11type) /*  MACHINE-C-TYPE-P */!=ECL_NIL) {
     goto L26;
    }
    (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(3, VV[16], v1name, v11type) /*  WARN */;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L26:;
    goto L16;
L17:;
   }
   {
    cl_object v10;
    {
     cl_object v11;
     v11 = ecl_make_cfun_va((cl_objectfn)LC3737__lambda17_va,ECL_NIL,Cblock,1);
     v10 = v11;
    }
    {
     cl_object v11;
     cl_object v12;
     cl_object v13;
     {
      cl_object v14;
      v14 = v3arg_types;
      if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v11 = v14;
     }
     v12 = ECL_NIL;
     v13 = v11;
     {
      cl_object v14;
      cl_object v15;
      v14 = ecl_list1(ECL_NIL);
      v15 = v14;
L46:;
      if (!(ecl_endp(v13))){
       goto L48;
      }
      goto L47;
L48:;
      v12 = ECL_CONS_CAR(v13);
      {
       cl_object v16;
       v16 = ECL_CONS_CDR(v13);
       if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v13 = v16;
      }
      {
       cl_object v16;
       v16 = v15;
       if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v16;
      }
      T1 = ecl_function_dispatch(cl_env_copy,v10)(1, v12);
      v15 = ecl_list1(T1);
      (ECL_CONS_CDR(T0)=v15,T0);
      goto L46;
L47:;
      v9arg_host_types = ecl_cdr(v14);
      goto L37;
     }
    }
   }
L37:;
   if (!((v4return_host_type)==(ECL_T))){
    goto L64;
   }
   v4return_host_type = ECL_SYM("OBJECT",1315);
L64:;
   {
    cl_object v10return_type;
    cl_object v11inline_info;
    if (!(ECL_CONSP(v4return_host_type))){
     goto L68;
    }
    T0 = ecl_car(v4return_host_type);
    if (!((T0)==(ECL_SYM("VALUES",899)))){
     goto L68;
    }
    v10return_type = ECL_T;
    goto L67;
L68:;
    v10return_type = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v4return_host_type) /*  HOST-TYPE->LISP-TYPE */;
L67:;
    v11inline_info = (cl_env_copy->function=ecl_fdefinition(VV[23]))->cfun.entry(18, ECL_SYM("NAME",1309), v1name, VV[24], v9arg_host_types, VV[25], v4return_host_type, VV[26], v10return_type, VV[27], v3arg_types, VV[28], v7exact_return_type, VV[29], v8multiple_values, VV[30], v6one_liner, VV[31], v5expansion) /*  MAKE-INLINE-INFO */;
    {
     cl_object v12;
     cl_object v13;
     cl_object v14;
     v12 = cl_list(2, v1name, v2safety);
     v13 = ecl_cmp_symbol_value(cl_env_copy,VV[1]);
     T0 = ecl_gethash_safe(v12,v13,ECL_NIL);
     v14 = CONS(v11inline_info,T0);
     value0 = si_hash_set(v12, v13, v14);
     return value0;
    }
   }
  }
 }
}
/* local function DEF-INLINE                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3739def_inline(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), v3);
  value0 = cl_list(3, ECL_SYM("APPLY",91), VV[34], T0);
  return value0;
 }
}
static cl_object LC3739def_inline_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[33]);
 {
  return LC3739def_inline(v4, v5);
 }
}
/* function definition for MAKE-INLINE-INFORMATION                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3740make_inline_information(cl_object v1_machine_)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 ecl_bds_bind(cl_env_copy,VV[36],v1_machine_);    /*  *MACHINE*               */
L1:;
 T0 = cl_make_hash_table(4, ECL_SYM("SIZE",1345), ecl_make_fixnum(768), ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
 ecl_bds_bind(cl_env_copy,VV[1],T0);              /*  *INLINE-INFORMATION*    */
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[38]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[39]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[40]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[41]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[42]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[43]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[44]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[45]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[46]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L20;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[48]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[49]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[50]);
L20:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[51]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[52]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[53]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[54]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[55]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[56]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[57];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L42;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[58]);
L42:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[59]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[60]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[61]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[62]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L56;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[63]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[64]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[65]);
L56:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[66]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[67]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[68]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[69]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[70]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[71]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[72]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[57];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L80;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[73]);
L80:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[74]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[75]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[76]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[77]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[78]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[79]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[80]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[81]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[82]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[83]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[84]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[85]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L110;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[86]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[87]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[88]);
L110:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[89]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[90]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[91]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[92]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[93]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[94]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[95]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[96]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[97]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[57];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L138;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[98]);
L138:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[99]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[100]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[101]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[102]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[103]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[104]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[105]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[106]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[107]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[108]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[109]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L166;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[110]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[111]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[112]);
L166:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[113]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[114]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[115]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[116]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[117]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[118]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[119]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[120]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[121]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[122]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[123]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[124]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[125]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[126]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[127]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[128]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[129]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[130]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[131]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[132]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[133]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[134]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[135]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[136]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[137]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[138]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[139]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[140]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[141]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[142]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[143]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[144]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[145]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[146]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[147]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[148]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[149]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[150]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[151]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[152]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[153]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[154]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[155]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[156]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[157]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[158]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[159]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[160]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[161]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[162]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[163]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[164]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[165]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[166]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[167]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[168]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[163]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[169]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[166]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[170]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[171]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[172]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[173]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[174]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[175]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[176]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[177]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[178]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[179]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[180]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[181]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[182]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[183]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[184]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[185]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[186]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[187]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[188]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[189]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[190]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[191]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[192]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[193]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[194]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[195]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[196]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[197]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[198]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[199]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[200]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[201]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[202]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[203]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[204]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[205]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[206]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[207]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[208]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[209]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[210]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[211]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[212]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[213]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[214]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[215]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[216]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[217]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[218]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[219]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[220]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[221]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[222]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[223]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[224]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[225]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[226]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[227]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[228]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[229]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[230]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[231]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[232]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[233]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[234]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[235]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[236]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[237]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[238]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[239]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[240]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[241]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[242]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[243]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[244]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[245]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[246]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[247]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[248]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[249]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[250]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L456;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[251]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[252]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[253]);
L456:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[254]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[255]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[256]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[257]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[258]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[259]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L478;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[260]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[261]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[262]);
L478:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[263]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[264]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[265]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[266]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[267]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[268]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[269]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[270]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[271]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[272]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[273]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[274]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[275]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[276]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[277]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[278]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[279]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[280]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[281]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[282]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[283]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[284]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[285]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[286]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[287]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[288]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[289]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[290]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[291]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[292]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[293]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[294]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[295]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[296]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[297]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[298]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[299]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[300]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[301]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[302]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[303]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[304];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L571;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[305]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[306]);
 goto L570;
L571:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[307]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[308]);
L570:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[309]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[310]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[311]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[312]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[313]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[314]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[315]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[316]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[317]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[318]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[319]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[320]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[321]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[322]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[323]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[324]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[325]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[326]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[327]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[328]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[329]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[330]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[331]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[332]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[333]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[334]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[335]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[336]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[337]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[338]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[339]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[340]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[341]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[342]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[343]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[344]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[345]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[346]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[347]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[348]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[349]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[350]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[351]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[352]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[353]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[354]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[355]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[356]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[357]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[358]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[359]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[360]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[361]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[362]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[363]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[364]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[365]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[366]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[367]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[368]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[369]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[370]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L706;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[371]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[372]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[373]);
L706:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[374]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[375]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[376]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L722;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[377]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[378]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[379]);
L722:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[380]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[381]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[382]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[383]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L740;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[384]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[385]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[386]);
L740:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[387]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[388]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[389]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[390]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L758;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[391]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[392]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[393]);
L758:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[394]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[395]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[396]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[397]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L776;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[398]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[399]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[400]);
L776:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[401]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[402]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[403]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[404]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L794;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[405]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[406]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[407]);
L794:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[408]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[409]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[410]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[411]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L812;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[412]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[413]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[414]);
L812:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[415]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[416]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[417]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[418]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L830;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[419]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[420]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[421]);
L830:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[422]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[423]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[424]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[425]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L848;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[426]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[427]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[428]);
L848:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[429]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[430]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[431]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[432]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[433]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[434]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[435]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[436]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[437]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[438]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[439]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[440]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[441]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[442]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[443]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[444]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[445]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[446]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[447]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[448]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[449]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[450]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[451]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[452]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[453]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[454]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[455]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[456]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[457]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[458]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[459]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[460]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[461]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[462]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[463]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[464]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[465]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[466]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[467]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[468]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[469]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[470]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[471]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[472]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[473]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[474]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[475]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[55]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[56]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[57];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L956;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[58]);
L956:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[59]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[60]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[61]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[66]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[476]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[477]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[478]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[479]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[480]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[481]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[482]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[483]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[484]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[485]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[57];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L991;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[486]);
 goto L990;
L991:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[487]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[488]);
L990:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[489]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[490]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[491]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[492]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[57];
  v4 = v2;
  if (ecl_memql(v3,v4)!=ECL_NIL) {
   goto L1008;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[493]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[494]);
L1008:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[495]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[496]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[497]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[498]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[499]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[500]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[501]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[502]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[503]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[57];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L1035;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[504]);
 goto L1034;
L1035:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[505]);
L1034:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[506]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[507]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[508]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[57];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L1049;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[509]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[510]);
 goto L1048;
L1049:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[511]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[512]);
L1048:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[513]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[514]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[515]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[516]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[517]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[518]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[519]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[520]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[521]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[522]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[523]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[524]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[525]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[526]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[527]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[47];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L1090;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[528]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[529]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[530]);
L1090:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[531]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[532]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[533];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L1104;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[534]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[535]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[536]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[537]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[538]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[539]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[540]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[541]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[542]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[543]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[544]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[545]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[546]);
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[547];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L1135;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[548]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[549]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[550]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[551]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[552]);
L1135:;
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[553]);
L1104:;
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v3 = VV[547];
  v4 = v2;
  if (Null(ecl_memql(v3,v4))){
   goto L1150;
  }
 }
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[554]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[555]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[556]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[557]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[558]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[559]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[560]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[561]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[562]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[563]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[564]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[565]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[566]);
 T0 = ecl_fdefinition(VV[5]);
 cl_apply(2, T0, VV[567]);
L1150:;
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[1]);
 cl_env_copy->nvalues = 1;
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L3740make_inline_information_va(cl_narg narg, cl_object v2_machine_, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[37]);
 {
  return L3740make_inline_information(v2_machine_);
 }
}
/* local function LAMBDA17                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3737__lambda17(cl_object v1x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v1x)==(ECL_SYM("*",20)))){
  goto L2;
 }
 value0 = v1x;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[18]))->cfun.entry(1, v1x) /*  LISP-TYPE->HOST-TYPE */;
 return value0;
}
static cl_object LC3737__lambda17_va(cl_narg narg, cl_object v2x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[17]);
 {
  return LC3737__lambda17(v2x);
 }
}
#include "cmp/cmpc-inl-sysfun.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecl1l39DjHXGy4s9_BWY0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPBACKEND-CXX;CMPC-INL-SYSFUN.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecl1l39DjHXGy4s9_BWY0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  ecl_cmp_defun(VV[571]);                         /*  INLINE-INFORMATION      */
  ecl_cmp_defun(VV[572]);                         /*  (SETF INLINE-INFORMATION) */
  ecl_cmp_defun(VV[573]);                         /*  %DEF-INLINE             */
  ecl_cmp_defmacro(VV[574]);                      /*  DEF-INLINE              */
  ecl_cmp_defun(VV[575]);                         /*  MAKE-INLINE-INFORMATION */
  {
   cl_object v1;
   v1 = ecl_cmp_symbol_value(cl_env_copy,VV[569]);
   {
    cl_object v2;
    v2 = L3740make_inline_information(ecl_cmp_symbol_value(cl_env_copy,VV[569]));
    ecl_structure_set(v1,VV[570],(cl_fixnum)(3),v2);
   }
  }
}
