/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/clos/inspect.lsp                    */
#include <ecl/ecl-cmp.h>
#include "clos/inspect.eclh"
/* local function SELECT-CLOS-N                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2735select_clos_n(cl_object v1instance)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2class;
  cl_object v3local_slotds;
  cl_object v4class_slotds;
  v2class = si_instance_class(v1instance);
  v3local_slotds = L2748class_local_slots(v2class);
  v4class_slotds = L2749class_class_slots(v2class);
  if (Null(v3local_slotds)){
   goto L6;
  }
  (cl_env_copy->function=(VV[4]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT */;
  cl_format(2, ECL_T, VV[5]);
  T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  {
   cl_object v5;
   v5 = v3local_slotds;
   goto L16;
L15:;
   {
    cl_object v6slotd;
    v6slotd = ecl_car(v5);
    (cl_env_copy->function=(VV[7]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT-1 */;
    T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v6slotd) /*  SLOT-DEFINITION-NAME */;
    cl_format(3, ECL_T, VV[8], T0);
    T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v6slotd) /*  SLOT-DEFINITION-NAME */;
    if (Null(cl_slot_boundp(v1instance, T0))){
     goto L23;
    }
    {
     cl_object v7;                                /*  UPDATE-FLAG             */
     cl_object v8;                                /*  NEW-VALUE               */
     T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v6slotd) /*  SLOT-DEFINITION-NAME */;
     T1 = cl_slot_value(v1instance, T0);
     value0 = (cl_env_copy->function=(VV[10]->symbol.gfdef))->cfun.entry(3, VV[11], T1, ECL_T) /*  READ-INSPECT-COMMAND */;
     {
      const int v9 = cl_env_copy->nvalues;
      v7 = value0;
      cl_object v10;
      v10 = (v9<=1)? ECL_NIL : cl_env_copy->values[1];
      v8 = v10;
     }
     if (Null(v7)){
      goto L22;
     }
     {
      cl_object v9;
      v9 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v6slotd) /*  SLOT-DEFINITION-NAME */;
      (cl_env_copy->function=ECL_CONS_CAR(VV[95]))->cfun.entry(3, v8, v1instance, v9) /*  (SETF SLOT-VALUE) */;
      goto L22;
     }
    }
L23:;
    {
     cl_object v7;                                /*  UPDATE-FLAG             */
     cl_object v8;                                /*  NEW-VALUE               */
     value0 = (cl_env_copy->function=(VV[10]->symbol.gfdef))->cfun.entry(3, VV[14], ECL_NIL, ECL_NIL) /*  READ-INSPECT-COMMAND */;
     {
      const int v9 = cl_env_copy->nvalues;
      v7 = value0;
      cl_object v10;
      v10 = (v9<=1)? ECL_NIL : cl_env_copy->values[1];
      v8 = v10;
     }
     if (Null(v7)){
      goto L22;
     }
     {
      cl_object v9;
      v9 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v6slotd) /*  SLOT-DEFINITION-NAME */;
      (cl_env_copy->function=ECL_CONS_CAR(VV[95]))->cfun.entry(3, v8, v1instance, v9) /*  (SETF SLOT-VALUE) */;
     }
    }
L22:;
   }
   v5 = ecl_cdr(v5);
L16:;
   if (Null(v5)){
    goto L33;
   }
   goto L15;
L33:;
  }
  T0 = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  goto L5;
L6:;
  (cl_env_copy->function=(VV[4]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT */;
  cl_format(2, ECL_T, VV[15]);
L5:;
  if (Null(v4class_slotds)){
   goto L37;
  }
  (cl_env_copy->function=(VV[4]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT */;
  cl_format(2, ECL_T, VV[16]);
  T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  {
   cl_object v5;
   v5 = v4class_slotds;
   goto L47;
L46:;
   {
    cl_object v6slotd;
    v6slotd = ecl_car(v5);
    (cl_env_copy->function=(VV[7]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT-1 */;
    T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v6slotd) /*  SLOT-DEFINITION-NAME */;
    cl_format(3, ECL_T, VV[8], T0);
    T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v6slotd) /*  SLOT-DEFINITION-NAME */;
    if (Null(cl_slot_boundp(v1instance, T0))){
     goto L54;
    }
    {
     cl_object v7;                                /*  UPDATE-FLAG             */
     cl_object v8;                                /*  NEW-VALUE               */
     T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v6slotd) /*  SLOT-DEFINITION-NAME */;
     T1 = cl_slot_value(v1instance, T0);
     value0 = (cl_env_copy->function=(VV[10]->symbol.gfdef))->cfun.entry(3, VV[11], T1, ECL_T) /*  READ-INSPECT-COMMAND */;
     {
      const int v9 = cl_env_copy->nvalues;
      v7 = value0;
      cl_object v10;
      v10 = (v9<=1)? ECL_NIL : cl_env_copy->values[1];
      v8 = v10;
     }
     if (Null(v7)){
      goto L53;
     }
     {
      cl_object v9;
      v9 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v6slotd) /*  SLOT-DEFINITION-NAME */;
      (cl_env_copy->function=ECL_CONS_CAR(VV[95]))->cfun.entry(3, v8, v1instance, v9) /*  (SETF SLOT-VALUE) */;
      goto L53;
     }
    }
L54:;
    {
     cl_object v7;                                /*  UPDATE-FLAG             */
     cl_object v8;                                /*  NEW-VALUE               */
     value0 = (cl_env_copy->function=(VV[10]->symbol.gfdef))->cfun.entry(3, VV[14], ECL_NIL, ECL_NIL) /*  READ-INSPECT-COMMAND */;
     {
      const int v9 = cl_env_copy->nvalues;
      v7 = value0;
      cl_object v10;
      v10 = (v9<=1)? ECL_NIL : cl_env_copy->values[1];
      v8 = v10;
     }
     if (Null(v7)){
      goto L53;
     }
     {
      cl_object v9;
      v9 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v6slotd) /*  SLOT-DEFINITION-NAME */;
      (cl_env_copy->function=ECL_CONS_CAR(VV[95]))->cfun.entry(3, v8, v1instance, v9) /*  (SETF SLOT-VALUE) */;
     }
    }
L53:;
   }
   v5 = ecl_cdr(v5);
L47:;
   if (Null(v5)){
    goto L64;
   }
   goto L46;
L64:;
  }
  T0 = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  value0 = ecl_cmp_symbol_value(cl_env_copy,VV[6]);
  cl_env_copy->nvalues = 1;
  return value0;
L37:;
  (cl_env_copy->function=(VV[4]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT */;
  value0 = cl_format(2, ECL_T, VV[17]);
  return value0;
 }
}
static cl_object LC2735select_clos_n_va(cl_narg narg, cl_object v5instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1]);
 {
  return LC2735select_clos_n(v5instance);
 }
}
/* function definition for SELECT-CLOS-N-INNER-CLASS                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2736select_clos_n_inner_class(cl_object v1instance)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2class;
  cl_object v3local_slotds;
  v2class = si_instance_class(v1instance);
  v3local_slotds = L2748class_local_slots(v2class);
  if (Null(v3local_slotds)){
   goto L4;
  }
  (cl_env_copy->function=(VV[4]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT */;
  cl_format(2, ECL_T, VV[19]);
  T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  {
   cl_object v4;
   v4 = v3local_slotds;
   goto L14;
L13:;
   {
    cl_object v5slotd;
    v5slotd = ecl_car(v4);
    (cl_env_copy->function=(VV[7]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT-1 */;
    T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v5slotd) /*  SLOT-DEFINITION-NAME */;
    cl_format(3, ECL_T, VV[8], T0);
    T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v5slotd) /*  SLOT-DEFINITION-NAME */;
    if (Null(cl_slot_boundp(v1instance, T0))){
     goto L21;
    }
    T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v5slotd) /*  SLOT-DEFINITION-NAME */;
    T1 = cl_slot_value(v1instance, T0);
    if (Null((cl_env_copy->function=(VV[10]->symbol.gfdef))->cfun.entry(3, VV[11], T1, ECL_T) /*  READ-INSPECT-COMMAND */)){
     goto L20;
    }
    ecl_princ(VV[20],ECL_NIL);
    cl_terpri(0);
    goto L20;
L21:;
    if (Null((cl_env_copy->function=(VV[10]->symbol.gfdef))->cfun.entry(3, VV[14], ECL_NIL, ECL_NIL) /*  READ-INSPECT-COMMAND */)){
     goto L20;
    }
    ecl_princ(VV[20],ECL_NIL);
    cl_terpri(0);
L20:;
   }
   v4 = ecl_cdr(v4);
L14:;
   if (Null(v4)){
    goto L29;
   }
   goto L13;
L29:;
  }
  T0 = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  value0 = ecl_cmp_symbol_value(cl_env_copy,VV[6]);
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  (cl_env_copy->function=(VV[4]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT */;
  value0 = cl_format(2, ECL_T, VV[21]);
  return value0;
 }
}
static cl_object L2736select_clos_n_inner_class_va(cl_narg narg, cl_object v4instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[18]);
 {
  return L2736select_clos_n_inner_class(v4instance);
 }
}
/* local function SELECT-CLOS-N                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2737select_clos_n(cl_object v1instance)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2736select_clos_n_inner_class(v1instance);
 return value0;
}
static cl_object LC2737select_clos_n_va(cl_narg narg, cl_object v2instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1]);
 {
  return LC2737select_clos_n(v2instance);
 }
}
/* local function SELECT-CLOS-N                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2738select_clos_n(cl_object v1instance)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2736select_clos_n_inner_class(v1instance);
 return value0;
}
static cl_object LC2738select_clos_n_va(cl_narg narg, cl_object v2instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1]);
 {
  return LC2738select_clos_n(v2instance);
 }
}
/* local function SELECT-CLOS-L                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2739select_clos_l(cl_object v1instance)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2class;
  cl_object v3local_slotds;
  cl_object v4class_slotds;
  v2class = si_instance_class(v1instance);
  v3local_slotds = L2748class_local_slots(v2class);
  v4class_slotds = L2749class_class_slots(v2class);
  cl_terpri(0);
  if (Null(v3local_slotds)){
   goto L7;
  }
  cl_format(2, ECL_T, VV[24]);
  {
   cl_object v5;
   v5 = v3local_slotds;
   goto L13;
L12:;
   {
    cl_object v6slotd;
    v6slotd = ecl_car(v5);
    T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v6slotd) /*  SLOT-DEFINITION-NAME */;
    cl_format(3, ECL_T, VV[25], T0);
   }
   v5 = ecl_cdr(v5);
L13:;
   if (Null(v5)){
    goto L20;
   }
   goto L12;
L20:;
   goto L6;
  }
L7:;
  cl_format(2, ECL_T, VV[15]);
L6:;
  cl_terpri(0);
  if (Null(v4class_slotds)){
   goto L24;
  }
  cl_format(2, ECL_T, VV[26]);
  {
   cl_object v5;
   v5 = v4class_slotds;
   goto L30;
L29:;
   {
    cl_object v6slotd;
    v6slotd = ecl_car(v5);
    T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v6slotd) /*  SLOT-DEFINITION-NAME */;
    cl_format(3, ECL_T, VV[25], T0);
   }
   v5 = ecl_cdr(v5);
L30:;
   if (Null(v5)){
    goto L37;
   }
   goto L29;
L37:;
   goto L23;
  }
L24:;
  cl_format(2, ECL_T, VV[17]);
L23:;
  value0 = cl_terpri(0);
  return value0;
 }
}
static cl_object LC2739select_clos_l_va(cl_narg narg, cl_object v5instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[23]);
 {
  return LC2739select_clos_l(v5instance);
 }
}
/* function definition for SELECT-CLOS-L-INNER-CLASS                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2740select_clos_l_inner_class(cl_object v1instance)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2class;
  cl_object v3local_slotds;
  v2class = si_instance_class(v1instance);
  v3local_slotds = L2748class_local_slots(v2class);
  cl_terpri(0);
  if (Null(v3local_slotds)){
   goto L6;
  }
  cl_format(2, ECL_T, VV[28]);
  {
   cl_object v4;
   v4 = v3local_slotds;
   goto L12;
L11:;
   {
    cl_object v5slotd;
    v5slotd = ecl_car(v4);
    T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v5slotd) /*  SLOT-DEFINITION-NAME */;
    cl_format(3, ECL_T, VV[25], T0);
   }
   v4 = ecl_cdr(v4);
L12:;
   if (Null(v4)){
    goto L19;
   }
   goto L11;
L19:;
   goto L5;
  }
L6:;
  cl_format(2, ECL_T, VV[21]);
L5:;
  value0 = cl_terpri(0);
  return value0;
 }
}
static cl_object L2740select_clos_l_inner_class_va(cl_narg narg, cl_object v4instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[27]);
 {
  return L2740select_clos_l_inner_class(v4instance);
 }
}
/* local function SELECT-CLOS-L                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2741select_clos_l(cl_object v1instance)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2740select_clos_l_inner_class(v1instance);
 return value0;
}
static cl_object LC2741select_clos_l_va(cl_narg narg, cl_object v2instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[23]);
 {
  return LC2741select_clos_l(v2instance);
 }
}
/* local function SELECT-CLOS-L                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2742select_clos_l(cl_object v1instance)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2740select_clos_l_inner_class(v1instance);
 return value0;
}
static cl_object LC2742select_clos_l_va(cl_narg narg, cl_object v2instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[23]);
 {
  return LC2742select_clos_l(v2instance);
 }
}
/* local function SELECT-CLOS-J                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2743select_clos_j(cl_object v1instance)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2class;
  cl_object v3local_slotds;
  cl_object v4class_slotds;
  cl_object v5slotd;
  v2class = si_instance_class(v1instance);
  v3local_slotds = L2748class_local_slots(v2class);
  v4class_slotds = L2749class_class_slots(v2class);
  {
   cl_object v6;
   cl_object v7;
   cl_object v8;
   cl_object v9;
   {
    cl_object v10;
    v10 = cl_read_preserving_whitespace(1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*QUERY-IO*",61)));
    (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
    v6 = v10;
   }
   v7 = ecl_append(v3local_slotds,v4class_slotds);
   v8 = (ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef);
   v9 = (ECL_SYM("EQ",335)->symbol.gfdef);
   {
    cl_object v10;
    v10 = v7;
    goto L16;
L15:;
    {
     cl_object v11;
     cl_object v12;
     {
      cl_object v13;
      v13 = v10;
      if (ecl_unlikely(ECL_ATOM(v13))) FEtype_error_cons(v13);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v11 = v13;
     }
     v12 = ECL_CONS_CAR(v11);
     T1 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v12) /*  SLOT-DEFINITION-NAME */;
     if (!((v6)==(T1))){
      goto L18;
     }
     T0 = v11;
     goto L6;
    }
L18:;
    v10 = ECL_CONS_CDR(v10);
L16:;
    if (v10==ECL_NIL) {
     goto L26;
    }
    goto L15;
L26:;
    T0 = ECL_NIL;
   }
  }
L6:;
  v5slotd = ecl_car(T0);
  if (Null(v5slotd)){
   goto L28;
  }
  T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  (cl_env_copy->function=(VV[7]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT-1 */;
  T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v5slotd) /*  SLOT-DEFINITION-NAME */;
  cl_format(3, ECL_T, VV[8], T0);
  T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v5slotd) /*  SLOT-DEFINITION-NAME */;
  if (Null(cl_slot_boundp(v1instance, T0))){
   goto L35;
  }
  {
   cl_object v6;                                  /*  UPDATE-FLAG             */
   cl_object v7;                                  /*  NEW-VALUE               */
   T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v5slotd) /*  SLOT-DEFINITION-NAME */;
   T1 = cl_slot_value(v1instance, T0);
   value0 = (cl_env_copy->function=(VV[10]->symbol.gfdef))->cfun.entry(3, VV[11], T1, ECL_T) /*  READ-INSPECT-COMMAND */;
   {
    const int v8 = cl_env_copy->nvalues;
    v6 = value0;
    cl_object v9;
    v9 = (v8<=1)? ECL_NIL : cl_env_copy->values[1];
    v7 = v9;
   }
   if (Null(v6)){
    goto L34;
   }
   {
    cl_object v8;
    v8 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v5slotd) /*  SLOT-DEFINITION-NAME */;
    (cl_env_copy->function=ECL_CONS_CAR(VV[95]))->cfun.entry(3, v7, v1instance, v8) /*  (SETF SLOT-VALUE) */;
    goto L34;
   }
  }
L35:;
  {
   cl_object v6;                                  /*  UPDATE-FLAG             */
   cl_object v7;                                  /*  NEW-VALUE               */
   value0 = (cl_env_copy->function=(VV[10]->symbol.gfdef))->cfun.entry(3, VV[14], ECL_NIL, ECL_NIL) /*  READ-INSPECT-COMMAND */;
   {
    const int v8 = cl_env_copy->nvalues;
    v6 = value0;
    cl_object v9;
    v9 = (v8<=1)? ECL_NIL : cl_env_copy->values[1];
    v7 = v9;
   }
   if (Null(v6)){
    goto L34;
   }
   {
    cl_object v8;
    v8 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v5slotd) /*  SLOT-DEFINITION-NAME */;
    (cl_env_copy->function=ECL_CONS_CAR(VV[95]))->cfun.entry(3, v7, v1instance, v8) /*  (SETF SLOT-VALUE) */;
   }
  }
L34:;
  T0 = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  value0 = ecl_cmp_symbol_value(cl_env_copy,VV[6]);
  cl_env_copy->nvalues = 1;
  return value0;
L28:;
  cl_terpri(0);
  T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v5slotd) /*  SLOT-DEFINITION-NAME */;
  cl_format(3, ECL_T, VV[35], T0);
  cl_terpri(0);
  value0 = cl_terpri(0);
  return value0;
 }
}
static cl_object LC2743select_clos_j_va(cl_narg narg, cl_object v6instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[30]);
 {
  return LC2743select_clos_j(v6instance);
 }
}
/* function definition for SELECT-CLOS-J-INNER-CLASS                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2744select_clos_j_inner_class(cl_object v1instance)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2class;
  cl_object v3local_slotds;
  cl_object v4slotd;
  v2class = si_instance_class(v1instance);
  v3local_slotds = L2748class_local_slots(v2class);
  {
   cl_object v5;
   cl_object v6;
   cl_object v7;
   {
    cl_object v8;
    v8 = cl_read_preserving_whitespace(1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*QUERY-IO*",61)));
    (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
    v5 = v8;
   }
   v6 = (ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef);
   v7 = (ECL_SYM("EQ",335)->symbol.gfdef);
   {
    cl_object v8;
    v8 = v3local_slotds;
    goto L14;
L13:;
    {
     cl_object v9;
     cl_object v10;
     {
      cl_object v11;
      v11 = v8;
      if (ecl_unlikely(ECL_ATOM(v11))) FEtype_error_cons(v11);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v9 = v11;
     }
     v10 = ECL_CONS_CAR(v9);
     T1 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v10) /*  SLOT-DEFINITION-NAME */;
     if (!((v5)==(T1))){
      goto L16;
     }
     T0 = v9;
     goto L5;
    }
L16:;
    v8 = ECL_CONS_CDR(v8);
L14:;
    if (v8==ECL_NIL) {
     goto L24;
    }
    goto L13;
L24:;
    T0 = ECL_NIL;
   }
  }
L5:;
  v4slotd = ecl_car(T0);
  if (Null(v4slotd)){
   goto L26;
  }
  T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  (cl_env_copy->function=(VV[7]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT-1 */;
  T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v4slotd) /*  SLOT-DEFINITION-NAME */;
  cl_format(3, ECL_T, VV[8], T0);
  T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v4slotd) /*  SLOT-DEFINITION-NAME */;
  if (Null(cl_slot_boundp(v1instance, T0))){
   goto L33;
  }
  T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v4slotd) /*  SLOT-DEFINITION-NAME */;
  T1 = cl_slot_value(v1instance, T0);
  if (Null((cl_env_copy->function=(VV[10]->symbol.gfdef))->cfun.entry(3, VV[11], T1, ECL_T) /*  READ-INSPECT-COMMAND */)){
   goto L32;
  }
  ecl_princ(VV[20],ECL_NIL);
  cl_terpri(0);
  goto L32;
L33:;
  if (Null((cl_env_copy->function=(VV[10]->symbol.gfdef))->cfun.entry(3, VV[14], ECL_NIL, ECL_NIL) /*  READ-INSPECT-COMMAND */)){
   goto L32;
  }
  ecl_princ(VV[20],ECL_NIL);
  cl_terpri(0);
L32:;
  T0 = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  value0 = ecl_cmp_symbol_value(cl_env_copy,VV[6]);
  cl_env_copy->nvalues = 1;
  return value0;
L26:;
  cl_terpri(0);
  T0 = (cl_env_copy->function=(ECL_SYM("SLOT-DEFINITION-NAME",1624)->symbol.gfdef))->cfun.entry(1, v4slotd) /*  SLOT-DEFINITION-NAME */;
  cl_format(3, ECL_T, VV[35], T0);
  cl_terpri(0);
  value0 = cl_terpri(0);
  return value0;
 }
}
static cl_object L2744select_clos_j_inner_class_va(cl_narg narg, cl_object v5instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[36]);
 {
  return L2744select_clos_j_inner_class(v5instance);
 }
}
/* local function SELECT-CLOS-J                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2745select_clos_j(cl_object v1instance)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2744select_clos_j_inner_class(v1instance);
 return value0;
}
static cl_object LC2745select_clos_j_va(cl_narg narg, cl_object v2instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[30]);
 {
  return LC2745select_clos_j(v2instance);
 }
}
/* local function SELECT-CLOS-J                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2746select_clos_j(cl_object v1instance)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2744select_clos_j_inner_class(v1instance);
 return value0;
}
static cl_object LC2746select_clos_j_va(cl_narg narg, cl_object v2instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[30]);
 {
  return LC2746select_clos_j(v2instance);
 }
}
/* function definition for SELECT-CLOS-?                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2747select_clos__()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 cl_terpri(0);
 value0 = cl_format(2, ECL_T, VV[39]);
 return value0;
}
/* function definition for CLASS-LOCAL-SLOTS                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2748class_local_slots(cl_object v1class)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=(ECL_SYM("CLASS-SLOTS",1570)->symbol.gfdef))->cfun.entry(1, v1class) /*  CLASS-SLOTS */;
 T1 = (ECL_SYM("SLOT-DEFINITION-ALLOCATION",1619)->symbol.gfdef);
 value0 = cl_remove(4, VV[40], T0, ECL_SYM("KEY",1297), T1);
 return value0;
}
static cl_object L2748class_local_slots_va(cl_narg narg, cl_object v2class, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2]);
 {
  return L2748class_local_slots(v2class);
 }
}
/* function definition for CLASS-CLASS-SLOTS                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2749class_class_slots(cl_object v1class)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=(ECL_SYM("CLASS-SLOTS",1570)->symbol.gfdef))->cfun.entry(1, v1class) /*  CLASS-SLOTS */;
 T1 = (ECL_SYM("SLOT-DEFINITION-ALLOCATION",1619)->symbol.gfdef);
 value0 = cl_remove(4, ECL_SYM("INSTANCE",1291), T0, ECL_SYM("KEY",1297), T1);
 return value0;
}
static cl_object L2749class_class_slots_va(cl_narg narg, cl_object v2class, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[3]);
 {
  return L2749class_class_slots(v2class);
 }
}
/* local function INSPECT-OBJ                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2750inspect_obj(cl_object v1instance)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2metaclass;
  T0 = si_instance_class(v1instance);
  v2metaclass = ECL_CLASS_OF(T0);
  T0 = cl_find_class(1, ECL_SYM("STANDARD-CLASS",977));
  if ((v2metaclass)==(T0)) {
   goto L2;
  }
  T0 = cl_find_class(1, ECL_SYM("FUNCALLABLE-STANDARD-CLASS",1592));
  if ((v2metaclass)==(T0)) {
   goto L2;
  }
 }
 cl_terpri(0);
 cl_format(2, ECL_T, VV[44]);
 T0 = si_instance_class(v1instance);
 cl_format(3, ECL_T, VV[45], T0);
 cl_env_copy->values[0] = ECL_NIL;
 cl_env_copy->nvalues = 1;
 cl_throw(VV[46]);
L2:;
 T0 = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
 ecl_cmp_setq(cl_env_copy,VV[6],T0);
 {
  cl_object v2class;
  cl_object v3local_slotds;
  cl_object v4class_slotds;
  v2class = si_instance_class(v1instance);
  v3local_slotds = L2748class_local_slots(v2class);
  v4class_slotds = L2749class_class_slots(v2class);
L16:;
  cl_format(3, ECL_T, VV[47], v1instance);
  T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  (cl_env_copy->function=(VV[4]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT */;
  T0 = (cl_env_copy->function=(ECL_SYM("CLASS-NAME",938)->symbol.gfdef))->cfun.entry(1, v2class) /*  CLASS-NAME */;
  cl_format(3, ECL_T, VV[48], T0);
  (cl_env_copy->function=(VV[4]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT */;
  {
   cl_fixnum v5;
   v5 = ecl_length(v3local_slotds);
   {
    cl_fixnum v6;
    v6 = ecl_length(v4class_slotds);
    cl_format(4, ECL_T, VV[49], ecl_make_fixnum(v5), ecl_make_fixnum(v6));
   }
  }
  cl_force_output(0);
  {
   cl_object v5;
   {
    cl_object v6char;
    v6char = cl_read_char(1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*QUERY-IO*",61)));
    goto L31;
L30:;
    v6char = cl_read_char(1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*QUERY-IO*",61)));
L31:;
    if (!(ecl_char_code(v6char)!=ecl_char_code(ECL_CODE_CHAR(32)))){
     goto L38;
    }
    if (cl_charNE(1, ECL_CODE_CHAR(9))!=ECL_NIL) {
     goto L35;
    }
    goto L36;
L38:;
    goto L36;
L36:;
    goto L30;
L35:;
    v5 = v6char;
   }
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(10))))){
    goto L45;
   }
   goto L42;
L45:;
   goto L43;
L43:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(13))))){
    goto L40;
   }
   goto L41;
L42:;
L41:;
   (cl_env_copy->function=(VV[1]->symbol.gfdef))->cfun.entry(1, v1instance) /*  SELECT-CLOS-N */;
   goto L12;
L40:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(110))))){
    goto L54;
   }
   goto L51;
L54:;
   goto L52;
L52:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(78))))){
    goto L49;
   }
   goto L50;
L51:;
L50:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   (cl_env_copy->function=(VV[1]->symbol.gfdef))->cfun.entry(1, v1instance) /*  SELECT-CLOS-N */;
   goto L12;
L49:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(115))))){
    goto L64;
   }
   goto L61;
L64:;
   goto L62;
L62:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(83))))){
    goto L59;
   }
   goto L60;
L61:;
L60:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   goto L12;
L59:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(112))))){
    goto L73;
   }
   goto L70;
L73:;
   goto L71;
L71:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(80))))){
    goto L68;
   }
   goto L69;
L70:;
L69:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   (cl_env_copy->function=(VV[58]->symbol.gfdef))->cfun.entry(1, v1instance) /*  SELECT-P */;
   goto L26;
L68:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(97))))){
    goto L82;
   }
   goto L79;
L82:;
   goto L80;
L80:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(65))))){
    goto L77;
   }
   goto L78;
L79:;
L78:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   cl_env_copy->values[0] = ECL_NIL;
   cl_env_copy->nvalues = 1;
   cl_throw(VV[46]);
L77:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(101))))){
    goto L92;
   }
   goto L89;
L92:;
   goto L90;
L90:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(69))))){
    goto L87;
   }
   goto L88;
L89:;
L88:;
   (cl_env_copy->function=(VV[63]->symbol.gfdef))->cfun.entry(0) /*  SELECT-E */;
   goto L26;
L87:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(113))))){
    goto L100;
   }
   goto L97;
L100:;
   goto L98;
L98:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(81))))){
    goto L95;
   }
   goto L96;
L97:;
L96:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   cl_env_copy->values[0] = ECL_NIL;
   cl_env_copy->nvalues = 1;
   cl_throw(VV[66]);
L95:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(108))))){
    goto L110;
   }
   goto L107;
L110:;
   goto L108;
L108:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(76))))){
    goto L105;
   }
   goto L106;
L107:;
L106:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   (cl_env_copy->function=(VV[23]->symbol.gfdef))->cfun.entry(1, v1instance) /*  SELECT-CLOS-L */;
   goto L26;
L105:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(106))))){
    goto L119;
   }
   goto L116;
L119:;
   goto L117;
L117:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(74))))){
    goto L114;
   }
   goto L115;
L116:;
L115:;
   (cl_env_copy->function=(VV[30]->symbol.gfdef))->cfun.entry(1, v1instance) /*  SELECT-CLOS-J */;
   goto L26;
L114:;
   if (!(((v5)==ECL_CODE_CHAR((ecl_character)(63))))){
    goto L122;
   }
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   L2747select_clos__();
   goto L26;
L122:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
  }
L26:;
  T0 = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  (cl_env_copy->function=(VV[4]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT */;
  goto L16;
 }
L12:;
 T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
 ecl_cmp_setq(cl_env_copy,VV[6],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[6]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2750inspect_obj_va(cl_narg narg, cl_object v2instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[43]);
 {
  return LC2750inspect_obj(v2instance);
 }
}
/* function definition for INSPECT-OBJ-INNER-CLASS                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L2751inspect_obj_inner_class(cl_object v1instance)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
 ecl_cmp_setq(cl_env_copy,VV[6],T0);
 {
  cl_object v2class;
  cl_object v3local_slotds;
  v2class = si_instance_class(v1instance);
  v3local_slotds = L2748class_local_slots(v2class);
L7:;
  cl_format(3, ECL_T, VV[47], v1instance);
  T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  (cl_env_copy->function=(VV[4]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT */;
  T0 = (cl_env_copy->function=(ECL_SYM("CLASS-NAME",938)->symbol.gfdef))->cfun.entry(1, v2class) /*  CLASS-NAME */;
  cl_format(3, ECL_T, VV[48], T0);
  (cl_env_copy->function=(VV[4]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT */;
  {
   cl_fixnum v4;
   v4 = ecl_length(v3local_slotds);
   cl_format(3, ECL_T, VV[73], ecl_make_fixnum(v4));
  }
  cl_force_output(0);
  {
   cl_object v4;
   {
    cl_object v5char;
    v5char = cl_read_char(1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*QUERY-IO*",61)));
    goto L22;
L21:;
    v5char = cl_read_char(1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*QUERY-IO*",61)));
L22:;
    if (!(ecl_char_code(v5char)!=ecl_char_code(ECL_CODE_CHAR(32)))){
     goto L29;
    }
    if (cl_charNE(1, ECL_CODE_CHAR(9))!=ECL_NIL) {
     goto L26;
    }
    goto L27;
L29:;
    goto L27;
L27:;
    goto L21;
L26:;
    v4 = v5char;
   }
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(10))))){
    goto L36;
   }
   goto L33;
L36:;
   goto L34;
L34:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(13))))){
    goto L31;
   }
   goto L32;
L33:;
L32:;
   (cl_env_copy->function=(VV[1]->symbol.gfdef))->cfun.entry(1, v1instance) /*  SELECT-CLOS-N */;
   goto L4;
L31:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(110))))){
    goto L45;
   }
   goto L42;
L45:;
   goto L43;
L43:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(78))))){
    goto L40;
   }
   goto L41;
L42:;
L41:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   (cl_env_copy->function=(VV[1]->symbol.gfdef))->cfun.entry(1, v1instance) /*  SELECT-CLOS-N */;
   goto L4;
L40:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(115))))){
    goto L55;
   }
   goto L52;
L55:;
   goto L53;
L53:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(83))))){
    goto L50;
   }
   goto L51;
L52:;
L51:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   goto L4;
L50:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(112))))){
    goto L64;
   }
   goto L61;
L64:;
   goto L62;
L62:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(80))))){
    goto L59;
   }
   goto L60;
L61:;
L60:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   (cl_env_copy->function=(VV[58]->symbol.gfdef))->cfun.entry(1, v1instance) /*  SELECT-P */;
   goto L17;
L59:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(97))))){
    goto L73;
   }
   goto L70;
L73:;
   goto L71;
L71:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(65))))){
    goto L68;
   }
   goto L69;
L70:;
L69:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   cl_env_copy->values[0] = ECL_NIL;
   cl_env_copy->nvalues = 1;
   cl_throw(VV[46]);
L68:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(101))))){
    goto L83;
   }
   goto L80;
L83:;
   goto L81;
L81:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(69))))){
    goto L78;
   }
   goto L79;
L80:;
L79:;
   (cl_env_copy->function=(VV[63]->symbol.gfdef))->cfun.entry(0) /*  SELECT-E */;
   goto L17;
L78:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(113))))){
    goto L91;
   }
   goto L88;
L91:;
   goto L89;
L89:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(81))))){
    goto L86;
   }
   goto L87;
L88:;
L87:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   cl_env_copy->values[0] = ECL_NIL;
   cl_env_copy->nvalues = 1;
   cl_throw(VV[66]);
L86:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(108))))){
    goto L101;
   }
   goto L98;
L101:;
   goto L99;
L99:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(76))))){
    goto L96;
   }
   goto L97;
L98:;
L97:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   (cl_env_copy->function=(VV[23]->symbol.gfdef))->cfun.entry(1, v1instance) /*  SELECT-CLOS-L */;
   goto L17;
L96:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(106))))){
    goto L110;
   }
   goto L107;
L110:;
   goto L108;
L108:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(74))))){
    goto L105;
   }
   goto L106;
L107:;
L106:;
   (cl_env_copy->function=(VV[30]->symbol.gfdef))->cfun.entry(1, v1instance) /*  SELECT-CLOS-J */;
   goto L17;
L105:;
   if (!(((v4)==ECL_CODE_CHAR((ecl_character)(63))))){
    goto L113;
   }
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
   L2747select_clos__();
   goto L17;
L113:;
   (cl_env_copy->function=(VV[31]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-READ-LINE */;
  }
L17:;
  T0 = ecl_minus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
  ecl_cmp_setq(cl_env_copy,VV[6],T0);
  (cl_env_copy->function=(VV[4]->symbol.gfdef))->cfun.entry(0) /*  INSPECT-INDENT */;
  goto L7;
 }
L4:;
 T0 = ecl_plus(ecl_cmp_symbol_value(cl_env_copy,VV[6]),ecl_make_int8_t(1));
 ecl_cmp_setq(cl_env_copy,VV[6],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[6]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L2751inspect_obj_inner_class_va(cl_narg narg, cl_object v2instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[72]);
 {
  return L2751inspect_obj_inner_class(v2instance);
 }
}
/* local function INSPECT-OBJ                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2752inspect_obj(cl_object v1instance)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2751inspect_obj_inner_class(v1instance);
 return value0;
}
static cl_object LC2752inspect_obj_va(cl_narg narg, cl_object v2instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[43]);
 {
  return LC2752inspect_obj(v2instance);
 }
}
/* local function INSPECT-OBJ                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2753inspect_obj(cl_object v1instance)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L2751inspect_obj_inner_class(v1instance);
 return value0;
}
static cl_object LC2753inspect_obj_va(cl_narg narg, cl_object v2instance, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[43]);
 {
  return LC2753inspect_obj(v2instance);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2754documentation(cl_object v1object, cl_object v2doc_type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = v2doc_type;
  v4 = VV[76];
  if (Null(ecl_memql(v3,v4))){
   goto L2;
  }
 }
 if (!((v2doc_type)==(ECL_SYM("TYPE",872)))){
  goto L6;
 }
 {
  cl_object v3c;
  v3c = cl_find_class(2, v1object, ECL_NIL);
  if (Null(v3c)){
   goto L9;
  }
  value0 = (cl_env_copy->function=(ECL_SYM("DOCUMENTATION",314)->symbol.gfdef))->cfun.entry(2, v3c, ECL_T) /*  DOCUMENTATION */;
  return value0;
L9:;
  value0 = si_get_documentation(v1object, v2doc_type);
  return value0;
 }
L6:;
 if (!((v2doc_type)==(ECL_SYM("FUNCTION",398)))){
  goto L11;
 }
 value0 = si_get_documentation(v1object, v2doc_type);
 if (value0!=ECL_NIL) {
  goto L14;
 }
 if (Null(cl_fboundp(v1object))){
  goto L17;
 }
 value0 = cl_macro_function(1, v1object);
 if (value0!=ECL_NIL) {
  goto L21;
 }
 T0 = cl_fdefinition(v1object);
 goto L19;
L21:;
 T0 = value0;
 goto L19;
L19:;
 value0 = (cl_env_copy->function=(ECL_SYM("DOCUMENTATION",314)->symbol.gfdef))->cfun.entry(2, T0, v2doc_type) /*  DOCUMENTATION */;
 return value0;
L17:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L14:;
 cl_env_copy->nvalues = 1;
 return value0;
L11:;
 value0 = si_get_documentation(v1object, v2doc_type);
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2754documentation_va(cl_narg narg, cl_object v4object, cl_object v5doc_type, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2754documentation(v4object, v5doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2755documentation(cl_object v1new_value, cl_object v2object, cl_object v3doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  cl_object v5;
  v4 = v3doc_type;
  v5 = VV[76];
  if (Null(ecl_memql(v4,v5))){
   goto L2;
  }
 }
 if (!((v3doc_type)==(ECL_SYM("TYPE",872)))){
  goto L6;
 }
 {
  cl_object v4c;
  v4c = cl_find_class(2, v2object, ECL_NIL);
  if (Null(v4c)){
   goto L9;
  }
  si_set_documentation(v2object, ECL_SYM("TYPE",872), ECL_NIL);
  si_set_documentation(v2object, ECL_SYM("STRUCTURE",829), ECL_NIL);
  (cl_env_copy->function=ECL_CONS_CAR(VV[96]))->cfun.entry(3, v1new_value, v4c, ECL_T) /*  (SETF DOCUMENTATION) */;
  goto L2;
L9:;
  si_set_documentation(v2object, v3doc_type, v1new_value);
  goto L2;
 }
L6:;
 if (!((v3doc_type)==(ECL_SYM("FUNCTION",398)))){
  goto L13;
 }
 if (Null(cl_fboundp(v2object))){
  goto L15;
 }
 {
  cl_object v5c;
  value0 = cl_macro_function(1, v2object);
  if (value0!=ECL_NIL) {
   goto L19;
  }
  v5c = cl_fdefinition(v2object);
  goto L17;
L19:;
  v5c = value0;
  goto L17;
L17:;
  si_set_documentation(v5c, ECL_SYM("FUNCTION",398), ECL_NIL);
  (cl_env_copy->function=ECL_CONS_CAR(VV[96]))->cfun.entry(3, v1new_value, v5c, ECL_SYM("FUNCTION",398)) /*  (SETF DOCUMENTATION) */;
  goto L2;
 }
L15:;
 si_set_documentation(v2object, v3doc_type, v1new_value);
 goto L2;
L13:;
 si_set_documentation(v2object, v3doc_type, v1new_value);
L2:;
 value0 = v1new_value;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2755documentation_va(cl_narg narg, cl_object v4new_value, cl_object v5object, cl_object v6doc_type, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2755documentation(v4new_value, v5object, v6doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2756documentation(cl_object v1object, cl_object v2doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v2doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v2doc_type)==(ECL_SYM("PACKAGE",619)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = si_get_documentation(v1object, ECL_SYM("PACKAGE",619));
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2756documentation_va(cl_narg narg, cl_object v3object, cl_object v4doc_type, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2756documentation(v3object, v4doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2757documentation(cl_object v1new_value, cl_object v2object, cl_object v3doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v3doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v3doc_type)==(ECL_SYM("PACKAGE",619)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = si_set_documentation(v2object, ECL_SYM("PACKAGE",619), v1new_value);
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2757documentation_va(cl_narg narg, cl_object v4new_value, cl_object v5object, cl_object v6doc_type, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2757documentation(v4new_value, v5object, v6doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2758documentation(cl_object v1object, cl_object v2doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v2doc_type)==(ECL_T))){
  goto L8;
 }
 goto L5;
L8:;
 goto L6;
L6:;
 if (!((v2doc_type)==(ECL_SYM("TYPE",872)))){
  goto L2;
 }
 goto L4;
L5:;
L4:;
 if (Null(cl_slot_boundp(v1object, ECL_SYM("DOCSTRING",1655)))){
  goto L2;
 }
 value0 = cl_slot_value(v1object, ECL_SYM("DOCSTRING",1655));
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2758documentation_va(cl_narg narg, cl_object v3object, cl_object v4doc_type, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2758documentation(v3object, v4doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2759documentation(cl_object v1new_value, cl_object v2object, cl_object v3doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v3doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v3doc_type)==(ECL_SYM("TYPE",872)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = (cl_env_copy->function=ECL_CONS_CAR(VV[95]))->cfun.entry(3, v1new_value, v2object, ECL_SYM("DOCSTRING",1655)) /*  (SETF SLOT-VALUE) */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2759documentation_va(cl_narg narg, cl_object v4new_value, cl_object v5object, cl_object v6doc_type, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2759documentation(v4new_value, v5object, v6doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2760documentation(cl_object v1object, cl_object v2doc_type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v2doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v2doc_type)==(ECL_SYM("TYPE",872)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 T0 = (cl_env_copy->function=(ECL_SYM("CLASS-NAME",938)->symbol.gfdef))->cfun.entry(1, v1object) /*  CLASS-NAME */;
 value0 = si_get_documentation(T0, ECL_SYM("STRUCTURE",829));
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2760documentation_va(cl_narg narg, cl_object v3object, cl_object v4doc_type, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2760documentation(v3object, v4doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2761documentation(cl_object v1new_value, cl_object v2object, cl_object v3doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v3doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v3doc_type)==(ECL_SYM("TYPE",872)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 {
  cl_object v4;
  v4 = (cl_env_copy->function=(ECL_SYM("CLASS-NAME",938)->symbol.gfdef))->cfun.entry(1, v2object) /*  CLASS-NAME */;
  value0 = (cl_env_copy->function=ECL_CONS_CAR(VV[96]))->cfun.entry(3, v1new_value, v4, ECL_SYM("STRUCTURE",829)) /*  (SETF DOCUMENTATION) */;
  return value0;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2761documentation_va(cl_narg narg, cl_object v5new_value, cl_object v6object, cl_object v7doc_type, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2761documentation(v5new_value, v6object, v7doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2762documentation(cl_object v1object, cl_object v2doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v2doc_type)==(ECL_SYM("FUNCTION",398)))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v2doc_type)==(ECL_SYM("COMPILER-MACRO",240)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = si_get_documentation(v1object, v2doc_type);
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2762documentation_va(cl_narg narg, cl_object v3object, cl_object v4doc_type, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2762documentation(v3object, v4doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2763documentation(cl_object v1new_value, cl_object v2object, cl_object v3doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v3doc_type)==(ECL_SYM("FUNCTION",398)))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v3doc_type)==(ECL_SYM("COMPILER-MACRO",240)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = si_set_documentation(v2object, v3doc_type, v1new_value);
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2763documentation_va(cl_narg narg, cl_object v4new_value, cl_object v5object, cl_object v6doc_type, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2763documentation(v4new_value, v5object, v6doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2764documentation(cl_object v1object, cl_object v2doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v2doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v2doc_type)==(ECL_SYM("FUNCTION",398)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = cl_slot_value(v1object, ECL_SYM("DOCSTRING",1655));
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2764documentation_va(cl_narg narg, cl_object v3object, cl_object v4doc_type, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2764documentation(v3object, v4doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2765documentation(cl_object v1new_value, cl_object v2object, cl_object v3doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v3doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v3doc_type)==(ECL_SYM("FUNCTION",398)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = (cl_env_copy->function=ECL_CONS_CAR(VV[95]))->cfun.entry(3, v1new_value, v2object, ECL_SYM("DOCSTRING",1655)) /*  (SETF SLOT-VALUE) */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2765documentation_va(cl_narg narg, cl_object v4new_value, cl_object v5object, cl_object v6doc_type, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2765documentation(v4new_value, v5object, v6doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2766documentation(cl_object v1object, cl_object v2doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v2doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v2doc_type)==(ECL_SYM("FUNCTION",398)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = cl_slot_value(v1object, ECL_SYM("DOCSTRING",1655));
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2766documentation_va(cl_narg narg, cl_object v3object, cl_object v4doc_type, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2766documentation(v3object, v4doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2767documentation(cl_object v1new_value, cl_object v2object, cl_object v3doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v3doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v3doc_type)==(ECL_SYM("FUNCTION",398)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = (cl_env_copy->function=ECL_CONS_CAR(VV[95]))->cfun.entry(3, v1new_value, v2object, ECL_SYM("DOCSTRING",1655)) /*  (SETF SLOT-VALUE) */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2767documentation_va(cl_narg narg, cl_object v4new_value, cl_object v5object, cl_object v6doc_type, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2767documentation(v4new_value, v5object, v6doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2768documentation(cl_object v1object, cl_object v2doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v2doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v2doc_type)==(ECL_SYM("FUNCTION",398)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = si_get_documentation(v1object, v2doc_type);
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2768documentation_va(cl_narg narg, cl_object v3object, cl_object v4doc_type, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2768documentation(v3object, v4doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2769documentation(cl_object v1new_value, cl_object v2object, cl_object v3doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v3doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v3doc_type)==(ECL_SYM("FUNCTION",398)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = si_set_documentation(v2object, v3doc_type, v1new_value);
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2769documentation_va(cl_narg narg, cl_object v4new_value, cl_object v5object, cl_object v6doc_type, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2769documentation(v4new_value, v5object, v6doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2770documentation(cl_object v1object, cl_object v2doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v2doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v2doc_type)==(ECL_SYM("FUNCTION",398)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = cl_slot_value(v1object, ECL_SYM("DOCSTRING",1655));
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2770documentation_va(cl_narg narg, cl_object v3object, cl_object v4doc_type, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2770documentation(v3object, v4doc_type);
 }
}
/* local function DOCUMENTATION                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2771documentation(cl_object v1new_value, cl_object v2object, cl_object v3doc_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v3doc_type)==(ECL_T))){
  goto L7;
 }
 goto L4;
L7:;
 goto L5;
L5:;
 if (!((v3doc_type)==(ECL_SYM("FUNCTION",398)))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = (cl_env_copy->function=ECL_CONS_CAR(VV[95]))->cfun.entry(3, v1new_value, v2object, ECL_SYM("DOCSTRING",1655)) /*  (SETF SLOT-VALUE) */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2771documentation_va(cl_narg narg, cl_object v4new_value, cl_object v5object, cl_object v6doc_type, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(ECL_SYM("DOCUMENTATION",314));
 {
  return LC2771documentation(v4new_value, v5object, v6doc_type);
 }
}
#include "clos/inspect.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecl0zu8S2MY4lIi9_AlF0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CLOS;INSPECT.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecl0zu8S2MY4lIi9_AlF0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2735select_clos_n_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, VV[1], ECL_NIL, VVtemp[1], VVtemp[2], T0);
  ecl_cmp_defun(VV[89]);                          /*  SELECT-CLOS-N-INNER-CLASS */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2737select_clos_n_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, VV[1], ECL_NIL, VVtemp[3], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2738select_clos_n_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, VV[1], ECL_NIL, VVtemp[4], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2739select_clos_l_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, VV[23], ECL_NIL, VVtemp[1], VVtemp[2], T0);
  ecl_cmp_defun(VV[90]);                          /*  SELECT-CLOS-L-INNER-CLASS */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2741select_clos_l_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, VV[23], ECL_NIL, VVtemp[3], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2742select_clos_l_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, VV[23], ECL_NIL, VVtemp[4], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2743select_clos_j_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, VV[30], ECL_NIL, VVtemp[1], VVtemp[2], T0);
  ecl_cmp_defun(VV[91]);                          /*  SELECT-CLOS-J-INNER-CLASS */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2745select_clos_j_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, VV[30], ECL_NIL, VVtemp[3], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2746select_clos_j_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, VV[30], ECL_NIL, VVtemp[4], VVtemp[2], T0);
  (void)0; /* No entry created for SELECT-CLOS-? */
  ecl_cmp_defun(VV[92]);                          /*  CLASS-LOCAL-SLOTS       */
  ecl_cmp_defun(VV[93]);                          /*  CLASS-CLASS-SLOTS       */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2750inspect_obj_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, VV[43], ECL_NIL, VVtemp[1], VVtemp[2], T0);
  ecl_cmp_defun(VV[94]);                          /*  INSPECT-OBJ-INNER-CLASS */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2752inspect_obj_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, VV[43], ECL_NIL, VVtemp[3], VVtemp[2], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2753inspect_obj_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, VV[43], ECL_NIL, VVtemp[4], VVtemp[2], T0);
  si_Xmake_constant(VV[75], VV[76]);
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(5, ECL_SYM("DOCUMENTATION",314), VV[77], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[5]) /*  ENSURE-GENERIC-FUNCTION */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(5, VV[78], VV[77], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[6]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2754documentation_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("DOCUMENTATION",314), ECL_NIL, VVtemp[7], VVtemp[5], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2755documentation_va,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  clos_install_method(5, VV[78], ECL_NIL, VVtemp[8], VVtemp[6], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2756documentation_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("DOCUMENTATION",314), ECL_NIL, VVtemp[9], VVtemp[5], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2757documentation_va,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  clos_install_method(5, VV[78], ECL_NIL, VVtemp[10], VVtemp[6], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2758documentation_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("DOCUMENTATION",314), ECL_NIL, VVtemp[11], VVtemp[5], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2759documentation_va,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  clos_install_method(5, VV[78], ECL_NIL, VVtemp[12], VVtemp[6], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2760documentation_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("DOCUMENTATION",314), ECL_NIL, VVtemp[13], VVtemp[5], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2761documentation_va,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  clos_install_method(5, VV[78], ECL_NIL, VVtemp[14], VVtemp[6], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2762documentation_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("DOCUMENTATION",314), ECL_NIL, VVtemp[15], VVtemp[5], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2763documentation_va,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  clos_install_method(5, VV[78], ECL_NIL, VVtemp[16], VVtemp[6], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2764documentation_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("DOCUMENTATION",314), ECL_NIL, VVtemp[17], VVtemp[5], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2765documentation_va,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  clos_install_method(5, VV[78], ECL_NIL, VVtemp[18], VVtemp[6], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2766documentation_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("DOCUMENTATION",314), ECL_NIL, VVtemp[19], VVtemp[5], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2767documentation_va,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  clos_install_method(5, VV[78], ECL_NIL, VVtemp[20], VVtemp[6], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2768documentation_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("DOCUMENTATION",314), ECL_NIL, VVtemp[21], VVtemp[5], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2769documentation_va,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  clos_install_method(5, VV[78], ECL_NIL, VVtemp[22], VVtemp[6], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2770documentation_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("DOCUMENTATION",314), ECL_NIL, VVtemp[23], VVtemp[5], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2771documentation_va,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  clos_install_method(5, VV[78], ECL_NIL, VVtemp[24], VVtemp[6], T0);
 }
}
