/* -*- Mode: C; c-basic-offset: 2; indent-tabs-mode: nil -*- */
/* vim: set filetype=c tabstop=2 shiftwidth=2 expandtab: */

/*
 * ecl_features.h - names of features compiled into ECL
 *
 * Copyright (c) 1984 Taiichi Yuasa and Masami Hagiya
 * Copyright (c) 1990 Giuseppe Attardi
 * Copyright (c) 2001 Juan Jose Garcia Ripoll
 *
 * See file 'LICENSE' for the copyright details.
 *
 */

#define FEATURE_NAMES "( :ecl :common :common-lisp :ansi-cl :ffi :prefixed-api :cdr-14 :package-local-nicknames :clos :ecl-pde :long-float :unix :threads :ecl-read-write-lock :boehm-gc :ecl-weak-hash :dffi :ieee-floating-point :floating-point-exceptions :long-long :little-endian :uint8-t :uint16-t :uint32-t :uint64-t :complex-float :dlopen :cmu-format :clos-streams :unicode :X86_64)"
ecl_def_ct_base_string(feature_names, FEATURE_NAMES, sizeof(FEATURE_NAMES)-1, static, const);

