/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/cmp/cmpprop.lsp                     */
#include <ecl/ecl-cmp.h>
#include "cmp/cmpprop.eclh"
/* local function PROP-MESSAGE                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3560prop_message(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4string;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4string = v5;
  }
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[0]))){
   goto L9;
  }
  value0 = cl_listX(4, ECL_SYM("FORMAT",389), ECL_SYM("*STANDARD-OUTPUT*",69), v4string, v3);
  return value0;
L9:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC3560prop_message_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2]);
 {
  return LC3560prop_message(v5, v6);
 }
}
/* function definition for P1ORDINARY                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3561p1ordinary(cl_object v1c1form, cl_object v2form)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L3563p1propagate(v2form);
 return value0;
}
static cl_object L3561p1ordinary_va(cl_narg narg, cl_object v3c1form, cl_object v4form, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[4]);
 {
  return L3561p1ordinary(v3c1form, v4form);
 }
}
/* function definition for P1FSET                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3562p1fset(cl_object v1c1form, cl_object v2fun, cl_object v3fname, cl_object v4macro, cl_object v5pprint, cl_object v6c1forms)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 L3580p1propagate_function(v2fun);
 value0 = ECL_SYM("FUNCTION",398);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3562p1fset_va(cl_narg narg, cl_object v7c1form, cl_object v8fun, cl_object v9fname, cl_object v10macro, cl_object v11pprint, cl_object v12c1forms, ...)
{
 if (ecl_unlikely(narg!=6)) FEwrong_num_arguments(VV[7]);
 {
  return L3562p1fset(v7c1form, v8fun, v9fname, v10macro, v11pprint, v12c1forms);
 }
}
/* function definition for P1PROPAGATE                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3563p1propagate(cl_object v1form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (v1form!=ECL_NIL) {
  goto L2;
 }
 value0 = ECL_SYM("NULL",607);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[10]))->cfun.entry(1, v1form) /*  C1FORM-P */)){
  goto L4;
 }
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  v2 = (cl_env_copy->function=ecl_fdefinition(VV[11]))->cfun.entry(1, v1form) /*  C1FORM-ENV */;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[12]))->cfun.entry(1, v1form) /*  C1FORM-FILE */;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[13]))->cfun.entry(1, v1form) /*  C1FORM-FILE-POSITION */;
  v5 = (cl_env_copy->function=ecl_fdefinition(VV[14]))->cfun.entry(1, v1form) /*  C1FORM-FORM */;
  v6 = (cl_env_copy->function=ecl_fdefinition(VV[15]))->cfun.entry(1, v1form) /*  C1FORM-TOPLEVEL-FORM */;
  v7 = (cl_env_copy->function=ecl_fdefinition(VV[16]))->cfun.entry(1, v1form) /*  C1FORM-NAME */;
  ecl_bds_bind(cl_env_copy,VV[17],v2);            /*  *CMP-ENV*               */
  ecl_bds_bind(cl_env_copy,ECL_SYM("*COMPILE-FILE-PATHNAME*",28),v3); /*  *COMPILE-FILE-PATHNAME* */
  ecl_bds_bind(cl_env_copy,VV[18],v4);            /*  *COMPILE-FILE-POSITION* */
  ecl_bds_bind(cl_env_copy,VV[19],v5);            /*  *CURRENT-FORM*          */
  ecl_bds_bind(cl_env_copy,VV[20],v6);            /*  *CURRENT-TOPLEVEL-FORM* */
  {
   cl_object v8propagator;
   v8propagator = ecl_gethash_safe(v7,ecl_cmp_symbol_value(cl_env_copy,VV[21]),ECL_NIL);
   if (Null(v8propagator)){
    ecl_bds_unwind_n(cl_env_copy,5);
    goto L4;
   }
   {
    cl_object v9new_type;
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[22]))->cfun.entry(1, v1form) /*  C1FORM-ARGS */;
    v9new_type = cl_apply(3, v8propagator, v1form, T0);
    {
     cl_object v10;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[24]))->cfun.entry(1, v1form) /*  C1FORM-TYPE */;
     v10 = (cl_env_copy->function=ecl_fdefinition(VV[23]))->cfun.entry(2, T0, v9new_type) /*  VALUES-TYPE-AND */;
     value0 = ecl_structure_set(v1form,VV[25],(cl_fixnum)(1),v10);
     cl_env_copy->nvalues = 1;
     ecl_bds_unwind_n(cl_env_copy,5);
     return value0;
    }
   }
  }
 }
L4:;
 (cl_env_copy->function=ecl_fdefinition(VV[26]))->cfun.entry(2, VV[27], v1form) /*  CMPNOTE */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[24]))->cfun.entry(1, v1form) /*  C1FORM-TYPE */;
 return value0;
}
static cl_object L3563p1propagate_va(cl_narg narg, cl_object v2form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[5]);
 {
  return L3563p1propagate(v2form);
 }
}
/* function definition for P1TRIVIAL                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3564p1trivial(cl_narg narg, cl_object v1form, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[29]);
 {
  va_list args; va_start(args,v1form);
  va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[24]))->cfun.entry(1, v1form) /*  C1FORM-TYPE */;
  return value0;
 }
}
/* function definition for P1VAR                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3565p1var(cl_object v1form, cl_object v2var, cl_object v3loc)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4loc_type;
  cl_object v5var_type;
  cl_object v6type;
  if (Null(v3loc)){
   goto L3;
  }
  v4loc_type = (cl_env_copy->function=ecl_fdefinition(VV[32]))->cfun.entry(1, v3loc) /*  LOC-LISP-TYPE */;
  goto L2;
L3:;
  v4loc_type = ECL_T;
L2:;
  v5var_type = (cl_env_copy->function=ecl_fdefinition(VV[32]))->cfun.entry(1, v2var) /*  LOC-LISP-TYPE */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(2, v4loc_type, v5var_type) /*  TYPE-AND */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[34]))->cfun.entry(1, v1form) /*  C1FORM-PRIMARY-TYPE */;
  v6type = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(2, T0, T1) /*  TYPE-AND */;
  value0 = v6type;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3565p1var_va(cl_narg narg, cl_object v7form, cl_object v8var, cl_object v9loc, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[31]);
 {
  return L3565p1var(v7form, v8var, v9loc);
 }
}
/* function definition for P1VALUES                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3566p1values(cl_object v1form, cl_object v2values)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4v;
  cl_object v5;
  {
   cl_object v6;
   v6 = v2values;
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3 = v6;
  }
  v4v = ECL_NIL;
  v5 = v3;
  {
   cl_object v6;
   cl_object v7;
   cl_object v8all_values;
   v6 = ecl_list1(ECL_NIL);
   v7 = v6;
   v8all_values = ECL_NIL;
L10:;
   if (!(ecl_endp(v5))){
    goto L12;
   }
   goto L11;
L12:;
   v4v = ECL_CONS_CAR(v5);
   {
    cl_object v9;
    v9 = ECL_CONS_CDR(v5);
    if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v9;
   }
   {
    cl_object v9;
    v9 = v7;
    if (ecl_unlikely(ECL_ATOM(v9))) FEtype_error_cons(v9);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T0 = v9;
   }
   T1 = L3563p1propagate(v4v);
   T2 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, T1) /*  VALUES-TYPE-PRIMARY-TYPE */;
   v7 = ecl_list1(T2);
   (ECL_CONS_CDR(T0)=v7,T0);
   v8all_values = ecl_cdr(v6);
   goto L10;
L11:;
   value0 = CONS(ECL_SYM("VALUES",899),v8all_values);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3566p1values_va(cl_narg narg, cl_object v9form, cl_object v10values, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[36]);
 {
  return L3566p1values(v9form, v10values);
 }
}
/* function definition for P1PROPAGATE-LIST                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3567p1propagate_list(cl_object v1list)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2final_type;
  v2final_type = ECL_T;
  {
   cl_object v3;
   cl_object v4f;
   cl_object v5;
   {
    cl_object v6;
    v6 = v1list;
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v6;
   }
   v4f = ECL_NIL;
   v5 = v3;
L8:;
   if (!(ecl_endp(v5))){
    goto L10;
   }
   goto L9;
L10:;
   v4f = ECL_CONS_CAR(v5);
   {
    cl_object v6;
    v6 = ECL_CONS_CDR(v5);
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v6;
   }
   v2final_type = L3563p1propagate(v4f);
   goto L8;
L9:;
   value0 = v2final_type;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L3567p1propagate_list_va(cl_narg narg, cl_object v6list, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[43]);
 {
  return L3567p1propagate_list(v6list);
 }
}
/* function definition for P1BLOCK                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3568p1block(cl_object v1c1form, cl_object v2blk, cl_object v3body)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_structure_set(v2blk,VV[46],(cl_fixnum)(8),ECL_NIL);
 {
  cl_object v4;
  cl_object v5;
  v4 = L3563p1propagate(v3body);
  v5 = (cl_env_copy->function=ecl_fdefinition(VV[47]))->cfun.entry(1, v2blk) /*  BLK-TYPE */;
  if (Null(v5)){
   goto L5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[48]))->cfun.entry(2, v5, v4) /*  VALUES-TYPE-OR */;
  return value0;
L5:;
  value0 = v4;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3568p1block_va(cl_narg narg, cl_object v6c1form, cl_object v7blk, cl_object v8body, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[45]);
 {
  return L3568p1block(v6c1form, v7blk, v8body);
 }
}
/* function definition for P1RETURN-FROM                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3569p1return_from(cl_object v1c1form, cl_object v2blk, cl_object v3return_type, cl_object v4value)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5values_type;
  cl_object v6blk_type;
  v5values_type = L3563p1propagate(v4value);
  v6blk_type = (cl_env_copy->function=ecl_fdefinition(VV[47]))->cfun.entry(1, v2blk) /*  BLK-TYPE */;
  {
   cl_object v7;
   if (Null(v6blk_type)){
    goto L6;
   }
   v7 = (cl_env_copy->function=ecl_fdefinition(VV[48]))->cfun.entry(2, v6blk_type, v5values_type) /*  VALUES-TYPE-OR */;
   goto L5;
L6:;
   v7 = v5values_type;
L5:;
   ecl_structure_set(v2blk,VV[46],(cl_fixnum)(8),v7);
  }
  value0 = v5values_type;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3569p1return_from_va(cl_narg narg, cl_object v7c1form, cl_object v8blk, cl_object v9return_type, cl_object v10value, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[50]);
 {
  return L3569p1return_from(v7c1form, v8blk, v9return_type, v10value);
 }
}
/* function definition for P1FCALL                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3571p1fcall(cl_object v1c1form, cl_object v2fun, cl_object v3args, cl_object v4fun_val, cl_object v5call_type)
{
 volatile cl_object lex0[1];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 lex0[0] = v4fun_val;                             /*  FUN-VAL                 */
L1:;
 L3563p1propagate(v2fun);
 L3567p1propagate_list(v3args);
 if (!((v5call_type)==(VV[53]))){
  goto L4;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[54]))->cfun.entry(2, lex0[0], v3args) /*  PROPAGATE-TYPES */;
 return value0;
L4:;
 if (!((v5call_type)==(ECL_SYM("LOCAL",1303)))){
  goto L6;
 }
 {
  cl_object v6local_arg_types;
  v6local_arg_types = (cl_env_copy->function=ecl_fdefinition(VV[59]))->cfun.entry(1, lex0[0]) /*  GET-LOCAL-ARG-TYPES */;
  {
   cl_object v7;
   cl_object v8arg_form;
   cl_object v9;
   {
    cl_object v10;
    v10 = v3args;
    if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v7 = v10;
   }
   v8arg_form = ECL_NIL;
   v9 = v7;
   {
    cl_object v10arg_type;
    v10arg_type = ECL_NIL;
L16:;
    if (!(ecl_endp(v9))){
     goto L18;
    }
    goto L17;
L18:;
    v8arg_form = ECL_CONS_CAR(v9);
    {
     cl_object v11;
     v11 = ECL_CONS_CDR(v9);
     if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v9 = v11;
    }
    {
     cl_object v11;
     v11 = v6local_arg_types;
     {
      cl_object v12;
      v12 = v11;
      {
       bool v13;
       v13 = ECL_LISTP(v12);
       if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(VV[62],v12);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v11)){
      goto L32;
     }
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v11);
      v6local_arg_types = v12;
      v11 = ECL_CONS_CAR(v11);
     }
L32:;
     v10arg_type = v11;
    }
    if (Null(v10arg_type)){
     goto L38;
    }
    LC3570and_form_type(lex0, v10arg_type, v8arg_form);
L38:;
    L3563p1propagate(v8arg_form);
    goto L16;
L17:;
   }
  }
 }
 {
  cl_object v6;
  cl_object v7;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[63]))->cfun.entry(1, lex0[0]) /*  GET-LOCAL-RETURN-TYPE */;
  if (value0!=ECL_NIL) {
   goto L44;
  }
  v6 = VV[64];
  goto L42;
L44:;
  v6 = value0;
  goto L42;
L42:;
  v7 = (cl_env_copy->function=ecl_fdefinition(VV[65]))->cfun.entry(1, lex0[0]) /*  FUN-RETURN-TYPE */;
  (cl_env_copy->function=ecl_fdefinition(VV[66]))->cfun.entry(2, v6, v1c1form) /*  AND-CALL-TYPE */;
  (cl_env_copy->function=ecl_fdefinition(VV[66]))->cfun.entry(2, v7, v1c1form) /*  AND-CALL-TYPE */;
  value0 = L3564p1trivial(1, v1c1form);
  return value0;
 }
L6:;
 if (!((v5call_type)==(VV[67]))){
  goto L49;
 }
 value0 = L3564p1trivial(1, v1c1form);
 return value0;
L49:;
 value0 = si_ecase_error(v5call_type, VV[68]);
 return value0;
}
static cl_object L3571p1fcall_va(cl_narg narg, cl_object v8c1form, cl_object v9fun, cl_object v10args, cl_object v11fun_val, cl_object v12call_type, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[52]);
 {
  return L3571p1fcall(v8c1form, v9fun, v10args, v11fun_val, v12call_type);
 }
}
/* function definition for P1MCALL                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3572p1mcall(cl_object v1c1form, cl_object v2fun, cl_object v3args, cl_object v4fun_val, cl_object v5call_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 L3563p1propagate(v2fun);
 L3567p1propagate_list(v3args);
 if (!((v5call_type)==(VV[53]))){
  goto L4;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[71]))->cfun.entry(1, v4fun_val) /*  GET-RETURN-TYPE */;
 if (value0!=ECL_NIL) {
  goto L7;
 }
 value0 = VV[64];
 cl_env_copy->nvalues = 1;
 return value0;
L7:;
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 if (!((v5call_type)==(ECL_SYM("LOCAL",1303)))){
  goto L9;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[63]))->cfun.entry(1, v4fun_val) /*  GET-LOCAL-RETURN-TYPE */;
 if (value0!=ECL_NIL) {
  goto L12;
 }
 value0 = VV[64];
 cl_env_copy->nvalues = 1;
 return value0;
L12:;
 cl_env_copy->nvalues = 1;
 return value0;
L9:;
 if (!((v5call_type)==(VV[67]))){
  goto L14;
 }
 value0 = L3564p1trivial(1, v1c1form);
 return value0;
L14:;
 value0 = si_ecase_error(v5call_type, VV[68]);
 return value0;
}
static cl_object L3572p1mcall_va(cl_narg narg, cl_object v6c1form, cl_object v7fun, cl_object v8args, cl_object v9fun_val, cl_object v10call_type, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[70]);
 {
  return L3572p1mcall(v6c1form, v7fun, v8args, v9fun_val, v10call_type);
 }
}
/* function definition for P1CATCH                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3573p1catch(cl_object v1c1form, cl_object v2tag, cl_object v3body)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 L3563p1propagate(v2tag);
 L3563p1propagate(v3body);
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3573p1catch_va(cl_narg narg, cl_object v4c1form, cl_object v5tag, cl_object v6body, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[73]);
 {
  return L3573p1catch(v4c1form, v5tag, v6body);
 }
}
/* function definition for P1THROW                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3574p1throw(cl_object v1c1form, cl_object v2catch_value, cl_object v3output_value)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 L3563p1propagate(v2catch_value);
 L3563p1propagate(v3output_value);
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3574p1throw_va(cl_narg narg, cl_object v4c1form, cl_object v5catch_value, cl_object v6output_value, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[75]);
 {
  return L3574p1throw(v4c1form, v5catch_value, v6output_value);
 }
}
/* function definition for P1IF                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3575p1if(cl_object v1c1form, cl_object v2fmla, cl_object v3true_branch, cl_object v4false_branch)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5t0;
  T0 = L3563p1propagate(v2fmla);
  v5t0 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, T0) /*  VALUES-TYPE-PRIMARY-TYPE */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(2, v5t0, ecl_cmp_symbol_value(cl_env_copy,VV[17])) /*  TYPE-TRUE-P */)){
   goto L3;
  }
  value0 = L3563p1propagate(v3true_branch);
  return value0;
L3:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[79]))->cfun.entry(2, v5t0, ecl_cmp_symbol_value(cl_env_copy,VV[17])) /*  TYPE-FALSE-P */)){
   goto L5;
  }
  value0 = L3563p1propagate(v4false_branch);
  return value0;
L5:;
  {
   cl_object v6;
   cl_object v7;
   v6 = L3563p1propagate(v3true_branch);
   v7 = L3563p1propagate(v4false_branch);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[48]))->cfun.entry(2, v6, v7) /*  VALUES-TYPE-OR */;
   return value0;
  }
 }
}
static cl_object L3575p1if_va(cl_narg narg, cl_object v8c1form, cl_object v9fmla, cl_object v10true_branch, cl_object v11false_branch, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[77]);
 {
  return L3575p1if(v8c1form, v9fmla, v10true_branch, v11false_branch);
 }
}
/* function definition for P1FMLA-NOT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3576p1fmla_not(cl_object v1c1form, cl_object v2form)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3t0;
  T0 = L3563p1propagate(v2form);
  v3t0 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, T0) /*  VALUES-TYPE-PRIMARY-TYPE */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(2, v3t0, ecl_cmp_symbol_value(cl_env_copy,VV[17])) /*  TYPE-TRUE-P */)){
   goto L3;
  }
  value0 = VV[82];
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[79]))->cfun.entry(2, v3t0, ecl_cmp_symbol_value(cl_env_copy,VV[17])) /*  TYPE-FALSE-P */)){
   goto L5;
  }
  value0 = VV[83];
  cl_env_copy->nvalues = 1;
  return value0;
L5:;
  value0 = VV[84];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3576p1fmla_not_va(cl_narg narg, cl_object v4c1form, cl_object v5form, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[81]);
 {
  return L3576p1fmla_not(v4c1form, v5form);
 }
}
/* function definition for P1FMLA-AND                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3577p1fmla_and(cl_object v1c1form, cl_object v2butlast, cl_object v3last)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4all_true;
  v4all_true = ECL_T;
  {
   cl_object v5;
   cl_object v6form;
   cl_object v7;
   {
    cl_object v8;
    v8 = v2butlast;
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v8;
   }
   v6form = ECL_NIL;
   v7 = v5;
   {
    cl_object v8type;
    v8type = ECL_NIL;
    {
     cl_object v9primary_type;
     v9primary_type = ECL_NIL;
L10:;
     if (!(ecl_endp(v7))){
      goto L12;
     }
     goto L11;
L12:;
     v6form = ECL_CONS_CAR(v7);
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v7);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v7 = v10;
     }
     v8type = L3563p1propagate(v6form);
     v9primary_type = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, v8type) /*  VALUES-TYPE-PRIMARY-TYPE */;
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[79]))->cfun.entry(2, v9primary_type, ecl_cmp_symbol_value(cl_env_copy,VV[17])) /*  TYPE-FALSE-P */)){
      goto L25;
     }
     value0 = v9primary_type;
     cl_env_copy->nvalues = 1;
     return value0;
L25:;
     if ((cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(2, v9primary_type, ecl_cmp_symbol_value(cl_env_copy,VV[17])) /*  TYPE-TRUE-P */!=ECL_NIL) {
      goto L24;
     }
     v4all_true = ECL_NIL;
L24:;
     goto L10;
L11:;
     v8type = L3563p1propagate(v3last);
     v9primary_type = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, v8type) /*  VALUES-TYPE-PRIMARY-TYPE */;
     if ((cl_env_copy->function=ecl_fdefinition(VV[79]))->cfun.entry(2, v9primary_type, ecl_cmp_symbol_value(cl_env_copy,VV[17])) /*  TYPE-FALSE-P */!=ECL_NIL) {
      goto L37;
     }
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(2, v9primary_type, ecl_cmp_symbol_value(cl_env_copy,VV[17])) /*  TYPE-TRUE-P */)){
      goto L35;
     }
     if (Null(v4all_true)){
      goto L35;
     }
     goto L36;
L37:;
L36:;
     value0 = v8type;
     cl_env_copy->nvalues = 1;
     return value0;
L35:;
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[48]))->cfun.entry(2, ECL_SYM("NULL",607), v8type) /*  VALUES-TYPE-OR */;
     return value0;
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
}
static cl_object L3577p1fmla_and_va(cl_narg narg, cl_object v10c1form, cl_object v11butlast, cl_object v12last, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[86]);
 {
  return L3577p1fmla_and(v10c1form, v11butlast, v12last);
 }
}
/* function definition for P1FMLA-OR                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3578p1fmla_or(cl_object v1c1form, cl_object v2butlast, cl_object v3last)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  cl_object v5form;
  cl_object v6;
  {
   cl_object v7;
   v7 = v2butlast;
   if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v4 = v7;
  }
  v5form = ECL_NIL;
  v6 = v4;
  {
   cl_object v7type;
   v7type = ECL_NIL;
   {
    cl_object v8primary_type;
    v8primary_type = ECL_NIL;
    {
     cl_object v9output_type;
     v9output_type = ECL_NIL;
     if (!(ecl_endp(v6))){
      goto L12;
     }
     goto L11;
L12:;
     v5form = ECL_CONS_CAR(v6);
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v6);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v6 = v10;
     }
     v7type = L3563p1propagate(v5form);
     v8primary_type = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, v7type) /*  VALUES-TYPE-PRIMARY-TYPE */;
     v9output_type = v8primary_type;
L10:;
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(2, v8primary_type, ecl_cmp_symbol_value(cl_env_copy,VV[17])) /*  TYPE-TRUE-P */)){
      goto L26;
     }
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(2, v9output_type, VV[89]) /*  TYPE-AND */;
     return value0;
L26:;
     if (!(ecl_endp(v6))){
      goto L28;
     }
     goto L11;
L28:;
     v5form = ECL_CONS_CAR(v6);
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v6);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v6 = v10;
     }
     v7type = L3563p1propagate(v5form);
     v8primary_type = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, v7type) /*  VALUES-TYPE-PRIMARY-TYPE */;
     v9output_type = (cl_env_copy->function=ecl_fdefinition(VV[90]))->cfun.entry(2, v8primary_type, v9output_type) /*  TYPE-OR */;
     goto L10;
L11:;
     v7type = L3563p1propagate(v3last);
     v8primary_type = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, v7type) /*  VALUES-TYPE-PRIMARY-TYPE */;
     v9output_type = (cl_env_copy->function=ecl_fdefinition(VV[48]))->cfun.entry(2, v7type, v9output_type) /*  VALUES-TYPE-OR */;
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[78]))->cfun.entry(2, v8primary_type, ecl_cmp_symbol_value(cl_env_copy,VV[17])) /*  TYPE-TRUE-P */)){
      goto L50;
     }
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[23]))->cfun.entry(2, v9output_type, VV[89]) /*  VALUES-TYPE-AND */;
     return value0;
L50:;
     value0 = v9output_type;
     cl_env_copy->nvalues = 1;
     return value0;
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
}
static cl_object L3578p1fmla_or_va(cl_narg narg, cl_object v10c1form, cl_object v11butlast, cl_object v12last, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[88]);
 {
  return L3578p1fmla_or(v10c1form, v11butlast, v12last);
 }
}
/* function definition for P1LAMBDA                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3579p1lambda(cl_narg narg, cl_object v1c1form, cl_object v2lambda_list, cl_object v3doc, cl_object v4body, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<4)) FEwrong_num_arguments(VV[92]);
 {
  va_list args; va_start(args,v4body);
  va_end(args);
  value0 = L3563p1propagate(v4body);
  return value0;
 }
}
/* function definition for P1PROPAGATE-FUNCTION                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3580p1propagate_function(cl_object v1fun)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[94]))->cfun.entry(1, v1fun) /*  FUN-LAMBDA */;
  v2 = L3563p1propagate(T0);
  value0 = ecl_structure_set(v1fun,VV[95],(cl_fixnum)(19),v2);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3580p1propagate_function_va(cl_narg narg, cl_object v3fun, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[8]);
 {
  return L3580p1propagate_function(v3fun);
 }
}
/* function definition for P1LET*                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3581p1let_(cl_object v1c1form, cl_object v2vars, cl_object v3forms, cl_object v4body)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5type;
  v5type = ECL_NIL;
  {
   cl_object v6;
   cl_object v7v;
   cl_object v8;
   {
    cl_object v9;
    v9 = v2vars;
    if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v6 = v9;
   }
   v7v = ECL_NIL;
   v8 = v6;
   {
    cl_object v9;
    cl_object v10f;
    cl_object v11;
    {
     cl_object v12;
     v12 = v3forms;
     if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v9 = v12;
    }
    v10f = ECL_NIL;
    v11 = v9;
L14:;
    if (!(ecl_endp(v8))){
     goto L16;
    }
    goto L15;
L16:;
    v7v = ECL_CONS_CAR(v8);
    {
     cl_object v12;
     v12 = ECL_CONS_CDR(v8);
     if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v8 = v12;
    }
    if (!(ecl_endp(v11))){
     goto L24;
    }
    goto L15;
L24:;
    v10f = ECL_CONS_CAR(v11);
    {
     cl_object v12;
     v12 = ECL_CONS_CDR(v11);
     if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v11 = v12;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[98]))->cfun.entry(1, v7v) /*  GLOBAL-VAR-P */!=ECL_NIL) {
     goto L32;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[99]))->cfun.entry(1, v7v) /*  VAR-SET-NODES */!=ECL_NIL) {
     goto L32;
    }
    v5type = L3563p1propagate(v10f);
    {
     cl_object v12;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, v5type) /*  VALUES-TYPE-PRIMARY-TYPE */;
     T1 = (cl_env_copy->function=ecl_fdefinition(VV[100]))->cfun.entry(1, v7v) /*  VAR-TYPE */;
     v12 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(2, T0, T1) /*  TYPE-AND */;
     ecl_structure_set(v7v,VV[101],(cl_fixnum)(11),v12);
    }
L32:;
    goto L14;
L15:;
   }
  }
 }
 value0 = L3563p1propagate(v4body);
 return value0;
}
static cl_object L3581p1let__va(cl_narg narg, cl_object v5c1form, cl_object v6vars, cl_object v7forms, cl_object v8body, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[97]);
 {
  return L3581p1let_(v5c1form, v6vars, v7forms, v8body);
 }
}
/* function definition for P1LOCALS                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3582p1locals(cl_object v1c1form, cl_object v2funs, cl_object v3body, cl_object v4labels)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5;
  cl_object v6f;
  cl_object v7;
  {
   cl_object v8;
   v8 = v2funs;
   if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v5 = v8;
  }
  v6f = ECL_NIL;
  v7 = v5;
L8:;
  if (!(ecl_endp(v7))){
   goto L10;
  }
  goto L9;
L10:;
  v6f = ECL_CONS_CAR(v7);
  {
   cl_object v8;
   v8 = ECL_CONS_CDR(v7);
   if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v7 = v8;
  }
  L3580p1propagate_function(v6f);
  goto L8;
L9:;
 }
 value0 = L3563p1propagate(v3body);
 return value0;
}
static cl_object L3582p1locals_va(cl_narg narg, cl_object v5c1form, cl_object v6funs, cl_object v7body, cl_object v8labels, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[103]);
 {
  return L3582p1locals(v5c1form, v6funs, v7body, v8labels);
 }
}
/* function definition for P1MULTIPLE-VALUE-BIND                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3583p1multiple_value_bind(cl_object v1c1form, cl_object v2vars_list, cl_object v3init_c1form, cl_object v4body)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5init_form_type;
  v5init_form_type = L3563p1propagate(v3init_c1form);
  {
   cl_object v6;
   cl_object v7v;
   cl_object v8;
   {
    cl_object v9;
    v9 = v2vars_list;
    if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v6 = v9;
   }
   v7v = ECL_NIL;
   v8 = v6;
   {
    cl_object v9;
    cl_object v10type;
    cl_object v11;
    {
     cl_object v12;
     {
      cl_fixnum v13;
      v13 = ecl_length(v2vars_list);
      v12 = (cl_env_copy->function=ecl_fdefinition(VV[106]))->cfun.entry(2, v5init_form_type, ecl_make_fixnum(v13)) /*  VALUES-TYPE-TO-N-TYPES */;
     }
     if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v9 = v12;
    }
    v10type = ECL_NIL;
    v11 = v9;
L14:;
    if (!(ecl_endp(v8))){
     goto L16;
    }
    goto L15;
L16:;
    v7v = ECL_CONS_CAR(v8);
    {
     cl_object v12;
     v12 = ECL_CONS_CDR(v8);
     if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v8 = v12;
    }
    if (!(ecl_endp(v11))){
     goto L24;
    }
    goto L15;
L24:;
    v10type = ECL_CONS_CAR(v11);
    {
     cl_object v12;
     v12 = ECL_CONS_CDR(v11);
     if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v11 = v12;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[98]))->cfun.entry(1, v7v) /*  GLOBAL-VAR-P */!=ECL_NIL) {
     goto L32;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[99]))->cfun.entry(1, v7v) /*  VAR-SET-NODES */!=ECL_NIL) {
     goto L32;
    }
    {
     cl_object v12;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[100]))->cfun.entry(1, v7v) /*  VAR-TYPE */;
     v12 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(2, T0, v10type) /*  TYPE-AND */;
     ecl_structure_set(v7v,VV[101],(cl_fixnum)(11),v12);
    }
L32:;
    goto L14;
L15:;
   }
  }
  value0 = L3563p1propagate(v4body);
  return value0;
 }
}
static cl_object L3583p1multiple_value_bind_va(cl_narg narg, cl_object v6c1form, cl_object v7vars_list, cl_object v8init_c1form, cl_object v9body, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[105]);
 {
  return L3583p1multiple_value_bind(v6c1form, v7vars_list, v8init_c1form, v9body);
 }
}
/* function definition for P1MULTIPLE-VALUE-SETQ                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3584p1multiple_value_setq(cl_object v1c1form, cl_object v2vars_list, cl_object v3value_c1form)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L3563p1propagate(v3value_c1form);
 return value0;
}
static cl_object L3584p1multiple_value_setq_va(cl_narg narg, cl_object v4c1form, cl_object v5vars_list, cl_object v6value_c1form, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[108]);
 {
  return L3584p1multiple_value_setq(v4c1form, v5vars_list, v6value_c1form);
 }
}
/* function definition for P1PROGN                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3585p1progn(cl_object v1c1form, cl_object v2forms)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L3567p1propagate_list(v2forms);
 return value0;
}
static cl_object L3585p1progn_va(cl_narg narg, cl_object v3c1form, cl_object v4forms, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[110]);
 {
  return L3585p1progn(v3c1form, v4forms);
 }
}
/* function definition for P1COMPILER-TYPECASE                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3586p1compiler_typecase(cl_object v1c1form, cl_object v2variable, cl_object v3expressions)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4var_type;
  v4var_type = (cl_env_copy->function=ecl_fdefinition(VV[100]))->cfun.entry(1, v2variable) /*  VAR-TYPE */;
  {
   cl_object v5output_type;
   v5output_type = ECL_T;
   {
    cl_object v6;
    cl_object v7a_type;
    cl_object v8c1form;
    cl_object v9;
    {
     cl_object v10;
     v10 = v3expressions;
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v6 = v10;
    }
    v7a_type = ECL_NIL;
    v8c1form = ECL_NIL;
    v9 = v6;
    {
     cl_object v10c1form_type;
     v10c1form_type = ECL_NIL;
L11:;
     if (!(ecl_endp(v9))){
      goto L13;
     }
     goto L12;
L13:;
     {
      cl_object v11;
      v11 = ECL_CONS_CAR(v9);
      v7a_type = ecl_car(v11);
      v11 = ecl_cdr(v11);
      v8c1form = ecl_car(v11);
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v9);
      if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v9 = v11;
     }
     v10c1form_type = L3563p1propagate(v8c1form);
     if (!((v7a_type)==(ECL_T))){
      goto L34;
     }
     goto L30;
L34:;
     goto L32;
L32:;
     if (!((v7a_type)==(ECL_SYM("OTHERWISE",617)))){
      goto L37;
     }
     goto L30;
L37:;
     goto L31;
L31:;
     if (Null(cl_subtypep(3, v4var_type, v7a_type, ecl_cmp_symbol_value(cl_env_copy,VV[17])))){
      goto L28;
     }
     goto L29;
L30:;
L29:;
     v5output_type = v10c1form_type;
L28:;
     goto L11;
L12:;
     value0 = v5output_type;
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
}
static cl_object L3586p1compiler_typecase_va(cl_narg narg, cl_object v11c1form, cl_object v12variable, cl_object v13expressions, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[112]);
 {
  return L3586p1compiler_typecase(v11c1form, v12variable, v13expressions);
 }
}
/* function definition for P1CHECKED-VALUE                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3587p1checked_value(cl_object v1c1form, cl_object v2type, cl_object v3value, cl_object v4let_form)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5value_type;
  v5value_type = L3563p1propagate(v3value);
  if (Null(cl_subtypep(3, v5value_type, v2type, ecl_cmp_symbol_value(cl_env_copy,VV[17])))){
   goto L3;
  }
  value0 = v5value_type;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  value0 = v2type;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3587p1checked_value_va(cl_narg narg, cl_object v6c1form, cl_object v7type, cl_object v8value, cl_object v9let_form, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[116]);
 {
  return L3587p1checked_value(v6c1form, v7type, v8value, v9let_form);
 }
}
/* function definition for P1PROGV                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3588p1progv(cl_object v1c1form, cl_object v2variables, cl_object v3values, cl_object v4body)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 L3563p1propagate(v2variables);
 L3563p1propagate(v3values);
 value0 = L3563p1propagate(v4body);
 return value0;
}
static cl_object L3588p1progv_va(cl_narg narg, cl_object v5c1form, cl_object v6variables, cl_object v7values, cl_object v8body, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[118]);
 {
  return L3588p1progv(v5c1form, v6variables, v7values, v8body);
 }
}
/* function definition for P1SETQ                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3589p1setq(cl_object v1c1form, cl_object v2var, cl_object v3value_c1form)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4value_type;
  v4value_type = L3563p1propagate(v3value_c1form);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[100]))->cfun.entry(1, v2var) /*  VAR-TYPE */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[41]))->cfun.entry(1, v4value_type) /*  VALUES-TYPE-PRIMARY-TYPE */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[33]))->cfun.entry(2, T0, T1) /*  TYPE-AND */;
  return value0;
 }
}
static cl_object L3589p1setq_va(cl_narg narg, cl_object v5c1form, cl_object v6var, cl_object v7value_c1form, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[120]);
 {
  return L3589p1setq(v5c1form, v6var, v7value_c1form);
 }
}
/* function definition for P1PSETQ                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3590p1psetq(cl_object v1c1form, cl_object v2vars, cl_object v3c1forms)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  cl_object v5form;
  cl_object v6;
  {
   cl_object v7;
   v7 = v3c1forms;
   if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v4 = v7;
  }
  v5form = ECL_NIL;
  v6 = v4;
L8:;
  if (!(ecl_endp(v6))){
   goto L10;
  }
  goto L9;
L10:;
  v5form = ECL_CONS_CAR(v6);
  {
   cl_object v7;
   v7 = ECL_CONS_CDR(v6);
   if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v6 = v7;
  }
  L3563p1propagate(v5form);
  goto L8;
L9:;
 }
 value0 = ECL_SYM("NULL",607);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3590p1psetq_va(cl_narg narg, cl_object v4c1form, cl_object v5vars, cl_object v6c1forms, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[122]);
 {
  return L3590p1psetq(v4c1form, v5vars, v6c1forms);
 }
}
/* function definition for P1MV-PROG1                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3591p1mv_prog1(cl_object v1c1form, cl_object v2form, cl_object v3body)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  v4 = L3563p1propagate(v2form);
  L3567p1propagate_list(v3body);
  value0 = v4;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3591p1mv_prog1_va(cl_narg narg, cl_object v5c1form, cl_object v6form, cl_object v7body, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[124]);
 {
  return L3591p1mv_prog1(v5c1form, v6form, v7body);
 }
}
/* function definition for P1GO                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3592p1go(cl_object v1c1form, cl_object v2tag_var, cl_object v3return_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3592p1go_va(cl_narg narg, cl_object v4c1form, cl_object v5tag_var, cl_object v6return_type, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[127]);
 {
  return L3592p1go(v4c1form, v5tag_var, v6return_type);
 }
}
/* function definition for P1TAGBODY                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3593p1tagbody(cl_object v1c1form, cl_object v2tag_loc, cl_object v3body)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  cl_object v5f;
  cl_object v6;
  {
   cl_object v7;
   v7 = v3body;
   if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v4 = v7;
  }
  v5f = ECL_NIL;
  v6 = v4;
L9:;
  if (!(ecl_endp(v6))){
   goto L11;
  }
  goto L10;
L11:;
  v5f = ECL_CONS_CAR(v6);
  {
   cl_object v7;
   v7 = ECL_CONS_CDR(v6);
   if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v6 = v7;
  }
  if ((cl_env_copy->function=ecl_fdefinition(VV[130]))->cfun.entry(1, v5f) /*  TAG-P */!=ECL_NIL) {
   goto L19;
  }
  L3563p1propagate(v5f);
L19:;
  goto L9;
L10:;
 }
 value0 = ECL_SYM("NULL",607);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L3593p1tagbody_va(cl_narg narg, cl_object v4c1form, cl_object v5tag_loc, cl_object v6body, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[129]);
 {
  return L3593p1tagbody(v4c1form, v5tag_loc, v6body);
 }
}
/* function definition for P1UNWIND-PROTECT                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L3594p1unwind_protect(cl_object v1c1form, cl_object v2form, cl_object v3body)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4output_type;
  v4output_type = L3563p1propagate(v2form);
  L3563p1propagate(v3body);
  value0 = v4output_type;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L3594p1unwind_protect_va(cl_narg narg, cl_object v5c1form, cl_object v6form, cl_object v7body, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[132]);
 {
  return L3594p1unwind_protect(v5c1form, v6form, v7body);
 }
}
/* local function AND-FORM-TYPE                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC3570and_form_type(volatile cl_object *lex0, cl_object v1type, cl_object v2form)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[14]))->cfun.entry(1, v2form) /*  C1FORM-FORM */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[58]))->cfun.entry(1, lex0[0]) /*  FUN-NAME */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[55]))->cfun.entry(6, v1type, v2form, T0, VV[56], VV[57], T1) /*  AND-FORM-TYPE */;
 return value0;
}
#include "cmp/cmpprop.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecl2dRfhTzWw35r9_WWV0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:CMP;CMPPROP.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecl2dRfhTzWw35r9_WWV0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  si_Xmake_special(VV[0]);
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[0],T0);
  ecl_cmp_defmacro(VV[134]);                      /*  PROP-MESSAGE            */
  ecl_cmp_defun(VV[135]);                         /*  P1ORDINARY              */
  ecl_cmp_defun(VV[136]);                         /*  P1FSET                  */
  ecl_cmp_defun(VV[137]);                         /*  P1PROPAGATE             */
  ecl_cmp_defun(VV[138]);                         /*  P1TRIVIAL               */
  ecl_cmp_defun(VV[139]);                         /*  P1VAR                   */
  ecl_cmp_defun(VV[140]);                         /*  P1VALUES                */
  ecl_cmp_defun(VV[141]);                         /*  P1PROPAGATE-LIST        */
  ecl_cmp_defun(VV[142]);                         /*  P1BLOCK                 */
  ecl_cmp_defun(VV[143]);                         /*  P1RETURN-FROM           */
  ecl_cmp_defun(VV[144]);                         /*  P1FCALL                 */
  ecl_cmp_defun(VV[145]);                         /*  P1MCALL                 */
  ecl_cmp_defun(VV[146]);                         /*  P1CATCH                 */
  ecl_cmp_defun(VV[147]);                         /*  P1THROW                 */
  ecl_cmp_defun(VV[148]);                         /*  P1IF                    */
  ecl_cmp_defun(VV[149]);                         /*  P1FMLA-NOT              */
  ecl_cmp_defun(VV[150]);                         /*  P1FMLA-AND              */
  ecl_cmp_defun(VV[151]);                         /*  P1FMLA-OR               */
  ecl_cmp_defun(VV[152]);                         /*  P1LAMBDA                */
  ecl_cmp_defun(VV[153]);                         /*  P1PROPAGATE-FUNCTION    */
  ecl_cmp_defun(VV[154]);                         /*  P1LET*                  */
  ecl_cmp_defun(VV[155]);                         /*  P1LOCALS                */
  ecl_cmp_defun(VV[156]);                         /*  P1MULTIPLE-VALUE-BIND   */
  ecl_cmp_defun(VV[157]);                         /*  P1MULTIPLE-VALUE-SETQ   */
  ecl_cmp_defun(VV[158]);                         /*  P1PROGN                 */
  ecl_cmp_defun(VV[159]);                         /*  P1COMPILER-TYPECASE     */
  ecl_cmp_defun(VV[160]);                         /*  P1CHECKED-VALUE         */
  ecl_cmp_defun(VV[161]);                         /*  P1PROGV                 */
  ecl_cmp_defun(VV[162]);                         /*  P1SETQ                  */
  ecl_cmp_defun(VV[163]);                         /*  P1PSETQ                 */
  ecl_cmp_defun(VV[164]);                         /*  P1MV-PROG1              */
  si_Xmake_special(VV[126]);
  if (ecl_boundp(cl_env_copy,VV[126])) {
   goto L101;
  }
  T0 = ecl_make_int8_t(-1);
  ecl_cmp_setq(cl_env_copy,VV[126],T0);
L101:;
  ecl_cmp_defun(VV[165]);                         /*  P1GO                    */
  ecl_cmp_defun(VV[166]);                         /*  P1TAGBODY               */
  ecl_cmp_defun(VV[167]);                         /*  P1UNWIND-PROTECT        */
 }
}
