/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/lsp/format.lsp                      */
#include <ecl/ecl-cmp.h>
#include "lsp/format.eclh"
/* function definition for FLOAT-TO-DIGITS*                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L513float_to_digits_(cl_object v1digits, cl_object v2number, cl_object v3position, cl_object v4relativep)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5;                                   /*  EXP                     */
  cl_object v6;                                   /*  STRING                  */
  value0 = si_float_to_digits(v1digits, v2number, v3position, v4relativep);
  {
   const int v7 = cl_env_copy->nvalues;
   v5 = value0;
   cl_object v8;
   v8 = (v7<=1)? ECL_NIL : cl_env_copy->values[1];
   v6 = v8;
  }
  if (Null(v3position)){
   goto L5;
  }
  T1 = ecl_abs(v3position);
  T2 = ecl_negate(T1);
  T0 = ecl_make_bool(ecl_lower(v5,T2));
  goto L3;
L5:;
  T0 = ECL_NIL;
  goto L3;
L3:;
  cl_env_copy->nvalues = 3;
  cl_env_copy->values[2] = T0;
  cl_env_copy->values[1] = v6;
  cl_env_copy->values[0] = v5;
  return cl_env_copy->values[0];
 }
}
static cl_object L513float_to_digits__va(cl_narg narg, cl_object v5digits, cl_object v6number, cl_object v7position, cl_object v8relativep, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[3]);
 {
  return L513float_to_digits_(v5digits, v6number, v7position, v8relativep);
 }
}
/* function definition for FLONUM-TO-STRING                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L514flonum_to_string(cl_narg narg, cl_object v1x, ...)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[5]);
 if (ecl_unlikely(narg>5)) FEwrong_num_arguments(VV[5]);
 {
  cl_object v2width;
  cl_object v3fdigits;
  cl_object v4scale;
  cl_object v5fmin;
  va_list args; va_start(args,v1x);
  {
   int i = 1;
   if (i >= narg) {
    v2width = ECL_NIL;
   } else {
    i++;
    v2width = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v3fdigits = ECL_NIL;
   } else {
    i++;
    v3fdigits = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4scale = ecl_make_int8_t(0);
   } else {
    i++;
    v4scale = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v5fmin = ecl_make_int8_t(0);
   } else {
    i++;
    v5fmin = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (!(ecl_zerop(v1x))){
   goto L5;
  }
  if (!(v3fdigits==ECL_NIL)){
   goto L7;
  }
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = ecl_make_int8_t(1);
  cl_env_copy->values[4] = ecl_make_int8_t(0);
  cl_env_copy->values[3] = ECL_NIL;
  cl_env_copy->values[2] = ECL_T;
  cl_env_copy->values[1] = ecl_make_int8_t(2);
  cl_env_copy->values[0] = VV[6];
  return cl_env_copy->values[0];
L7:;
  if (!(ecl_zerop(v3fdigits))){
   goto L9;
  }
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = ecl_make_int8_t(1);
  cl_env_copy->values[4] = ecl_make_int8_t(1);
  cl_env_copy->values[3] = ECL_T;
  cl_env_copy->values[2] = ECL_NIL;
  cl_env_copy->values[1] = ecl_make_int8_t(2);
  cl_env_copy->values[0] = VV[7];
  return cl_env_copy->values[0];
L9:;
  {
   cl_object v6s;
   T0 = ecl_one_plus(v3fdigits);
   v6s = cl_make_string(3, T0, ECL_SYM("INITIAL-ELEMENT",1286), ECL_CODE_CHAR(48));
   ecl_char_set(v6s,(cl_fixnum)(0),(ecl_character)(46));
   {
    cl_fixnum v7;
    v7 = ecl_length(v6s);
    cl_env_copy->nvalues = 6;
    cl_env_copy->values[5] = ecl_make_int8_t(1);
    cl_env_copy->values[4] = ecl_make_int8_t(0);
    cl_env_copy->values[3] = ECL_NIL;
    cl_env_copy->values[2] = ECL_T;
    cl_env_copy->values[1] = ecl_make_fixnum(v7);
    cl_env_copy->values[0] = v6s;
    return cl_env_copy->values[0];
   }
  }
L5:;
  {
   cl_object v7;                                  /*  E                       */
   cl_object v8;                                  /*  STRING                  */
   cl_object v9;                                  /*  ZERO?                   */
   if (Null(v3fdigits)){
    goto L14;
   }
   T0 = ecl_plus(v3fdigits,v4scale);
   T1 = ecl_negate(T0);
   T2 = ecl_plus(v5fmin,v4scale);
   T3 = ecl_negate(T2);
   T4 = ((ecl_float_nan_p(T3) || ecl_lowereq(T1,T3))?T1:T3);
   value0 = L513float_to_digits_(ECL_NIL, v1x, T4, ECL_NIL);
   goto L13;
L14:;
   if (!(v2width==ECL_NIL)){
    goto L16;
   }
   value0 = L513float_to_digits_(ECL_NIL, v1x, ECL_NIL, ECL_NIL);
   goto L13;
L16:;
   {
    cl_object v10;
    cl_object v11;
    {
     struct ecl_stack_frame _ecl_inner_frame_aux;
     cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
     T0 = ecl_minus(v2width,ecl_make_int8_t(2));
     T1 = ((ecl_float_nan_p(v4scale) || ecl_greatereq(ecl_make_int8_t(0),v4scale))?ecl_make_int8_t(0):v4scale);
     T2 = ecl_plus(T0,T1);
     T3 = ((ecl_float_nan_p(T2) || ecl_greatereq(ecl_make_int8_t(0),T2))?ecl_make_int8_t(0):T2);
     cl_env_copy->values[0] = L513float_to_digits_(ECL_NIL, v1x, T3, ECL_T);
     ecl_stack_frame_push_values(_ecl_inner_frame);
     v10 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
     ecl_stack_frame_close(_ecl_inner_frame);
    }
    {
     struct ecl_stack_frame _ecl_inner_frame_aux;
     cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
     T0 = ecl_plus(v5fmin,v4scale);
     T1 = ecl_negate(T0);
     cl_env_copy->values[0] = L513float_to_digits_(ECL_NIL, v1x, T1, ECL_NIL);
     ecl_stack_frame_push_values(_ecl_inner_frame);
     v11 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
     ecl_stack_frame_close(_ecl_inner_frame);
    }
    T0 = ecl_car(v11);
    T1 = ecl_car(v10);
    if (!(ecl_greatereq(T0,T1))){
     goto L22;
    }
    value0 = cl_values_list(v10);
    goto L13;
L22:;
    value0 = cl_values_list(v11);
   }
L13:;
   {
    const int v10 = cl_env_copy->nvalues;
    v7 = value0;
    cl_object v11;
    v11 = (v10<=1)? ECL_NIL : cl_env_copy->values[1];
    v8 = v11;
    v11 = (v10<=2)? ECL_NIL : cl_env_copy->values[2];
    v9 = v11;
   }
   {
    cl_object v10exp;
    cl_object v11stream;
    cl_object v12length;
    v10exp = ecl_plus(v7,v4scale);
    v11stream = cl_make_string_output_stream(0);
    v12length = ecl_make_fixnum(ecl_length(v8));
    if (!(ecl_plusp(v10exp))){
     goto L27;
    }
    T0 = ((ecl_float_nan_p(v10exp) || ecl_lowereq(v12length,v10exp))?v12length:v10exp);
    cl_write_string(4, v8, v11stream, ECL_SYM("END",1256), T0);
    {
     cl_object v13;
     v13 = ecl_minus(v10exp,v12length);
     {
      cl_object v14i;
      v14i = ecl_make_int8_t(0);
      goto L33;
L32:;
      cl_write_char(2, ECL_CODE_CHAR(48), v11stream);
      v14i = ecl_one_plus(v14i);
L33:;
      if (!(ecl_lower(v14i,v13))){
       goto L38;
      }
      goto L32;
L38:;
     }
    }
L27:;
    cl_write_char(2, ECL_CODE_CHAR(46), v11stream);
    if (Null(v9)){
     goto L42;
    }
    if (Null(v3fdigits)){
     goto L42;
    }
    {
     cl_object v13i;
     v13i = ecl_make_int8_t(0);
     goto L47;
L46:;
     cl_write_char(2, ECL_CODE_CHAR(48), v11stream);
     v13i = ecl_one_plus(v13i);
L47:;
     if (!(ecl_lower(v13i,v3fdigits))){
      goto L52;
     }
     goto L46;
L52:;
     goto L41;
    }
L42:;
    if (Null(v3fdigits)){
     goto L54;
    }
    {
     cl_object v14characters_used;
     v14characters_used = ecl_make_int8_t(0);
     {
      cl_object v15;
      T0 = ecl_negate(v10exp);
      v15 = ((ecl_float_nan_p(v3fdigits) || ecl_lowereq(T0,v3fdigits))?T0:v3fdigits);
      {
       cl_object v16i;
       v16i = ecl_make_int8_t(0);
       goto L61;
L60:;
       v14characters_used = ecl_plus(v14characters_used,ecl_make_int8_t(1));
       cl_write_char(2, ECL_CODE_CHAR(48), v11stream);
       v16i = ecl_one_plus(v16i);
L61:;
       if (!(ecl_lower(v16i,v15))){
        goto L68;
       }
       goto L60;
L68:;
      }
     }
     {
      cl_object v15start;
      cl_object v16end;
      T0 = ((ecl_float_nan_p(v10exp) || ecl_lowereq(v12length,v10exp))?v12length:v10exp);
      v15start = ((ecl_float_nan_p(T0) || ecl_greatereq(ecl_make_int8_t(0),T0))?ecl_make_int8_t(0):T0);
      T0 = ecl_minus(v3fdigits,v14characters_used);
      T1 = ecl_plus(v15start,T0);
      T2 = ((ecl_float_nan_p(T1) || ecl_lowereq(v12length,T1))?v12length:T1);
      v16end = ((ecl_float_nan_p(T2) || ecl_greatereq(v15start,T2))?v15start:T2);
      cl_write_string(6, v8, v11stream, ECL_SYM("START",1347), v15start, ECL_SYM("END",1256), v16end);
      {
       cl_object v17;
       v17 = ecl_minus(v16end,v15start);
       v14characters_used = ecl_plus(v14characters_used,v17);
      }
      {
       cl_object v17;
       v17 = ecl_minus(v3fdigits,v14characters_used);
       {
        cl_object v18i;
        v18i = ecl_make_int8_t(0);
        goto L79;
L78:;
        cl_write_char(2, ECL_CODE_CHAR(48), v11stream);
        v18i = ecl_one_plus(v18i);
L79:;
        if (!(ecl_lower(v18i,v17))){
         goto L84;
        }
        goto L78;
L84:;
        goto L41;
       }
      }
     }
    }
L54:;
    if (Null(v9)){
     goto L86;
    }
    cl_write_char(2, ECL_CODE_CHAR(48), v11stream);
    goto L41;
L86:;
    {
     cl_object v19;
     v19 = ecl_negate(v10exp);
     {
      cl_object v20i;
      v20i = ecl_make_int8_t(0);
      goto L92;
L91:;
      cl_write_char(2, ECL_CODE_CHAR(48), v11stream);
      v20i = ecl_one_plus(v20i);
L92:;
      if (!(ecl_lower(v20i,v19))){
       goto L97;
      }
      goto L91;
L97:;
     }
    }
    {
     cl_object v19start;
     T0 = ((ecl_float_nan_p(v10exp) || ecl_lowereq(v12length,v10exp))?v12length:v10exp);
     v19start = ((ecl_float_nan_p(T0) || ecl_greatereq(ecl_make_int8_t(0),T0))?ecl_make_int8_t(0):T0);
     cl_write_string(4, v8, v11stream, ECL_SYM("START",1347), v19start);
    }
L41:;
    {
     cl_object v13string;
     cl_object v14length;
     cl_object v15position;
     v13string = cl_get_output_stream_string(v11stream);
     v14length = ecl_make_fixnum(ecl_length(v13string));
     v15position = cl_position(2, ECL_CODE_CHAR(46), v13string);
     {
      bool v16;
      v16 = ecl_number_equalp(v15position,ecl_make_int8_t(0));
      T0 = ecl_make_integer((ecl_fixnum(v14length))-1);
      {
       bool v17;
       v17 = ecl_number_equalp(v15position,T0);
       cl_env_copy->nvalues = 6;
       cl_env_copy->values[5] = v7;
       cl_env_copy->values[4] = v15position;
       cl_env_copy->values[3] = ecl_make_bool(v17);
       cl_env_copy->values[2] = ecl_make_bool(v16);
       cl_env_copy->values[1] = v14length;
       cl_env_copy->values[0] = v13string;
       return cl_env_copy->values[0];
      }
     }
    }
   }
  }
 }
}
/* function definition for EXPONENT-IN-BASE10                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L515exponent_in_base10(cl_object v1x)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ecl_number_equalp(v1x,ecl_make_int8_t(0)))){
  goto L2;
 }
 value0 = ecl_make_int8_t(1);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 T0 = ecl_abs(v1x);
 T1 = cl_log(2, T0, ecl_make_int8_t(10));
 T2 = ecl_floor1(T1);
 value0 = ecl_one_plus(T2);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L515exponent_in_base10_va(cl_narg narg, cl_object v2x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[9]);
 {
  return L515exponent_in_base10(v2x);
 }
}
/* function definition for MAKE-FORMAT-DIRECTIVE                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L516make_format_directive(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[14];
   cl_parse_key(args,7,L516make_format_directivekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[7])) {
    v1 = ECL_T;
   } else {
    v1 = keyvars[0];
   }
   if (Null(keyvars[8])) {
    v2 = ecl_make_int8_t(0);
   } else {
    v2 = keyvars[1];
   }
   if (Null(keyvars[9])) {
    v3 = ecl_make_int8_t(0);
   } else {
    v3 = keyvars[2];
   }
   if (Null(keyvars[10])) {
    v4 = ECL_CODE_CHAR(32);
   } else {
    v4 = keyvars[3];
   }
   v5 = keyvars[4];
   v6 = keyvars[5];
   v7 = keyvars[6];
  }
  T0 = cl_list(8, VV[12], v1, v2, v3, v4, v5, v6, v7);
  value0 = cl_make_array(5, VV[16], ECL_SYM("ELEMENT-TYPE",1255), ECL_T, ECL_SYM("INITIAL-CONTENTS",1287), T0);
  return value0;
 }
}
/* function definition for TOKENIZE-CONTROL-STRING                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L517tokenize_control_string(cl_object v1string)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3index;
  cl_object v4result;
  v2 = ecl_make_fixnum(ecl_length(v1string));
  v3index = ecl_make_int8_t(0);
  v4result = ECL_NIL;
L6:;
  {
   cl_object v5next_directive;
   value0 = cl_position(4, ECL_CODE_CHAR(126), v1string, ECL_SYM("START",1347), v3index);
   if (value0!=ECL_NIL) {
    goto L10;
   }
   v5next_directive = v2;
   goto L8;
L10:;
   v5next_directive = value0;
   goto L8;
L8:;
   if (!(ecl_greater(v5next_directive,v3index))){
    goto L12;
   }
   T0 = cl_subseq(3, v1string, v3index, v5next_directive);
   v4result = CONS(T0,v4result);
L12:;
   if (!((ecl_fixnum(v5next_directive))==(ecl_fixnum(v2)))){
    goto L15;
   }
   goto L5;
L15:;
   {
    cl_object v6directive;
    v6directive = L519parse_directive(v1string, v5next_directive);
    v4result = CONS(v6directive,v4result);
    v3index = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v6directive) /*  FORMAT-DIRECTIVE-END */;
   }
  }
  goto L6;
L5:;
  value0 = cl_nreverse(v4result);
  return value0;
 }
}
/* function definition for PARSE-DIRECTIVE                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L519parse_directive(cl_object v1string, cl_object v2start)
{
 cl_object T0, T1, T2;
 volatile cl_object lex0[4];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 lex0[0] = v1string;                              /*  STRING                  */
 lex0[1] = v2start;                               /*  START                   */
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5params;
  cl_object v6colonp;
  cl_object v7atsignp;
  v3 = ecl_one_plus(lex0[1]);
  v4 = ecl_make_fixnum(ecl_length(lex0[0]));
  lex0[2] = v3;                                   /*  POSN                    */
  v5params = ECL_NIL;
  v6colonp = ECL_NIL;
  v7atsignp = ECL_NIL;
  lex0[3] = v4;                                   /*  END                     */
L8:;
  {
   cl_object v8char;
   v8char = LC518get_char(lex0);
   if (v6colonp!=ECL_NIL) {
    goto L12;
   }
   if (v7atsignp!=ECL_NIL) {
    goto L12;
   }
   if (cl_charLE(3, ECL_CODE_CHAR(48), v8char, ECL_CODE_CHAR(57))!=ECL_NIL) {
    goto L16;
   }
   if (ecl_char_code(v8char)==ecl_char_code(ECL_CODE_CHAR(43))) {
    goto L16;
   }
   if (!(ecl_char_code(v8char)==ecl_char_code(ECL_CODE_CHAR(45)))){
    goto L12;
   }
   goto L13;
L16:;
L13:;
   {
    cl_object v9;                                 /*  PARAM                   */
    cl_object v10;                                /*  NEW-POSN                */
    value0 = cl_parse_integer(5, lex0[0], ECL_SYM("START",1347), lex0[2], ECL_SYM("JUNK-ALLOWED",1296), ECL_T);
    {
     v9 = value0;
     v10 = cl_env_copy->values[1];
    }
    T0 = CONS(lex0[2],v9);
    v5params = CONS(T0,v5params);
    lex0[2] = v10;
    {
     cl_object v11;
     v11 = LC518get_char(lex0);
     if (((v11)==ECL_CODE_CHAR((ecl_character)(44)))) {
      goto L10;
     }
     if (!(((v11)==ECL_CODE_CHAR((ecl_character)(58))))){
      goto L31;
     }
     goto L28;
L31:;
     goto L29;
L29:;
     if (!(((v11)==ECL_CODE_CHAR((ecl_character)(64))))){
      goto L26;
     }
     goto L27;
L28:;
L27:;
     lex0[2] = ecl_minus(lex0[2],ecl_make_int8_t(1));
     goto L10;
L26:;
     goto L7;
    }
   }
L12:;
   if (v6colonp!=ECL_NIL) {
    goto L35;
   }
   if (v7atsignp!=ECL_NIL) {
    goto L35;
   }
   if (ecl_char_code(v8char)==ecl_char_code(ECL_CODE_CHAR(118))) {
    goto L39;
   }
   if (!(ecl_char_code(v8char)==ecl_char_code(ECL_CODE_CHAR(86)))){
    goto L35;
   }
   goto L36;
L39:;
L36:;
   T0 = CONS(lex0[2],VV[33]);
   v5params = CONS(T0,v5params);
   lex0[2] = ecl_plus(lex0[2],ecl_make_int8_t(1));
   {
    cl_object v9;
    v9 = LC518get_char(lex0);
    if (((v9)==ECL_CODE_CHAR((ecl_character)(44)))) {
     goto L10;
    }
    if (!(((v9)==ECL_CODE_CHAR((ecl_character)(58))))){
     goto L52;
    }
    goto L49;
L52:;
    goto L50;
L50:;
    if (!(((v9)==ECL_CODE_CHAR((ecl_character)(64))))){
     goto L47;
    }
    goto L48;
L49:;
L48:;
    lex0[2] = ecl_minus(lex0[2],ecl_make_int8_t(1));
    goto L10;
L47:;
    goto L7;
   }
L35:;
   if (v6colonp!=ECL_NIL) {
    goto L56;
   }
   if (v7atsignp!=ECL_NIL) {
    goto L56;
   }
   if (!(ecl_char_code(v8char)==ecl_char_code(ECL_CODE_CHAR(35)))){
    goto L56;
   }
   T0 = CONS(lex0[2],VV[34]);
   v5params = CONS(T0,v5params);
   lex0[2] = ecl_plus(lex0[2],ecl_make_int8_t(1));
   {
    cl_object v10;
    v10 = LC518get_char(lex0);
    if (((v10)==ECL_CODE_CHAR((ecl_character)(44)))) {
     goto L10;
    }
    if (!(((v10)==ECL_CODE_CHAR((ecl_character)(58))))){
     goto L71;
    }
    goto L68;
L71:;
    goto L69;
L69:;
    if (!(((v10)==ECL_CODE_CHAR((ecl_character)(64))))){
     goto L66;
    }
    goto L67;
L68:;
L67:;
    lex0[2] = ecl_minus(lex0[2],ecl_make_int8_t(1));
    goto L10;
L66:;
    goto L7;
   }
L56:;
   if (v6colonp!=ECL_NIL) {
    goto L75;
   }
   if (v7atsignp!=ECL_NIL) {
    goto L75;
   }
   if (!(ecl_char_code(v8char)==ecl_char_code(ECL_CODE_CHAR(39)))){
    goto L75;
   }
   lex0[2] = ecl_plus(lex0[2],ecl_make_int8_t(1));
   T0 = LC518get_char(lex0);
   T1 = CONS(lex0[2],T0);
   v5params = CONS(T1,v5params);
   lex0[2] = ecl_plus(lex0[2],ecl_make_int8_t(1));
   T0 = LC518get_char(lex0);
   if (ecl_char_code(T0)==ecl_char_code(ECL_CODE_CHAR(44))) {
    goto L10;
   }
   lex0[2] = ecl_minus(lex0[2],ecl_make_int8_t(1));
   goto L10;
L75:;
   if (v6colonp!=ECL_NIL) {
    goto L89;
   }
   if (v7atsignp!=ECL_NIL) {
    goto L89;
   }
   if (!(ecl_char_code(v8char)==ecl_char_code(ECL_CODE_CHAR(44)))){
    goto L89;
   }
   T0 = CONS(lex0[2],ECL_NIL);
   v5params = CONS(T0,v5params);
   goto L10;
L89:;
   if (!(ecl_char_code(v8char)==ecl_char_code(ECL_CODE_CHAR(58)))){
    goto L94;
   }
   if (Null(v6colonp)){
    goto L96;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[35], ECL_SYM("CONTROL-STRING",1242), lex0[0], ECL_SYM("OFFSET",1316), lex0[2]);
   goto L10;
L96:;
   v6colonp = ECL_T;
   goto L10;
L94:;
   if (!(ecl_char_code(v8char)==ecl_char_code(ECL_CODE_CHAR(64)))){
    goto L99;
   }
   if (Null(v7atsignp)){
    goto L101;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[36], ECL_SYM("CONTROL-STRING",1242), lex0[0], ECL_SYM("OFFSET",1316), lex0[2]);
   goto L10;
L101:;
   v7atsignp = ECL_T;
   goto L10;
L99:;
   goto L7;
  }
L10:;
  lex0[2] = ecl_plus(lex0[2],ecl_make_int8_t(1));
  goto L8;
L7:;
  {
   cl_object v8char;
   v8char = LC518get_char(lex0);
   if (!(ecl_char_code(v8char)==ecl_char_code(ECL_CODE_CHAR(47)))){
    goto L107;
   }
   {
    cl_object v9closing_slash;
    T0 = ecl_one_plus(lex0[2]);
    v9closing_slash = cl_position(4, ECL_CODE_CHAR(47), lex0[0], ECL_SYM("START",1347), T0);
    if (Null(v9closing_slash)){
     goto L110;
    }
    lex0[2] = v9closing_slash;
    goto L107;
L110:;
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[37], ECL_SYM("CONTROL-STRING",1242), lex0[0], ECL_SYM("OFFSET",1316), lex0[2]);
   }
L107:;
   T0 = ecl_one_plus(lex0[2]);
   T1 = cl_char_upcase(v8char);
   T2 = cl_nreverse(v5params);
   value0 = L516make_format_directive(14, VV[38], lex0[0], ECL_SYM("START",1347), lex0[1], ECL_SYM("END",1256), T0, VV[39], T1, VV[40], v6colonp, VV[41], v7atsignp, VV[42], T2);
   return value0;
  }
 }
}
/* function definition for FORMATTER-AUX                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L520formatter_aux(volatile cl_narg narg, cl_object volatile v1stream, cl_object volatile v2string_or_fun, cl_object volatile v3orig_args, ...)
{
 cl_object T0;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[54]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[54]);
 {
  cl_object volatile v4args;
  va_list args; va_start(args,v3orig_args);
  {
   int i = 3;
   if (i >= narg) {
    v4args = v3orig_args;
   } else {
    i++;
    v4args = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(cl_functionp(v2string_or_fun))){
   goto L2;
  }
  value0 = cl_apply(3, v2string_or_fun, v1stream, v4args);
  return value0;
L2:;
  value0 = VV[50];                                /*  BEGIN CATCH CATCH3597   */
  {
   ecl_frs_push(cl_env_copy,value0);
   if (__ecl_frs_push_result!=0) {
    value0 = cl_env_copy->values[0];
   } else {
    {
     cl_object v5string;
     if (Null(cl_simple_string_p(v2string_or_fun))){
      goto L8;
     }
     v5string = v2string_or_fun;
     goto L7;
L8:;
     if (!(ECL_STRINGP(v2string_or_fun))){
      goto L10;
     }
     v5string = si_coerce_to_vector(v2string_or_fun, ECL_SYM("CHARACTER",224), ECL_SYM("*",20), ECL_T);
     goto L7;
L10:;
     v5string = si_etypecase_error(v2string_or_fun, VV[52]);
L7:;
     ecl_bds_bind(cl_env_copy,VV[24],ECL_NIL);    /*  *OUTPUT-LAYOUT-MODE*    */
     ecl_bds_bind(cl_env_copy,VV[22],v5string);   /*  *DEFAULT-FORMAT-ERROR-CONTROL-STRING* */
     ecl_bds_bind(cl_env_copy,VV[44],ECL_NIL);    /*  *LOGICAL-BLOCK-POPPER*  */
     T0 = L517tokenize_control_string(v5string);
     value0 = L521interpret_directive_list(v1stream, T0, v3orig_args, v4args);
     ecl_bds_unwind1(cl_env_copy);
     ecl_bds_unwind1(cl_env_copy);
     ecl_bds_unwind1(cl_env_copy);
    }
   }
  }
  ecl_frs_pop(cl_env_copy);                       /*  END CATCH CATCH3597     */
  return value0;
 }
}
/* function definition for INTERPRET-DIRECTIVE-LIST                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L521interpret_directive_list(cl_object v1stream, cl_object v2directives, cl_object v3orig_args, cl_object v4args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v2directives)){
  goto L2;
 }
 {
  cl_object v5directive;
  v5directive = ecl_car(v2directives);
  if (Null(cl_simple_string_p(v5directive))){
   goto L5;
  }
  cl_write_string(2, v5directive, v1stream);
  v2directives = ecl_cdr(v2directives);
  goto L1;
L5:;
  if (!(ECL_VECTORP(v5directive))){
   goto L13;
  }
  {
   cl_object v6;                                  /*  NEW-DIRECTIVES          */
   cl_object v7;                                  /*  NEW-ARGS                */
   {
    cl_object v8code;
    cl_object v9function;
    T0 = (cl_env_copy->function=(VV[55]->symbol.gfdef))->cfun.entry(1, v5directive) /*  FORMAT-DIRECTIVE-CHARACTER */;
    v8code = cl_char_code(T0);
    if (!((ecl_fixnum(v8code))<(ecl_fixnum(ecl_cmp_symbol_value(cl_env_copy,VV[19]))))){
     goto L19;
    }
    v9function = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[21]),ecl_fixnum(v8code));
    goto L17;
L19:;
    v9function = ECL_NIL;
    goto L17;
L17:;
    T0 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v5directive) /*  FORMAT-DIRECTIVE-END */;
    T1 = ecl_one_minus(T0);
    ecl_bds_bind(cl_env_copy,VV[23],T1);          /*  *DEFAULT-FORMAT-ERROR-OFFSET* */
    if (v9function!=ECL_NIL) {
     goto L21;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[56]);
L21:;
    {
     cl_object v10;                               /*  NEW-DIRECTIVES          */
     cl_object v11;                               /*  NEW-ARGS                */
     T0 = ecl_cdr(v2directives);
     value0 = ecl_function_dispatch(cl_env_copy,v9function)(5, v1stream, v5directive, T0, v3orig_args, v4args);
     {
      const int v12 = cl_env_copy->nvalues;
      v10 = value0;
      cl_object v13;
      v13 = (v12<=1)? ECL_NIL : cl_env_copy->values[1];
      v11 = v13;
     }
     cl_env_copy->nvalues = 2;
     cl_env_copy->values[1] = v11;
     cl_env_copy->values[0] = v10;
     value0 = cl_env_copy->values[0];
     ecl_bds_unwind1(cl_env_copy);
    }
   }
   {
    v6 = value0;
    v7 = cl_env_copy->values[1];
   }
   v2directives = v6;
   v4args = v7;
   goto L1;
  }
L13:;
  value0 = si_etypecase_error(v5directive, VV[57]);
  return value0;
 }
L2:;
 value0 = v4args;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* local function FORMATTER                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC522formatter(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4control_string;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4control_string = v5;
  }
  if (Null(v3)){
   goto L9;
  }
  si_dm_too_many_arguments(v1);
L9:;
  T0 = L523_formatter(v4control_string);
  value0 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
  return value0;
 }
}
static cl_object LC522formatter_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[61]);
 {
  return LC522formatter(v5, v6);
 }
}
/* function definition for %FORMATTER                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L523_formatter(cl_object volatile v1control_string)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = VV[62];                                 /*  BEGIN CATCH CATCH3598   */
 {
  ecl_frs_push(cl_env_copy,value0);
  if (__ecl_frs_push_result!=0) {
  } else {
   {
    cl_object v2guts;
    cl_object v3args;
    ecl_bds_bind(cl_env_copy,VV[49],ECL_NIL);     /*  *SIMPLE-ARGS*           */
    ecl_bds_bind(cl_env_copy,VV[47],ECL_T);       /*  *ONLY-SIMPLE-ARGS*      */
    v2guts = L524expand_control_string(v1control_string);
    v3args = ECL_NIL;
    {
     cl_object v4;
     v4 = ecl_cmp_symbol_value(cl_env_copy,VV[49]);
     goto L11;
L10:;
     {
      cl_object v5arg;
      v5arg = ecl_car(v4);
      T0 = ecl_car(v5arg);
      T1 = ecl_cdr(v5arg);
      T2 = cl_list(8, ECL_SYM("ERROR",339), VV[64], VV[29], VV[65], ECL_SYM("CONTROL-STRING",1242), v1control_string, ECL_SYM("OFFSET",1316), T1);
      T3 = cl_list(2, T0, T2);
      v3args = CONS(T3,v3args);
     }
     v4 = ecl_cdr(v4);
L11:;
     if (Null(v4)){
      goto L19;
     }
     goto L10;
L19:;
    }
    T0 = ecl_append(v3args,VV[66]);
    T1 = cl_listX(3, ECL_SYM("STREAM",802), ECL_SYM("&OPTIONAL",13), T0);
    value0 = cl_list(4, ECL_SYM("LAMBDA",454), T1, v2guts, VV[67]);
    ecl_frs_pop_n(cl_env_copy, 1);
    ecl_bds_unwind1(cl_env_copy);
    ecl_bds_unwind1(cl_env_copy);
    return value0;
   }
  }
 }
 ecl_frs_pop(cl_env_copy);                        /*  END CATCH CATCH3598     */
 ecl_bds_bind(cl_env_copy,VV[48],ECL_T);          /*  *ORIG-ARGS-AVAILABLE*   */
 ecl_bds_bind(cl_env_copy,VV[47],ECL_NIL);        /*  *ONLY-SIMPLE-ARGS*      */
 T0 = L524expand_control_string(v1control_string);
 T1 = cl_list(4, ECL_SYM("LET",479), VV[69], T0, VV[67]);
 value0 = cl_list(3, ECL_SYM("LAMBDA",454), VV[68], T1);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
/* function definition for EXPAND-CONTROL-STRING                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L524expand_control_string(cl_object v1string)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2string;
  cl_object v3directives;
  if (Null(cl_simple_string_p(v1string))){
   goto L3;
  }
  v2string = v1string;
  goto L2;
L3:;
  if (!(ECL_STRINGP(v1string))){
   goto L5;
  }
  v2string = si_coerce_to_vector(v1string, ECL_SYM("CHARACTER",224), ECL_SYM("*",20), ECL_T);
  goto L2;
L5:;
  v2string = si_etypecase_error(v1string, VV[52]);
L2:;
  ecl_bds_bind(cl_env_copy,VV[24],ECL_NIL);       /*  *OUTPUT-LAYOUT-MODE*    */
  ecl_bds_bind(cl_env_copy,VV[22],v2string);      /*  *DEFAULT-FORMAT-ERROR-CONTROL-STRING* */
  v3directives = L517tokenize_control_string(v2string);
  T0 = L525expand_directive_list(v3directives);
  value0 = cl_listX(3, ECL_SYM("BLOCK",139), ECL_NIL, T0);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
/* function definition for EXPAND-DIRECTIVE-LIST                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L525expand_directive_list(cl_object v1directives)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2results;
  cl_object v3remaining_directives;
  v2results = ECL_NIL;
  v3remaining_directives = v1directives;
L5:;
  if (v3remaining_directives!=ECL_NIL) {
   goto L7;
  }
  goto L4;
L7:;
  {
   cl_object v4;                                  /*  FORM                    */
   cl_object v5;                                  /*  NEW-DIRECTIVES          */
   T0 = ecl_car(v3remaining_directives);
   T1 = ecl_cdr(v3remaining_directives);
   value0 = L526expand_directive(T0, T1);
   {
    const int v6 = cl_env_copy->nvalues;
    v4 = value0;
    cl_object v7;
    v7 = (v6<=1)? ECL_NIL : cl_env_copy->values[1];
    v5 = v7;
   }
   if (Null(v4)){
    goto L10;
   }
   v2results = CONS(v4,v2results);
L10:;
   v3remaining_directives = v5;
  }
  goto L5;
L4:;
  value0 = cl_reverse(v2results);
  return value0;
 }
}
/* function definition for EXPAND-DIRECTIVE                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L526expand_directive(cl_object v1directive, cl_object v2more_directives)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_simple_string_p(v1directive))){
  goto L2;
 }
 T0 = cl_list(3, ECL_SYM("WRITE-STRING",926), v1directive, ECL_SYM("STREAM",802));
 cl_env_copy->nvalues = 2;
 cl_env_copy->values[1] = v2more_directives;
 cl_env_copy->values[0] = T0;
 return cl_env_copy->values[0];
L2:;
 if (!(ECL_VECTORP(v1directive))){
  goto L4;
 }
 {
  cl_object v3code;
  cl_object v4expander;
  T0 = (cl_env_copy->function=(VV[55]->symbol.gfdef))->cfun.entry(1, v1directive) /*  FORMAT-DIRECTIVE-CHARACTER */;
  v3code = cl_char_code(T0);
  if (!((ecl_fixnum(v3code))<(ecl_fixnum(ecl_cmp_symbol_value(cl_env_copy,VV[19]))))){
   goto L9;
  }
  v4expander = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[20]),ecl_fixnum(v3code));
  goto L7;
L9:;
  v4expander = ECL_NIL;
  goto L7;
L7:;
  T0 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v1directive) /*  FORMAT-DIRECTIVE-END */;
  T1 = ecl_one_minus(T0);
  ecl_bds_bind(cl_env_copy,VV[23],T1);            /*  *DEFAULT-FORMAT-ERROR-OFFSET* */
  if (Null(v4expander)){
   goto L11;
  }
  value0 = ecl_function_dispatch(cl_env_copy,v4expander)(2, v1directive, v2more_directives);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L11:;
  value0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[72]);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
L4:;
 value0 = si_etypecase_error(v1directive, VV[73]);
 return value0;
}
/* function definition for EXPAND-NEXT-ARG                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L527expand_next_arg(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[74]);
 {
  cl_object v1offset;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1offset = ECL_NIL;
   } else {
    i++;
    v1offset = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (ecl_cmp_symbol_value(cl_env_copy,VV[48])!=ECL_NIL) {
   goto L4;
  }
  if (ecl_cmp_symbol_value(cl_env_copy,VV[47])!=ECL_NIL) {
   goto L2;
  }
  goto L3;
L4:;
L3:;
  value0 = v1offset;
  if (value0!=ECL_NIL) {
   goto L8;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,VV[23]);
  goto L6;
L8:;
  T0 = value0;
  goto L6;
L6:;
  value0 = cl_list(3, ecl_cmp_symbol_value(cl_env_copy,VV[45]), ecl_cmp_symbol_value(cl_env_copy,VV[22]), T0);
  return value0;
L2:;
  {
   cl_object v2symbol;
   v2symbol = cl_gensym(1, VV[75]);
   value0 = v1offset;
   if (value0!=ECL_NIL) {
    goto L15;
   }
   T0 = ecl_cmp_symbol_value(cl_env_copy,VV[23]);
   goto L13;
L15:;
   T0 = value0;
   goto L13;
L13:;
   T1 = CONS(v2symbol,T0);
   T2 = CONS(T1,ecl_cmp_symbol_value(cl_env_copy,VV[49]));
   ecl_cmp_setq(cl_env_copy,VV[49],T2);
   value0 = v2symbol;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for NEED-HAIRY-ARGS                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L528need_hairy_args()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[47]))){
  goto L2;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* local function EXPANDER-NEXT-ARG                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC529expander_next_arg(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4string;
  cl_object v5offset;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4string = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5offset = v6;
  }
  if (Null(v3)){
   goto L15;
  }
  si_dm_too_many_arguments(v1);
L15:;
  T0 = cl_list(8, ECL_SYM("ERROR",339), VV[64], VV[29], VV[78], ECL_SYM("CONTROL-STRING",1242), v4string, ECL_SYM("OFFSET",1316), v5offset);
  value0 = cl_list(4, ECL_SYM("IF",950), VV[67], VV[77], T0);
  return value0;
 }
}
static cl_object LC529expander_next_arg_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[46]);
 {
  return LC529expander_next_arg(v6, v7);
 }
}
/* local function EXPANDER-PPRINT-NEXT-ARG                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC530expander_pprint_next_arg(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4string;
  cl_object v5offset;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4string = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5offset = v6;
  }
  if (Null(v3)){
   goto L15;
  }
  si_dm_too_many_arguments(v1);
L15:;
  T0 = cl_list(8, ECL_SYM("ERROR",339), VV[64], VV[29], VV[78], ECL_SYM("CONTROL-STRING",1242), v4string, ECL_SYM("OFFSET",1316), v5offset);
  T1 = cl_list(3, ECL_SYM("WHEN",909), VV[81], T0);
  value0 = cl_listX(3, ECL_SYM("PROGN",674), T1, VV[82]);
  return value0;
 }
}
static cl_object LC530expander_pprint_next_arg_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[80]);
 {
  return LC530expander_pprint_next_arg(v6, v7);
 }
}
/* function definition for %SET-FORMAT-DIRECTIVE-EXPANDER                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L531_set_format_directive_expander(cl_object v1char, cl_object v2fn)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cmp_symbol_value(cl_env_copy,VV[20]);
  T0 = v3;
  {
   cl_object v4;
   T2 = cl_char_upcase(v1char);
   v4 = cl_char_code(T2);
   if (ecl_unlikely((ecl_fixnum(v4))>=(v3)->vector.dim))
           FEwrong_index(ECL_NIL,v3,-1,ecl_make_fixnum(ecl_fixnum(v4)),(v3)->vector.dim);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   T1 = v4;
  }
  ecl_aset_unsafe(T0,ecl_fixnum(T1),v2fn);
 }
 value0 = v1char;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L531_set_format_directive_expander_va(cl_narg narg, cl_object v3char, cl_object v4fn, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[84]);
 {
  return L531_set_format_directive_expander(v3char, v4fn);
 }
}
/* function definition for %SET-FORMAT-DIRECTIVE-INTERPRETER                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L532_set_format_directive_interpreter(cl_object v1char, cl_object v2fn)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cmp_symbol_value(cl_env_copy,VV[21]);
  T0 = v3;
  {
   cl_object v4;
   T2 = cl_char_upcase(v1char);
   v4 = cl_char_code(T2);
   if (ecl_unlikely((ecl_fixnum(v4))>=(v3)->vector.dim))
           FEwrong_index(ECL_NIL,v3,-1,ecl_make_fixnum(ecl_fixnum(v4)),(v3)->vector.dim);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   T1 = v4;
  }
  ecl_aset_unsafe(T0,ecl_fixnum(T1),v2fn);
 }
 value0 = v1char;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for FIND-DIRECTIVE                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L534find_directive(cl_object v1directives, cl_object v2kind, cl_object v3stop_at_semi)
{
 cl_object T0, T1;
 volatile cl_object lex0[1];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 lex0[0] = v1directives;                          /*  DIRECTIVES              */
L1:;
 if (Null(lex0[0])){
  goto L2;
 }
 {
  cl_object v4next;
  v4next = ecl_car(lex0[0]);
  if (Null((cl_env_copy->function=(VV[14]->symbol.gfdef))->cfun.entry(1, v4next) /*  FORMAT-DIRECTIVE-P */)){
   goto L5;
  }
  {
   cl_object v5char;
   v5char = (cl_env_copy->function=(VV[55]->symbol.gfdef))->cfun.entry(1, v4next) /*  FORMAT-DIRECTIVE-CHARACTER */;
   if (ecl_char_code(v2kind)==ecl_char_code(v5char)) {
    goto L10;
   }
   if (Null(v3stop_at_semi)){
    goto L8;
   }
   if (!(ecl_char_code(v5char)==ecl_char_code(ECL_CODE_CHAR(59)))){
    goto L8;
   }
   goto L9;
L10:;
L9:;
   value0 = ecl_car(lex0[0]);
   cl_env_copy->nvalues = 1;
   return value0;
L8:;
   if (!(((v5char)==ECL_CODE_CHAR((ecl_character)(40))))){
    goto L16;
   }
   T1 = LC533after(lex0, ECL_CODE_CHAR(41));
   goto L15;
L16:;
   if (!(((v5char)==ECL_CODE_CHAR((ecl_character)(60))))){
    goto L18;
   }
   T1 = LC533after(lex0, ECL_CODE_CHAR(62));
   goto L15;
L18:;
   if (!(((v5char)==ECL_CODE_CHAR((ecl_character)(91))))){
    goto L20;
   }
   T1 = LC533after(lex0, ECL_CODE_CHAR(93));
   goto L15;
L20:;
   if (!(((v5char)==ECL_CODE_CHAR((ecl_character)(123))))){
    goto L22;
   }
   T1 = LC533after(lex0, ECL_CODE_CHAR(125));
   goto L15;
L22:;
   T1 = lex0[0];
L15:;
   T0 = ecl_cdr(T1);
   lex0[0] = T0;
   goto L1;
  }
L5:;
  T0 = ecl_cdr(lex0[0]);
  lex0[0] = T0;
  goto L1;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for FORMAT-WRITE-FIELD                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L535format_write_field(cl_object v1stream, cl_object v2string, cl_object v3mincol, cl_object v4colinc, cl_object v5minpad, cl_object v6padchar, cl_object v7padleft)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (v7padleft!=ECL_NIL) {
  goto L2;
 }
 cl_write_string(2, v2string, v1stream);
L2:;
 v5minpad = ((ecl_float_nan_p(ecl_make_int8_t(0)) || ecl_greatereq(v5minpad,ecl_make_int8_t(0)))?v5minpad:ecl_make_int8_t(0));
 {
  cl_object v8i;
  v8i = ecl_make_int8_t(0);
  goto L9;
L8:;
  cl_write_char(2, v6padchar, v1stream);
  v8i = ecl_one_plus(v8i);
L9:;
  if (!(ecl_lower(v8i,v5minpad))){
   goto L14;
  }
  goto L8;
L14:;
 }
 if (Null(v3mincol)){
  goto L18;
 }
 if (Null(v5minpad)){
  goto L18;
 }
 if (Null(v4colinc)){
  goto L18;
 }
 {
  cl_object v8chars;
  {
   cl_fixnum v9;
   v9 = ecl_length(v2string);
   v8chars = ecl_plus(ecl_make_fixnum(v9),v5minpad);
  }
  goto L25;
L24:;
  {
   cl_object v9i;
   v9i = ecl_make_int8_t(0);
   goto L30;
L29:;
   cl_write_char(2, v6padchar, v1stream);
   v9i = ecl_one_plus(v9i);
L30:;
   if (!(ecl_lower(v9i,v4colinc))){
    goto L35;
   }
   goto L29;
L35:;
  }
  v8chars = ecl_plus(v8chars,v4colinc);
L25:;
  if (ecl_greatereq(v8chars,v3mincol)) {
   goto L39;
  }
  goto L24;
L39:;
  goto L16;
 }
L18:;
 goto L16;
L16:;
 if (Null(v7padleft)){
  goto L41;
 }
 value0 = cl_write_string(2, v2string, v1stream);
 return value0;
L41:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for FORMAT-PRINC                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_princ(cl_object v1stream, cl_object v2arg, cl_object v3colonp, cl_object v4atsignp, cl_object v5mincol, cl_object v6colinc, cl_object v7minpad, cl_object v8padchar)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 ecl_character v9padchar;
 v9padchar = ecl_char_code(v8padchar);
L1:;
 if (v2arg!=ECL_NIL) {
  goto L5;
 }
 if (v3colonp!=ECL_NIL) {
  goto L3;
 }
 goto L4;
L5:;
L4:;
 T0 = cl_princ_to_string(v2arg);
 goto L2;
L3:;
 T0 = VV[93];
L2:;
 value0 = L535format_write_field(v1stream, T0, v5mincol, v6colinc, v7minpad, ECL_CODE_CHAR(v9padchar), v4atsignp);
 return value0;
}
cl_object si_format_princ_va(cl_narg narg, cl_object v10stream, cl_object v11arg, cl_object v12colonp, cl_object v13atsignp, cl_object v14mincol, cl_object v15colinc, cl_object v16minpad, cl_object v17padchar, ...)
{
 if (ecl_unlikely(narg!=8)) FEwrong_num_arguments(VV[92]);
 {
  return si_format_princ(v10stream, v11arg, v12colonp, v13atsignp, v14mincol, v15colinc, v16minpad, v17padchar);
 }
}
/* local function LATIN_CAPITAL_LETTER_A-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC536latin_capital_letter_a_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v5)){
   goto L6;
  }
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L15;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L15:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L23;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(0));
    goto L9;
L23:;
    if (!((v9param)==(VV[34]))){
     goto L25;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L9;
L25:;
    if (!((v9param)==(ECL_NIL))){
     goto L29;
    }
    T1 = ecl_make_int8_t(0);
    goto L9;
L29:;
    T1 = v9param;
   }
L9:;
   T2 = cl_list(2, VV[100], T1);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L38;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L38:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L46;
    }
    T4 = L527expand_next_arg(1, v8offset);
    T3 = cl_list(3, ECL_SYM("OR",616), T4, ecl_make_int8_t(1));
    goto L32;
L46:;
    if (!((v9param)==(VV[34]))){
     goto L48;
    }
    T4 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T4);
    T3 = VV[107];
    goto L32;
L48:;
    if (!((v9param)==(ECL_NIL))){
     goto L52;
    }
    T3 = ecl_make_int8_t(1);
    goto L32;
L52:;
    T3 = v9param;
   }
L32:;
   T4 = cl_list(2, VV[101], T3);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L61;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L61:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L69;
    }
    T6 = L527expand_next_arg(1, v8offset);
    T5 = cl_list(3, ECL_SYM("OR",616), T6, ecl_make_int8_t(0));
    goto L55;
L69:;
    if (!((v9param)==(VV[34]))){
     goto L71;
    }
    T6 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T6);
    T5 = VV[107];
    goto L55;
L71:;
    if (!((v9param)==(ECL_NIL))){
     goto L75;
    }
    T5 = ecl_make_int8_t(0);
    goto L55;
L75:;
    T5 = v9param;
   }
L55:;
   T6 = cl_list(2, VV[102], T5);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L84;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L84:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L92;
    }
    T8 = L527expand_next_arg(1, v8offset);
    T7 = cl_list(3, ECL_SYM("OR",616), T8, ECL_CODE_CHAR(32));
    goto L78;
L92:;
    if (!((v9param)==(VV[34]))){
     goto L94;
    }
    T8 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T8);
    T7 = VV[107];
    goto L78;
L94:;
    if (!((v9param)==(ECL_NIL))){
     goto L98;
    }
    T7 = ECL_CODE_CHAR(32);
    goto L78;
L98:;
    T7 = v9param;
   }
L78:;
   T8 = cl_list(2, VV[103], T7);
   T9 = cl_list(4, T2, T4, T6, T8);
   if (Null(v6)){
    goto L102;
   }
   T11 = ecl_list1(ecl_make_int8_t(4));
   T12 = ecl_caar(v6);
   T10 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T11, ECL_SYM("OFFSET",1316), T12);
   goto L101;
L102:;
   T10 = ECL_NIL;
L101:;
   T11 = L527expand_next_arg(0);
   T12 = cl_list(2, ECL_SYM("QUOTE",682), v3);
   T13 = cl_list(2, ECL_SYM("QUOTE",682), v4);
   T14 = cl_list(9, VV[92], ECL_SYM("STREAM",802), T11, T12, T13, VV[100], VV[101], VV[102], VV[103]);
   T15 = ecl_list1(T14);
   T16 = ecl_append(T10,T15);
   T0 = cl_listX(3, ECL_SYM("LET",479), T9, T16);
   goto L5;
  }
L6:;
  if (Null(v3)){
   goto L105;
  }
  T2 = L527expand_next_arg(0);
  T1 = cl_list(3, ECL_SYM("OR",616), T2, VV[93]);
  goto L104;
L105:;
  T1 = L527expand_next_arg(0);
L104:;
  T0 = cl_list(3, ECL_SYM("PRINC",663), T1, ECL_SYM("STREAM",802));
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC536latin_capital_letter_a_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[95]);
 {
  return LC536latin_capital_letter_a_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA418                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC537__lambda418(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v8)){
   goto L6;
  }
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10mincol;
    cl_object v11colinc;
    cl_object v12minpad;
    cl_object v13padchar;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L15;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L15:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L23;
     }
     if (!(v5args==ECL_NIL)){
      goto L28;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L28:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L30;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L30:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L36;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L36:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L26;
     }
     v10mincol = ecl_make_int8_t(0);
     goto L9;
L26:;
     v10mincol = value0;
     goto L9;
L23:;
     if (!((v16param)==(VV[34]))){
      goto L42;
     }
     v10mincol = ecl_make_fixnum(ecl_length(v5args));
     goto L9;
L42:;
     if (!((v16param)==(ECL_NIL))){
      goto L44;
     }
     v10mincol = ecl_make_int8_t(0);
     goto L9;
L44:;
     v10mincol = v16param;
    }
L9:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L53;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L53:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L61;
     }
     if (!(v5args==ECL_NIL)){
      goto L66;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L66:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L68;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L68:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L74;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L74:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L64;
     }
     v11colinc = ecl_make_int8_t(1);
     goto L47;
L64:;
     v11colinc = value0;
     goto L47;
L61:;
     if (!((v16param)==(VV[34]))){
      goto L80;
     }
     v11colinc = ecl_make_fixnum(ecl_length(v5args));
     goto L47;
L80:;
     if (!((v16param)==(ECL_NIL))){
      goto L82;
     }
     v11colinc = ecl_make_int8_t(1);
     goto L47;
L82:;
     v11colinc = v16param;
    }
L47:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L91;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L91:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L99;
     }
     if (!(v5args==ECL_NIL)){
      goto L104;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L104:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L106;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L106:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L112;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L112:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L102;
     }
     v12minpad = ecl_make_int8_t(0);
     goto L85;
L102:;
     v12minpad = value0;
     goto L85;
L99:;
     if (!((v16param)==(VV[34]))){
      goto L118;
     }
     v12minpad = ecl_make_fixnum(ecl_length(v5args));
     goto L85;
L118:;
     if (!((v16param)==(ECL_NIL))){
      goto L120;
     }
     v12minpad = ecl_make_int8_t(0);
     goto L85;
L120:;
     v12minpad = v16param;
    }
L85:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L129;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L129:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L137;
     }
     if (!(v5args==ECL_NIL)){
      goto L142;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L142:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L144;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L144:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L150;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L150:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L140;
     }
     v13padchar = ECL_CODE_CHAR(32);
     goto L123;
L140:;
     v13padchar = value0;
     goto L123;
L137:;
     if (!((v16param)==(VV[34]))){
      goto L156;
     }
     v13padchar = ecl_make_fixnum(ecl_length(v5args));
     goto L123;
L156:;
     if (!((v16param)==(ECL_NIL))){
      goto L158;
     }
     v13padchar = ECL_CODE_CHAR(32);
     goto L123;
L158:;
     v13padchar = v16param;
    }
L123:;
    if (Null(v9)){
     goto L161;
    }
    T0 = ecl_list1(ecl_make_int8_t(4));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L161:;
    if (!(v5args==ECL_NIL)){
     goto L163;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L163:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L165;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L165:;
    {
     cl_object v14;
     v14 = v5args;
     {
      cl_object v15;
      v15 = v14;
      {
       bool v16;
       v16 = ECL_LISTP(v15);
       if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v14)){
      goto L172;
     }
     {
      cl_object v15;
      v15 = ECL_CONS_CDR(v14);
      v5args = v15;
      v14 = ECL_CONS_CAR(v14);
     }
L172:;
     T0 = v14;
    }
    si_format_princ(v1stream, T0, v6, v7, v10mincol, v11colinc, v12minpad, v13padchar);
    goto L5;
   }
  }
L6:;
  if (Null(v6)){
   goto L179;
  }
  if (!(v5args==ECL_NIL)){
   goto L184;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L184:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L186;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L186:;
  {
   cl_object v14;
   v14 = v5args;
   {
    cl_object v15;
    v15 = v14;
    {
     bool v16;
     v16 = ECL_LISTP(v15);
     if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v14)){
    goto L192;
   }
   {
    cl_object v15;
    v15 = ECL_CONS_CDR(v14);
    v5args = v15;
    v14 = ECL_CONS_CAR(v14);
   }
L192:;
   value0 = v14;
  }
  if (value0!=ECL_NIL) {
   goto L182;
  }
  T0 = VV[93];
  goto L178;
L182:;
  T0 = value0;
  goto L178;
L179:;
  if (!(v5args==ECL_NIL)){
   goto L198;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L198:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L200;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L200:;
  {
   cl_object v14;
   v14 = v5args;
   {
    cl_object v15;
    v15 = v14;
    {
     bool v16;
     v16 = ECL_LISTP(v15);
     if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v14)){
    goto L206;
   }
   {
    cl_object v15;
    v15 = ECL_CONS_CDR(v14);
    v5args = v15;
    v14 = ECL_CONS_CAR(v14);
   }
L206:;
   T0 = v14;
  }
L178:;
  ecl_princ(T0,v1stream);
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC537__lambda418_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[111]);
 {
  return LC537__lambda418(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* function definition for FORMAT-PRIN1                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_prin1(cl_object v1stream, cl_object v2arg, cl_object v3colonp, cl_object v4atsignp, cl_object v5mincol, cl_object v6colinc, cl_object v7minpad, cl_object v8padchar)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 ecl_character v9padchar;
 v9padchar = ecl_char_code(v8padchar);
L1:;
 if (v2arg!=ECL_NIL) {
  goto L5;
 }
 if (v3colonp!=ECL_NIL) {
  goto L3;
 }
 goto L4;
L5:;
L4:;
 T0 = cl_prin1_to_string(v2arg);
 goto L2;
L3:;
 T0 = VV[93];
L2:;
 value0 = L535format_write_field(v1stream, T0, v5mincol, v6colinc, v7minpad, ECL_CODE_CHAR(v9padchar), v4atsignp);
 return value0;
}
cl_object si_format_prin1_va(cl_narg narg, cl_object v10stream, cl_object v11arg, cl_object v12colonp, cl_object v13atsignp, cl_object v14mincol, cl_object v15colinc, cl_object v16minpad, cl_object v17padchar, ...)
{
 if (ecl_unlikely(narg!=8)) FEwrong_num_arguments(VV[114]);
 {
  return si_format_prin1(v10stream, v11arg, v12colonp, v13atsignp, v14mincol, v15colinc, v16minpad, v17padchar);
 }
}
/* local function LATIN_CAPITAL_LETTER_S-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC538latin_capital_letter_s_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v5)){
   goto L6;
  }
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L15;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L15:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L23;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(0));
    goto L9;
L23:;
    if (!((v9param)==(VV[34]))){
     goto L25;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L9;
L25:;
    if (!((v9param)==(ECL_NIL))){
     goto L29;
    }
    T1 = ecl_make_int8_t(0);
    goto L9;
L29:;
    T1 = v9param;
   }
L9:;
   T2 = cl_list(2, VV[117], T1);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L38;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L38:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L46;
    }
    T4 = L527expand_next_arg(1, v8offset);
    T3 = cl_list(3, ECL_SYM("OR",616), T4, ecl_make_int8_t(1));
    goto L32;
L46:;
    if (!((v9param)==(VV[34]))){
     goto L48;
    }
    T4 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T4);
    T3 = VV[107];
    goto L32;
L48:;
    if (!((v9param)==(ECL_NIL))){
     goto L52;
    }
    T3 = ecl_make_int8_t(1);
    goto L32;
L52:;
    T3 = v9param;
   }
L32:;
   T4 = cl_list(2, VV[118], T3);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L61;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L61:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L69;
    }
    T6 = L527expand_next_arg(1, v8offset);
    T5 = cl_list(3, ECL_SYM("OR",616), T6, ecl_make_int8_t(0));
    goto L55;
L69:;
    if (!((v9param)==(VV[34]))){
     goto L71;
    }
    T6 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T6);
    T5 = VV[107];
    goto L55;
L71:;
    if (!((v9param)==(ECL_NIL))){
     goto L75;
    }
    T5 = ecl_make_int8_t(0);
    goto L55;
L75:;
    T5 = v9param;
   }
L55:;
   T6 = cl_list(2, VV[119], T5);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L84;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L84:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L92;
    }
    T8 = L527expand_next_arg(1, v8offset);
    T7 = cl_list(3, ECL_SYM("OR",616), T8, ECL_CODE_CHAR(32));
    goto L78;
L92:;
    if (!((v9param)==(VV[34]))){
     goto L94;
    }
    T8 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T8);
    T7 = VV[107];
    goto L78;
L94:;
    if (!((v9param)==(ECL_NIL))){
     goto L98;
    }
    T7 = ECL_CODE_CHAR(32);
    goto L78;
L98:;
    T7 = v9param;
   }
L78:;
   T8 = cl_list(2, VV[120], T7);
   T9 = cl_list(4, T2, T4, T6, T8);
   if (Null(v6)){
    goto L102;
   }
   T11 = ecl_list1(ecl_make_int8_t(4));
   T12 = ecl_caar(v6);
   T10 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T11, ECL_SYM("OFFSET",1316), T12);
   goto L101;
L102:;
   T10 = ECL_NIL;
L101:;
   T11 = L527expand_next_arg(0);
   T12 = cl_list(9, VV[114], ECL_SYM("STREAM",802), T11, v3, v4, VV[117], VV[118], VV[119], VV[120]);
   T13 = ecl_list1(T12);
   T14 = ecl_append(T10,T13);
   T0 = cl_listX(3, ECL_SYM("LET",479), T9, T14);
   goto L5;
  }
L6:;
  if (Null(v3)){
   goto L104;
  }
  T1 = L527expand_next_arg(0);
  T2 = cl_list(2, VV[121], T1);
  T3 = ecl_list1(T2);
  T0 = cl_list(3, ECL_SYM("LET",479), T3, VV[122]);
  goto L5;
L104:;
  T1 = L527expand_next_arg(0);
  T0 = cl_list(3, ECL_SYM("PRIN1",661), T1, ECL_SYM("STREAM",802));
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC538latin_capital_letter_s_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[116]);
 {
  return LC538latin_capital_letter_s_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA564                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC539__lambda564(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v8)){
   goto L6;
  }
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10mincol;
    cl_object v11colinc;
    cl_object v12minpad;
    cl_object v13padchar;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L15;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L15:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L23;
     }
     if (!(v5args==ECL_NIL)){
      goto L28;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L28:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L30;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L30:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L36;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L36:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L26;
     }
     v10mincol = ecl_make_int8_t(0);
     goto L9;
L26:;
     v10mincol = value0;
     goto L9;
L23:;
     if (!((v16param)==(VV[34]))){
      goto L42;
     }
     v10mincol = ecl_make_fixnum(ecl_length(v5args));
     goto L9;
L42:;
     if (!((v16param)==(ECL_NIL))){
      goto L44;
     }
     v10mincol = ecl_make_int8_t(0);
     goto L9;
L44:;
     v10mincol = v16param;
    }
L9:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L53;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L53:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L61;
     }
     if (!(v5args==ECL_NIL)){
      goto L66;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L66:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L68;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L68:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L74;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L74:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L64;
     }
     v11colinc = ecl_make_int8_t(1);
     goto L47;
L64:;
     v11colinc = value0;
     goto L47;
L61:;
     if (!((v16param)==(VV[34]))){
      goto L80;
     }
     v11colinc = ecl_make_fixnum(ecl_length(v5args));
     goto L47;
L80:;
     if (!((v16param)==(ECL_NIL))){
      goto L82;
     }
     v11colinc = ecl_make_int8_t(1);
     goto L47;
L82:;
     v11colinc = v16param;
    }
L47:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L91;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L91:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L99;
     }
     if (!(v5args==ECL_NIL)){
      goto L104;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L104:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L106;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L106:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L112;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L112:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L102;
     }
     v12minpad = ecl_make_int8_t(0);
     goto L85;
L102:;
     v12minpad = value0;
     goto L85;
L99:;
     if (!((v16param)==(VV[34]))){
      goto L118;
     }
     v12minpad = ecl_make_fixnum(ecl_length(v5args));
     goto L85;
L118:;
     if (!((v16param)==(ECL_NIL))){
      goto L120;
     }
     v12minpad = ecl_make_int8_t(0);
     goto L85;
L120:;
     v12minpad = v16param;
    }
L85:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L129;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L129:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L137;
     }
     if (!(v5args==ECL_NIL)){
      goto L142;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L142:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L144;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L144:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L150;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L150:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L140;
     }
     v13padchar = ECL_CODE_CHAR(32);
     goto L123;
L140:;
     v13padchar = value0;
     goto L123;
L137:;
     if (!((v16param)==(VV[34]))){
      goto L156;
     }
     v13padchar = ecl_make_fixnum(ecl_length(v5args));
     goto L123;
L156:;
     if (!((v16param)==(ECL_NIL))){
      goto L158;
     }
     v13padchar = ECL_CODE_CHAR(32);
     goto L123;
L158:;
     v13padchar = v16param;
    }
L123:;
    if (Null(v9)){
     goto L161;
    }
    T0 = ecl_list1(ecl_make_int8_t(4));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L161:;
    if (!(v5args==ECL_NIL)){
     goto L163;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L163:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L165;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L165:;
    {
     cl_object v14;
     v14 = v5args;
     {
      cl_object v15;
      v15 = v14;
      {
       bool v16;
       v16 = ECL_LISTP(v15);
       if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v14)){
      goto L172;
     }
     {
      cl_object v15;
      v15 = ECL_CONS_CDR(v14);
      v5args = v15;
      v14 = ECL_CONS_CAR(v14);
     }
L172:;
     T0 = v14;
    }
    si_format_prin1(v1stream, T0, v6, v7, v10mincol, v11colinc, v12minpad, v13padchar);
    goto L5;
   }
  }
L6:;
  if (Null(v6)){
   goto L178;
  }
  {
   cl_object v14arg;
   if (!(v5args==ECL_NIL)){
    goto L181;
   }
   cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L181:;
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
    goto L183;
   }
   ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L183:;
   {
    cl_object v15;
    v15 = v5args;
    {
     cl_object v16;
     v16 = v15;
     {
      bool v17;
      v17 = ECL_LISTP(v16);
      if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v15)){
     goto L189;
    }
    {
     cl_object v16;
     v16 = ECL_CONS_CDR(v15);
     v5args = v16;
     v15 = ECL_CONS_CAR(v15);
    }
L189:;
    v14arg = v15;
   }
   if (Null(v14arg)){
    goto L195;
   }
   (ecl_prin1(v14arg,v1stream));
   goto L5;
L195:;
   ecl_princ(VV[93],v1stream);
   goto L5;
  }
L178:;
  if (!(v5args==ECL_NIL)){
   goto L197;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L197:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L199;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L199:;
  {
   cl_object v15;
   v15 = v5args;
   {
    cl_object v16;
    v16 = v15;
    {
     bool v17;
     v17 = ECL_LISTP(v16);
     if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v15)){
    goto L206;
   }
   {
    cl_object v16;
    v16 = ECL_CONS_CDR(v15);
    v5args = v16;
    v15 = ECL_CONS_CAR(v15);
   }
L206:;
   T0 = v15;
  }
  (ecl_prin1(T0,v1stream));
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC539__lambda564_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[123]);
 {
  return LC539__lambda564(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function LATIN_CAPITAL_LETTER_C-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC540latin_capital_letter_c_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v5)){
   goto L6;
  }
  T1 = ecl_caar(v5);
  cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[125], ECL_SYM("OFFSET",1316), T1);
L6:;
  if (Null(v3)){
   goto L8;
  }
  T1 = L527expand_next_arg(0);
  T0 = cl_list(3, VV[126], T1, ECL_SYM("STREAM",802));
  goto L5;
L8:;
  if (Null(v4)){
   goto L10;
  }
  T1 = L527expand_next_arg(0);
  T0 = cl_list(3, ECL_SYM("PRIN1",661), T1, ECL_SYM("STREAM",802));
  goto L5;
L10:;
  T1 = L527expand_next_arg(0);
  T0 = cl_list(3, ECL_SYM("WRITE-CHAR",923), T1, ECL_SYM("STREAM",802));
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC540latin_capital_letter_c_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[124]);
 {
  return LC540latin_capital_letter_c_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA645                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC541__lambda645(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v8)){
   goto L6;
  }
  T0 = ecl_list1(ecl_make_int8_t(0));
  T1 = ecl_caar(v8);
  cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L6:;
  if (Null(v6)){
   goto L8;
  }
  if (!(v5args==ECL_NIL)){
   goto L10;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L10:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L12;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L12:;
  {
   cl_object v9;
   v9 = v5args;
   {
    cl_object v10;
    v10 = v9;
    {
     bool v11;
     v11 = ECL_LISTP(v10);
     if (ecl_unlikely(!(v11)))
         FEwrong_type_argument(VV[106],v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v9)){
    goto L19;
   }
   {
    cl_object v10;
    v10 = ECL_CONS_CDR(v9);
    v5args = v10;
    v9 = ECL_CONS_CAR(v9);
   }
L19:;
   T0 = v9;
  }
  si_format_print_named_character(T0, v1stream);
  goto L5;
L8:;
  if (Null(v7)){
   goto L25;
  }
  if (!(v5args==ECL_NIL)){
   goto L27;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L27:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L29;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L29:;
  {
   cl_object v9;
   v9 = v5args;
   {
    cl_object v10;
    v10 = v9;
    {
     bool v11;
     v11 = ECL_LISTP(v10);
     if (ecl_unlikely(!(v11)))
         FEwrong_type_argument(VV[106],v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v9)){
    goto L36;
   }
   {
    cl_object v10;
    v10 = ECL_CONS_CDR(v9);
    v5args = v10;
    v9 = ECL_CONS_CAR(v9);
   }
L36:;
   T0 = v9;
  }
  (ecl_prin1(T0,v1stream));
  goto L5;
L25:;
  if (!(v5args==ECL_NIL)){
   goto L42;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L42:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L44;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L44:;
  {
   cl_object v9;
   v9 = v5args;
   {
    cl_object v10;
    v10 = v9;
    {
     bool v11;
     v11 = ECL_LISTP(v10);
     if (ecl_unlikely(!(v11)))
         FEwrong_type_argument(VV[106],v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v9)){
    goto L51;
   }
   {
    cl_object v10;
    v10 = ECL_CONS_CDR(v9);
    v5args = v10;
    v9 = ECL_CONS_CAR(v9);
   }
L51:;
   T0 = v9;
  }
  cl_write_char(2, T0, v1stream);
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC541__lambda645_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[127]);
 {
  return LC541__lambda645(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* function definition for CHAR-PRINTING-P                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L542char_printing_p(cl_object v1char)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (((v1char)==ECL_CODE_CHAR((ecl_character)(32)))) {
  goto L3;
 }
 value0 = cl_graphic_char_p(v1char);
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for FORMAT-PRINT-NAMED-CHARACTER                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_print_named_character(cl_object v1char, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 ecl_character v3char;
 v3char = ecl_char_code(v1char);
L1:;
 if (L542char_printing_p(ECL_CODE_CHAR(v3char))!=ECL_NIL) {
  goto L2;
 }
 T0 = cl_char_name(ECL_CODE_CHAR(v3char));
 value0 = cl_write_string(2, T0, v2stream);
 return value0;
L2:;
 value0 = cl_write_char(2, ECL_CODE_CHAR(v3char), v2stream);
 return value0;
}
cl_object si_format_print_named_character_va(cl_narg narg, cl_object v4char, cl_object v5stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[126]);
 {
  return si_format_print_named_character(v4char, v5stream);
 }
}
/* local function LATIN_CAPITAL_LETTER_W-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC543latin_capital_letter_w_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  L629check_output_layout_mode(ecl_make_int8_t(1));
  if (Null(v5)){
   goto L7;
  }
  T1 = ecl_caar(v5);
  cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[125], ECL_SYM("OFFSET",1316), T1);
L7:;
  if (v3!=ECL_NIL) {
   goto L11;
  }
  if (Null(v4)){
   goto L9;
  }
  goto L10;
L11:;
L10:;
  if (Null(v3)){
   goto L14;
  }
  T1 = VV[132];
  goto L13;
L14:;
  T1 = ECL_NIL;
L13:;
  if (Null(v4)){
   goto L17;
  }
  T2 = VV[133];
  goto L16;
L17:;
  T2 = ECL_NIL;
L16:;
  T3 = ecl_append(T1,T2);
  T4 = L527expand_next_arg(0);
  T5 = cl_list(3, ECL_SYM("WRITE-OBJECT",1192), T4, ECL_SYM("STREAM",802));
  T0 = cl_list(3, ECL_SYM("LET",479), T3, T5);
  goto L6;
L9:;
  T1 = L527expand_next_arg(0);
  T0 = cl_list(3, ECL_SYM("WRITE-OBJECT",1192), T1, ECL_SYM("STREAM",802));
L6:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC543latin_capital_letter_w_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[130]);
 {
  return LC543latin_capital_letter_w_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA668                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC544__lambda668(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  L629check_output_layout_mode(ecl_make_int8_t(1));
  if (Null(v8)){
   goto L7;
  }
  T0 = ecl_list1(ecl_make_int8_t(0));
  T1 = ecl_caar(v8);
  cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L7:;
  {
   cl_object v9;
   cl_object v10;
   cl_object v11;
   value0 = v6;
   if (value0!=ECL_NIL) {
    goto L11;
   }
   v9 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PRINT-PRETTY*",57));
   goto L9;
L11:;
   v9 = value0;
   goto L9;
L9:;
   if (Null(v7)){
    goto L15;
   }
   v10 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PRINT-LEVEL*",53));
   goto L13;
L15:;
   v10 = ECL_NIL;
   goto L13;
L13:;
   if (Null(v7)){
    goto L19;
   }
   v11 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PRINT-LENGTH*",52));
   goto L17;
L19:;
   v11 = ECL_NIL;
   goto L17;
L17:;
   ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-PRETTY*",57),v9); /*  *PRINT-PRETTY* */
   ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-LEVEL*",53),v10); /*  *PRINT-LEVEL* */
   ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-LENGTH*",52),v11); /*  *PRINT-LENGTH* */
   if (!(v5args==ECL_NIL)){
    goto L21;
   }
   cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L21:;
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
    goto L23;
   }
   ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L23:;
   {
    cl_object v12;
    v12 = v5args;
    {
     cl_object v13;
     v13 = v12;
     {
      bool v14;
      v14 = ECL_LISTP(v13);
      if (ecl_unlikely(!(v14)))
         FEwrong_type_argument(VV[106],v13);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v12)){
     goto L30;
    }
    {
     cl_object v13;
     v13 = ECL_CONS_CDR(v12);
     v5args = v13;
     v12 = ECL_CONS_CAR(v12);
    }
L30:;
    T0 = v12;
   }
   si_write_object(T0, v1stream);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC544__lambda668_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[134]);
 {
  return LC544__lambda668(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* function definition for FORMAT-PRINT-INTEGER                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_print_integer(cl_object v1stream, cl_object v2number, cl_object v3print_commas_p, cl_object v4print_sign_p, cl_object v5radix, cl_object v6mincol, cl_object v7padchar, cl_object v8commachar, cl_object v9commainterval)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 int8_t v10radix;
 ecl_character v11padchar;
 ecl_character v12commachar;
 v10radix = ecl_to_int8_t(v5radix);
 v11padchar = ecl_char_code(v7padchar);
 v12commachar = ecl_char_code(v8commachar);
L1:;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-BASE*",47),ecl_make_int8_t(v10radix)); /*  *PRINT-BASE* */
 ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-RADIX*",58),ECL_NIL); /*  *PRINT-RADIX* */
 if (!(ECL_FIXNUMP(v2number)||ECL_BIGNUMP(v2number))){
  goto L2;
 }
 {
  cl_object v13text;
  cl_object v14commaed;
  cl_object v15signed;
  T0 = ecl_abs(v2number);
  v13text = cl_princ_to_string(T0);
  if (Null(v3print_commas_p)){
   goto L6;
  }
  v14commaed = L545format_add_commas(v13text, ECL_CODE_CHAR(v12commachar), v9commainterval);
  goto L5;
L6:;
  v14commaed = v13text;
L5:;
  if (!(ecl_minusp(v2number))){
   goto L9;
  }
  v15signed = cl_concatenate(3, ECL_SYM("STRING",808), VV[137], v14commaed);
  goto L8;
L9:;
  if (Null(v4print_sign_p)){
   goto L11;
  }
  v15signed = cl_concatenate(3, ECL_SYM("STRING",808), VV[138], v14commaed);
  goto L8;
L11:;
  v15signed = v14commaed;
L8:;
  value0 = L535format_write_field(v1stream, v15signed, v6mincol, ecl_make_int8_t(1), ecl_make_int8_t(0), ECL_CODE_CHAR(v11padchar), ECL_T);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
L2:;
 value0 = ecl_princ(v2number,v1stream);
 cl_env_copy->nvalues = 1;
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
cl_object si_format_print_integer_va(cl_narg narg, cl_object v16stream, cl_object v17number, cl_object v18print_commas_p, cl_object v19print_sign_p, cl_object v20radix, cl_object v21mincol, cl_object v22padchar, cl_object v23commachar, cl_object v24commainterval, ...)
{
 if (ecl_unlikely(narg!=9)) FEwrong_num_arguments(VV[135]);
 {
  return si_format_print_integer(v16stream, v17number, v18print_commas_p, v19print_sign_p, v20radix, v21mincol, v22padchar, v23commachar, v24commainterval);
 }
}
/* function definition for FORMAT-ADD-COMMAS                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L545format_add_commas(cl_object v1string, cl_object v2commachar, cl_object v3commainterval)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4length;
  v4length = ecl_make_fixnum(ecl_length(v1string));
  {
   cl_object v5;                                  /*  COMMAS                  */
   cl_object v6;                                  /*  EXTRA                   */
   T0 = ecl_make_integer((ecl_fixnum(v4length))-1);
   value0 = ecl_truncate2(T0,v3commainterval);
   {
    v5 = value0;
    v6 = cl_env_copy->values[1];
   }
   {
    cl_object v7;
    cl_object v8;
    T0 = ecl_plus(v4length,v5);
    v7 = cl_make_string(1, T0);
    v8 = ecl_one_plus(v6);
    cl_replace(6, v7, v1string, ECL_SYM("END1",1257), v8, ECL_SYM("END2",1258), v8);
    {
     cl_object v9src;
     cl_object v10dst;
     v9src = v8;
     v10dst = v8;
     goto L12;
L11:;
     ecl_elt_set(v7,ecl_to_size(v10dst),v2commachar);
     T0 = ecl_one_plus(v10dst);
     T1 = ecl_plus(v9src,v3commainterval);
     cl_replace(8, v7, v1string, ECL_SYM("START1",1348), T0, ECL_SYM("START2",1349), v9src, ECL_SYM("END2",1258), T1);
     v9src = ecl_plus(v9src,v3commainterval);
     T0 = ecl_plus(v10dst,v3commainterval);
     v10dst = ecl_plus(T0,ecl_make_int8_t(1));
L12:;
     if (ecl_number_equalp(v9src,v4length)) {
      goto L19;
     }
     goto L11;
L19:;
    }
    value0 = v7;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for EXPAND-FORMAT-INTEGER                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L546expand_format_integer(cl_object v1base, cl_object v2colonp, cl_object v3atsignp, cl_object v4params)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (v2colonp!=ECL_NIL) {
  goto L4;
 }
 if (v3atsignp!=ECL_NIL) {
  goto L4;
 }
 if (Null(v4params)){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 {
  cl_object v5;
  v5 = v4params;
  {
   cl_object v6param_and_offset;
   cl_object v7offset;
   cl_object v8param;
   {
    cl_object v9;
    v9 = v5;
    {
     cl_object v10;
     v10 = v9;
     {
      bool v11;
      v11 = ECL_LISTP(v10);
      if (ecl_unlikely(!(v11)))
         FEwrong_type_argument(VV[106],v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v9)){
     goto L14;
    }
    {
     cl_object v10;
     v10 = ECL_CONS_CDR(v9);
     v5 = v10;
     v9 = ECL_CONS_CAR(v9);
    }
L14:;
    v6param_and_offset = v9;
   }
   v7offset = ecl_car(v6param_and_offset);
   v8param = ecl_cdr(v6param_and_offset);
   if (!((v8param)==(VV[33]))){
    goto L22;
   }
   T1 = L527expand_next_arg(1, v7offset);
   T0 = cl_list(3, ECL_SYM("OR",616), T1, ecl_make_int8_t(0));
   goto L8;
L22:;
   if (!((v8param)==(VV[34]))){
    goto L24;
   }
   T1 = ECL_NIL;
   ecl_cmp_setq(cl_env_copy,VV[47],T1);
   T0 = VV[107];
   goto L8;
L24:;
   if (!((v8param)==(ECL_NIL))){
    goto L28;
   }
   T0 = ecl_make_int8_t(0);
   goto L8;
L28:;
   T0 = v8param;
  }
L8:;
  T1 = cl_list(2, VV[141], T0);
  {
   cl_object v6param_and_offset;
   cl_object v7offset;
   cl_object v8param;
   {
    cl_object v9;
    v9 = v5;
    {
     cl_object v10;
     v10 = v9;
     {
      bool v11;
      v11 = ECL_LISTP(v10);
      if (ecl_unlikely(!(v11)))
         FEwrong_type_argument(VV[106],v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v9)){
     goto L37;
    }
    {
     cl_object v10;
     v10 = ECL_CONS_CDR(v9);
     v5 = v10;
     v9 = ECL_CONS_CAR(v9);
    }
L37:;
    v6param_and_offset = v9;
   }
   v7offset = ecl_car(v6param_and_offset);
   v8param = ecl_cdr(v6param_and_offset);
   if (!((v8param)==(VV[33]))){
    goto L45;
   }
   T3 = L527expand_next_arg(1, v7offset);
   T2 = cl_list(3, ECL_SYM("OR",616), T3, ECL_CODE_CHAR(32));
   goto L31;
L45:;
   if (!((v8param)==(VV[34]))){
    goto L47;
   }
   T3 = ECL_NIL;
   ecl_cmp_setq(cl_env_copy,VV[47],T3);
   T2 = VV[107];
   goto L31;
L47:;
   if (!((v8param)==(ECL_NIL))){
    goto L51;
   }
   T2 = ECL_CODE_CHAR(32);
   goto L31;
L51:;
   T2 = v8param;
  }
L31:;
  T3 = cl_list(2, VV[142], T2);
  {
   cl_object v6param_and_offset;
   cl_object v7offset;
   cl_object v8param;
   {
    cl_object v9;
    v9 = v5;
    {
     cl_object v10;
     v10 = v9;
     {
      bool v11;
      v11 = ECL_LISTP(v10);
      if (ecl_unlikely(!(v11)))
         FEwrong_type_argument(VV[106],v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v9)){
     goto L60;
    }
    {
     cl_object v10;
     v10 = ECL_CONS_CDR(v9);
     v5 = v10;
     v9 = ECL_CONS_CAR(v9);
    }
L60:;
    v6param_and_offset = v9;
   }
   v7offset = ecl_car(v6param_and_offset);
   v8param = ecl_cdr(v6param_and_offset);
   if (!((v8param)==(VV[33]))){
    goto L68;
   }
   T5 = L527expand_next_arg(1, v7offset);
   T4 = cl_list(3, ECL_SYM("OR",616), T5, ECL_CODE_CHAR(44));
   goto L54;
L68:;
   if (!((v8param)==(VV[34]))){
    goto L70;
   }
   T5 = ECL_NIL;
   ecl_cmp_setq(cl_env_copy,VV[47],T5);
   T4 = VV[107];
   goto L54;
L70:;
   if (!((v8param)==(ECL_NIL))){
    goto L74;
   }
   T4 = ECL_CODE_CHAR(44);
   goto L54;
L74:;
   T4 = v8param;
  }
L54:;
  T5 = cl_list(2, VV[143], T4);
  {
   cl_object v6param_and_offset;
   cl_object v7offset;
   cl_object v8param;
   {
    cl_object v9;
    v9 = v5;
    {
     cl_object v10;
     v10 = v9;
     {
      bool v11;
      v11 = ECL_LISTP(v10);
      if (ecl_unlikely(!(v11)))
         FEwrong_type_argument(VV[106],v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v9)){
     goto L83;
    }
    {
     cl_object v10;
     v10 = ECL_CONS_CDR(v9);
     v5 = v10;
     v9 = ECL_CONS_CAR(v9);
    }
L83:;
    v6param_and_offset = v9;
   }
   v7offset = ecl_car(v6param_and_offset);
   v8param = ecl_cdr(v6param_and_offset);
   if (!((v8param)==(VV[33]))){
    goto L91;
   }
   T7 = L527expand_next_arg(1, v7offset);
   T6 = cl_list(3, ECL_SYM("OR",616), T7, ecl_make_int8_t(3));
   goto L77;
L91:;
   if (!((v8param)==(VV[34]))){
    goto L93;
   }
   T7 = ECL_NIL;
   ecl_cmp_setq(cl_env_copy,VV[47],T7);
   T6 = VV[107];
   goto L77;
L93:;
   if (!((v8param)==(ECL_NIL))){
    goto L97;
   }
   T6 = ecl_make_int8_t(3);
   goto L77;
L97:;
   T6 = v8param;
  }
L77:;
  T7 = cl_list(2, VV[144], T6);
  T8 = cl_list(4, T1, T3, T5, T7);
  if (Null(v5)){
   goto L101;
  }
  T10 = ecl_list1(ecl_make_int8_t(4));
  T11 = ecl_caar(v5);
  T9 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T10, ECL_SYM("OFFSET",1316), T11);
  goto L100;
L101:;
  T9 = ECL_NIL;
L100:;
  T10 = L527expand_next_arg(0);
  T11 = cl_list(10, VV[135], ECL_SYM("STREAM",802), T10, v2colonp, v3atsignp, v1base, VV[141], VV[142], VV[143], VV[144]);
  T12 = ecl_list1(T11);
  T13 = ecl_append(T9,T12);
  value0 = cl_listX(3, ECL_SYM("LET",479), T8, T13);
  return value0;
 }
L2:;
 T0 = L527expand_next_arg(0);
 value0 = cl_listX(7, ECL_SYM("WRITE",921), T0, ECL_SYM("STREAM",1350), ECL_SYM("STREAM",802), ECL_SYM("BASE",1231), v1base, VV[145]);
 return value0;
}
static cl_object L546expand_format_integer_va(cl_narg narg, cl_object v6base, cl_object v7colonp, cl_object v8atsignp, cl_object v9params, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[140]);
 {
  return L546expand_format_integer(v6base, v7colonp, v8atsignp, v9params);
 }
}
/* local function LATIN_CAPITAL_LETTER_D-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC547latin_capital_letter_d_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  T0 = L546expand_format_integer(ecl_make_int8_t(10), v3, v4, v5);
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC547latin_capital_letter_d_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[147]);
 {
  return LC547latin_capital_letter_d_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA769                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC548__lambda769(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (v6!=ECL_NIL) {
   goto L8;
  }
  if (v7!=ECL_NIL) {
   goto L8;
  }
  if (Null(v8)){
   goto L6;
  }
  goto L7;
L8:;
L7:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10mincol;
    cl_object v11padchar;
    cl_object v12commachar;
    cl_object v13commainterval;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L18;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L18:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L26;
     }
     if (!(v5args==ECL_NIL)){
      goto L31;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L31:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L33;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L33:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L39;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L39:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L29;
     }
     v10mincol = ecl_make_int8_t(0);
     goto L12;
L29:;
     v10mincol = value0;
     goto L12;
L26:;
     if (!((v16param)==(VV[34]))){
      goto L45;
     }
     v10mincol = ecl_make_fixnum(ecl_length(v5args));
     goto L12;
L45:;
     if (!((v16param)==(ECL_NIL))){
      goto L47;
     }
     v10mincol = ecl_make_int8_t(0);
     goto L12;
L47:;
     v10mincol = v16param;
    }
L12:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L56;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L56:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L64;
     }
     if (!(v5args==ECL_NIL)){
      goto L69;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L69:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L71;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L71:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L77;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L77:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L67;
     }
     v11padchar = ECL_CODE_CHAR(32);
     goto L50;
L67:;
     v11padchar = value0;
     goto L50;
L64:;
     if (!((v16param)==(VV[34]))){
      goto L83;
     }
     v11padchar = ecl_make_fixnum(ecl_length(v5args));
     goto L50;
L83:;
     if (!((v16param)==(ECL_NIL))){
      goto L85;
     }
     v11padchar = ECL_CODE_CHAR(32);
     goto L50;
L85:;
     v11padchar = v16param;
    }
L50:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L94;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L94:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L102;
     }
     if (!(v5args==ECL_NIL)){
      goto L107;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L107:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L109;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L109:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L115;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L115:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L105;
     }
     v12commachar = ECL_CODE_CHAR(44);
     goto L88;
L105:;
     v12commachar = value0;
     goto L88;
L102:;
     if (!((v16param)==(VV[34]))){
      goto L121;
     }
     v12commachar = ecl_make_fixnum(ecl_length(v5args));
     goto L88;
L121:;
     if (!((v16param)==(ECL_NIL))){
      goto L123;
     }
     v12commachar = ECL_CODE_CHAR(44);
     goto L88;
L123:;
     v12commachar = v16param;
    }
L88:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L132;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L132:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L140;
     }
     if (!(v5args==ECL_NIL)){
      goto L145;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L145:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L147;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L147:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L153;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L153:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L143;
     }
     v13commainterval = ecl_make_int8_t(3);
     goto L126;
L143:;
     v13commainterval = value0;
     goto L126;
L140:;
     if (!((v16param)==(VV[34]))){
      goto L159;
     }
     v13commainterval = ecl_make_fixnum(ecl_length(v5args));
     goto L126;
L159:;
     if (!((v16param)==(ECL_NIL))){
      goto L161;
     }
     v13commainterval = ecl_make_int8_t(3);
     goto L126;
L161:;
     v13commainterval = v16param;
    }
L126:;
    if (Null(v9)){
     goto L164;
    }
    T0 = ecl_list1(ecl_make_int8_t(4));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L164:;
    if (!(v5args==ECL_NIL)){
     goto L166;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L166:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L168;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L168:;
    {
     cl_object v14;
     v14 = v5args;
     {
      cl_object v15;
      v15 = v14;
      {
       bool v16;
       v16 = ECL_LISTP(v15);
       if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v14)){
      goto L175;
     }
     {
      cl_object v15;
      v15 = ECL_CONS_CDR(v14);
      v5args = v15;
      v14 = ECL_CONS_CAR(v14);
     }
L175:;
     T0 = v14;
    }
    si_format_print_integer(v1stream, T0, v6, v7, ecl_make_int8_t(10), v10mincol, v11padchar, v12commachar, v13commainterval);
    goto L5;
   }
  }
L6:;
  if (!(v5args==ECL_NIL)){
   goto L181;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L181:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L183;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L183:;
  {
   cl_object v14;
   v14 = v5args;
   {
    cl_object v15;
    v15 = v14;
    {
     bool v16;
     v16 = ECL_LISTP(v15);
     if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v14)){
    goto L190;
   }
   {
    cl_object v15;
    v15 = ECL_CONS_CDR(v14);
    v5args = v15;
    v14 = ECL_CONS_CAR(v14);
   }
L190:;
   T0 = v14;
  }
  cl_write(9, T0, ECL_SYM("STREAM",1350), v1stream, ECL_SYM("BASE",1231), ecl_make_int8_t(10), ECL_SYM("RADIX",1332), ECL_NIL, ECL_SYM("ESCAPE",1261), ECL_NIL);
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC548__lambda769_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[148]);
 {
  return LC548__lambda769(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function LATIN_CAPITAL_LETTER_B-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC549latin_capital_letter_b_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  T0 = L546expand_format_integer(ecl_make_int8_t(2), v3, v4, v5);
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC549latin_capital_letter_b_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[150]);
 {
  return LC549latin_capital_letter_b_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA847                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC550__lambda847(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (v6!=ECL_NIL) {
   goto L8;
  }
  if (v7!=ECL_NIL) {
   goto L8;
  }
  if (Null(v8)){
   goto L6;
  }
  goto L7;
L8:;
L7:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10mincol;
    cl_object v11padchar;
    cl_object v12commachar;
    cl_object v13commainterval;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L18;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L18:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L26;
     }
     if (!(v5args==ECL_NIL)){
      goto L31;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L31:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L33;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L33:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L39;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L39:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L29;
     }
     v10mincol = ecl_make_int8_t(0);
     goto L12;
L29:;
     v10mincol = value0;
     goto L12;
L26:;
     if (!((v16param)==(VV[34]))){
      goto L45;
     }
     v10mincol = ecl_make_fixnum(ecl_length(v5args));
     goto L12;
L45:;
     if (!((v16param)==(ECL_NIL))){
      goto L47;
     }
     v10mincol = ecl_make_int8_t(0);
     goto L12;
L47:;
     v10mincol = v16param;
    }
L12:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L56;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L56:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L64;
     }
     if (!(v5args==ECL_NIL)){
      goto L69;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L69:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L71;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L71:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L77;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L77:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L67;
     }
     v11padchar = ECL_CODE_CHAR(32);
     goto L50;
L67:;
     v11padchar = value0;
     goto L50;
L64:;
     if (!((v16param)==(VV[34]))){
      goto L83;
     }
     v11padchar = ecl_make_fixnum(ecl_length(v5args));
     goto L50;
L83:;
     if (!((v16param)==(ECL_NIL))){
      goto L85;
     }
     v11padchar = ECL_CODE_CHAR(32);
     goto L50;
L85:;
     v11padchar = v16param;
    }
L50:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L94;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L94:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L102;
     }
     if (!(v5args==ECL_NIL)){
      goto L107;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L107:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L109;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L109:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L115;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L115:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L105;
     }
     v12commachar = ECL_CODE_CHAR(44);
     goto L88;
L105:;
     v12commachar = value0;
     goto L88;
L102:;
     if (!((v16param)==(VV[34]))){
      goto L121;
     }
     v12commachar = ecl_make_fixnum(ecl_length(v5args));
     goto L88;
L121:;
     if (!((v16param)==(ECL_NIL))){
      goto L123;
     }
     v12commachar = ECL_CODE_CHAR(44);
     goto L88;
L123:;
     v12commachar = v16param;
    }
L88:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L132;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L132:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L140;
     }
     if (!(v5args==ECL_NIL)){
      goto L145;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L145:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L147;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L147:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L153;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L153:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L143;
     }
     v13commainterval = ecl_make_int8_t(3);
     goto L126;
L143:;
     v13commainterval = value0;
     goto L126;
L140:;
     if (!((v16param)==(VV[34]))){
      goto L159;
     }
     v13commainterval = ecl_make_fixnum(ecl_length(v5args));
     goto L126;
L159:;
     if (!((v16param)==(ECL_NIL))){
      goto L161;
     }
     v13commainterval = ecl_make_int8_t(3);
     goto L126;
L161:;
     v13commainterval = v16param;
    }
L126:;
    if (Null(v9)){
     goto L164;
    }
    T0 = ecl_list1(ecl_make_int8_t(4));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L164:;
    if (!(v5args==ECL_NIL)){
     goto L166;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L166:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L168;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L168:;
    {
     cl_object v14;
     v14 = v5args;
     {
      cl_object v15;
      v15 = v14;
      {
       bool v16;
       v16 = ECL_LISTP(v15);
       if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v14)){
      goto L175;
     }
     {
      cl_object v15;
      v15 = ECL_CONS_CDR(v14);
      v5args = v15;
      v14 = ECL_CONS_CAR(v14);
     }
L175:;
     T0 = v14;
    }
    si_format_print_integer(v1stream, T0, v6, v7, ecl_make_int8_t(2), v10mincol, v11padchar, v12commachar, v13commainterval);
    goto L5;
   }
  }
L6:;
  if (!(v5args==ECL_NIL)){
   goto L181;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L181:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L183;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L183:;
  {
   cl_object v14;
   v14 = v5args;
   {
    cl_object v15;
    v15 = v14;
    {
     bool v16;
     v16 = ECL_LISTP(v15);
     if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v14)){
    goto L190;
   }
   {
    cl_object v15;
    v15 = ECL_CONS_CDR(v14);
    v5args = v15;
    v14 = ECL_CONS_CAR(v14);
   }
L190:;
   T0 = v14;
  }
  cl_write(9, T0, ECL_SYM("STREAM",1350), v1stream, ECL_SYM("BASE",1231), ecl_make_int8_t(2), ECL_SYM("RADIX",1332), ECL_NIL, ECL_SYM("ESCAPE",1261), ECL_NIL);
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC550__lambda847_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[151]);
 {
  return LC550__lambda847(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function LATIN_CAPITAL_LETTER_O-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC551latin_capital_letter_o_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  T0 = L546expand_format_integer(ecl_make_int8_t(8), v3, v4, v5);
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC551latin_capital_letter_o_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[152]);
 {
  return LC551latin_capital_letter_o_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA925                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC552__lambda925(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (v6!=ECL_NIL) {
   goto L8;
  }
  if (v7!=ECL_NIL) {
   goto L8;
  }
  if (Null(v8)){
   goto L6;
  }
  goto L7;
L8:;
L7:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10mincol;
    cl_object v11padchar;
    cl_object v12commachar;
    cl_object v13commainterval;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L18;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L18:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L26;
     }
     if (!(v5args==ECL_NIL)){
      goto L31;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L31:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L33;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L33:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L39;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L39:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L29;
     }
     v10mincol = ecl_make_int8_t(0);
     goto L12;
L29:;
     v10mincol = value0;
     goto L12;
L26:;
     if (!((v16param)==(VV[34]))){
      goto L45;
     }
     v10mincol = ecl_make_fixnum(ecl_length(v5args));
     goto L12;
L45:;
     if (!((v16param)==(ECL_NIL))){
      goto L47;
     }
     v10mincol = ecl_make_int8_t(0);
     goto L12;
L47:;
     v10mincol = v16param;
    }
L12:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L56;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L56:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L64;
     }
     if (!(v5args==ECL_NIL)){
      goto L69;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L69:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L71;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L71:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L77;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L77:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L67;
     }
     v11padchar = ECL_CODE_CHAR(32);
     goto L50;
L67:;
     v11padchar = value0;
     goto L50;
L64:;
     if (!((v16param)==(VV[34]))){
      goto L83;
     }
     v11padchar = ecl_make_fixnum(ecl_length(v5args));
     goto L50;
L83:;
     if (!((v16param)==(ECL_NIL))){
      goto L85;
     }
     v11padchar = ECL_CODE_CHAR(32);
     goto L50;
L85:;
     v11padchar = v16param;
    }
L50:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L94;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L94:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L102;
     }
     if (!(v5args==ECL_NIL)){
      goto L107;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L107:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L109;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L109:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L115;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L115:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L105;
     }
     v12commachar = ECL_CODE_CHAR(44);
     goto L88;
L105:;
     v12commachar = value0;
     goto L88;
L102:;
     if (!((v16param)==(VV[34]))){
      goto L121;
     }
     v12commachar = ecl_make_fixnum(ecl_length(v5args));
     goto L88;
L121:;
     if (!((v16param)==(ECL_NIL))){
      goto L123;
     }
     v12commachar = ECL_CODE_CHAR(44);
     goto L88;
L123:;
     v12commachar = v16param;
    }
L88:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L132;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L132:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L140;
     }
     if (!(v5args==ECL_NIL)){
      goto L145;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L145:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L147;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L147:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L153;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L153:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L143;
     }
     v13commainterval = ecl_make_int8_t(3);
     goto L126;
L143:;
     v13commainterval = value0;
     goto L126;
L140:;
     if (!((v16param)==(VV[34]))){
      goto L159;
     }
     v13commainterval = ecl_make_fixnum(ecl_length(v5args));
     goto L126;
L159:;
     if (!((v16param)==(ECL_NIL))){
      goto L161;
     }
     v13commainterval = ecl_make_int8_t(3);
     goto L126;
L161:;
     v13commainterval = v16param;
    }
L126:;
    if (Null(v9)){
     goto L164;
    }
    T0 = ecl_list1(ecl_make_int8_t(4));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L164:;
    if (!(v5args==ECL_NIL)){
     goto L166;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L166:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L168;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L168:;
    {
     cl_object v14;
     v14 = v5args;
     {
      cl_object v15;
      v15 = v14;
      {
       bool v16;
       v16 = ECL_LISTP(v15);
       if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v14)){
      goto L175;
     }
     {
      cl_object v15;
      v15 = ECL_CONS_CDR(v14);
      v5args = v15;
      v14 = ECL_CONS_CAR(v14);
     }
L175:;
     T0 = v14;
    }
    si_format_print_integer(v1stream, T0, v6, v7, ecl_make_int8_t(8), v10mincol, v11padchar, v12commachar, v13commainterval);
    goto L5;
   }
  }
L6:;
  if (!(v5args==ECL_NIL)){
   goto L181;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L181:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L183;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L183:;
  {
   cl_object v14;
   v14 = v5args;
   {
    cl_object v15;
    v15 = v14;
    {
     bool v16;
     v16 = ECL_LISTP(v15);
     if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v14)){
    goto L190;
   }
   {
    cl_object v15;
    v15 = ECL_CONS_CDR(v14);
    v5args = v15;
    v14 = ECL_CONS_CAR(v14);
   }
L190:;
   T0 = v14;
  }
  cl_write(9, T0, ECL_SYM("STREAM",1350), v1stream, ECL_SYM("BASE",1231), ecl_make_int8_t(8), ECL_SYM("RADIX",1332), ECL_NIL, ECL_SYM("ESCAPE",1261), ECL_NIL);
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC552__lambda925_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[153]);
 {
  return LC552__lambda925(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function LATIN_CAPITAL_LETTER_X-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC553latin_capital_letter_x_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  T0 = L546expand_format_integer(ecl_make_int8_t(16), v3, v4, v5);
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC553latin_capital_letter_x_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[154]);
 {
  return LC553latin_capital_letter_x_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA1003                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC554__lambda1003(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (v6!=ECL_NIL) {
   goto L8;
  }
  if (v7!=ECL_NIL) {
   goto L8;
  }
  if (Null(v8)){
   goto L6;
  }
  goto L7;
L8:;
L7:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10mincol;
    cl_object v11padchar;
    cl_object v12commachar;
    cl_object v13commainterval;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L18;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L18:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L26;
     }
     if (!(v5args==ECL_NIL)){
      goto L31;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L31:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L33;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L33:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L39;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L39:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L29;
     }
     v10mincol = ecl_make_int8_t(0);
     goto L12;
L29:;
     v10mincol = value0;
     goto L12;
L26:;
     if (!((v16param)==(VV[34]))){
      goto L45;
     }
     v10mincol = ecl_make_fixnum(ecl_length(v5args));
     goto L12;
L45:;
     if (!((v16param)==(ECL_NIL))){
      goto L47;
     }
     v10mincol = ecl_make_int8_t(0);
     goto L12;
L47:;
     v10mincol = v16param;
    }
L12:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L56;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L56:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L64;
     }
     if (!(v5args==ECL_NIL)){
      goto L69;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L69:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L71;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L71:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L77;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L77:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L67;
     }
     v11padchar = ECL_CODE_CHAR(32);
     goto L50;
L67:;
     v11padchar = value0;
     goto L50;
L64:;
     if (!((v16param)==(VV[34]))){
      goto L83;
     }
     v11padchar = ecl_make_fixnum(ecl_length(v5args));
     goto L50;
L83:;
     if (!((v16param)==(ECL_NIL))){
      goto L85;
     }
     v11padchar = ECL_CODE_CHAR(32);
     goto L50;
L85:;
     v11padchar = v16param;
    }
L50:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L94;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L94:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L102;
     }
     if (!(v5args==ECL_NIL)){
      goto L107;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L107:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L109;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L109:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L115;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L115:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L105;
     }
     v12commachar = ECL_CODE_CHAR(44);
     goto L88;
L105:;
     v12commachar = value0;
     goto L88;
L102:;
     if (!((v16param)==(VV[34]))){
      goto L121;
     }
     v12commachar = ecl_make_fixnum(ecl_length(v5args));
     goto L88;
L121:;
     if (!((v16param)==(ECL_NIL))){
      goto L123;
     }
     v12commachar = ECL_CODE_CHAR(44);
     goto L88;
L123:;
     v12commachar = v16param;
    }
L88:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L132;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L132:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L140;
     }
     if (!(v5args==ECL_NIL)){
      goto L145;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L145:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L147;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L147:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L153;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L153:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L143;
     }
     v13commainterval = ecl_make_int8_t(3);
     goto L126;
L143:;
     v13commainterval = value0;
     goto L126;
L140:;
     if (!((v16param)==(VV[34]))){
      goto L159;
     }
     v13commainterval = ecl_make_fixnum(ecl_length(v5args));
     goto L126;
L159:;
     if (!((v16param)==(ECL_NIL))){
      goto L161;
     }
     v13commainterval = ecl_make_int8_t(3);
     goto L126;
L161:;
     v13commainterval = v16param;
    }
L126:;
    if (Null(v9)){
     goto L164;
    }
    T0 = ecl_list1(ecl_make_int8_t(4));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L164:;
    if (!(v5args==ECL_NIL)){
     goto L166;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L166:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L168;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L168:;
    {
     cl_object v14;
     v14 = v5args;
     {
      cl_object v15;
      v15 = v14;
      {
       bool v16;
       v16 = ECL_LISTP(v15);
       if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v14)){
      goto L175;
     }
     {
      cl_object v15;
      v15 = ECL_CONS_CDR(v14);
      v5args = v15;
      v14 = ECL_CONS_CAR(v14);
     }
L175:;
     T0 = v14;
    }
    si_format_print_integer(v1stream, T0, v6, v7, ecl_make_int8_t(16), v10mincol, v11padchar, v12commachar, v13commainterval);
    goto L5;
   }
  }
L6:;
  if (!(v5args==ECL_NIL)){
   goto L181;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L181:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L183;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L183:;
  {
   cl_object v14;
   v14 = v5args;
   {
    cl_object v15;
    v15 = v14;
    {
     bool v16;
     v16 = ECL_LISTP(v15);
     if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v14)){
    goto L190;
   }
   {
    cl_object v15;
    v15 = ECL_CONS_CDR(v14);
    v5args = v15;
    v14 = ECL_CONS_CAR(v14);
   }
L190:;
   T0 = v14;
  }
  cl_write(9, T0, ECL_SYM("STREAM",1350), v1stream, ECL_SYM("BASE",1231), ecl_make_int8_t(16), ECL_SYM("RADIX",1332), ECL_NIL, ECL_SYM("ESCAPE",1261), ECL_NIL);
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC554__lambda1003_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[155]);
 {
  return LC554__lambda1003(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function LATIN_CAPITAL_LETTER_R-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC555latin_capital_letter_r_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L13;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L13:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L21;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ECL_NIL);
    goto L7;
L21:;
    if (!((v9param)==(VV[34]))){
     goto L23;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L7;
L23:;
    if (!((v9param)==(ECL_NIL))){
     goto L27;
    }
    T1 = ECL_NIL;
    goto L7;
L27:;
    T1 = v9param;
   }
L7:;
   T2 = cl_list(2, VV[157], T1);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L36;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L36:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L44;
    }
    T4 = L527expand_next_arg(1, v8offset);
    T3 = cl_list(3, ECL_SYM("OR",616), T4, ecl_make_int8_t(0));
    goto L30;
L44:;
    if (!((v9param)==(VV[34]))){
     goto L46;
    }
    T4 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T4);
    T3 = VV[107];
    goto L30;
L46:;
    if (!((v9param)==(ECL_NIL))){
     goto L50;
    }
    T3 = ecl_make_int8_t(0);
    goto L30;
L50:;
    T3 = v9param;
   }
L30:;
   T4 = cl_list(2, VV[158], T3);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L59;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L59:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L67;
    }
    T6 = L527expand_next_arg(1, v8offset);
    T5 = cl_list(3, ECL_SYM("OR",616), T6, ECL_CODE_CHAR(32));
    goto L53;
L67:;
    if (!((v9param)==(VV[34]))){
     goto L69;
    }
    T6 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T6);
    T5 = VV[107];
    goto L53;
L69:;
    if (!((v9param)==(ECL_NIL))){
     goto L73;
    }
    T5 = ECL_CODE_CHAR(32);
    goto L53;
L73:;
    T5 = v9param;
   }
L53:;
   T6 = cl_list(2, VV[159], T5);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L82;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L82:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L90;
    }
    T8 = L527expand_next_arg(1, v8offset);
    T7 = cl_list(3, ECL_SYM("OR",616), T8, ECL_CODE_CHAR(44));
    goto L76;
L90:;
    if (!((v9param)==(VV[34]))){
     goto L92;
    }
    T8 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T8);
    T7 = VV[107];
    goto L76;
L92:;
    if (!((v9param)==(ECL_NIL))){
     goto L96;
    }
    T7 = ECL_CODE_CHAR(44);
    goto L76;
L96:;
    T7 = v9param;
   }
L76:;
   T8 = cl_list(2, VV[160], T7);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L105;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L105:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L113;
    }
    T10 = L527expand_next_arg(1, v8offset);
    T9 = cl_list(3, ECL_SYM("OR",616), T10, ecl_make_int8_t(3));
    goto L99;
L113:;
    if (!((v9param)==(VV[34]))){
     goto L115;
    }
    T10 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T10);
    T9 = VV[107];
    goto L99;
L115:;
    if (!((v9param)==(ECL_NIL))){
     goto L119;
    }
    T9 = ecl_make_int8_t(3);
    goto L99;
L119:;
    T9 = v9param;
   }
L99:;
   T10 = cl_list(2, VV[161], T9);
   T11 = cl_list(5, T2, T4, T6, T8, T10);
   if (Null(v6)){
    goto L123;
   }
   T13 = ecl_list1(ecl_make_int8_t(5));
   T14 = ecl_caar(v6);
   T12 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T13, ECL_SYM("OFFSET",1316), T14);
   goto L122;
L123:;
   T12 = ECL_NIL;
L122:;
   {
    cl_object v7n_arg;
    v7n_arg = cl_gensym(0);
    T14 = L527expand_next_arg(0);
    T15 = cl_list(2, v7n_arg, T14);
    T16 = ecl_list1(T15);
    T17 = cl_list(10, VV[135], ECL_SYM("STREAM",802), v7n_arg, v3, v4, VV[157], VV[158], VV[159], VV[160], VV[161]);
    if (Null(v4)){
     goto L128;
    }
    if (Null(v3)){
     goto L130;
    }
    T18 = cl_list(3, VV[162], ECL_SYM("STREAM",802), v7n_arg);
    goto L127;
L130:;
    T18 = cl_list(3, VV[163], ECL_SYM("STREAM",802), v7n_arg);
    goto L127;
L128:;
    if (Null(v3)){
     goto L132;
    }
    T18 = cl_list(3, VV[164], ECL_SYM("STREAM",802), v7n_arg);
    goto L127;
L132:;
    T18 = cl_list(3, VV[165], ECL_SYM("STREAM",802), v7n_arg);
L127:;
    T19 = cl_list(4, ECL_SYM("IF",950), VV[157], T17, T18);
    T13 = cl_list(3, ECL_SYM("LET",479), T16, T19);
   }
   T14 = ecl_list1(T13);
   T15 = ecl_append(T12,T14);
   T0 = cl_listX(3, ECL_SYM("LET",479), T11, T15);
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC555latin_capital_letter_r_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[156]);
 {
  return LC555latin_capital_letter_r_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA1162                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC556__lambda1162(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10base;
    cl_object v11mincol;
    cl_object v12padchar;
    cl_object v13commachar;
    cl_object v14commainterval;
    {
     cl_object v15param_and_offset;
     cl_object v16offset;
     cl_object v17param;
     {
      cl_object v18;
      v18 = v9;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L13;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v9 = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L13:;
      v15param_and_offset = v18;
     }
     v16offset = ecl_car(v15param_and_offset);
     v17param = ecl_cdr(v15param_and_offset);
     if (!((v17param)==(VV[33]))){
      goto L21;
     }
     if (!(v5args==ECL_NIL)){
      goto L26;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v16offset);
L26:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L28;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L28:;
     {
      cl_object v18;
      v18 = v5args;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L34;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v5args = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L34:;
      value0 = v18;
     }
     if (value0!=ECL_NIL) {
      goto L24;
     }
     v10base = ECL_NIL;
     goto L7;
L24:;
     v10base = value0;
     goto L7;
L21:;
     if (!((v17param)==(VV[34]))){
      goto L40;
     }
     v10base = ecl_make_fixnum(ecl_length(v5args));
     goto L7;
L40:;
     if (!((v17param)==(ECL_NIL))){
      goto L42;
     }
     v10base = ECL_NIL;
     goto L7;
L42:;
     v10base = v17param;
    }
L7:;
    {
     cl_object v15param_and_offset;
     cl_object v16offset;
     cl_object v17param;
     {
      cl_object v18;
      v18 = v9;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L51;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v9 = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L51:;
      v15param_and_offset = v18;
     }
     v16offset = ecl_car(v15param_and_offset);
     v17param = ecl_cdr(v15param_and_offset);
     if (!((v17param)==(VV[33]))){
      goto L59;
     }
     if (!(v5args==ECL_NIL)){
      goto L64;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v16offset);
L64:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L66;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L66:;
     {
      cl_object v18;
      v18 = v5args;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L72;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v5args = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L72:;
      value0 = v18;
     }
     if (value0!=ECL_NIL) {
      goto L62;
     }
     v11mincol = ecl_make_int8_t(0);
     goto L45;
L62:;
     v11mincol = value0;
     goto L45;
L59:;
     if (!((v17param)==(VV[34]))){
      goto L78;
     }
     v11mincol = ecl_make_fixnum(ecl_length(v5args));
     goto L45;
L78:;
     if (!((v17param)==(ECL_NIL))){
      goto L80;
     }
     v11mincol = ecl_make_int8_t(0);
     goto L45;
L80:;
     v11mincol = v17param;
    }
L45:;
    {
     cl_object v15param_and_offset;
     cl_object v16offset;
     cl_object v17param;
     {
      cl_object v18;
      v18 = v9;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L89;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v9 = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L89:;
      v15param_and_offset = v18;
     }
     v16offset = ecl_car(v15param_and_offset);
     v17param = ecl_cdr(v15param_and_offset);
     if (!((v17param)==(VV[33]))){
      goto L97;
     }
     if (!(v5args==ECL_NIL)){
      goto L102;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v16offset);
L102:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L104;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L104:;
     {
      cl_object v18;
      v18 = v5args;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L110;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v5args = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L110:;
      value0 = v18;
     }
     if (value0!=ECL_NIL) {
      goto L100;
     }
     v12padchar = ECL_CODE_CHAR(32);
     goto L83;
L100:;
     v12padchar = value0;
     goto L83;
L97:;
     if (!((v17param)==(VV[34]))){
      goto L116;
     }
     v12padchar = ecl_make_fixnum(ecl_length(v5args));
     goto L83;
L116:;
     if (!((v17param)==(ECL_NIL))){
      goto L118;
     }
     v12padchar = ECL_CODE_CHAR(32);
     goto L83;
L118:;
     v12padchar = v17param;
    }
L83:;
    {
     cl_object v15param_and_offset;
     cl_object v16offset;
     cl_object v17param;
     {
      cl_object v18;
      v18 = v9;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L127;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v9 = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L127:;
      v15param_and_offset = v18;
     }
     v16offset = ecl_car(v15param_and_offset);
     v17param = ecl_cdr(v15param_and_offset);
     if (!((v17param)==(VV[33]))){
      goto L135;
     }
     if (!(v5args==ECL_NIL)){
      goto L140;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v16offset);
L140:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L142;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L142:;
     {
      cl_object v18;
      v18 = v5args;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L148;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v5args = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L148:;
      value0 = v18;
     }
     if (value0!=ECL_NIL) {
      goto L138;
     }
     v13commachar = ECL_CODE_CHAR(44);
     goto L121;
L138:;
     v13commachar = value0;
     goto L121;
L135:;
     if (!((v17param)==(VV[34]))){
      goto L154;
     }
     v13commachar = ecl_make_fixnum(ecl_length(v5args));
     goto L121;
L154:;
     if (!((v17param)==(ECL_NIL))){
      goto L156;
     }
     v13commachar = ECL_CODE_CHAR(44);
     goto L121;
L156:;
     v13commachar = v17param;
    }
L121:;
    {
     cl_object v15param_and_offset;
     cl_object v16offset;
     cl_object v17param;
     {
      cl_object v18;
      v18 = v9;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L165;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v9 = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L165:;
      v15param_and_offset = v18;
     }
     v16offset = ecl_car(v15param_and_offset);
     v17param = ecl_cdr(v15param_and_offset);
     if (!((v17param)==(VV[33]))){
      goto L173;
     }
     if (!(v5args==ECL_NIL)){
      goto L178;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v16offset);
L178:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L180;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L180:;
     {
      cl_object v18;
      v18 = v5args;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L186;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v5args = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L186:;
      value0 = v18;
     }
     if (value0!=ECL_NIL) {
      goto L176;
     }
     v14commainterval = ecl_make_int8_t(3);
     goto L159;
L176:;
     v14commainterval = value0;
     goto L159;
L173:;
     if (!((v17param)==(VV[34]))){
      goto L192;
     }
     v14commainterval = ecl_make_fixnum(ecl_length(v5args));
     goto L159;
L192:;
     if (!((v17param)==(ECL_NIL))){
      goto L194;
     }
     v14commainterval = ecl_make_int8_t(3);
     goto L159;
L194:;
     v14commainterval = v17param;
    }
L159:;
    if (Null(v9)){
     goto L197;
    }
    T0 = ecl_list1(ecl_make_int8_t(5));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L197:;
    if (Null(v10base)){
     goto L199;
    }
    if (!(v5args==ECL_NIL)){
     goto L201;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L201:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L203;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L203:;
    {
     cl_object v15;
     v15 = v5args;
     {
      cl_object v16;
      v16 = v15;
      {
       bool v17;
       v17 = ECL_LISTP(v16);
       if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v15)){
      goto L210;
     }
     {
      cl_object v16;
      v16 = ECL_CONS_CDR(v15);
      v5args = v16;
      v15 = ECL_CONS_CAR(v15);
     }
L210:;
     T0 = v15;
    }
    si_format_print_integer(v1stream, T0, v6, v7, v10base, v11mincol, v12padchar, v13commachar, v14commainterval);
    goto L5;
L199:;
    if (Null(v7)){
     goto L216;
    }
    if (Null(v6)){
     goto L218;
    }
    if (!(v5args==ECL_NIL)){
     goto L220;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L220:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L222;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L222:;
    {
     cl_object v15;
     v15 = v5args;
     {
      cl_object v16;
      v16 = v15;
      {
       bool v17;
       v17 = ECL_LISTP(v16);
       if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v15)){
      goto L229;
     }
     {
      cl_object v16;
      v16 = ECL_CONS_CDR(v15);
      v5args = v16;
      v15 = ECL_CONS_CAR(v15);
     }
L229:;
     T0 = v15;
    }
    si_format_print_old_roman(v1stream, T0);
    goto L5;
L218:;
    if (!(v5args==ECL_NIL)){
     goto L235;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L235:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L237;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L237:;
    {
     cl_object v15;
     v15 = v5args;
     {
      cl_object v16;
      v16 = v15;
      {
       bool v17;
       v17 = ECL_LISTP(v16);
       if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v15)){
      goto L244;
     }
     {
      cl_object v16;
      v16 = ECL_CONS_CDR(v15);
      v5args = v16;
      v15 = ECL_CONS_CAR(v15);
     }
L244:;
     T0 = v15;
    }
    si_format_print_roman(v1stream, T0);
    goto L5;
L216:;
    if (Null(v6)){
     goto L250;
    }
    if (!(v5args==ECL_NIL)){
     goto L252;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L252:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L254;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L254:;
    {
     cl_object v15;
     v15 = v5args;
     {
      cl_object v16;
      v16 = v15;
      {
       bool v17;
       v17 = ECL_LISTP(v16);
       if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v15)){
      goto L261;
     }
     {
      cl_object v16;
      v16 = ECL_CONS_CDR(v15);
      v5args = v16;
      v15 = ECL_CONS_CAR(v15);
     }
L261:;
     T0 = v15;
    }
    si_format_print_ordinal(v1stream, T0);
    goto L5;
L250:;
    if (!(v5args==ECL_NIL)){
     goto L267;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L267:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L269;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L269:;
    {
     cl_object v15;
     v15 = v5args;
     {
      cl_object v16;
      v16 = v15;
      {
       bool v17;
       v17 = ECL_LISTP(v16);
       if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v15)){
      goto L276;
     }
     {
      cl_object v16;
      v16 = ECL_CONS_CDR(v15);
      v5args = v16;
      v15 = ECL_CONS_CAR(v15);
     }
L276:;
     T0 = v15;
    }
    si_format_print_cardinal(v1stream, T0);
   }
  }
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC556__lambda1162_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[166]);
 {
  return LC556__lambda1162(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* function definition for FORMAT-PRINT-SMALL-CARDINAL                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L557format_print_small_cardinal(cl_object v1stream, cl_object v2n)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;                                   /*  HUNDREDS                */
  cl_object v4;                                   /*  REM                     */
  value0 = ecl_truncate2(v2n,ecl_make_int8_t(100));
  {
   v3 = value0;
   v4 = cl_env_copy->values[1];
  }
  if (!(ecl_plusp(v3))){
   goto L3;
  }
  T0 = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[167]),ecl_to_size(v3));
  cl_write_string(2, T0, v1stream);
  cl_write_string(2, VV[180], v1stream);
  if (!(ecl_plusp(v4))){
   goto L3;
  }
  cl_write_char(2, ECL_CODE_CHAR(32), v1stream);
L3:;
  if (!(ecl_plusp(v4))){
   goto L8;
  }
  {
   cl_object v5;                                  /*  TENS                    */
   cl_object v6;                                  /*  ONES                    */
   value0 = ecl_truncate2(v4,ecl_make_int8_t(10));
   {
    v5 = value0;
    v6 = cl_env_copy->values[1];
   }
   if (!(ecl_lower(ecl_make_int8_t(1),v5))){
    goto L11;
   }
   T0 = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[169]),ecl_to_size(v5));
   cl_write_string(2, T0, v1stream);
   if (!(ecl_plusp(v6))){
    goto L14;
   }
   cl_write_char(2, ECL_CODE_CHAR(45), v1stream);
   T0 = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[167]),ecl_to_size(v6));
   value0 = cl_write_string(2, T0, v1stream);
   return value0;
L14:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L11:;
   if (!(ecl_number_equalp(v5,ecl_make_int8_t(1)))){
    goto L17;
   }
   T0 = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[171]),ecl_to_size(v6));
   value0 = cl_write_string(2, T0, v1stream);
   return value0;
L17:;
   if (!(ecl_plusp(v6))){
    goto L19;
   }
   T0 = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[167]),ecl_to_size(v6));
   value0 = cl_write_string(2, T0, v1stream);
   return value0;
L19:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L8:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for FORMAT-PRINT-CARDINAL                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_print_cardinal(cl_object v1stream, cl_object v2n)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ecl_minusp(v2n))){
  goto L2;
 }
 cl_write_string(2, VV[181], v1stream);
 T0 = ecl_negate(v2n);
 value0 = L558format_print_cardinal_aux(v1stream, T0, ecl_make_int8_t(0), v2n);
 return value0;
L2:;
 if (!(ecl_zerop(v2n))){
  goto L5;
 }
 value0 = cl_write_string(2, VV[183], v1stream);
 return value0;
L5:;
 value0 = L558format_print_cardinal_aux(v1stream, v2n, ecl_make_int8_t(0), v2n);
 return value0;
}
cl_object si_format_print_cardinal_va(cl_narg narg, cl_object v3stream, cl_object v4n, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[165]);
 {
  return si_format_print_cardinal(v3stream, v4n);
 }
}
/* function definition for FORMAT-PRINT-CARDINAL-AUX                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L558format_print_cardinal_aux(cl_object v1stream, cl_object v2n, cl_object v3period, cl_object v4err)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5;                                   /*  BEYOND                  */
  cl_object v6;                                   /*  HERE                    */
  value0 = ecl_truncate2(v2n,ecl_make_fixnum(1000));
  {
   v5 = value0;
   v6 = cl_env_copy->values[1];
  }
  if (ecl_lowereq(v3period,ecl_make_int8_t(20))) {
   goto L3;
  }
  cl_error(2, VV[185], v4err);
L3:;
  if (ecl_zerop(v5)) {
   goto L5;
  }
  T0 = ecl_one_plus(v3period);
  L558format_print_cardinal_aux(v1stream, v5, T0, v4err);
L5:;
  if (ecl_zerop(v6)) {
   goto L7;
  }
  if (ecl_zerop(v5)) {
   goto L9;
  }
  cl_write_char(2, ECL_CODE_CHAR(32), v1stream);
L9:;
  L557format_print_small_cardinal(v1stream, v6);
  T0 = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[173]),ecl_to_size(v3period));
  value0 = cl_write_string(2, T0, v1stream);
  return value0;
L7:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for FORMAT-PRINT-ORDINAL                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_print_ordinal(cl_object v1stream, cl_object v2n)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ecl_minusp(v2n))){
  goto L2;
 }
 cl_write_string(2, VV[181], v1stream);
L2:;
 {
  cl_object v3number;
  v3number = ecl_abs(v2n);
  {
   cl_object v4;                                  /*  TOP                     */
   cl_object v5;                                  /*  BOT                     */
   value0 = ecl_truncate2(v3number,ecl_make_int8_t(100));
   {
    v4 = value0;
    v5 = cl_env_copy->values[1];
   }
   if (ecl_zerop(v4)) {
    goto L6;
   }
   T0 = ecl_minus(v3number,v5);
   si_format_print_cardinal(v1stream, T0);
L6:;
   if (!(ecl_plusp(v4))){
    goto L8;
   }
   if (!(ecl_plusp(v5))){
    goto L8;
   }
   cl_write_char(2, ECL_CODE_CHAR(32), v1stream);
L8:;
   {
    cl_object v6;                                 /*  TENS                    */
    cl_object v7;                                 /*  ONES                    */
    value0 = ecl_truncate2(v5,ecl_make_int8_t(10));
    {
     v6 = value0;
     v7 = cl_env_copy->values[1];
    }
    if (!(ecl_number_equalp(v5,ecl_make_int8_t(12)))){
     goto L12;
    }
    value0 = cl_write_string(2, VV[186], v1stream);
    return value0;
L12:;
    if (!(ecl_number_equalp(v6,ecl_make_int8_t(1)))){
     goto L14;
    }
    T0 = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[171]),ecl_to_size(v7));
    cl_write_string(2, T0, v1stream);
    value0 = cl_write_string(2, VV[187], v1stream);
    return value0;
L14:;
    if (!(ecl_zerop(v6))){
     goto L17;
    }
    if (!(ecl_plusp(v7))){
     goto L17;
    }
    T0 = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[175]),ecl_to_size(v7));
    value0 = cl_write_string(2, T0, v1stream);
    return value0;
L17:;
    if (!(ecl_zerop(v7))){
     goto L20;
    }
    if (!(ecl_plusp(v6))){
     goto L20;
    }
    T0 = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[177]),ecl_to_size(v6));
    value0 = cl_write_string(2, T0, v1stream);
    return value0;
L20:;
    if (!(ecl_plusp(v5))){
     goto L23;
    }
    T0 = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[169]),ecl_to_size(v6));
    cl_write_string(2, T0, v1stream);
    cl_write_char(2, ECL_CODE_CHAR(45), v1stream);
    T0 = ecl_aref1(ecl_cmp_symbol_value(cl_env_copy,VV[175]),ecl_to_size(v7));
    value0 = cl_write_string(2, T0, v1stream);
    return value0;
L23:;
    if (!(ecl_plusp(v3number))){
     goto L27;
    }
    value0 = cl_write_string(2, VV[187], v1stream);
    return value0;
L27:;
    value0 = cl_write_string(2, VV[188], v1stream);
    return value0;
   }
  }
 }
}
cl_object si_format_print_ordinal_va(cl_narg narg, cl_object v4stream, cl_object v5n, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[164]);
 {
  return si_format_print_ordinal(v4stream, v5n);
 }
}
/* function definition for FORMAT-PRINT-OLD-ROMAN                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_print_old_roman(cl_object v1stream, cl_object v2n)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (cl_L(3, ecl_make_int8_t(0), v2n, ecl_make_fixnum(5000))!=ECL_NIL) {
  goto L2;
 }
 cl_error(2, VV[190], v2n);
L2:;
 {
  cl_object v3char_list;
  cl_object v4val_list;
  cl_object v5cur_char;
  cl_object v6cur_val;
  cl_object v7start;
  v3char_list = VV[191];
  v4val_list = VV[192];
  v5cur_char = ECL_CODE_CHAR(77);
  v6cur_val = ecl_make_fixnum(1000);
  v7start = v2n;
  goto L11;
L10:;
  T0 = ecl_cdr(v3char_list);
  T1 = ecl_cdr(v4val_list);
  T2 = ecl_car(v3char_list);
  T3 = ecl_car(v4val_list);
  {
   cl_object v8i;
   v8i = v7start;
   goto L22;
L21:;
   cl_write_char(2, v5cur_char, v1stream);
   v8i = ecl_minus(v8i,v6cur_val);
L22:;
   if (ecl_lower(v8i,v6cur_val)) {
    goto L27;
   }
   goto L21;
L27:;
   v7start = v8i;
  }
  v6cur_val = T3;
  v5cur_char = T2;
  v4val_list = T1;
  v3char_list = T0;
L11:;
  if (ecl_zerop(v7start)) {
   goto L29;
  }
  goto L10;
L29:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
cl_object si_format_print_old_roman_va(cl_narg narg, cl_object v8stream, cl_object v9n, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[162]);
 {
  return si_format_print_old_roman(v8stream, v9n);
 }
}
/* function definition for FORMAT-PRINT-ROMAN                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_print_roman(cl_object v1stream, cl_object v2n)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (cl_L(3, ecl_make_int8_t(0), v2n, ecl_make_fixnum(4000))!=ECL_NIL) {
  goto L2;
 }
 cl_error(2, VV[194], v2n);
L2:;
 {
  cl_object v3char_list;
  cl_object v4val_list;
  cl_object v5sub_chars;
  cl_object v6sub_val;
  cl_object v7cur_char;
  cl_object v8cur_val;
  cl_object v9cur_sub_char;
  cl_object v10cur_sub_val;
  cl_object v11start;
  v3char_list = VV[191];
  v4val_list = VV[192];
  v5sub_chars = VV[195];
  v6sub_val = VV[196];
  v7cur_char = ECL_CODE_CHAR(77);
  v8cur_val = ecl_make_fixnum(1000);
  v9cur_sub_char = ECL_CODE_CHAR(67);
  v10cur_sub_val = ecl_make_int8_t(100);
  v11start = v2n;
  goto L15;
L14:;
  T0 = ecl_cdr(v3char_list);
  T1 = ecl_cdr(v4val_list);
  T2 = ecl_cdr(v5sub_chars);
  T3 = ecl_cdr(v6sub_val);
  T4 = ecl_car(v3char_list);
  T5 = ecl_car(v4val_list);
  T6 = ecl_car(v5sub_chars);
  T7 = ecl_car(v6sub_val);
  {
   cl_object v12i;
   v12i = v11start;
   goto L30;
L29:;
   cl_write_char(2, v7cur_char, v1stream);
   v12i = ecl_minus(v12i,v8cur_val);
L30:;
   if (ecl_lower(v12i,v8cur_val)) {
    goto L35;
   }
   goto L29;
L35:;
   T8 = ecl_minus(v8cur_val,v10cur_sub_val);
   if (!(ecl_lowereq(T8,v12i))){
    goto L37;
   }
   cl_write_char(2, v9cur_sub_char, v1stream);
   cl_write_char(2, v7cur_char, v1stream);
   T8 = ecl_minus(v8cur_val,v10cur_sub_val);
   v11start = ecl_minus(v12i,T8);
   goto L26;
L37:;
   v11start = v12i;
  }
L26:;
  v10cur_sub_val = T7;
  v9cur_sub_char = T6;
  v8cur_val = T5;
  v7cur_char = T4;
  v6sub_val = T3;
  v5sub_chars = T2;
  v4val_list = T1;
  v3char_list = T0;
L15:;
  if (ecl_zerop(v11start)) {
   goto L41;
  }
  goto L14;
L41:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
cl_object si_format_print_roman_va(cl_narg narg, cl_object v12stream, cl_object v13n, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[163]);
 {
  return si_format_print_roman(v12stream, v13n);
 }
}
/* local function LATIN_CAPITAL_LETTER_P-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC559latin_capital_letter_p_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  v6 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-END */;
  if (Null(v5)){
   goto L7;
  }
  T1 = ecl_caar(v5);
  cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[125], ECL_SYM("OFFSET",1316), T1);
L7:;
  {
   cl_object v7arg;
   if (v3!=ECL_NIL) {
    goto L10;
   }
   v7arg = L527expand_next_arg(0);
   goto L9;
L10:;
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[48]))){
    goto L12;
   }
   T1 = ecl_one_minus(v6);
   T2 = cl_list(6, ECL_SYM("ERROR",339), VV[64], VV[29], VV[200], ECL_SYM("OFFSET",1316), T1);
   v7arg = cl_list(4, ECL_SYM("IF",950), VV[199], T2, VV[201]);
   goto L9;
L12:;
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[47]))){
    goto L14;
   }
   if (ecl_cmp_symbol_value(cl_env_copy,VV[49])!=ECL_NIL) {
    goto L16;
   }
   cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[200]);
L16:;
   v7arg = ecl_caar(ecl_cmp_symbol_value(cl_env_copy,VV[49]));
   goto L9;
L14:;
   cl_env_copy->values[0] = ECL_NIL;
   cl_env_copy->nvalues = 1;
   cl_throw(VV[62]);
L9:;
   if (Null(v4)){
    goto L19;
   }
   T1 = cl_list(3, ECL_SYM("EQL",336), v7arg, ecl_make_int8_t(1));
   T2 = cl_listX(3, ECL_SYM("IF",950), T1, VV[202]);
   T0 = cl_list(3, ECL_SYM("WRITE-STRING",926), T2, ECL_SYM("STREAM",802));
   goto L6;
L19:;
   T1 = cl_list(3, ECL_SYM("EQL",336), v7arg, ecl_make_int8_t(1));
   T0 = cl_list(3, ECL_SYM("UNLESS",886), T1, VV[203]);
  }
L6:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC559latin_capital_letter_p_format_directive_expander_va(cl_narg narg, cl_object v7, cl_object v8, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[198]);
 {
  return LC559latin_capital_letter_p_format_directive_expander(v7, v8);
 }
}
/* local function LAMBDA1291                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC560__lambda1291(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v8)){
   goto L6;
  }
  T0 = ecl_list1(ecl_make_int8_t(0));
  T1 = ecl_caar(v8);
  cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L6:;
  {
   cl_object v9arg;
   if (Null(v6)){
    goto L9;
   }
   if (!((v4orig_args)==(v5args))){
    goto L11;
   }
   v9arg = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[200]);
   goto L8;
L11:;
   {
    cl_object v10arg_ptr;
    v10arg_ptr = v4orig_args;
    goto L16;
L15:;
    v10arg_ptr = ecl_cdr(v10arg_ptr);
L16:;
    T0 = ecl_cdr(v10arg_ptr);
    if ((T0)==(v5args)) {
     goto L20;
    }
    goto L15;
L20:;
    v9arg = ecl_car(v10arg_ptr);
    goto L8;
   }
L9:;
   if (!(v5args==ECL_NIL)){
    goto L22;
   }
   cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L22:;
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
    goto L24;
   }
   ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L24:;
   {
    cl_object v11;
    v11 = v5args;
    {
     cl_object v12;
     v12 = v11;
     {
      bool v13;
      v13 = ECL_LISTP(v12);
      if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(VV[106],v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v11)){
     goto L30;
    }
    {
     cl_object v12;
     v12 = ECL_CONS_CDR(v11);
     v5args = v12;
     v11 = ECL_CONS_CAR(v11);
    }
L30:;
    v9arg = v11;
   }
L8:;
   if (Null(v7)){
    goto L36;
   }
   if (!((v9arg)==(ecl_make_int8_t(1)))){
    goto L39;
   }
   T0 = VV[205];
   goto L38;
L39:;
   T0 = VV[206];
L38:;
   cl_write_string(2, T0, v1stream);
   goto L5;
L36:;
   if ((v9arg)==(ecl_make_int8_t(1))) {
    goto L5;
   }
   cl_write_char(2, ECL_CODE_CHAR(115), v1stream);
  }
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC560__lambda1291_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[204]);
 {
  return LC560__lambda1291(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* function definition for DECIMAL-STRING                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L561decimal_string(cl_object v1n)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_write_to_string(7, v1n, ECL_SYM("BASE",1231), ecl_make_int8_t(10), ECL_SYM("RADIX",1332), ECL_NIL, ECL_SYM("ESCAPE",1261), ECL_NIL);
 return value0;
}
/* local function LATIN_CAPITAL_LETTER_F-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC562latin_capital_letter_f_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v3)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[209]);
L5:;
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L15;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L15:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L23;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ECL_NIL);
    goto L9;
L23:;
    if (!((v9param)==(VV[34]))){
     goto L25;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L9;
L25:;
    if (!((v9param)==(ECL_NIL))){
     goto L29;
    }
    T1 = ECL_NIL;
    goto L9;
L29:;
    T1 = v9param;
   }
L9:;
   T2 = cl_list(2, VV[210], T1);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L38;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L38:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L46;
    }
    T4 = L527expand_next_arg(1, v8offset);
    T3 = cl_list(3, ECL_SYM("OR",616), T4, ECL_NIL);
    goto L32;
L46:;
    if (!((v9param)==(VV[34]))){
     goto L48;
    }
    T4 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T4);
    T3 = VV[107];
    goto L32;
L48:;
    if (!((v9param)==(ECL_NIL))){
     goto L52;
    }
    T3 = ECL_NIL;
    goto L32;
L52:;
    T3 = v9param;
   }
L32:;
   T4 = cl_list(2, VV[211], T3);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L61;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L61:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L69;
    }
    T6 = L527expand_next_arg(1, v8offset);
    T5 = cl_list(3, ECL_SYM("OR",616), T6, ecl_make_int8_t(0));
    goto L55;
L69:;
    if (!((v9param)==(VV[34]))){
     goto L71;
    }
    T6 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T6);
    T5 = VV[107];
    goto L55;
L71:;
    if (!((v9param)==(ECL_NIL))){
     goto L75;
    }
    T5 = ecl_make_int8_t(0);
    goto L55;
L75:;
    T5 = v9param;
   }
L55:;
   T6 = cl_list(2, VV[212], T5);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L84;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L84:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L92;
    }
    T8 = L527expand_next_arg(1, v8offset);
    T7 = cl_list(3, ECL_SYM("OR",616), T8, ECL_NIL);
    goto L78;
L92:;
    if (!((v9param)==(VV[34]))){
     goto L94;
    }
    T8 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T8);
    T7 = VV[107];
    goto L78;
L94:;
    if (!((v9param)==(ECL_NIL))){
     goto L98;
    }
    T7 = ECL_NIL;
    goto L78;
L98:;
    T7 = v9param;
   }
L78:;
   T8 = cl_list(2, VV[213], T7);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L107;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L107:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L115;
    }
    T10 = L527expand_next_arg(1, v8offset);
    T9 = cl_list(3, ECL_SYM("OR",616), T10, ECL_CODE_CHAR(32));
    goto L101;
L115:;
    if (!((v9param)==(VV[34]))){
     goto L117;
    }
    T10 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T10);
    T9 = VV[107];
    goto L101;
L117:;
    if (!((v9param)==(ECL_NIL))){
     goto L121;
    }
    T9 = ECL_CODE_CHAR(32);
    goto L101;
L121:;
    T9 = v9param;
   }
L101:;
   T10 = cl_list(2, VV[214], T9);
   T11 = cl_list(5, T2, T4, T6, T8, T10);
   if (Null(v6)){
    goto L125;
   }
   T13 = ecl_list1(ecl_make_int8_t(5));
   T14 = ecl_caar(v6);
   T12 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T13, ECL_SYM("OFFSET",1316), T14);
   goto L124;
L125:;
   T12 = ECL_NIL;
L124:;
   T13 = L527expand_next_arg(0);
   T14 = cl_list(9, VV[215], ECL_SYM("STREAM",802), T13, VV[210], VV[211], VV[212], VV[213], VV[214], v4);
   T15 = ecl_list1(T14);
   T16 = ecl_append(T12,T15);
   T0 = cl_listX(3, ECL_SYM("LET",479), T11, T16);
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC562latin_capital_letter_f_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[208]);
 {
  return LC562latin_capital_letter_f_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA1391                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC563__lambda1391(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v6)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[209]);
L5:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10w;
    cl_object v11d;
    cl_object v12k;
    cl_object v13ovf;
    cl_object v14pad;
    {
     cl_object v15param_and_offset;
     cl_object v16offset;
     cl_object v17param;
     {
      cl_object v18;
      v18 = v9;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L15;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v9 = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L15:;
      v15param_and_offset = v18;
     }
     v16offset = ecl_car(v15param_and_offset);
     v17param = ecl_cdr(v15param_and_offset);
     if (!((v17param)==(VV[33]))){
      goto L23;
     }
     if (!(v5args==ECL_NIL)){
      goto L28;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v16offset);
L28:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L30;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L30:;
     {
      cl_object v18;
      v18 = v5args;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L36;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v5args = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L36:;
      value0 = v18;
     }
     if (value0!=ECL_NIL) {
      goto L26;
     }
     v10w = ECL_NIL;
     goto L9;
L26:;
     v10w = value0;
     goto L9;
L23:;
     if (!((v17param)==(VV[34]))){
      goto L42;
     }
     v10w = ecl_make_fixnum(ecl_length(v5args));
     goto L9;
L42:;
     if (!((v17param)==(ECL_NIL))){
      goto L44;
     }
     v10w = ECL_NIL;
     goto L9;
L44:;
     v10w = v17param;
    }
L9:;
    {
     cl_object v15param_and_offset;
     cl_object v16offset;
     cl_object v17param;
     {
      cl_object v18;
      v18 = v9;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L53;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v9 = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L53:;
      v15param_and_offset = v18;
     }
     v16offset = ecl_car(v15param_and_offset);
     v17param = ecl_cdr(v15param_and_offset);
     if (!((v17param)==(VV[33]))){
      goto L61;
     }
     if (!(v5args==ECL_NIL)){
      goto L66;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v16offset);
L66:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L68;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L68:;
     {
      cl_object v18;
      v18 = v5args;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L74;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v5args = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L74:;
      value0 = v18;
     }
     if (value0!=ECL_NIL) {
      goto L64;
     }
     v11d = ECL_NIL;
     goto L47;
L64:;
     v11d = value0;
     goto L47;
L61:;
     if (!((v17param)==(VV[34]))){
      goto L80;
     }
     v11d = ecl_make_fixnum(ecl_length(v5args));
     goto L47;
L80:;
     if (!((v17param)==(ECL_NIL))){
      goto L82;
     }
     v11d = ECL_NIL;
     goto L47;
L82:;
     v11d = v17param;
    }
L47:;
    {
     cl_object v15param_and_offset;
     cl_object v16offset;
     cl_object v17param;
     {
      cl_object v18;
      v18 = v9;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L91;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v9 = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L91:;
      v15param_and_offset = v18;
     }
     v16offset = ecl_car(v15param_and_offset);
     v17param = ecl_cdr(v15param_and_offset);
     if (!((v17param)==(VV[33]))){
      goto L99;
     }
     if (!(v5args==ECL_NIL)){
      goto L104;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v16offset);
L104:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L106;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L106:;
     {
      cl_object v18;
      v18 = v5args;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L112;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v5args = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L112:;
      value0 = v18;
     }
     if (value0!=ECL_NIL) {
      goto L102;
     }
     v12k = ecl_make_int8_t(0);
     goto L85;
L102:;
     v12k = value0;
     goto L85;
L99:;
     if (!((v17param)==(VV[34]))){
      goto L118;
     }
     v12k = ecl_make_fixnum(ecl_length(v5args));
     goto L85;
L118:;
     if (!((v17param)==(ECL_NIL))){
      goto L120;
     }
     v12k = ecl_make_int8_t(0);
     goto L85;
L120:;
     v12k = v17param;
    }
L85:;
    {
     cl_object v15param_and_offset;
     cl_object v16offset;
     cl_object v17param;
     {
      cl_object v18;
      v18 = v9;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L129;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v9 = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L129:;
      v15param_and_offset = v18;
     }
     v16offset = ecl_car(v15param_and_offset);
     v17param = ecl_cdr(v15param_and_offset);
     if (!((v17param)==(VV[33]))){
      goto L137;
     }
     if (!(v5args==ECL_NIL)){
      goto L142;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v16offset);
L142:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L144;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L144:;
     {
      cl_object v18;
      v18 = v5args;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L150;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v5args = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L150:;
      value0 = v18;
     }
     if (value0!=ECL_NIL) {
      goto L140;
     }
     v13ovf = ECL_NIL;
     goto L123;
L140:;
     v13ovf = value0;
     goto L123;
L137:;
     if (!((v17param)==(VV[34]))){
      goto L156;
     }
     v13ovf = ecl_make_fixnum(ecl_length(v5args));
     goto L123;
L156:;
     if (!((v17param)==(ECL_NIL))){
      goto L158;
     }
     v13ovf = ECL_NIL;
     goto L123;
L158:;
     v13ovf = v17param;
    }
L123:;
    {
     cl_object v15param_and_offset;
     cl_object v16offset;
     cl_object v17param;
     {
      cl_object v18;
      v18 = v9;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L167;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v9 = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L167:;
      v15param_and_offset = v18;
     }
     v16offset = ecl_car(v15param_and_offset);
     v17param = ecl_cdr(v15param_and_offset);
     if (!((v17param)==(VV[33]))){
      goto L175;
     }
     if (!(v5args==ECL_NIL)){
      goto L180;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v16offset);
L180:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L182;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L182:;
     {
      cl_object v18;
      v18 = v5args;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L188;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v5args = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L188:;
      value0 = v18;
     }
     if (value0!=ECL_NIL) {
      goto L178;
     }
     v14pad = ECL_CODE_CHAR(32);
     goto L161;
L178:;
     v14pad = value0;
     goto L161;
L175:;
     if (!((v17param)==(VV[34]))){
      goto L194;
     }
     v14pad = ecl_make_fixnum(ecl_length(v5args));
     goto L161;
L194:;
     if (!((v17param)==(ECL_NIL))){
      goto L196;
     }
     v14pad = ECL_CODE_CHAR(32);
     goto L161;
L196:;
     v14pad = v17param;
    }
L161:;
    if (Null(v9)){
     goto L199;
    }
    T0 = ecl_list1(ecl_make_int8_t(5));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L199:;
    if (!(v5args==ECL_NIL)){
     goto L201;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L201:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L203;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L203:;
    {
     cl_object v15;
     v15 = v5args;
     {
      cl_object v16;
      v16 = v15;
      {
       bool v17;
       v17 = ECL_LISTP(v16);
       if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v15)){
      goto L210;
     }
     {
      cl_object v16;
      v16 = ECL_CONS_CDR(v15);
      v5args = v16;
      v15 = ECL_CONS_CAR(v15);
     }
L210:;
     T0 = v15;
    }
    si_format_fixed(v1stream, T0, v10w, v11d, v12k, v13ovf, v14pad, v7);
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC563__lambda1391_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[216]);
 {
  return LC563__lambda1391(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* function definition for FORMAT-FIXED                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_fixed(cl_object v1stream, cl_object v2number, cl_object v3w, cl_object v4d, cl_object v5k, cl_object v6ovf, cl_object v7pad, cl_object v8atsign)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 ecl_character v9pad;
 v9pad = ecl_char_code(v7pad);
L1:;
 if (!(ecl_numberp(v2number))){
  goto L2;
 }
 if (!(floatp(v2number))){
  goto L4;
 }
 value0 = L564format_fixed_aux(v1stream, v2number, v3w, v4d, v5k, v6ovf, ECL_CODE_CHAR(v9pad), v8atsign);
 return value0;
L4:;
 if (Null(cl_rationalp(v2number))){
  goto L6;
 }
 {
  float v10;
  v10 = ecl_to_float(v2number);
  value0 = L564format_fixed_aux(v1stream, ecl_make_single_float(v10), v3w, v4d, v5k, v6ovf, ECL_CODE_CHAR(v9pad), v8atsign);
  return value0;
 }
L6:;
 T0 = L561decimal_string(v2number);
 value0 = L535format_write_field(v1stream, T0, v3w, ecl_make_int8_t(1), ecl_make_int8_t(0), ECL_CODE_CHAR(32), ECL_T);
 return value0;
L2:;
 value0 = si_format_princ(v1stream, v2number, ECL_NIL, ECL_NIL, v3w, ecl_make_int8_t(1), ecl_make_int8_t(0), ECL_CODE_CHAR(v9pad));
 return value0;
}
cl_object si_format_fixed_va(cl_narg narg, cl_object v10stream, cl_object v11number, cl_object v12w, cl_object v13d, cl_object v14k, cl_object v15ovf, cl_object v16pad, cl_object v17atsign, ...)
{
 if (ecl_unlikely(narg!=8)) FEwrong_num_arguments(VV[215]);
 {
  return si_format_fixed(v10stream, v11number, v12w, v13d, v14k, v15ovf, v16pad, v17atsign);
 }
}
/* function definition for FORMAT-FIXED-AUX                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L564format_fixed_aux(cl_object v1stream, cl_object v2number, cl_object v3w, cl_object v4d, cl_object v5k, cl_object v6ovf, cl_object v7pad, cl_object v8atsign)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (v3w!=ECL_NIL) {
  goto L6;
 }
 if (v4d!=ECL_NIL) {
  goto L6;
 }
 if (Null(v5k)){
  goto L4;
 }
 goto L5;
L6:;
L5:;
 if (!(floatp(v2number))){
  goto L2;
 }
 if (si_float_infinity_p(v2number)!=ECL_NIL) {
  goto L10;
 }
 if (Null(si_float_nan_p(v2number))){
  goto L2;
 }
 goto L3;
L10:;
 goto L3;
L4:;
L3:;
 (ecl_prin1(v2number,v1stream));
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 {
  cl_object v9spaceleft;
  v9spaceleft = v3w;
  if (Null(v3w)){
   goto L14;
  }
  if (v8atsign!=ECL_NIL) {
   goto L17;
  }
  if (ecl_minusp(v2number)) {
   goto L17;
  }
  if (!(ecl_zerop(v2number))){
   goto L14;
  }
  T0 = cl_atan(2, v2number, ecl_make_int8_t(-1));
  if (!(ecl_minusp(T0))){
   goto L14;
  }
  goto L15;
L17:;
L15:;
  v9spaceleft = ecl_minus(v9spaceleft,ecl_make_int8_t(1));
L14:;
  {
   cl_object v10;                                 /*  STR                     */
   cl_object v11;                                 /*  LEN                     */
   cl_object v12;                                 /*  LPOINT                  */
   cl_object v13;                                 /*  TPOINT                  */
   T0 = ecl_abs(v2number);
   value0 = L514flonum_to_string(4, T0, v9spaceleft, v4d, v5k);
   {
    const int v14 = cl_env_copy->nvalues;
    v10 = value0;
    cl_object v15;
    v15 = (v14<=1)? ECL_NIL : cl_env_copy->values[1];
    v11 = v15;
    v15 = (v14<=2)? ECL_NIL : cl_env_copy->values[2];
    v12 = v15;
    v15 = (v14<=3)? ECL_NIL : cl_env_copy->values[3];
    v13 = v15;
   }
   if (!((v4d)==(ecl_make_int8_t(0)))){
    goto L23;
   }
   v13 = ECL_NIL;
L23:;
   if (Null(v3w)){
    goto L26;
   }
   v9spaceleft = ecl_minus(v9spaceleft,v11);
   if (Null(v13)){
    goto L30;
   }
   v9spaceleft = ecl_minus(v9spaceleft,ecl_make_int8_t(1));
L30:;
   if (Null(v12)){
    goto L26;
   }
   if (ecl_greater(v9spaceleft,ecl_make_int8_t(0))) {
    goto L36;
   }
   if (!((v4d)==(ecl_make_int8_t(0)))){
    goto L34;
   }
   goto L35;
L36:;
L35:;
   v9spaceleft = ecl_minus(v9spaceleft,ecl_make_int8_t(1));
   goto L26;
L34:;
   v12 = ECL_NIL;
L26:;
   if (Null(v3w)){
    goto L40;
   }
   if (!(ecl_lower(v9spaceleft,ecl_make_int8_t(0)))){
    goto L40;
   }
   if (Null(v6ovf)){
    goto L40;
   }
   {
    cl_object v14i;
    v14i = ecl_make_int8_t(0);
    goto L47;
L46:;
    cl_write_char(2, v6ovf, v1stream);
    v14i = ecl_one_plus(v14i);
L47:;
    if (!(ecl_lower(v14i,v3w))){
     goto L52;
    }
    goto L46;
L52:;
   }
   value0 = ECL_T;
   cl_env_copy->nvalues = 1;
   return value0;
L40:;
   if (Null(v3w)){
    goto L54;
   }
   {
    cl_object v14i;
    v14i = ecl_make_int8_t(0);
    goto L58;
L57:;
    cl_write_char(2, v7pad, v1stream);
    v14i = ecl_one_plus(v14i);
L58:;
    if (!(ecl_lower(v14i,v9spaceleft))){
     goto L63;
    }
    goto L57;
L63:;
   }
L54:;
   if (ecl_minusp(v2number)) {
    goto L68;
   }
   if (!(ecl_zerop(v2number))){
    goto L66;
   }
   T0 = cl_atan(2, v2number, ecl_make_int8_t(-1));
   if (!(ecl_minusp(T0))){
    goto L66;
   }
   goto L67;
L68:;
L67:;
   cl_write_char(2, ECL_CODE_CHAR(45), v1stream);
   goto L65;
L66:;
   if (Null(v8atsign)){
    goto L65;
   }
   cl_write_char(2, ECL_CODE_CHAR(43), v1stream);
L65:;
   if (Null(v12)){
    goto L72;
   }
   cl_write_char(2, ECL_CODE_CHAR(48), v1stream);
L72:;
   cl_write_string(2, v10, v1stream);
   if (Null(v13)){
    goto L75;
   }
   cl_write_char(2, ECL_CODE_CHAR(48), v1stream);
L75:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function LATIN_CAPITAL_LETTER_E-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC565latin_capital_letter_e_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v3)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[209]);
L5:;
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L15;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L15:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L23;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ECL_NIL);
    goto L9;
L23:;
    if (!((v9param)==(VV[34]))){
     goto L25;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L9;
L25:;
    if (!((v9param)==(ECL_NIL))){
     goto L29;
    }
    T1 = ECL_NIL;
    goto L9;
L29:;
    T1 = v9param;
   }
L9:;
   T2 = cl_list(2, VV[220], T1);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L38;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L38:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L46;
    }
    T4 = L527expand_next_arg(1, v8offset);
    T3 = cl_list(3, ECL_SYM("OR",616), T4, ECL_NIL);
    goto L32;
L46:;
    if (!((v9param)==(VV[34]))){
     goto L48;
    }
    T4 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T4);
    T3 = VV[107];
    goto L32;
L48:;
    if (!((v9param)==(ECL_NIL))){
     goto L52;
    }
    T3 = ECL_NIL;
    goto L32;
L52:;
    T3 = v9param;
   }
L32:;
   T4 = cl_list(2, VV[221], T3);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L61;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L61:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L69;
    }
    T6 = L527expand_next_arg(1, v8offset);
    T5 = cl_list(3, ECL_SYM("OR",616), T6, ECL_NIL);
    goto L55;
L69:;
    if (!((v9param)==(VV[34]))){
     goto L71;
    }
    T6 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T6);
    T5 = VV[107];
    goto L55;
L71:;
    if (!((v9param)==(ECL_NIL))){
     goto L75;
    }
    T5 = ECL_NIL;
    goto L55;
L75:;
    T5 = v9param;
   }
L55:;
   T6 = cl_list(2, VV[222], T5);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L84;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L84:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L92;
    }
    T8 = L527expand_next_arg(1, v8offset);
    T7 = cl_list(3, ECL_SYM("OR",616), T8, ecl_make_int8_t(1));
    goto L78;
L92:;
    if (!((v9param)==(VV[34]))){
     goto L94;
    }
    T8 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T8);
    T7 = VV[107];
    goto L78;
L94:;
    if (!((v9param)==(ECL_NIL))){
     goto L98;
    }
    T7 = ecl_make_int8_t(1);
    goto L78;
L98:;
    T7 = v9param;
   }
L78:;
   T8 = cl_list(2, VV[223], T7);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L107;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L107:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L115;
    }
    T10 = L527expand_next_arg(1, v8offset);
    T9 = cl_list(3, ECL_SYM("OR",616), T10, ECL_NIL);
    goto L101;
L115:;
    if (!((v9param)==(VV[34]))){
     goto L117;
    }
    T10 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T10);
    T9 = VV[107];
    goto L101;
L117:;
    if (!((v9param)==(ECL_NIL))){
     goto L121;
    }
    T9 = ECL_NIL;
    goto L101;
L121:;
    T9 = v9param;
   }
L101:;
   T10 = cl_list(2, VV[224], T9);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L130;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L130:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L138;
    }
    T12 = L527expand_next_arg(1, v8offset);
    T11 = cl_list(3, ECL_SYM("OR",616), T12, ECL_CODE_CHAR(32));
    goto L124;
L138:;
    if (!((v9param)==(VV[34]))){
     goto L140;
    }
    T12 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T12);
    T11 = VV[107];
    goto L124;
L140:;
    if (!((v9param)==(ECL_NIL))){
     goto L144;
    }
    T11 = ECL_CODE_CHAR(32);
    goto L124;
L144:;
    T11 = v9param;
   }
L124:;
   T12 = cl_list(2, VV[225], T11);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L153;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L153:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L161;
    }
    T14 = L527expand_next_arg(1, v8offset);
    T13 = cl_list(3, ECL_SYM("OR",616), T14, ECL_NIL);
    goto L147;
L161:;
    if (!((v9param)==(VV[34]))){
     goto L163;
    }
    T14 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T14);
    T13 = VV[107];
    goto L147;
L163:;
    if (!((v9param)==(ECL_NIL))){
     goto L167;
    }
    T13 = ECL_NIL;
    goto L147;
L167:;
    T13 = v9param;
   }
L147:;
   T14 = cl_list(2, VV[226], T13);
   T15 = cl_list(7, T2, T4, T6, T8, T10, T12, T14);
   if (Null(v6)){
    goto L171;
   }
   T17 = ecl_list1(ecl_make_int8_t(7));
   T18 = ecl_caar(v6);
   T16 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T17, ECL_SYM("OFFSET",1316), T18);
   goto L170;
L171:;
   T16 = ECL_NIL;
L170:;
   T17 = L527expand_next_arg(0);
   T18 = cl_list(11, VV[227], ECL_SYM("STREAM",802), T17, VV[220], VV[221], VV[222], VV[223], VV[224], VV[225], VV[226], v4);
   T19 = ecl_list1(T18);
   T20 = ecl_append(T16,T19);
   T0 = cl_listX(3, ECL_SYM("LET",479), T15, T20);
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC565latin_capital_letter_e_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[219]);
 {
  return LC565latin_capital_letter_e_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA1615                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC566__lambda1615(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v6)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[209]);
L5:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10w;
    cl_object v11d;
    cl_object v12e;
    cl_object v13k;
    cl_object v14ovf;
    cl_object v15pad;
    cl_object v16mark;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L15;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L15:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L23;
     }
     if (!(v5args==ECL_NIL)){
      goto L28;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L28:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L30;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L30:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L36;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L36:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L26;
     }
     v10w = ECL_NIL;
     goto L9;
L26:;
     v10w = value0;
     goto L9;
L23:;
     if (!((v19param)==(VV[34]))){
      goto L42;
     }
     v10w = ecl_make_fixnum(ecl_length(v5args));
     goto L9;
L42:;
     if (!((v19param)==(ECL_NIL))){
      goto L44;
     }
     v10w = ECL_NIL;
     goto L9;
L44:;
     v10w = v19param;
    }
L9:;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L53;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L53:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L61;
     }
     if (!(v5args==ECL_NIL)){
      goto L66;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L66:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L68;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L68:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L74;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L74:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L64;
     }
     v11d = ECL_NIL;
     goto L47;
L64:;
     v11d = value0;
     goto L47;
L61:;
     if (!((v19param)==(VV[34]))){
      goto L80;
     }
     v11d = ecl_make_fixnum(ecl_length(v5args));
     goto L47;
L80:;
     if (!((v19param)==(ECL_NIL))){
      goto L82;
     }
     v11d = ECL_NIL;
     goto L47;
L82:;
     v11d = v19param;
    }
L47:;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L91;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L91:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L99;
     }
     if (!(v5args==ECL_NIL)){
      goto L104;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L104:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L106;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L106:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L112;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L112:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L102;
     }
     v12e = ECL_NIL;
     goto L85;
L102:;
     v12e = value0;
     goto L85;
L99:;
     if (!((v19param)==(VV[34]))){
      goto L118;
     }
     v12e = ecl_make_fixnum(ecl_length(v5args));
     goto L85;
L118:;
     if (!((v19param)==(ECL_NIL))){
      goto L120;
     }
     v12e = ECL_NIL;
     goto L85;
L120:;
     v12e = v19param;
    }
L85:;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L129;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L129:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L137;
     }
     if (!(v5args==ECL_NIL)){
      goto L142;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L142:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L144;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L144:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L150;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L150:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L140;
     }
     v13k = ecl_make_int8_t(1);
     goto L123;
L140:;
     v13k = value0;
     goto L123;
L137:;
     if (!((v19param)==(VV[34]))){
      goto L156;
     }
     v13k = ecl_make_fixnum(ecl_length(v5args));
     goto L123;
L156:;
     if (!((v19param)==(ECL_NIL))){
      goto L158;
     }
     v13k = ecl_make_int8_t(1);
     goto L123;
L158:;
     v13k = v19param;
    }
L123:;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L167;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L167:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L175;
     }
     if (!(v5args==ECL_NIL)){
      goto L180;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L180:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L182;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L182:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L188;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L188:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L178;
     }
     v14ovf = ECL_NIL;
     goto L161;
L178:;
     v14ovf = value0;
     goto L161;
L175:;
     if (!((v19param)==(VV[34]))){
      goto L194;
     }
     v14ovf = ecl_make_fixnum(ecl_length(v5args));
     goto L161;
L194:;
     if (!((v19param)==(ECL_NIL))){
      goto L196;
     }
     v14ovf = ECL_NIL;
     goto L161;
L196:;
     v14ovf = v19param;
    }
L161:;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L205;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L205:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L213;
     }
     if (!(v5args==ECL_NIL)){
      goto L218;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L218:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L220;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L220:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L226;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L226:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L216;
     }
     v15pad = ECL_CODE_CHAR(32);
     goto L199;
L216:;
     v15pad = value0;
     goto L199;
L213:;
     if (!((v19param)==(VV[34]))){
      goto L232;
     }
     v15pad = ecl_make_fixnum(ecl_length(v5args));
     goto L199;
L232:;
     if (!((v19param)==(ECL_NIL))){
      goto L234;
     }
     v15pad = ECL_CODE_CHAR(32);
     goto L199;
L234:;
     v15pad = v19param;
    }
L199:;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L243;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L243:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L251;
     }
     if (!(v5args==ECL_NIL)){
      goto L256;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L256:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L258;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L258:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L264;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L264:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L254;
     }
     v16mark = ECL_NIL;
     goto L237;
L254:;
     v16mark = value0;
     goto L237;
L251:;
     if (!((v19param)==(VV[34]))){
      goto L270;
     }
     v16mark = ecl_make_fixnum(ecl_length(v5args));
     goto L237;
L270:;
     if (!((v19param)==(ECL_NIL))){
      goto L272;
     }
     v16mark = ECL_NIL;
     goto L237;
L272:;
     v16mark = v19param;
    }
L237:;
    if (Null(v9)){
     goto L275;
    }
    T0 = ecl_list1(ecl_make_int8_t(7));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L275:;
    if (!(v5args==ECL_NIL)){
     goto L277;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L277:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L279;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L279:;
    {
     cl_object v17;
     v17 = v5args;
     {
      cl_object v18;
      v18 = v17;
      {
       bool v19;
       v19 = ECL_LISTP(v18);
       if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v17)){
      goto L286;
     }
     {
      cl_object v18;
      v18 = ECL_CONS_CDR(v17);
      v5args = v18;
      v17 = ECL_CONS_CAR(v17);
     }
L286:;
     T0 = v17;
    }
    si_format_exponential(v1stream, T0, v10w, v11d, v12e, v13k, v14ovf, v15pad, v16mark, v7);
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC566__lambda1615_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[228]);
 {
  return LC566__lambda1615(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* function definition for FORMAT-EXPONENTIAL                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_exponential(cl_object v1stream, cl_object v2number, cl_object v3w, cl_object v4d, cl_object v5e, cl_object v6k, cl_object v7ovf, cl_object v8pad, cl_object v9marker, cl_object v10atsign)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 ecl_character v11pad;
 v11pad = ecl_char_code(v8pad);
L1:;
 if (ecl_numberp(v2number)) {
  goto L2;
 }
 value0 = si_format_princ(v1stream, v2number, ECL_NIL, ECL_NIL, v3w, ecl_make_int8_t(1), ecl_make_int8_t(0), ECL_CODE_CHAR(v11pad));
 return value0;
L2:;
 if (!(floatp(v2number))){
  goto L4;
 }
 value0 = L568format_exp_aux(v1stream, v2number, v3w, v4d, v5e, v6k, v7ovf, ECL_CODE_CHAR(v11pad), v9marker, v10atsign);
 return value0;
L4:;
 if (Null(cl_rationalp(v2number))){
  goto L6;
 }
 {
  float v12;
  v12 = ecl_to_float(v2number);
  value0 = L568format_exp_aux(v1stream, ecl_make_single_float(v12), v3w, v4d, v5e, v6k, v7ovf, ECL_CODE_CHAR(v11pad), v9marker, v10atsign);
  return value0;
 }
L6:;
 T0 = L561decimal_string(v2number);
 value0 = L535format_write_field(v1stream, T0, v3w, ecl_make_int8_t(1), ecl_make_int8_t(0), ECL_CODE_CHAR(32), ECL_T);
 return value0;
}
cl_object si_format_exponential_va(cl_narg narg, cl_object v12stream, cl_object v13number, cl_object v14w, cl_object v15d, cl_object v16e, cl_object v17k, cl_object v18ovf, cl_object v19pad, cl_object v20marker, cl_object v21atsign, ...)
{
 if (ecl_unlikely(narg!=10)) FEwrong_num_arguments(VV[227]);
 {
  return si_format_exponential(v12stream, v13number, v14w, v15d, v16e, v17k, v18ovf, v19pad, v20marker, v21atsign);
 }
}
/* function definition for FORMAT-EXPONENT-MARKER                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L567format_exponent_marker(cl_object v1number)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_typep(2, v1number, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*READ-DEFAULT-FLOAT-FORMAT*",64))))){
  goto L2;
 }
 value0 = ECL_CODE_CHAR(101);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!(ECL_SINGLE_FLOAT_P(v1number))){
  goto L4;
 }
 value0 = ECL_CODE_CHAR(102);
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 if (!(ECL_DOUBLE_FLOAT_P(v1number))){
  goto L6;
 }
 value0 = ECL_CODE_CHAR(100);
 cl_env_copy->nvalues = 1;
 return value0;
L6:;
 if (!(ECL_SINGLE_FLOAT_P(v1number))){
  goto L8;
 }
 value0 = ECL_CODE_CHAR(115);
 cl_env_copy->nvalues = 1;
 return value0;
L8:;
 if (!(ECL_LONG_FLOAT_P(v1number))){
  goto L10;
 }
 value0 = ECL_CODE_CHAR(108);
 cl_env_copy->nvalues = 1;
 return value0;
L10:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for FORMAT-EXP-AUX                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L568format_exp_aux(cl_object v1stream, cl_object v2number, cl_object v3w, cl_object v4d, cl_object v5e, cl_object v6k, cl_object v7ovf, cl_object v8pad, cl_object v9marker, cl_object v10atsign)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(floatp(v2number))){
  goto L2;
 }
 if (si_float_infinity_p(v2number)!=ECL_NIL) {
  goto L5;
 }
 if (Null(si_float_nan_p(v2number))){
  goto L2;
 }
 goto L3;
L5:;
L3:;
 value0 = (ecl_prin1(v2number,v1stream));
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 {
  cl_object v11expt;
  cl_object v12rescaled_expt;
  cl_object v13estr;
  cl_object v14elen;
  cl_object v15fdig;
  cl_object v16fmin;
  cl_object v17spaceleft;
  v11expt = L515exponent_in_base10(v2number);
  v12rescaled_expt = ecl_minus(v11expt,v6k);
  T0 = ecl_abs(v12rescaled_expt);
  v13estr = L561decimal_string(T0);
  if (Null(v5e)){
   goto L11;
  }
  {
   cl_fixnum v18;
   v18 = ecl_length(v13estr);
   v14elen = ((ecl_float_nan_p(v5e) || ecl_greatereq(ecl_make_fixnum(v18),v5e))?ecl_make_fixnum(v18):v5e);
   goto L10;
  }
L11:;
  v14elen = ecl_make_fixnum(ecl_length(v13estr));
L10:;
  if (Null(v4d)){
   goto L14;
  }
  if (!(ecl_plusp(v6k))){
   goto L16;
  }
  T0 = ecl_minus(v4d,v6k);
  v15fdig = ecl_one_plus(T0);
  goto L13;
L16:;
  v15fdig = v4d;
  goto L13;
L14:;
  v15fdig = ECL_NIL;
L13:;
  if (!(ecl_minusp(v6k))){
   goto L19;
  }
  v16fmin = ecl_minus(ecl_make_int8_t(1),v6k);
  goto L18;
L19:;
  v16fmin = ecl_make_int8_t(0);
L18:;
  if (Null(v3w)){
   goto L22;
  }
  T0 = ecl_minus(v3w,ecl_make_int8_t(2));
  T1 = ecl_minus(T0,v14elen);
  if (v10atsign!=ECL_NIL) {
   goto L27;
  }
  if (!(ecl_minusp(v2number))){
   goto L25;
  }
  goto L26;
L27:;
L26:;
  T2 = ecl_make_int8_t(1);
  goto L24;
L25:;
  T2 = ecl_make_int8_t(0);
L24:;
  v17spaceleft = ecl_minus(T1,T2);
  goto L21;
L22:;
  v17spaceleft = ECL_NIL;
L21:;
  if (Null(v3w)){
   goto L29;
  }
  if (Null(v7ovf)){
   goto L29;
  }
  if (Null(v5e)){
   goto L29;
  }
  if (!(ecl_greater(v14elen,v5e))){
   goto L29;
  }
  {
   cl_object v18i;
   v18i = ecl_make_int8_t(0);
   goto L36;
L35:;
   cl_write_char(2, v7ovf, v1stream);
   v18i = ecl_one_plus(v18i);
L36:;
   if (!(ecl_lower(v18i,v3w))){
    goto L41;
   }
   goto L35;
L41:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L29:;
  {
   cl_object v19;                                 /*  FSTR                    */
   cl_object v20;                                 /*  FLEN                    */
   cl_object v21;                                 /*  LPOINT                  */
   cl_object v22;                                 /*  TPOINT                  */
   cl_object v23;                                 /*  EXPT-AFTER-ROUNDING     */
   T0 = ecl_negate(v12rescaled_expt);
   value0 = L514flonum_to_string(5, v2number, v17spaceleft, v15fdig, T0, v16fmin);
   {
    const int v24 = cl_env_copy->nvalues;
    v19 = value0;
    cl_object v25;
    v25 = (v24<=1)? ECL_NIL : cl_env_copy->values[1];
    v20 = v25;
    v25 = (v24<=2)? ECL_NIL : cl_env_copy->values[2];
    v21 = v25;
    v25 = (v24<=3)? ECL_NIL : cl_env_copy->values[3];
    v22 = v25;
    v25 = (v24<=5)? ECL_NIL : cl_env_copy->values[5];
    v23 = v25;
   }
   if (!(!ecl_number_equalp(v23,v11expt))){
    goto L44;
   }
   v12rescaled_expt = ecl_minus(v23,v6k);
   T0 = ecl_abs(v12rescaled_expt);
   v13estr = L561decimal_string(T0);
   if (Null(v5e)){
    goto L52;
   }
   {
    cl_fixnum v24;
    v24 = ecl_length(v13estr);
    v14elen = ((ecl_float_nan_p(v5e) || ecl_greatereq(ecl_make_fixnum(v24),v5e))?ecl_make_fixnum(v24):v5e);
    goto L51;
   }
L52:;
   v14elen = ecl_make_fixnum(ecl_length(v13estr));
L51:;
   if (Null(v3w)){
    goto L56;
   }
   T0 = ecl_minus(v3w,ecl_make_int8_t(2));
   T1 = ecl_minus(T0,v14elen);
   if (v10atsign!=ECL_NIL) {
    goto L61;
   }
   if (!(ecl_minusp(v2number))){
    goto L59;
   }
   goto L60;
L61:;
L60:;
   T2 = ecl_make_int8_t(1);
   goto L58;
L59:;
   T2 = ecl_make_int8_t(0);
L58:;
   v17spaceleft = ecl_minus(T1,T2);
   goto L55;
L56:;
   v17spaceleft = ECL_NIL;
L55:;
   {
    cl_object v24;
    cl_object v25;
    cl_object v26;
    cl_object v27;
    T0 = ecl_negate(v12rescaled_expt);
    value0 = L514flonum_to_string(5, v2number, v17spaceleft, v15fdig, T0, v16fmin);
    {
     const int v28 = cl_env_copy->nvalues;
     v24 = value0;
     cl_object v29;
     v29 = (v28<=1)? ECL_NIL : cl_env_copy->values[1];
     v25 = v29;
     v29 = (v28<=2)? ECL_NIL : cl_env_copy->values[2];
     v26 = v29;
     v29 = (v28<=3)? ECL_NIL : cl_env_copy->values[3];
     v27 = v29;
    }
    v19 = v24;
    v20 = v25;
    v21 = v26;
    v22 = v27;
   }
L44:;
   if (!((v15fdig)==(ecl_make_int8_t(0)))){
    goto L72;
   }
   v22 = ECL_NIL;
L72:;
   if (Null(v3w)){
    goto L75;
   }
   v17spaceleft = ecl_minus(v17spaceleft,v20);
   if (Null(v21)){
    goto L79;
   }
   if (!(ecl_greater(v17spaceleft,ecl_make_int8_t(0)))){
    goto L81;
   }
   v17spaceleft = ecl_minus(v17spaceleft,ecl_make_int8_t(1));
   goto L79;
L81:;
   v21 = ECL_NIL;
L79:;
   if (Null(v22)){
    goto L75;
   }
   if (!(ecl_lowereq(v17spaceleft,ecl_make_int8_t(0)))){
    goto L86;
   }
   v22 = ECL_NIL;
   goto L75;
L86:;
   v17spaceleft = ecl_minus(v17spaceleft,ecl_make_int8_t(1));
L75:;
   if (Null(v3w)){
    goto L90;
   }
   if (!(ecl_lower(v17spaceleft,ecl_make_int8_t(0)))){
    goto L90;
   }
   if (Null(v7ovf)){
    goto L90;
   }
   {
    cl_object v24i;
    v24i = ecl_make_int8_t(0);
    goto L96;
L95:;
    cl_write_char(2, v7ovf, v1stream);
    v24i = ecl_one_plus(v24i);
L96:;
    if (!(ecl_lower(v24i,v3w))){
     goto L101;
    }
    goto L95;
L101:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
   }
L90:;
   if (Null(v3w)){
    goto L103;
   }
   {
    cl_object v25i;
    v25i = ecl_make_int8_t(0);
    goto L107;
L106:;
    cl_write_char(2, v8pad, v1stream);
    v25i = ecl_one_plus(v25i);
L107:;
    if (!(ecl_lower(v25i,v17spaceleft))){
     goto L112;
    }
    goto L106;
L112:;
   }
L103:;
   if (!(ecl_minusp(v2number))){
    goto L115;
   }
   cl_write_char(2, ECL_CODE_CHAR(45), v1stream);
   goto L114;
L115:;
   if (Null(v10atsign)){
    goto L114;
   }
   cl_write_char(2, ECL_CODE_CHAR(43), v1stream);
L114:;
   if (Null(v21)){
    goto L118;
   }
   cl_write_char(2, ECL_CODE_CHAR(48), v1stream);
L118:;
   cl_write_string(2, v19, v1stream);
   if (Null(v22)){
    goto L121;
   }
   cl_write_char(2, ECL_CODE_CHAR(48), v1stream);
L121:;
   if (Null(v9marker)){
    goto L125;
   }
   T0 = v9marker;
   goto L124;
L125:;
   T0 = L567format_exponent_marker(v2number);
L124:;
   cl_write_char(2, T0, v1stream);
   if (!(ecl_minusp(v12rescaled_expt))){
    goto L129;
   }
   T0 = ECL_CODE_CHAR(45);
   goto L128;
L129:;
   T0 = ECL_CODE_CHAR(43);
L128:;
   cl_write_char(2, T0, v1stream);
   if (Null(v5e)){
    goto L131;
   }
   {
    cl_object v25;
    {
     cl_fixnum v26;
     v26 = ecl_length(v13estr);
     v25 = ecl_minus(v5e,ecl_make_fixnum(v26));
    }
    {
     cl_object v26i;
     v26i = ecl_make_int8_t(0);
     goto L136;
L135:;
     cl_write_char(2, ECL_CODE_CHAR(48), v1stream);
     v26i = ecl_one_plus(v26i);
L136:;
     if (!(ecl_lower(v26i,v25))){
      goto L141;
     }
     goto L135;
L141:;
    }
   }
L131:;
   value0 = cl_write_string(2, v13estr, v1stream);
   return value0;
  }
 }
}
/* local function LATIN_CAPITAL_LETTER_G-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC569latin_capital_letter_g_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v3)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[209]);
L5:;
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L15;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L15:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L23;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ECL_NIL);
    goto L9;
L23:;
    if (!((v9param)==(VV[34]))){
     goto L25;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L9;
L25:;
    if (!((v9param)==(ECL_NIL))){
     goto L29;
    }
    T1 = ECL_NIL;
    goto L9;
L29:;
    T1 = v9param;
   }
L9:;
   T2 = cl_list(2, VV[233], T1);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L38;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L38:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L46;
    }
    T4 = L527expand_next_arg(1, v8offset);
    T3 = cl_list(3, ECL_SYM("OR",616), T4, ECL_NIL);
    goto L32;
L46:;
    if (!((v9param)==(VV[34]))){
     goto L48;
    }
    T4 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T4);
    T3 = VV[107];
    goto L32;
L48:;
    if (!((v9param)==(ECL_NIL))){
     goto L52;
    }
    T3 = ECL_NIL;
    goto L32;
L52:;
    T3 = v9param;
   }
L32:;
   T4 = cl_list(2, VV[234], T3);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L61;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L61:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L69;
    }
    T6 = L527expand_next_arg(1, v8offset);
    T5 = cl_list(3, ECL_SYM("OR",616), T6, ECL_NIL);
    goto L55;
L69:;
    if (!((v9param)==(VV[34]))){
     goto L71;
    }
    T6 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T6);
    T5 = VV[107];
    goto L55;
L71:;
    if (!((v9param)==(ECL_NIL))){
     goto L75;
    }
    T5 = ECL_NIL;
    goto L55;
L75:;
    T5 = v9param;
   }
L55:;
   T6 = cl_list(2, VV[235], T5);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L84;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L84:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L92;
    }
    T8 = L527expand_next_arg(1, v8offset);
    T7 = cl_list(3, ECL_SYM("OR",616), T8, ecl_make_int8_t(0));
    goto L78;
L92:;
    if (!((v9param)==(VV[34]))){
     goto L94;
    }
    T8 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T8);
    T7 = VV[107];
    goto L78;
L94:;
    if (!((v9param)==(ECL_NIL))){
     goto L98;
    }
    T7 = ecl_make_int8_t(0);
    goto L78;
L98:;
    T7 = v9param;
   }
L78:;
   T8 = cl_list(2, VV[236], T7);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L107;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L107:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L115;
    }
    T10 = L527expand_next_arg(1, v8offset);
    T9 = cl_list(3, ECL_SYM("OR",616), T10, ECL_NIL);
    goto L101;
L115:;
    if (!((v9param)==(VV[34]))){
     goto L117;
    }
    T10 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T10);
    T9 = VV[107];
    goto L101;
L117:;
    if (!((v9param)==(ECL_NIL))){
     goto L121;
    }
    T9 = ECL_NIL;
    goto L101;
L121:;
    T9 = v9param;
   }
L101:;
   T10 = cl_list(2, VV[237], T9);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L130;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L130:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L138;
    }
    T12 = L527expand_next_arg(1, v8offset);
    T11 = cl_list(3, ECL_SYM("OR",616), T12, ECL_CODE_CHAR(32));
    goto L124;
L138:;
    if (!((v9param)==(VV[34]))){
     goto L140;
    }
    T12 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T12);
    T11 = VV[107];
    goto L124;
L140:;
    if (!((v9param)==(ECL_NIL))){
     goto L144;
    }
    T11 = ECL_CODE_CHAR(32);
    goto L124;
L144:;
    T11 = v9param;
   }
L124:;
   T12 = cl_list(2, VV[238], T11);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L153;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L153:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L161;
    }
    T14 = L527expand_next_arg(1, v8offset);
    T13 = cl_list(3, ECL_SYM("OR",616), T14, ECL_NIL);
    goto L147;
L161:;
    if (!((v9param)==(VV[34]))){
     goto L163;
    }
    T14 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T14);
    T13 = VV[107];
    goto L147;
L163:;
    if (!((v9param)==(ECL_NIL))){
     goto L167;
    }
    T13 = ECL_NIL;
    goto L147;
L167:;
    T13 = v9param;
   }
L147:;
   T14 = cl_list(2, VV[239], T13);
   T15 = cl_list(7, T2, T4, T6, T8, T10, T12, T14);
   if (Null(v6)){
    goto L171;
   }
   T17 = ecl_list1(ecl_make_int8_t(7));
   T18 = ecl_caar(v6);
   T16 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T17, ECL_SYM("OFFSET",1316), T18);
   goto L170;
L171:;
   T16 = ECL_NIL;
L170:;
   T17 = L527expand_next_arg(0);
   T18 = cl_list(11, VV[240], ECL_SYM("STREAM",802), T17, VV[233], VV[234], VV[235], VV[236], VV[237], VV[238], VV[239], v4);
   T19 = ecl_list1(T18);
   T20 = ecl_append(T16,T19);
   T0 = cl_listX(3, ECL_SYM("LET",479), T15, T20);
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC569latin_capital_letter_g_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[232]);
 {
  return LC569latin_capital_letter_g_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA1887                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC570__lambda1887(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v6)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[209]);
L5:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10w;
    cl_object v11d;
    cl_object v12e;
    cl_object v13k;
    cl_object v14ovf;
    cl_object v15pad;
    cl_object v16mark;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L15;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L15:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L23;
     }
     if (!(v5args==ECL_NIL)){
      goto L28;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L28:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L30;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L30:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L36;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L36:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L26;
     }
     v10w = ECL_NIL;
     goto L9;
L26:;
     v10w = value0;
     goto L9;
L23:;
     if (!((v19param)==(VV[34]))){
      goto L42;
     }
     v10w = ecl_make_fixnum(ecl_length(v5args));
     goto L9;
L42:;
     if (!((v19param)==(ECL_NIL))){
      goto L44;
     }
     v10w = ECL_NIL;
     goto L9;
L44:;
     v10w = v19param;
    }
L9:;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L53;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L53:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L61;
     }
     if (!(v5args==ECL_NIL)){
      goto L66;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L66:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L68;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L68:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L74;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L74:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L64;
     }
     v11d = ECL_NIL;
     goto L47;
L64:;
     v11d = value0;
     goto L47;
L61:;
     if (!((v19param)==(VV[34]))){
      goto L80;
     }
     v11d = ecl_make_fixnum(ecl_length(v5args));
     goto L47;
L80:;
     if (!((v19param)==(ECL_NIL))){
      goto L82;
     }
     v11d = ECL_NIL;
     goto L47;
L82:;
     v11d = v19param;
    }
L47:;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L91;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L91:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L99;
     }
     if (!(v5args==ECL_NIL)){
      goto L104;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L104:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L106;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L106:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L112;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L112:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L102;
     }
     v12e = ECL_NIL;
     goto L85;
L102:;
     v12e = value0;
     goto L85;
L99:;
     if (!((v19param)==(VV[34]))){
      goto L118;
     }
     v12e = ecl_make_fixnum(ecl_length(v5args));
     goto L85;
L118:;
     if (!((v19param)==(ECL_NIL))){
      goto L120;
     }
     v12e = ECL_NIL;
     goto L85;
L120:;
     v12e = v19param;
    }
L85:;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L129;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L129:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L137;
     }
     if (!(v5args==ECL_NIL)){
      goto L142;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L142:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L144;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L144:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L150;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L150:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L140;
     }
     v13k = ecl_make_int8_t(0);
     goto L123;
L140:;
     v13k = value0;
     goto L123;
L137:;
     if (!((v19param)==(VV[34]))){
      goto L156;
     }
     v13k = ecl_make_fixnum(ecl_length(v5args));
     goto L123;
L156:;
     if (!((v19param)==(ECL_NIL))){
      goto L158;
     }
     v13k = ecl_make_int8_t(0);
     goto L123;
L158:;
     v13k = v19param;
    }
L123:;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L167;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L167:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L175;
     }
     if (!(v5args==ECL_NIL)){
      goto L180;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L180:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L182;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L182:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L188;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L188:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L178;
     }
     v14ovf = ECL_NIL;
     goto L161;
L178:;
     v14ovf = value0;
     goto L161;
L175:;
     if (!((v19param)==(VV[34]))){
      goto L194;
     }
     v14ovf = ecl_make_fixnum(ecl_length(v5args));
     goto L161;
L194:;
     if (!((v19param)==(ECL_NIL))){
      goto L196;
     }
     v14ovf = ECL_NIL;
     goto L161;
L196:;
     v14ovf = v19param;
    }
L161:;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L205;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L205:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L213;
     }
     if (!(v5args==ECL_NIL)){
      goto L218;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L218:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L220;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L220:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L226;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L226:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L216;
     }
     v15pad = ECL_CODE_CHAR(32);
     goto L199;
L216:;
     v15pad = value0;
     goto L199;
L213:;
     if (!((v19param)==(VV[34]))){
      goto L232;
     }
     v15pad = ecl_make_fixnum(ecl_length(v5args));
     goto L199;
L232:;
     if (!((v19param)==(ECL_NIL))){
      goto L234;
     }
     v15pad = ECL_CODE_CHAR(32);
     goto L199;
L234:;
     v15pad = v19param;
    }
L199:;
    {
     cl_object v17param_and_offset;
     cl_object v18offset;
     cl_object v19param;
     {
      cl_object v20;
      v20 = v9;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L243;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v9 = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L243:;
      v17param_and_offset = v20;
     }
     v18offset = ecl_car(v17param_and_offset);
     v19param = ecl_cdr(v17param_and_offset);
     if (!((v19param)==(VV[33]))){
      goto L251;
     }
     if (!(v5args==ECL_NIL)){
      goto L256;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v18offset);
L256:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L258;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L258:;
     {
      cl_object v20;
      v20 = v5args;
      {
       cl_object v21;
       v21 = v20;
       {
        bool v22;
        v22 = ECL_LISTP(v21);
        if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v20)){
       goto L264;
      }
      {
       cl_object v21;
       v21 = ECL_CONS_CDR(v20);
       v5args = v21;
       v20 = ECL_CONS_CAR(v20);
      }
L264:;
      value0 = v20;
     }
     if (value0!=ECL_NIL) {
      goto L254;
     }
     v16mark = ECL_NIL;
     goto L237;
L254:;
     v16mark = value0;
     goto L237;
L251:;
     if (!((v19param)==(VV[34]))){
      goto L270;
     }
     v16mark = ecl_make_fixnum(ecl_length(v5args));
     goto L237;
L270:;
     if (!((v19param)==(ECL_NIL))){
      goto L272;
     }
     v16mark = ECL_NIL;
     goto L237;
L272:;
     v16mark = v19param;
    }
L237:;
    if (Null(v9)){
     goto L275;
    }
    T0 = ecl_list1(ecl_make_int8_t(7));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L275:;
    if (!(v5args==ECL_NIL)){
     goto L277;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L277:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L279;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L279:;
    {
     cl_object v17;
     v17 = v5args;
     {
      cl_object v18;
      v18 = v17;
      {
       bool v19;
       v19 = ECL_LISTP(v18);
       if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v17)){
      goto L286;
     }
     {
      cl_object v18;
      v18 = ECL_CONS_CDR(v17);
      v5args = v18;
      v17 = ECL_CONS_CAR(v17);
     }
L286:;
     T0 = v17;
    }
    si_format_general(v1stream, T0, v10w, v11d, v12e, v13k, v14ovf, v15pad, v16mark, v7);
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC570__lambda1887_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[241]);
 {
  return LC570__lambda1887(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* function definition for FORMAT-GENERAL                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_general(cl_object v1stream, cl_object v2number, cl_object v3w, cl_object v4d, cl_object v5e, cl_object v6k, cl_object v7ovf, cl_object v8pad, cl_object v9marker, cl_object v10atsign)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 ecl_character v11pad;
 v11pad = ecl_char_code(v8pad);
L1:;
 if (!(ecl_numberp(v2number))){
  goto L2;
 }
 if (!(floatp(v2number))){
  goto L4;
 }
 value0 = L571format_general_aux(v1stream, v2number, v3w, v4d, v5e, v6k, v7ovf, ECL_CODE_CHAR(v11pad), v9marker, v10atsign);
 return value0;
L4:;
 if (Null(cl_rationalp(v2number))){
  goto L6;
 }
 {
  float v12;
  v12 = ecl_to_float(v2number);
  value0 = L571format_general_aux(v1stream, ecl_make_single_float(v12), v3w, v4d, v5e, v6k, v7ovf, ECL_CODE_CHAR(v11pad), v9marker, v10atsign);
  return value0;
 }
L6:;
 T0 = L561decimal_string(v2number);
 value0 = L535format_write_field(v1stream, T0, v3w, ecl_make_int8_t(1), ecl_make_int8_t(0), ECL_CODE_CHAR(32), ECL_T);
 return value0;
L2:;
 value0 = si_format_princ(v1stream, v2number, ECL_NIL, ECL_NIL, v3w, ecl_make_int8_t(1), ecl_make_int8_t(0), ECL_CODE_CHAR(v11pad));
 return value0;
}
cl_object si_format_general_va(cl_narg narg, cl_object v12stream, cl_object v13number, cl_object v14w, cl_object v15d, cl_object v16e, cl_object v17k, cl_object v18ovf, cl_object v19pad, cl_object v20marker, cl_object v21atsign, ...)
{
 if (ecl_unlikely(narg!=10)) FEwrong_num_arguments(VV[240]);
 {
  return si_format_general(v12stream, v13number, v14w, v15d, v16e, v17k, v18ovf, v19pad, v20marker, v21atsign);
 }
}
/* function definition for FORMAT-GENERAL-AUX                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L571format_general_aux(cl_object v1stream, cl_object v2number, cl_object v3w, cl_object v4d, cl_object v5e, cl_object v6k, cl_object v7ovf, cl_object v8pad, cl_object v9marker, cl_object v10atsign)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(floatp(v2number))){
  goto L2;
 }
 if (si_float_infinity_p(v2number)!=ECL_NIL) {
  goto L5;
 }
 if (Null(si_float_nan_p(v2number))){
  goto L2;
 }
 goto L3;
L5:;
L3:;
 value0 = (ecl_prin1(v2number,v1stream));
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 {
  cl_object v11n;
  v11n = L515exponent_in_base10(v2number);
  if (v4d!=ECL_NIL) {
   goto L8;
  }
  {
   cl_object v12;                                 /*  LEN                     */
   T0 = ecl_abs(v2number);
   value0 = L514flonum_to_string(1, T0);
   {
    const int v13 = cl_env_copy->nvalues;
    cl_object v14;
    v14 = (v13<=1)? ECL_NIL : cl_env_copy->values[1];
    v12 = v14;
   }
   {
    cl_object v13q;
    if (!(ecl_number_equalp(v12,ecl_make_int8_t(1)))){
     goto L12;
    }
    v13q = ecl_make_int8_t(1);
    goto L11;
L12:;
    v13q = ecl_one_minus(v12);
L11:;
    T0 = ((ecl_float_nan_p(ecl_make_int8_t(7)) || ecl_lowereq(v11n,ecl_make_int8_t(7)))?v11n:ecl_make_int8_t(7));
    v4d = ((ecl_float_nan_p(T0) || ecl_greatereq(v13q,T0))?v13q:T0);
   }
  }
L8:;
  {
   cl_object v12ee;
   cl_object v13ww;
   cl_object v14dd;
   if (Null(v5e)){
    goto L16;
   }
   v12ee = ecl_plus(v5e,ecl_make_int8_t(2));
   goto L15;
L16:;
   v12ee = ecl_make_int8_t(4);
L15:;
   if (Null(v3w)){
    goto L19;
   }
   v13ww = ecl_minus(v3w,v12ee);
   goto L18;
L19:;
   v13ww = ECL_NIL;
L18:;
   v14dd = ecl_minus(v4d,v11n);
   if (Null(cl_LE(3, ecl_make_int8_t(0), v14dd, v4d))){
    goto L22;
   }
   {
    cl_object v15char;
    if (Null(L564format_fixed_aux(v1stream, v2number, v13ww, v14dd, ecl_make_int8_t(0), v7ovf, v8pad, v10atsign))){
     goto L25;
    }
    v15char = v7ovf;
    goto L24;
L25:;
    v15char = ECL_CODE_CHAR(32);
L24:;
    {
     cl_object v16i;
     v16i = ecl_make_int8_t(0);
     goto L29;
L28:;
     cl_write_char(2, v15char, v1stream);
     v16i = ecl_one_plus(v16i);
L29:;
     if (!(ecl_lower(v16i,v12ee))){
      goto L34;
     }
     goto L28;
L34:;
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
L22:;
   value0 = v6k;
   if (value0!=ECL_NIL) {
    goto L38;
   }
   T0 = ecl_make_int8_t(1);
   goto L36;
L38:;
   T0 = value0;
   goto L36;
L36:;
   value0 = L568format_exp_aux(v1stream, v2number, v3w, v4d, v5e, T0, v7ovf, v8pad, v9marker, v10atsign);
   return value0;
  }
 }
}
/* local function DOLLAR_SIGN-FORMAT-DIRECTIVE-EXPANDER                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC572dollar_sign_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L13;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L13:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L21;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(2));
    goto L7;
L21:;
    if (!((v9param)==(VV[34]))){
     goto L23;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L7;
L23:;
    if (!((v9param)==(ECL_NIL))){
     goto L27;
    }
    T1 = ecl_make_int8_t(2);
    goto L7;
L27:;
    T1 = v9param;
   }
L7:;
   T2 = cl_list(2, VV[245], T1);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L36;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L36:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L44;
    }
    T4 = L527expand_next_arg(1, v8offset);
    T3 = cl_list(3, ECL_SYM("OR",616), T4, ecl_make_int8_t(1));
    goto L30;
L44:;
    if (!((v9param)==(VV[34]))){
     goto L46;
    }
    T4 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T4);
    T3 = VV[107];
    goto L30;
L46:;
    if (!((v9param)==(ECL_NIL))){
     goto L50;
    }
    T3 = ecl_make_int8_t(1);
    goto L30;
L50:;
    T3 = v9param;
   }
L30:;
   T4 = cl_list(2, VV[246], T3);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L59;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L59:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L67;
    }
    T6 = L527expand_next_arg(1, v8offset);
    T5 = cl_list(3, ECL_SYM("OR",616), T6, ecl_make_int8_t(0));
    goto L53;
L67:;
    if (!((v9param)==(VV[34]))){
     goto L69;
    }
    T6 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T6);
    T5 = VV[107];
    goto L53;
L69:;
    if (!((v9param)==(ECL_NIL))){
     goto L73;
    }
    T5 = ecl_make_int8_t(0);
    goto L53;
L73:;
    T5 = v9param;
   }
L53:;
   T6 = cl_list(2, VV[247], T5);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L82;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L82:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L90;
    }
    T8 = L527expand_next_arg(1, v8offset);
    T7 = cl_list(3, ECL_SYM("OR",616), T8, ECL_CODE_CHAR(32));
    goto L76;
L90:;
    if (!((v9param)==(VV[34]))){
     goto L92;
    }
    T8 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T8);
    T7 = VV[107];
    goto L76;
L92:;
    if (!((v9param)==(ECL_NIL))){
     goto L96;
    }
    T7 = ECL_CODE_CHAR(32);
    goto L76;
L96:;
    T7 = v9param;
   }
L76:;
   T8 = cl_list(2, VV[248], T7);
   T9 = cl_list(4, T2, T4, T6, T8);
   if (Null(v6)){
    goto L100;
   }
   T11 = ecl_list1(ecl_make_int8_t(4));
   T12 = ecl_caar(v6);
   T10 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T11, ECL_SYM("OFFSET",1316), T12);
   goto L99;
L100:;
   T10 = ECL_NIL;
L99:;
   T11 = L527expand_next_arg(0);
   T12 = cl_list(9, VV[249], ECL_SYM("STREAM",802), T11, VV[245], VV[246], VV[247], VV[248], v3, v4);
   T13 = ecl_list1(T12);
   T14 = ecl_append(T10,T13);
   T0 = cl_listX(3, ECL_SYM("LET",479), T9, T14);
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC572dollar_sign_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[244]);
 {
  return LC572dollar_sign_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA2080                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC573__lambda2080(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10d;
    cl_object v11n;
    cl_object v12w;
    cl_object v13pad;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L13;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L13:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L21;
     }
     if (!(v5args==ECL_NIL)){
      goto L26;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L26:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L28;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L28:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L34;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L34:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L24;
     }
     v10d = ecl_make_int8_t(2);
     goto L7;
L24:;
     v10d = value0;
     goto L7;
L21:;
     if (!((v16param)==(VV[34]))){
      goto L40;
     }
     v10d = ecl_make_fixnum(ecl_length(v5args));
     goto L7;
L40:;
     if (!((v16param)==(ECL_NIL))){
      goto L42;
     }
     v10d = ecl_make_int8_t(2);
     goto L7;
L42:;
     v10d = v16param;
    }
L7:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L51;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L51:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L59;
     }
     if (!(v5args==ECL_NIL)){
      goto L64;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L64:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L66;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L66:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L72;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L72:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L62;
     }
     v11n = ecl_make_int8_t(1);
     goto L45;
L62:;
     v11n = value0;
     goto L45;
L59:;
     if (!((v16param)==(VV[34]))){
      goto L78;
     }
     v11n = ecl_make_fixnum(ecl_length(v5args));
     goto L45;
L78:;
     if (!((v16param)==(ECL_NIL))){
      goto L80;
     }
     v11n = ecl_make_int8_t(1);
     goto L45;
L80:;
     v11n = v16param;
    }
L45:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L89;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L89:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L97;
     }
     if (!(v5args==ECL_NIL)){
      goto L102;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L102:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L104;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L104:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L110;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L110:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L100;
     }
     v12w = ecl_make_int8_t(0);
     goto L83;
L100:;
     v12w = value0;
     goto L83;
L97:;
     if (!((v16param)==(VV[34]))){
      goto L116;
     }
     v12w = ecl_make_fixnum(ecl_length(v5args));
     goto L83;
L116:;
     if (!((v16param)==(ECL_NIL))){
      goto L118;
     }
     v12w = ecl_make_int8_t(0);
     goto L83;
L118:;
     v12w = v16param;
    }
L83:;
    {
     cl_object v14param_and_offset;
     cl_object v15offset;
     cl_object v16param;
     {
      cl_object v17;
      v17 = v9;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L127;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v9 = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L127:;
      v14param_and_offset = v17;
     }
     v15offset = ecl_car(v14param_and_offset);
     v16param = ecl_cdr(v14param_and_offset);
     if (!((v16param)==(VV[33]))){
      goto L135;
     }
     if (!(v5args==ECL_NIL)){
      goto L140;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L140:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L142;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L142:;
     {
      cl_object v17;
      v17 = v5args;
      {
       cl_object v18;
       v18 = v17;
       {
        bool v19;
        v19 = ECL_LISTP(v18);
        if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v17)){
       goto L148;
      }
      {
       cl_object v18;
       v18 = ECL_CONS_CDR(v17);
       v5args = v18;
       v17 = ECL_CONS_CAR(v17);
      }
L148:;
      value0 = v17;
     }
     if (value0!=ECL_NIL) {
      goto L138;
     }
     v13pad = ECL_CODE_CHAR(32);
     goto L121;
L138:;
     v13pad = value0;
     goto L121;
L135:;
     if (!((v16param)==(VV[34]))){
      goto L154;
     }
     v13pad = ecl_make_fixnum(ecl_length(v5args));
     goto L121;
L154:;
     if (!((v16param)==(ECL_NIL))){
      goto L156;
     }
     v13pad = ECL_CODE_CHAR(32);
     goto L121;
L156:;
     v13pad = v16param;
    }
L121:;
    if (Null(v9)){
     goto L159;
    }
    T0 = ecl_list1(ecl_make_int8_t(4));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L159:;
    if (!(v5args==ECL_NIL)){
     goto L161;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L161:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L163;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L163:;
    {
     cl_object v14;
     v14 = v5args;
     {
      cl_object v15;
      v15 = v14;
      {
       bool v16;
       v16 = ECL_LISTP(v15);
       if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v14)){
      goto L170;
     }
     {
      cl_object v15;
      v15 = ECL_CONS_CDR(v14);
      v5args = v15;
      v14 = ECL_CONS_CAR(v14);
     }
L170:;
     T0 = v14;
    }
    si_format_dollars(v1stream, T0, v10d, v11n, v12w, v13pad, v6, v7);
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC573__lambda2080_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[250]);
 {
  return LC573__lambda2080(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* function definition for FORMAT-DOLLARS                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_dollars(cl_object v1stream, cl_object v2number, cl_object v3d, cl_object v4n, cl_object v5w, cl_object v6pad, cl_object v7colon, cl_object v8atsign)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 ecl_character v9pad;
 v9pad = ecl_char_code(v6pad);
L1:;
 if (Null(cl_rationalp(v2number))){
  goto L2;
 }
 v2number = ecl_make_single_float(ecl_to_float(v2number));
L2:;
 if (!(floatp(v2number))){
  goto L5;
 }
 {
  cl_object v10signstr;
  cl_object v11signlen;
  if (!(ecl_minusp(v2number))){
   goto L8;
  }
  v10signstr = VV[137];
  goto L7;
L8:;
  if (Null(v8atsign)){
   goto L10;
  }
  v10signstr = VV[138];
  goto L7;
L10:;
  v10signstr = VV[251];
L7:;
  v11signlen = ecl_make_fixnum(ecl_length(v10signstr));
  {
   cl_object v12;                                 /*  STR                     */
   cl_object v13;                                 /*  STRLEN                  */
   cl_object v14;                                 /*  POINTPLACE              */
   T0 = ecl_abs(v2number);
   value0 = L514flonum_to_string(3, T0, ECL_NIL, v3d);
   {
    const int v15 = cl_env_copy->nvalues;
    v12 = value0;
    cl_object v16;
    v16 = (v15<=1)? ECL_NIL : cl_env_copy->values[1];
    v13 = v16;
    v16 = (v15<=4)? ECL_NIL : cl_env_copy->values[4];
    v14 = v16;
   }
   if (Null(v7colon)){
    goto L14;
   }
   cl_write_string(2, v10signstr, v1stream);
L14:;
   {
    cl_object v15;
    T0 = ecl_minus(v5w,v11signlen);
    T1 = ecl_minus(v4n,v14);
    T2 = ((ecl_float_nan_p(T1) || ecl_greatereq(ecl_make_int8_t(0),T1))?ecl_make_int8_t(0):T1);
    T3 = ecl_minus(T0,T2);
    v15 = ecl_minus(T3,v13);
    {
     cl_object v16i;
     v16i = ecl_make_int8_t(0);
     goto L20;
L19:;
     cl_write_char(2, ECL_CODE_CHAR(v9pad), v1stream);
     v16i = ecl_one_plus(v16i);
L20:;
     if (!(ecl_lower(v16i,v15))){
      goto L25;
     }
     goto L19;
L25:;
    }
   }
   if (v7colon!=ECL_NIL) {
    goto L27;
   }
   cl_write_string(2, v10signstr, v1stream);
L27:;
   {
    cl_object v15;
    v15 = ecl_minus(v4n,v14);
    {
     cl_object v16i;
     v16i = ecl_make_int8_t(0);
     goto L33;
L32:;
     cl_write_char(2, ECL_CODE_CHAR(48), v1stream);
     v16i = ecl_one_plus(v16i);
L33:;
     if (!(ecl_lower(v16i,v15))){
      goto L38;
     }
     goto L32;
L38:;
    }
   }
   value0 = cl_write_string(2, v12, v1stream);
   return value0;
  }
 }
L5:;
 T0 = L561decimal_string(v2number);
 value0 = L535format_write_field(v1stream, T0, v5w, ecl_make_int8_t(1), ecl_make_int8_t(0), ECL_CODE_CHAR(32), ECL_T);
 return value0;
}
cl_object si_format_dollars_va(cl_narg narg, cl_object v12stream, cl_object v13number, cl_object v14d, cl_object v15n, cl_object v16w, cl_object v17pad, cl_object v18colon, cl_object v19atsign, ...)
{
 if (ecl_unlikely(narg!=8)) FEwrong_num_arguments(VV[249]);
 {
  return si_format_dollars(v12stream, v13number, v14d, v15n, v16w, v17pad, v18colon, v19atsign);
 }
}
/* local function PERCENT_SIGN-FORMAT-DIRECTIVE-EXPANDER                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC574percent_sign_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (v3!=ECL_NIL) {
   goto L7;
  }
  if (Null(v4)){
   goto L5;
  }
  goto L6;
L7:;
L6:;
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[254]);
L5:;
  if (Null(v5)){
   goto L10;
  }
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L19;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L19:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L27;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(1));
    goto L13;
L27:;
    if (!((v9param)==(VV[34]))){
     goto L29;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L13;
L29:;
    if (!((v9param)==(ECL_NIL))){
     goto L33;
    }
    T1 = ecl_make_int8_t(1);
    goto L13;
L33:;
    T1 = v9param;
   }
L13:;
   T2 = cl_list(2, VV[255], T1);
   T3 = ecl_list1(T2);
   if (Null(v6)){
    goto L37;
   }
   T5 = ecl_list1(ecl_make_int8_t(1));
   T6 = ecl_caar(v6);
   T4 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T5, ECL_SYM("OFFSET",1316), T6);
   goto L36;
L37:;
   T4 = ECL_NIL;
L36:;
   T5 = cl_list(2, VV[256], VV[255]);
   T6 = cl_list(3, ECL_SYM("DOTIMES",316), T5, VV[257]);
   T7 = ecl_list1(T6);
   T8 = ecl_append(T4,T7);
   T0 = cl_listX(3, ECL_SYM("LET",479), T3, T8);
   goto L9;
  }
L10:;
  T0 = VV[257];
L9:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC574percent_sign_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[253]);
 {
  return LC574percent_sign_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA2183                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC575__lambda2183(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (v6!=ECL_NIL) {
   goto L7;
  }
  if (Null(v7)){
   goto L5;
  }
  goto L6;
L7:;
L6:;
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[254]);
L5:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10count;
    {
     cl_object v11param_and_offset;
     cl_object v12offset;
     cl_object v13param;
     {
      cl_object v14;
      v14 = v9;
      {
       cl_object v15;
       v15 = v14;
       {
        bool v16;
        v16 = ECL_LISTP(v15);
        if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v14)){
       goto L17;
      }
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v14);
       v9 = v15;
       v14 = ECL_CONS_CAR(v14);
      }
L17:;
      v11param_and_offset = v14;
     }
     v12offset = ecl_car(v11param_and_offset);
     v13param = ecl_cdr(v11param_and_offset);
     if (!((v13param)==(VV[33]))){
      goto L25;
     }
     if (!(v5args==ECL_NIL)){
      goto L30;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v12offset);
L30:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L32;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L32:;
     {
      cl_object v14;
      v14 = v5args;
      {
       cl_object v15;
       v15 = v14;
       {
        bool v16;
        v16 = ECL_LISTP(v15);
        if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v14)){
       goto L38;
      }
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v14);
       v5args = v15;
       v14 = ECL_CONS_CAR(v14);
      }
L38:;
      value0 = v14;
     }
     if (value0!=ECL_NIL) {
      goto L28;
     }
     v10count = ecl_make_int8_t(1);
     goto L11;
L28:;
     v10count = value0;
     goto L11;
L25:;
     if (!((v13param)==(VV[34]))){
      goto L44;
     }
     v10count = ecl_make_fixnum(ecl_length(v5args));
     goto L11;
L44:;
     if (!((v13param)==(ECL_NIL))){
      goto L46;
     }
     v10count = ecl_make_int8_t(1);
     goto L11;
L46:;
     v10count = v13param;
    }
L11:;
    if (Null(v9)){
     goto L49;
    }
    T0 = ecl_list1(ecl_make_int8_t(1));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L49:;
    {
     cl_object v11i;
     v11i = ecl_make_int8_t(0);
     goto L53;
L52:;
     (ecl_terpri(v1stream));
     v11i = ecl_one_plus(v11i);
L53:;
     if (!(ecl_lower(v11i,v10count))){
      goto L58;
     }
     goto L52;
L58:;
    }
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC575__lambda2183_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[258]);
 {
  return LC575__lambda2183(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function AMPERSAND-FORMAT-DIRECTIVE-EXPANDER                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC576ampersand_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (v3!=ECL_NIL) {
   goto L7;
  }
  if (Null(v4)){
   goto L5;
  }
  goto L6;
L7:;
L6:;
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[254]);
L5:;
  if (Null(v5)){
   goto L10;
  }
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L19;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L19:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L27;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(1));
    goto L13;
L27:;
    if (!((v9param)==(VV[34]))){
     goto L29;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L13;
L29:;
    if (!((v9param)==(ECL_NIL))){
     goto L33;
    }
    T1 = ecl_make_int8_t(1);
    goto L13;
L33:;
    T1 = v9param;
   }
L13:;
   T2 = cl_list(2, VV[260], T1);
   T3 = ecl_list1(T2);
   if (Null(v6)){
    goto L37;
   }
   T5 = ecl_list1(ecl_make_int8_t(1));
   T6 = ecl_caar(v6);
   T4 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T5, ECL_SYM("OFFSET",1316), T6);
   goto L36;
L37:;
   T4 = ECL_NIL;
L36:;
   T5 = cl_list(2, ECL_SYM("1-",73), VV[260]);
   T6 = cl_list(2, VV[256], T5);
   T7 = cl_list(3, ECL_SYM("DOTIMES",316), T6, VV[257]);
   T8 = cl_list(3, ECL_SYM("PROGN",674), VV[261], T7);
   T9 = ecl_list1(T8);
   T10 = ecl_append(T4,T9);
   T0 = cl_listX(3, ECL_SYM("LET",479), T3, T10);
   goto L9;
  }
L10:;
  T0 = VV[261];
L9:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC576ampersand_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[259]);
 {
  return LC576ampersand_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA2233                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC577__lambda2233(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (v6!=ECL_NIL) {
   goto L7;
  }
  if (Null(v7)){
   goto L5;
  }
  goto L6;
L7:;
L6:;
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[254]);
L5:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10count;
    {
     cl_object v11param_and_offset;
     cl_object v12offset;
     cl_object v13param;
     {
      cl_object v14;
      v14 = v9;
      {
       cl_object v15;
       v15 = v14;
       {
        bool v16;
        v16 = ECL_LISTP(v15);
        if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v14)){
       goto L17;
      }
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v14);
       v9 = v15;
       v14 = ECL_CONS_CAR(v14);
      }
L17:;
      v11param_and_offset = v14;
     }
     v12offset = ecl_car(v11param_and_offset);
     v13param = ecl_cdr(v11param_and_offset);
     if (!((v13param)==(VV[33]))){
      goto L25;
     }
     if (!(v5args==ECL_NIL)){
      goto L30;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v12offset);
L30:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L32;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L32:;
     {
      cl_object v14;
      v14 = v5args;
      {
       cl_object v15;
       v15 = v14;
       {
        bool v16;
        v16 = ECL_LISTP(v15);
        if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v14)){
       goto L38;
      }
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v14);
       v5args = v15;
       v14 = ECL_CONS_CAR(v14);
      }
L38:;
      value0 = v14;
     }
     if (value0!=ECL_NIL) {
      goto L28;
     }
     v10count = ecl_make_int8_t(1);
     goto L11;
L28:;
     v10count = value0;
     goto L11;
L25:;
     if (!((v13param)==(VV[34]))){
      goto L44;
     }
     v10count = ecl_make_fixnum(ecl_length(v5args));
     goto L11;
L44:;
     if (!((v13param)==(ECL_NIL))){
      goto L46;
     }
     v10count = ecl_make_int8_t(1);
     goto L11;
L46:;
     v10count = v13param;
    }
L11:;
    if (Null(v9)){
     goto L49;
    }
    T0 = ecl_list1(ecl_make_int8_t(1));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L49:;
    cl_fresh_line(1, v1stream);
    {
     cl_object v11;
     v11 = ecl_one_minus(v10count);
     {
      cl_object v12i;
      v12i = ecl_make_int8_t(0);
      goto L55;
L54:;
      (ecl_terpri(v1stream));
      v12i = ecl_one_plus(v12i);
L55:;
      if (!(ecl_lower(v12i,v11))){
       goto L60;
      }
      goto L54;
L60:;
     }
    }
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC577__lambda2233_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[262]);
 {
  return LC577__lambda2233(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function VERTICAL_LINE-FORMAT-DIRECTIVE-EXPANDER                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC578vertical_line_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (v3!=ECL_NIL) {
   goto L7;
  }
  if (Null(v4)){
   goto L5;
  }
  goto L6;
L7:;
L6:;
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[254]);
L5:;
  if (Null(v5)){
   goto L10;
  }
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L19;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L19:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L27;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(1));
    goto L13;
L27:;
    if (!((v9param)==(VV[34]))){
     goto L29;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L13;
L29:;
    if (!((v9param)==(ECL_NIL))){
     goto L33;
    }
    T1 = ecl_make_int8_t(1);
    goto L13;
L33:;
    T1 = v9param;
   }
L13:;
   T2 = cl_list(2, VV[264], T1);
   T3 = ecl_list1(T2);
   if (Null(v6)){
    goto L37;
   }
   T5 = ecl_list1(ecl_make_int8_t(1));
   T6 = ecl_caar(v6);
   T4 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T5, ECL_SYM("OFFSET",1316), T6);
   goto L36;
L37:;
   T4 = ECL_NIL;
L36:;
   T5 = cl_list(2, VV[256], VV[264]);
   T6 = cl_list(3, ECL_SYM("DOTIMES",316), T5, VV[265]);
   T7 = ecl_list1(T6);
   T8 = ecl_append(T4,T7);
   T0 = cl_listX(3, ECL_SYM("LET",479), T3, T8);
   goto L9;
  }
L10:;
  T0 = VV[265];
L9:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC578vertical_line_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[263]);
 {
  return LC578vertical_line_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA2283                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC579__lambda2283(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (v6!=ECL_NIL) {
   goto L7;
  }
  if (Null(v7)){
   goto L5;
  }
  goto L6;
L7:;
L6:;
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[254]);
L5:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10count;
    {
     cl_object v11param_and_offset;
     cl_object v12offset;
     cl_object v13param;
     {
      cl_object v14;
      v14 = v9;
      {
       cl_object v15;
       v15 = v14;
       {
        bool v16;
        v16 = ECL_LISTP(v15);
        if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v14)){
       goto L17;
      }
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v14);
       v9 = v15;
       v14 = ECL_CONS_CAR(v14);
      }
L17:;
      v11param_and_offset = v14;
     }
     v12offset = ecl_car(v11param_and_offset);
     v13param = ecl_cdr(v11param_and_offset);
     if (!((v13param)==(VV[33]))){
      goto L25;
     }
     if (!(v5args==ECL_NIL)){
      goto L30;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v12offset);
L30:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L32;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L32:;
     {
      cl_object v14;
      v14 = v5args;
      {
       cl_object v15;
       v15 = v14;
       {
        bool v16;
        v16 = ECL_LISTP(v15);
        if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v14)){
       goto L38;
      }
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v14);
       v5args = v15;
       v14 = ECL_CONS_CAR(v14);
      }
L38:;
      value0 = v14;
     }
     if (value0!=ECL_NIL) {
      goto L28;
     }
     v10count = ecl_make_int8_t(1);
     goto L11;
L28:;
     v10count = value0;
     goto L11;
L25:;
     if (!((v13param)==(VV[34]))){
      goto L44;
     }
     v10count = ecl_make_fixnum(ecl_length(v5args));
     goto L11;
L44:;
     if (!((v13param)==(ECL_NIL))){
      goto L46;
     }
     v10count = ecl_make_int8_t(1);
     goto L11;
L46:;
     v10count = v13param;
    }
L11:;
    if (Null(v9)){
     goto L49;
    }
    T0 = ecl_list1(ecl_make_int8_t(1));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L49:;
    {
     cl_object v11i;
     v11i = ecl_make_int8_t(0);
     goto L53;
L52:;
     cl_write_char(2, ECL_CODE_CHAR(12), v1stream);
     v11i = ecl_one_plus(v11i);
L53:;
     if (!(ecl_lower(v11i,v10count))){
      goto L58;
     }
     goto L52;
L58:;
    }
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC579__lambda2283_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[266]);
 {
  return LC579__lambda2283(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function TILDE-FORMAT-DIRECTIVE-EXPANDER                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC580tilde_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (v3!=ECL_NIL) {
   goto L7;
  }
  if (Null(v4)){
   goto L5;
  }
  goto L6;
L7:;
L6:;
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[254]);
L5:;
  if (Null(v5)){
   goto L10;
  }
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L19;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L19:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L27;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(1));
    goto L13;
L27:;
    if (!((v9param)==(VV[34]))){
     goto L29;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L13;
L29:;
    if (!((v9param)==(ECL_NIL))){
     goto L33;
    }
    T1 = ecl_make_int8_t(1);
    goto L13;
L33:;
    T1 = v9param;
   }
L13:;
   T2 = cl_list(2, VV[268], T1);
   T3 = ecl_list1(T2);
   if (Null(v6)){
    goto L37;
   }
   T5 = ecl_list1(ecl_make_int8_t(1));
   T6 = ecl_caar(v6);
   T4 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T5, ECL_SYM("OFFSET",1316), T6);
   goto L36;
L37:;
   T4 = ECL_NIL;
L36:;
   T5 = cl_list(2, VV[256], VV[268]);
   T6 = cl_list(3, ECL_SYM("DOTIMES",316), T5, VV[269]);
   T7 = ecl_list1(T6);
   T8 = ecl_append(T4,T7);
   T0 = cl_listX(3, ECL_SYM("LET",479), T3, T8);
   goto L9;
  }
L10:;
  T0 = VV[269];
L9:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC580tilde_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[267]);
 {
  return LC580tilde_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA2333                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC581__lambda2333(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (v6!=ECL_NIL) {
   goto L7;
  }
  if (Null(v7)){
   goto L5;
  }
  goto L6;
L7:;
L6:;
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[254]);
L5:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10count;
    {
     cl_object v11param_and_offset;
     cl_object v12offset;
     cl_object v13param;
     {
      cl_object v14;
      v14 = v9;
      {
       cl_object v15;
       v15 = v14;
       {
        bool v16;
        v16 = ECL_LISTP(v15);
        if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v14)){
       goto L17;
      }
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v14);
       v9 = v15;
       v14 = ECL_CONS_CAR(v14);
      }
L17:;
      v11param_and_offset = v14;
     }
     v12offset = ecl_car(v11param_and_offset);
     v13param = ecl_cdr(v11param_and_offset);
     if (!((v13param)==(VV[33]))){
      goto L25;
     }
     if (!(v5args==ECL_NIL)){
      goto L30;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v12offset);
L30:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L32;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L32:;
     {
      cl_object v14;
      v14 = v5args;
      {
       cl_object v15;
       v15 = v14;
       {
        bool v16;
        v16 = ECL_LISTP(v15);
        if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v14)){
       goto L38;
      }
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v14);
       v5args = v15;
       v14 = ECL_CONS_CAR(v14);
      }
L38:;
      value0 = v14;
     }
     if (value0!=ECL_NIL) {
      goto L28;
     }
     v10count = ecl_make_int8_t(1);
     goto L11;
L28:;
     v10count = value0;
     goto L11;
L25:;
     if (!((v13param)==(VV[34]))){
      goto L44;
     }
     v10count = ecl_make_fixnum(ecl_length(v5args));
     goto L11;
L44:;
     if (!((v13param)==(ECL_NIL))){
      goto L46;
     }
     v10count = ecl_make_int8_t(1);
     goto L11;
L46:;
     v10count = v13param;
    }
L11:;
    if (Null(v9)){
     goto L49;
    }
    T0 = ecl_list1(ecl_make_int8_t(1));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L49:;
    {
     cl_object v11i;
     v11i = ecl_make_int8_t(0);
     goto L53;
L52:;
     cl_write_char(2, ECL_CODE_CHAR(126), v1stream);
     v11i = ecl_one_plus(v11i);
L53:;
     if (!(ecl_lower(v11i,v10count))){
      goto L58;
     }
     goto L52;
L58:;
    }
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC581__lambda2333_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[270]);
 {
  return LC581__lambda2333(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function Newline-FORMAT-DIRECTIVE-EXPANDER                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC582_newline_format_directive_expander_(cl_object v1, cl_object v2directives)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v3)){
   goto L5;
  }
  if (Null(v4)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[272]);
L5:;
  if (Null(v5)){
   goto L9;
  }
  T1 = ecl_caar(v5);
  cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[125], ECL_SYM("OFFSET",1316), T1);
L9:;
  if (Null(v4)){
   goto L11;
  }
  T0 = VV[273];
  goto L8;
L11:;
  T0 = ECL_NIL;
L8:;
  if (v3!=ECL_NIL) {
   goto L14;
  }
  if (Null(v2directives)){
   goto L14;
  }
  T2 = ecl_car(v2directives);
  if (Null(cl_simple_string_p(T2))){
   goto L14;
  }
  T2 = ecl_car(v2directives);
  T3 = cl_string_left_trim(VV[274], T2);
  T4 = ecl_cdr(v2directives);
  T1 = CONS(T3,T4);
  goto L13;
L14:;
  T1 = v2directives;
L13:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = T1;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC582_newline_format_directive_expander__va(cl_narg narg, cl_object v6, cl_object v7directives, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[271]);
 {
  return LC582_newline_format_directive_expander_(v6, v7directives);
 }
}
/* local function LAMBDA2366                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC583__lambda2366(cl_object v1stream, cl_object v2, cl_object v3directives, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v6)){
   goto L5;
  }
  if (Null(v7)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[272]);
L5:;
  if (Null(v8)){
   goto L9;
  }
  T0 = ecl_list1(ecl_make_int8_t(0));
  T1 = ecl_caar(v8);
  cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L9:;
  if (Null(v7)){
   goto L8;
  }
  cl_write_char(2, ECL_CODE_CHAR(10), v1stream);
L8:;
  if (v6!=ECL_NIL) {
   goto L13;
  }
  if (Null(v3directives)){
   goto L13;
  }
  T1 = ecl_car(v3directives);
  if (Null(cl_simple_string_p(T1))){
   goto L13;
  }
  T1 = ecl_car(v3directives);
  T2 = cl_string_left_trim(VV[274], T1);
  T3 = ecl_cdr(v3directives);
  T0 = CONS(T2,T3);
  goto L12;
L13:;
  T0 = v3directives;
L12:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC583__lambda2366_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11directives, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[275]);
 {
  return LC583__lambda2366(v9stream, v10, v11directives, v12orig_args, v13args);
 }
}
/* local function Return-FORMAT-DIRECTIVE-EXPANDER                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC584_return_format_directive_expander_(cl_object v1, cl_object v2directives)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v3)){
   goto L5;
  }
  if (Null(v4)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[272]);
L5:;
  if (Null(v5)){
   goto L9;
  }
  T1 = ecl_caar(v5);
  cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[125], ECL_SYM("OFFSET",1316), T1);
L9:;
  if (Null(v4)){
   goto L11;
  }
  T0 = VV[273];
  goto L8;
L11:;
  T0 = ECL_NIL;
L8:;
  if (v3!=ECL_NIL) {
   goto L14;
  }
  if (Null(v2directives)){
   goto L14;
  }
  T2 = ecl_car(v2directives);
  if (Null(cl_simple_string_p(T2))){
   goto L14;
  }
  T2 = ecl_car(v2directives);
  T3 = cl_string_left_trim(VV[274], T2);
  T4 = ecl_cdr(v2directives);
  T1 = CONS(T3,T4);
  goto L13;
L14:;
  T1 = v2directives;
L13:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = T1;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC584_return_format_directive_expander__va(cl_narg narg, cl_object v6, cl_object v7directives, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[276]);
 {
  return LC584_return_format_directive_expander_(v6, v7directives);
 }
}
/* local function LAMBDA2379                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC585__lambda2379(cl_object v1stream, cl_object v2, cl_object v3directives, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v6)){
   goto L5;
  }
  if (Null(v7)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[272]);
L5:;
  if (Null(v8)){
   goto L9;
  }
  T0 = ecl_list1(ecl_make_int8_t(0));
  T1 = ecl_caar(v8);
  cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L9:;
  if (Null(v7)){
   goto L8;
  }
  cl_write_char(2, ECL_CODE_CHAR(10), v1stream);
L8:;
  if (v6!=ECL_NIL) {
   goto L13;
  }
  if (Null(v3directives)){
   goto L13;
  }
  T1 = ecl_car(v3directives);
  if (Null(cl_simple_string_p(T1))){
   goto L13;
  }
  T1 = ecl_car(v3directives);
  T2 = cl_string_left_trim(VV[274], T1);
  T3 = ecl_cdr(v3directives);
  T0 = CONS(T2,T3);
  goto L12;
L13:;
  T0 = v3directives;
L12:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC585__lambda2379_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11directives, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[277]);
 {
  return LC585__lambda2379(v9stream, v10, v11directives, v12orig_args, v13args);
 }
}
/* local function LATIN_CAPITAL_LETTER_T-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC586latin_capital_letter_t_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v3)){
   goto L6;
  }
  L629check_output_layout_mode(ecl_make_int8_t(1));
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L16;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L16:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L24;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(1));
    goto L10;
L24:;
    if (!((v9param)==(VV[34]))){
     goto L26;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L10;
L26:;
    if (!((v9param)==(ECL_NIL))){
     goto L30;
    }
    T1 = ecl_make_int8_t(1);
    goto L10;
L30:;
    T1 = v9param;
   }
L10:;
   T2 = cl_list(2, VV[279], T1);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L39;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L39:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L47;
    }
    T4 = L527expand_next_arg(1, v8offset);
    T3 = cl_list(3, ECL_SYM("OR",616), T4, ecl_make_int8_t(1));
    goto L33;
L47:;
    if (!((v9param)==(VV[34]))){
     goto L49;
    }
    T4 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T4);
    T3 = VV[107];
    goto L33;
L49:;
    if (!((v9param)==(ECL_NIL))){
     goto L53;
    }
    T3 = ecl_make_int8_t(1);
    goto L33;
L53:;
    T3 = v9param;
   }
L33:;
   T4 = cl_list(2, VV[280], T3);
   T5 = cl_list(2, T2, T4);
   if (Null(v6)){
    goto L57;
   }
   T7 = ecl_list1(ecl_make_int8_t(2));
   T8 = ecl_caar(v6);
   T6 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T7, ECL_SYM("OFFSET",1316), T8);
   goto L56;
L57:;
   T6 = ECL_NIL;
L56:;
   if (Null(v4)){
    goto L60;
   }
   T7 = VV[281];
   goto L59;
L60:;
   T7 = VV[282];
L59:;
   T8 = cl_list(5, ECL_SYM("PPRINT-TAB",659), T7, VV[279], VV[280], ECL_SYM("STREAM",802));
   T9 = ecl_list1(T8);
   T10 = ecl_append(T6,T9);
   T0 = cl_listX(3, ECL_SYM("LET",479), T5, T10);
   goto L5;
  }
L6:;
  if (Null(v4)){
   goto L62;
  }
  {
   cl_object v7;
   v7 = v5;
   {
    cl_object v8param_and_offset;
    cl_object v9offset;
    cl_object v10param;
    {
     cl_object v11;
     v11 = v7;
     {
      cl_object v12;
      v12 = v11;
      {
       bool v13;
       v13 = ECL_LISTP(v12);
       if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(VV[106],v12);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v11)){
      goto L71;
     }
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v11);
      v7 = v12;
      v11 = ECL_CONS_CAR(v11);
     }
L71:;
     v8param_and_offset = v11;
    }
    v9offset = ecl_car(v8param_and_offset);
    v10param = ecl_cdr(v8param_and_offset);
    if (!((v10param)==(VV[33]))){
     goto L79;
    }
    T2 = L527expand_next_arg(1, v9offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(1));
    goto L65;
L79:;
    if (!((v10param)==(VV[34]))){
     goto L81;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L65;
L81:;
    if (!((v10param)==(ECL_NIL))){
     goto L85;
    }
    T1 = ecl_make_int8_t(1);
    goto L65;
L85:;
    T1 = v10param;
   }
L65:;
   T2 = cl_list(2, VV[283], T1);
   {
    cl_object v8param_and_offset;
    cl_object v9offset;
    cl_object v10param;
    {
     cl_object v11;
     v11 = v7;
     {
      cl_object v12;
      v12 = v11;
      {
       bool v13;
       v13 = ECL_LISTP(v12);
       if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(VV[106],v12);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v11)){
      goto L94;
     }
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v11);
      v7 = v12;
      v11 = ECL_CONS_CAR(v11);
     }
L94:;
     v8param_and_offset = v11;
    }
    v9offset = ecl_car(v8param_and_offset);
    v10param = ecl_cdr(v8param_and_offset);
    if (!((v10param)==(VV[33]))){
     goto L102;
    }
    T4 = L527expand_next_arg(1, v9offset);
    T3 = cl_list(3, ECL_SYM("OR",616), T4, ecl_make_int8_t(1));
    goto L88;
L102:;
    if (!((v10param)==(VV[34]))){
     goto L104;
    }
    T4 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T4);
    T3 = VV[107];
    goto L88;
L104:;
    if (!((v10param)==(ECL_NIL))){
     goto L108;
    }
    T3 = ecl_make_int8_t(1);
    goto L88;
L108:;
    T3 = v10param;
   }
L88:;
   T4 = cl_list(2, VV[284], T3);
   T5 = cl_list(2, T2, T4);
   if (Null(v7)){
    goto L112;
   }
   T7 = ecl_list1(ecl_make_int8_t(2));
   T8 = ecl_caar(v7);
   T6 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T7, ECL_SYM("OFFSET",1316), T8);
   goto L111;
L112:;
   T6 = ECL_NIL;
L111:;
   T7 = cl_list(4, VV[285], ECL_SYM("STREAM",802), VV[283], VV[284]);
   T8 = ecl_list1(T7);
   T9 = ecl_append(T6,T8);
   T0 = cl_listX(3, ECL_SYM("LET",479), T5, T9);
   goto L5;
  }
L62:;
  {
   cl_object v8;
   v8 = v5;
   {
    cl_object v9param_and_offset;
    cl_object v10offset;
    cl_object v11param;
    {
     cl_object v12;
     v12 = v8;
     {
      cl_object v13;
      v13 = v12;
      {
       bool v14;
       v14 = ECL_LISTP(v13);
       if (ecl_unlikely(!(v14)))
         FEwrong_type_argument(VV[106],v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v12)){
      goto L121;
     }
     {
      cl_object v13;
      v13 = ECL_CONS_CDR(v12);
      v8 = v13;
      v12 = ECL_CONS_CAR(v12);
     }
L121:;
     v9param_and_offset = v12;
    }
    v10offset = ecl_car(v9param_and_offset);
    v11param = ecl_cdr(v9param_and_offset);
    if (!((v11param)==(VV[33]))){
     goto L129;
    }
    T2 = L527expand_next_arg(1, v10offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(1));
    goto L115;
L129:;
    if (!((v11param)==(VV[34]))){
     goto L131;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L115;
L131:;
    if (!((v11param)==(ECL_NIL))){
     goto L135;
    }
    T1 = ecl_make_int8_t(1);
    goto L115;
L135:;
    T1 = v11param;
   }
L115:;
   T2 = cl_list(2, VV[286], T1);
   {
    cl_object v9param_and_offset;
    cl_object v10offset;
    cl_object v11param;
    {
     cl_object v12;
     v12 = v8;
     {
      cl_object v13;
      v13 = v12;
      {
       bool v14;
       v14 = ECL_LISTP(v13);
       if (ecl_unlikely(!(v14)))
         FEwrong_type_argument(VV[106],v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v12)){
      goto L144;
     }
     {
      cl_object v13;
      v13 = ECL_CONS_CDR(v12);
      v8 = v13;
      v12 = ECL_CONS_CAR(v12);
     }
L144:;
     v9param_and_offset = v12;
    }
    v10offset = ecl_car(v9param_and_offset);
    v11param = ecl_cdr(v9param_and_offset);
    if (!((v11param)==(VV[33]))){
     goto L152;
    }
    T4 = L527expand_next_arg(1, v10offset);
    T3 = cl_list(3, ECL_SYM("OR",616), T4, ecl_make_int8_t(1));
    goto L138;
L152:;
    if (!((v11param)==(VV[34]))){
     goto L154;
    }
    T4 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T4);
    T3 = VV[107];
    goto L138;
L154:;
    if (!((v11param)==(ECL_NIL))){
     goto L158;
    }
    T3 = ecl_make_int8_t(1);
    goto L138;
L158:;
    T3 = v11param;
   }
L138:;
   T4 = cl_list(2, VV[287], T3);
   T5 = cl_list(2, T2, T4);
   if (Null(v8)){
    goto L162;
   }
   T7 = ecl_list1(ecl_make_int8_t(2));
   T8 = ecl_caar(v8);
   T6 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T7, ECL_SYM("OFFSET",1316), T8);
   goto L161;
L162:;
   T6 = ECL_NIL;
L161:;
   T7 = cl_list(4, VV[288], ECL_SYM("STREAM",802), VV[286], VV[287]);
   T8 = ecl_list1(T7);
   T9 = ecl_append(T6,T8);
   T0 = cl_listX(3, ECL_SYM("LET",479), T5, T9);
  }
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC586latin_capital_letter_t_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[278]);
 {
  return LC586latin_capital_letter_t_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA2492                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC587__lambda2492(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v6)){
   goto L6;
  }
  L629check_output_layout_mode(ecl_make_int8_t(1));
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10n;
    cl_object v11m;
    {
     cl_object v12param_and_offset;
     cl_object v13offset;
     cl_object v14param;
     {
      cl_object v15;
      v15 = v9;
      {
       cl_object v16;
       v16 = v15;
       {
        bool v17;
        v17 = ECL_LISTP(v16);
        if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v15)){
       goto L16;
      }
      {
       cl_object v16;
       v16 = ECL_CONS_CDR(v15);
       v9 = v16;
       v15 = ECL_CONS_CAR(v15);
      }
L16:;
      v12param_and_offset = v15;
     }
     v13offset = ecl_car(v12param_and_offset);
     v14param = ecl_cdr(v12param_and_offset);
     if (!((v14param)==(VV[33]))){
      goto L24;
     }
     if (!(v5args==ECL_NIL)){
      goto L29;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v13offset);
L29:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L31;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L31:;
     {
      cl_object v15;
      v15 = v5args;
      {
       cl_object v16;
       v16 = v15;
       {
        bool v17;
        v17 = ECL_LISTP(v16);
        if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v15)){
       goto L37;
      }
      {
       cl_object v16;
       v16 = ECL_CONS_CDR(v15);
       v5args = v16;
       v15 = ECL_CONS_CAR(v15);
      }
L37:;
      value0 = v15;
     }
     if (value0!=ECL_NIL) {
      goto L27;
     }
     v10n = ecl_make_int8_t(1);
     goto L10;
L27:;
     v10n = value0;
     goto L10;
L24:;
     if (!((v14param)==(VV[34]))){
      goto L43;
     }
     v10n = ecl_make_fixnum(ecl_length(v5args));
     goto L10;
L43:;
     if (!((v14param)==(ECL_NIL))){
      goto L45;
     }
     v10n = ecl_make_int8_t(1);
     goto L10;
L45:;
     v10n = v14param;
    }
L10:;
    {
     cl_object v12param_and_offset;
     cl_object v13offset;
     cl_object v14param;
     {
      cl_object v15;
      v15 = v9;
      {
       cl_object v16;
       v16 = v15;
       {
        bool v17;
        v17 = ECL_LISTP(v16);
        if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v15)){
       goto L54;
      }
      {
       cl_object v16;
       v16 = ECL_CONS_CDR(v15);
       v9 = v16;
       v15 = ECL_CONS_CAR(v15);
      }
L54:;
      v12param_and_offset = v15;
     }
     v13offset = ecl_car(v12param_and_offset);
     v14param = ecl_cdr(v12param_and_offset);
     if (!((v14param)==(VV[33]))){
      goto L62;
     }
     if (!(v5args==ECL_NIL)){
      goto L67;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v13offset);
L67:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L69;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L69:;
     {
      cl_object v15;
      v15 = v5args;
      {
       cl_object v16;
       v16 = v15;
       {
        bool v17;
        v17 = ECL_LISTP(v16);
        if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v15)){
       goto L75;
      }
      {
       cl_object v16;
       v16 = ECL_CONS_CDR(v15);
       v5args = v16;
       v15 = ECL_CONS_CAR(v15);
      }
L75:;
      value0 = v15;
     }
     if (value0!=ECL_NIL) {
      goto L65;
     }
     v11m = ecl_make_int8_t(1);
     goto L48;
L65:;
     v11m = value0;
     goto L48;
L62:;
     if (!((v14param)==(VV[34]))){
      goto L81;
     }
     v11m = ecl_make_fixnum(ecl_length(v5args));
     goto L48;
L81:;
     if (!((v14param)==(ECL_NIL))){
      goto L83;
     }
     v11m = ecl_make_int8_t(1);
     goto L48;
L83:;
     v11m = v14param;
    }
L48:;
    if (Null(v9)){
     goto L86;
    }
    T0 = ecl_list1(ecl_make_int8_t(2));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L86:;
    if (Null(v7)){
     goto L89;
    }
    T0 = VV[281];
    goto L88;
L89:;
    T0 = VV[282];
L88:;
    cl_pprint_tab(4, T0, v10n, v11m, v1stream);
    goto L5;
   }
  }
L6:;
  if (Null(v7)){
   goto L91;
  }
  {
   cl_object v12;
   v12 = v8;
   {
    cl_object v13colrel;
    cl_object v14colinc;
    {
     cl_object v15param_and_offset;
     cl_object v16offset;
     cl_object v17param;
     {
      cl_object v18;
      v18 = v12;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L100;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v12 = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L100:;
      v15param_and_offset = v18;
     }
     v16offset = ecl_car(v15param_and_offset);
     v17param = ecl_cdr(v15param_and_offset);
     if (!((v17param)==(VV[33]))){
      goto L108;
     }
     if (!(v5args==ECL_NIL)){
      goto L113;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v16offset);
L113:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L115;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L115:;
     {
      cl_object v18;
      v18 = v5args;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L121;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v5args = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L121:;
      value0 = v18;
     }
     if (value0!=ECL_NIL) {
      goto L111;
     }
     v13colrel = ecl_make_int8_t(1);
     goto L94;
L111:;
     v13colrel = value0;
     goto L94;
L108:;
     if (!((v17param)==(VV[34]))){
      goto L127;
     }
     v13colrel = ecl_make_fixnum(ecl_length(v5args));
     goto L94;
L127:;
     if (!((v17param)==(ECL_NIL))){
      goto L129;
     }
     v13colrel = ecl_make_int8_t(1);
     goto L94;
L129:;
     v13colrel = v17param;
    }
L94:;
    {
     cl_object v15param_and_offset;
     cl_object v16offset;
     cl_object v17param;
     {
      cl_object v18;
      v18 = v12;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L138;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v12 = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L138:;
      v15param_and_offset = v18;
     }
     v16offset = ecl_car(v15param_and_offset);
     v17param = ecl_cdr(v15param_and_offset);
     if (!((v17param)==(VV[33]))){
      goto L146;
     }
     if (!(v5args==ECL_NIL)){
      goto L151;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v16offset);
L151:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L153;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L153:;
     {
      cl_object v18;
      v18 = v5args;
      {
       cl_object v19;
       v19 = v18;
       {
        bool v20;
        v20 = ECL_LISTP(v19);
        if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(VV[106],v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v18)){
       goto L159;
      }
      {
       cl_object v19;
       v19 = ECL_CONS_CDR(v18);
       v5args = v19;
       v18 = ECL_CONS_CAR(v18);
      }
L159:;
      value0 = v18;
     }
     if (value0!=ECL_NIL) {
      goto L149;
     }
     v14colinc = ecl_make_int8_t(1);
     goto L132;
L149:;
     v14colinc = value0;
     goto L132;
L146:;
     if (!((v17param)==(VV[34]))){
      goto L165;
     }
     v14colinc = ecl_make_fixnum(ecl_length(v5args));
     goto L132;
L165:;
     if (!((v17param)==(ECL_NIL))){
      goto L167;
     }
     v14colinc = ecl_make_int8_t(1);
     goto L132;
L167:;
     v14colinc = v17param;
    }
L132:;
    if (Null(v12)){
     goto L170;
    }
    T0 = ecl_list1(ecl_make_int8_t(2));
    T1 = ecl_caar(v12);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L170:;
    si_format_relative_tab(v1stream, v13colrel, v14colinc);
    goto L5;
   }
  }
L91:;
  {
   cl_object v15;
   v15 = v8;
   {
    cl_object v16colnum;
    cl_object v17colinc;
    {
     cl_object v18param_and_offset;
     cl_object v19offset;
     cl_object v20param;
     {
      cl_object v21;
      v21 = v15;
      {
       cl_object v22;
       v22 = v21;
       {
        bool v23;
        v23 = ECL_LISTP(v22);
        if (ecl_unlikely(!(v23)))
         FEwrong_type_argument(VV[106],v22);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v21)){
       goto L179;
      }
      {
       cl_object v22;
       v22 = ECL_CONS_CDR(v21);
       v15 = v22;
       v21 = ECL_CONS_CAR(v21);
      }
L179:;
      v18param_and_offset = v21;
     }
     v19offset = ecl_car(v18param_and_offset);
     v20param = ecl_cdr(v18param_and_offset);
     if (!((v20param)==(VV[33]))){
      goto L187;
     }
     if (!(v5args==ECL_NIL)){
      goto L192;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v19offset);
L192:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L194;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L194:;
     {
      cl_object v21;
      v21 = v5args;
      {
       cl_object v22;
       v22 = v21;
       {
        bool v23;
        v23 = ECL_LISTP(v22);
        if (ecl_unlikely(!(v23)))
         FEwrong_type_argument(VV[106],v22);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v21)){
       goto L200;
      }
      {
       cl_object v22;
       v22 = ECL_CONS_CDR(v21);
       v5args = v22;
       v21 = ECL_CONS_CAR(v21);
      }
L200:;
      value0 = v21;
     }
     if (value0!=ECL_NIL) {
      goto L190;
     }
     v16colnum = ecl_make_int8_t(1);
     goto L173;
L190:;
     v16colnum = value0;
     goto L173;
L187:;
     if (!((v20param)==(VV[34]))){
      goto L206;
     }
     v16colnum = ecl_make_fixnum(ecl_length(v5args));
     goto L173;
L206:;
     if (!((v20param)==(ECL_NIL))){
      goto L208;
     }
     v16colnum = ecl_make_int8_t(1);
     goto L173;
L208:;
     v16colnum = v20param;
    }
L173:;
    {
     cl_object v18param_and_offset;
     cl_object v19offset;
     cl_object v20param;
     {
      cl_object v21;
      v21 = v15;
      {
       cl_object v22;
       v22 = v21;
       {
        bool v23;
        v23 = ECL_LISTP(v22);
        if (ecl_unlikely(!(v23)))
         FEwrong_type_argument(VV[106],v22);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v21)){
       goto L217;
      }
      {
       cl_object v22;
       v22 = ECL_CONS_CDR(v21);
       v15 = v22;
       v21 = ECL_CONS_CAR(v21);
      }
L217:;
      v18param_and_offset = v21;
     }
     v19offset = ecl_car(v18param_and_offset);
     v20param = ecl_cdr(v18param_and_offset);
     if (!((v20param)==(VV[33]))){
      goto L225;
     }
     if (!(v5args==ECL_NIL)){
      goto L230;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v19offset);
L230:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L232;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L232:;
     {
      cl_object v21;
      v21 = v5args;
      {
       cl_object v22;
       v22 = v21;
       {
        bool v23;
        v23 = ECL_LISTP(v22);
        if (ecl_unlikely(!(v23)))
         FEwrong_type_argument(VV[106],v22);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v21)){
       goto L238;
      }
      {
       cl_object v22;
       v22 = ECL_CONS_CDR(v21);
       v5args = v22;
       v21 = ECL_CONS_CAR(v21);
      }
L238:;
      value0 = v21;
     }
     if (value0!=ECL_NIL) {
      goto L228;
     }
     v17colinc = ecl_make_int8_t(1);
     goto L211;
L228:;
     v17colinc = value0;
     goto L211;
L225:;
     if (!((v20param)==(VV[34]))){
      goto L244;
     }
     v17colinc = ecl_make_fixnum(ecl_length(v5args));
     goto L211;
L244:;
     if (!((v20param)==(ECL_NIL))){
      goto L246;
     }
     v17colinc = ecl_make_int8_t(1);
     goto L211;
L246:;
     v17colinc = v20param;
    }
L211:;
    if (Null(v15)){
     goto L249;
    }
    T0 = ecl_list1(ecl_make_int8_t(2));
    T1 = ecl_caar(v15);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L249:;
    si_format_absolute_tab(v1stream, v16colnum, v17colinc);
   }
  }
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC587__lambda2492_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[289]);
 {
  return LC587__lambda2492(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* function definition for OUTPUT-SPACES                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L588output_spaces(cl_object v1stream, cl_object v2n)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
L3:;
 {
  cl_fixnum v3;
  v3 = ecl_length(VV[291]);
  if (!(ecl_lower(v2n,ecl_make_fixnum(v3)))){
   goto L5;
  }
 }
 goto L2;
L5:;
 cl_write_string(2, VV[291], v1stream);
 {
  cl_object v3;
  v3 = ecl_make_fixnum(ecl_length(VV[291]));
  v2n = ecl_minus(v2n,v3);
 }
 goto L3;
L2:;
 value0 = cl_write_string(4, VV[291], v1stream, ECL_SYM("END",1256), v2n);
 return value0;
}
/* function definition for FORMAT-RELATIVE-TAB                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_relative_tab(cl_object v1stream, cl_object v2colrel, cl_object v3colinc)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=(VV[292]->symbol.gfdef))->cfun.entry(1, v1stream) /*  PRETTY-STREAM-P */)){
  goto L2;
 }
 value0 = cl_pprint_tab(4, VV[293], v2colrel, v3colinc, v1stream);
 return value0;
L2:;
 {
  cl_object v4cur;
  cl_object v5spaces;
  v4cur = si_file_column(v1stream);
  if (Null(v4cur)){
   goto L6;
  }
  if (!(ecl_plusp(v3colinc))){
   goto L6;
  }
  T0 = ecl_plus(v4cur,v2colrel);
  T1 = ecl_ceiling2(T0,v3colinc);
  T2 = ecl_times(T1,v3colinc);
  v5spaces = ecl_minus(T2,v4cur);
  goto L5;
L6:;
  v5spaces = v2colrel;
L5:;
  value0 = L588output_spaces(v1stream, v5spaces);
  return value0;
 }
}
cl_object si_format_relative_tab_va(cl_narg narg, cl_object v6stream, cl_object v7colrel, cl_object v8colinc, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[285]);
 {
  return si_format_relative_tab(v6stream, v7colrel, v8colinc);
 }
}
/* function definition for FORMAT-ABSOLUTE-TAB                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_absolute_tab(cl_object v1stream, cl_object v2colnum, cl_object v3colinc)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=(VV[292]->symbol.gfdef))->cfun.entry(1, v1stream) /*  PRETTY-STREAM-P */)){
  goto L2;
 }
 value0 = cl_pprint_tab(4, ECL_SYM("LINE",1677), v2colnum, v3colinc, v1stream);
 return value0;
L2:;
 {
  cl_object v4cur;
  v4cur = si_file_column(v1stream);
  if (!(v4cur==ECL_NIL)){
   goto L5;
  }
  value0 = cl_write_string(2, VV[295], v1stream);
  return value0;
L5:;
  if (!(ecl_lower(v4cur,v2colnum))){
   goto L7;
  }
  T0 = ecl_minus(v2colnum,v4cur);
  value0 = L588output_spaces(v1stream, T0);
  return value0;
L7:;
  if (ecl_zerop(v3colinc)) {
   goto L9;
  }
  T0 = ecl_minus(v4cur,v2colnum);
  T1 = (ecl_truncate2(T0,v3colinc),cl_env_copy->values[1]);
  T2 = ecl_minus(v3colinc,T1);
  value0 = L588output_spaces(v1stream, T2);
  return value0;
L9:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
cl_object si_format_absolute_tab_va(cl_narg narg, cl_object v5stream, cl_object v6colnum, cl_object v7colinc, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[288]);
 {
  return si_format_absolute_tab(v5stream, v6colnum, v7colinc);
 }
}
/* local function LOW_LINE-FORMAT-DIRECTIVE-EXPANDER                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC589low_line_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  L629check_output_layout_mode(ecl_make_int8_t(1));
  if (Null(v5)){
   goto L7;
  }
  T1 = ecl_caar(v5);
  cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[125], ECL_SYM("OFFSET",1316), T1);
L7:;
  if (Null(v3)){
   goto L10;
  }
  if (Null(v4)){
   goto L12;
  }
  T1 = VV[298];
  goto L9;
L12:;
  T1 = VV[299];
  goto L9;
L10:;
  if (Null(v4)){
   goto L14;
  }
  T1 = VV[300];
  goto L9;
L14:;
  T1 = VV[301];
L9:;
  T0 = cl_list(3, ECL_SYM("PPRINT-NEWLINE",657), T1, ECL_SYM("STREAM",802));
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC589low_line_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[297]);
 {
  return LC589low_line_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA2605                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC590__lambda2605(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  L629check_output_layout_mode(ecl_make_int8_t(1));
  if (Null(v8)){
   goto L7;
  }
  T0 = ecl_list1(ecl_make_int8_t(0));
  T1 = ecl_caar(v8);
  cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L7:;
  if (Null(v6)){
   goto L10;
  }
  if (Null(v7)){
   goto L12;
  }
  T0 = VV[298];
  goto L9;
L12:;
  T0 = VV[299];
  goto L9;
L10:;
  if (Null(v7)){
   goto L14;
  }
  T0 = VV[300];
  goto L9;
L14:;
  T0 = VV[301];
L9:;
  cl_pprint_newline(2, T0, v1stream);
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC590__lambda2605_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[302]);
 {
  return LC590__lambda2605(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function LATIN_CAPITAL_LETTER_I-FORMAT-DIRECTIVE-EXPANDER            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC591latin_capital_letter_i_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  L629check_output_layout_mode(ecl_make_int8_t(1));
  if (Null(v4)){
   goto L6;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[304]);
L6:;
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L16;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L16:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L24;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(0));
    goto L10;
L24:;
    if (!((v9param)==(VV[34]))){
     goto L26;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L10;
L26:;
    if (!((v9param)==(ECL_NIL))){
     goto L30;
    }
    T1 = ecl_make_int8_t(0);
    goto L10;
L30:;
    T1 = v9param;
   }
L10:;
   T2 = cl_list(2, VV[305], T1);
   T3 = ecl_list1(T2);
   if (Null(v6)){
    goto L34;
   }
   T5 = ecl_list1(ecl_make_int8_t(1));
   T6 = ecl_caar(v6);
   T4 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T5, ECL_SYM("OFFSET",1316), T6);
   goto L33;
L34:;
   T4 = ECL_NIL;
L33:;
   if (Null(v3)){
    goto L37;
   }
   T5 = VV[306];
   goto L36;
L37:;
   T5 = ECL_SYM("BLOCK",1232);
L36:;
   T6 = cl_list(4, ECL_SYM("PPRINT-INDENT",654), T5, VV[305], ECL_SYM("STREAM",802));
   T7 = ecl_list1(T6);
   T8 = ecl_append(T4,T7);
   T0 = cl_listX(3, ECL_SYM("LET",479), T3, T8);
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC591latin_capital_letter_i_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[303]);
 {
  return LC591latin_capital_letter_i_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA2635                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC592__lambda2635(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  L629check_output_layout_mode(ecl_make_int8_t(1));
  if (Null(v7)){
   goto L6;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[304]);
L6:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10n;
    {
     cl_object v11param_and_offset;
     cl_object v12offset;
     cl_object v13param;
     {
      cl_object v14;
      v14 = v9;
      {
       cl_object v15;
       v15 = v14;
       {
        bool v16;
        v16 = ECL_LISTP(v15);
        if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v14)){
       goto L16;
      }
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v14);
       v9 = v15;
       v14 = ECL_CONS_CAR(v14);
      }
L16:;
      v11param_and_offset = v14;
     }
     v12offset = ecl_car(v11param_and_offset);
     v13param = ecl_cdr(v11param_and_offset);
     if (!((v13param)==(VV[33]))){
      goto L24;
     }
     if (!(v5args==ECL_NIL)){
      goto L29;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v12offset);
L29:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L31;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L31:;
     {
      cl_object v14;
      v14 = v5args;
      {
       cl_object v15;
       v15 = v14;
       {
        bool v16;
        v16 = ECL_LISTP(v15);
        if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v14)){
       goto L37;
      }
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v14);
       v5args = v15;
       v14 = ECL_CONS_CAR(v14);
      }
L37:;
      value0 = v14;
     }
     if (value0!=ECL_NIL) {
      goto L27;
     }
     v10n = ecl_make_int8_t(0);
     goto L10;
L27:;
     v10n = value0;
     goto L10;
L24:;
     if (!((v13param)==(VV[34]))){
      goto L43;
     }
     v10n = ecl_make_fixnum(ecl_length(v5args));
     goto L10;
L43:;
     if (!((v13param)==(ECL_NIL))){
      goto L45;
     }
     v10n = ecl_make_int8_t(0);
     goto L10;
L45:;
     v10n = v13param;
    }
L10:;
    if (Null(v9)){
     goto L48;
    }
    T0 = ecl_list1(ecl_make_int8_t(1));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L48:;
    if (Null(v6)){
     goto L51;
    }
    T0 = VV[306];
    goto L50;
L51:;
    T0 = ECL_SYM("BLOCK",1232);
L50:;
    cl_pprint_indent(3, T0, v10n, v1stream);
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC592__lambda2635_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[307]);
 {
  return LC592__lambda2635(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function ASTERISK-FORMAT-DIRECTIVE-EXPANDER                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC593asterisk_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  v6 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-END */;
  if (Null(v4)){
   goto L7;
  }
  if (Null(v3)){
   goto L9;
  }
  T0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[309]);
  goto L6;
L9:;
  {
   cl_object v7;
   v7 = v5;
   {
    cl_object v8param_and_offset;
    cl_object v9offset;
    cl_object v10param;
    {
     cl_object v11;
     v11 = v7;
     {
      cl_object v12;
      v12 = v11;
      {
       bool v13;
       v13 = ECL_LISTP(v12);
       if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(VV[106],v12);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v11)){
      goto L18;
     }
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v11);
      v7 = v12;
      v11 = ECL_CONS_CAR(v11);
     }
L18:;
     v8param_and_offset = v11;
    }
    v9offset = ecl_car(v8param_and_offset);
    v10param = ecl_cdr(v8param_and_offset);
    if (!((v10param)==(VV[33]))){
     goto L26;
    }
    T2 = L527expand_next_arg(1, v9offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(0));
    goto L12;
L26:;
    if (!((v10param)==(VV[34]))){
     goto L28;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L12;
L28:;
    if (!((v10param)==(ECL_NIL))){
     goto L32;
    }
    T1 = ecl_make_int8_t(0);
    goto L12;
L32:;
    T1 = v10param;
   }
L12:;
   T2 = cl_list(2, VV[310], T1);
   T3 = ecl_list1(T2);
   if (Null(v7)){
    goto L36;
   }
   T5 = ecl_list1(ecl_make_int8_t(1));
   T6 = ecl_caar(v7);
   T4 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T5, ECL_SYM("OFFSET",1316), T6);
   goto L35;
L36:;
   T4 = ECL_NIL;
L35:;
   if (ecl_cmp_symbol_value(cl_env_copy,VV[48])!=ECL_NIL) {
    goto L39;
   }
   cl_env_copy->values[0] = ECL_NIL;
   cl_env_copy->nvalues = 1;
   cl_throw(VV[62]);
L39:;
   T5 = ECL_NIL;
   T6 = cl_list(4, ECL_SYM("<=",75), ecl_make_int8_t(0), VV[310], VV[311]);
   T7 = cl_list(3, ECL_SYM("NTHCDR",606), VV[310], VV[312]);
   T8 = cl_list(3, ECL_SYM("SETF",753), VV[67], T7);
   T9 = cl_list(3, ECL_SYM("LIST",483), VV[310], VV[311]);
   T10 = ecl_one_minus(v6);
   T11 = cl_list(8, ECL_SYM("ERROR",339), VV[64], VV[29], VV[313], VV[110], T9, ECL_SYM("OFFSET",1316), T10);
   T12 = cl_list(4, ECL_SYM("IF",950), T6, T8, T11);
   T13 = cl_list(2, T5, T12);
   T14 = ecl_append(T4,T13);
   T0 = cl_listX(3, ECL_SYM("LET",479), T3, T14);
   goto L6;
  }
L7:;
  if (Null(v3)){
   goto L42;
  }
  {
   cl_object v8;
   v8 = v5;
   {
    cl_object v9param_and_offset;
    cl_object v10offset;
    cl_object v11param;
    {
     cl_object v12;
     v12 = v8;
     {
      cl_object v13;
      v13 = v12;
      {
       bool v14;
       v14 = ECL_LISTP(v13);
       if (ecl_unlikely(!(v14)))
         FEwrong_type_argument(VV[106],v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v12)){
      goto L51;
     }
     {
      cl_object v13;
      v13 = ECL_CONS_CDR(v12);
      v8 = v13;
      v12 = ECL_CONS_CAR(v12);
     }
L51:;
     v9param_and_offset = v12;
    }
    v10offset = ecl_car(v9param_and_offset);
    v11param = ecl_cdr(v9param_and_offset);
    if (!((v11param)==(VV[33]))){
     goto L59;
    }
    T2 = L527expand_next_arg(1, v10offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(1));
    goto L45;
L59:;
    if (!((v11param)==(VV[34]))){
     goto L61;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L45;
L61:;
    if (!((v11param)==(ECL_NIL))){
     goto L65;
    }
    T1 = ecl_make_int8_t(1);
    goto L45;
L65:;
    T1 = v11param;
   }
L45:;
   T2 = cl_list(2, VV[314], T1);
   T3 = ecl_list1(T2);
   if (Null(v8)){
    goto L69;
   }
   T5 = ecl_list1(ecl_make_int8_t(1));
   T6 = ecl_caar(v8);
   T4 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T5, ECL_SYM("OFFSET",1316), T6);
   goto L68;
L69:;
   T4 = ECL_NIL;
L68:;
   if (ecl_cmp_symbol_value(cl_env_copy,VV[48])!=ECL_NIL) {
    goto L72;
   }
   cl_env_copy->values[0] = ECL_NIL;
   cl_env_copy->nvalues = 1;
   cl_throw(VV[62]);
L72:;
   T5 = ECL_NIL;
   T6 = cl_list(3, ECL_SYM("-",19), VV[318], VV[314]);
   T7 = cl_list(2, VV[317], T6);
   T8 = ecl_list1(T7);
   T9 = ecl_one_minus(v6);
   T10 = cl_list(8, ECL_SYM("ERROR",339), VV[64], VV[29], VV[321], VV[110], VV[322], ECL_SYM("OFFSET",1316), T9);
   T11 = cl_list(4, ECL_SYM("IF",950), VV[319], VV[320], T10);
   T12 = cl_list(3, ECL_SYM("LET",479), T8, T11);
   T13 = cl_list(2, VV[316], T12);
   T14 = cl_list(3, ECL_SYM("DO",309), VV[315], T13);
   T15 = cl_list(2, T5, T14);
   T16 = ecl_append(T4,T15);
   T0 = cl_listX(3, ECL_SYM("LET",479), T3, T16);
   goto L6;
  }
L42:;
  if (Null(v5)){
   goto L75;
  }
  {
   cl_object v9;
   v9 = v5;
   {
    cl_object v10param_and_offset;
    cl_object v11offset;
    cl_object v12param;
    {
     cl_object v13;
     v13 = v9;
     {
      cl_object v14;
      v14 = v13;
      {
       bool v15;
       v15 = ECL_LISTP(v14);
       if (ecl_unlikely(!(v15)))
         FEwrong_type_argument(VV[106],v14);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v13)){
      goto L84;
     }
     {
      cl_object v14;
      v14 = ECL_CONS_CDR(v13);
      v9 = v14;
      v13 = ECL_CONS_CAR(v13);
     }
L84:;
     v10param_and_offset = v13;
    }
    v11offset = ecl_car(v10param_and_offset);
    v12param = ecl_cdr(v10param_and_offset);
    if (!((v12param)==(VV[33]))){
     goto L92;
    }
    T2 = L527expand_next_arg(1, v11offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ecl_make_int8_t(1));
    goto L78;
L92:;
    if (!((v12param)==(VV[34]))){
     goto L94;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L78;
L94:;
    if (!((v12param)==(ECL_NIL))){
     goto L98;
    }
    T1 = ecl_make_int8_t(1);
    goto L78;
L98:;
    T1 = v12param;
   }
L78:;
   T2 = cl_list(2, VV[323], T1);
   T3 = ecl_list1(T2);
   if (Null(v9)){
    goto L102;
   }
   T5 = ecl_list1(ecl_make_int8_t(1));
   T6 = ecl_caar(v9);
   T4 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T5, ECL_SYM("OFFSET",1316), T6);
   goto L101;
L102:;
   T4 = ECL_NIL;
L101:;
   T5 = ECL_NIL;
   ecl_cmp_setq(cl_env_copy,VV[47],T5);
   T5 = cl_list(2, VV[256], VV[323]);
   T6 = L527expand_next_arg(0);
   T7 = cl_list(3, ECL_SYM("DOTIMES",316), T5, T6);
   T8 = cl_list(2, ECL_NIL, T7);
   T9 = ecl_append(T4,T8);
   T0 = cl_listX(3, ECL_SYM("LET",479), T3, T9);
   goto L6;
  }
L75:;
  T0 = L527expand_next_arg(0);
L6:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC593asterisk_format_directive_expander_va(cl_narg narg, cl_object v7, cl_object v8, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[308]);
 {
  return LC593asterisk_format_directive_expander(v7, v8);
 }
}
/* local function LAMBDA2714                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC594__lambda2714(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v7)){
   goto L6;
  }
  if (Null(v6)){
   goto L8;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[309]);
  goto L5;
L8:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10posn;
    {
     cl_object v11param_and_offset;
     cl_object v12offset;
     cl_object v13param;
     {
      cl_object v14;
      v14 = v9;
      {
       cl_object v15;
       v15 = v14;
       {
        bool v16;
        v16 = ECL_LISTP(v15);
        if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v14)){
       goto L17;
      }
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v14);
       v9 = v15;
       v14 = ECL_CONS_CAR(v14);
      }
L17:;
      v11param_and_offset = v14;
     }
     v12offset = ecl_car(v11param_and_offset);
     v13param = ecl_cdr(v11param_and_offset);
     if (!((v13param)==(VV[33]))){
      goto L25;
     }
     if (!(v5args==ECL_NIL)){
      goto L30;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v12offset);
L30:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L32;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L32:;
     {
      cl_object v14;
      v14 = v5args;
      {
       cl_object v15;
       v15 = v14;
       {
        bool v16;
        v16 = ECL_LISTP(v15);
        if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v14)){
       goto L38;
      }
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v14);
       v5args = v15;
       v14 = ECL_CONS_CAR(v14);
      }
L38:;
      value0 = v14;
     }
     if (value0!=ECL_NIL) {
      goto L28;
     }
     v10posn = ecl_make_int8_t(0);
     goto L11;
L28:;
     v10posn = value0;
     goto L11;
L25:;
     if (!((v13param)==(VV[34]))){
      goto L44;
     }
     v10posn = ecl_make_fixnum(ecl_length(v5args));
     goto L11;
L44:;
     if (!((v13param)==(ECL_NIL))){
      goto L46;
     }
     v10posn = ecl_make_int8_t(0);
     goto L11;
L46:;
     v10posn = v13param;
    }
L11:;
    if (Null(v9)){
     goto L49;
    }
    T0 = ecl_list1(ecl_make_int8_t(1));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L49:;
    {
     cl_fixnum v11;
     v11 = ecl_length(v4orig_args);
     if (Null(cl_LE(3, ecl_make_int8_t(0), v10posn, ecl_make_fixnum(v11)))){
      goto L51;
     }
    }
    v5args = ecl_nthcdr(ecl_to_size(v10posn),v4orig_args);
    goto L5;
L51:;
    {
     cl_fixnum v11;
     v11 = ecl_length(v4orig_args);
     T0 = cl_list(2, v10posn, ecl_make_fixnum(v11));
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[325], VV[110], T0);
     goto L5;
    }
   }
  }
L6:;
  if (Null(v6)){
   goto L54;
  }
  {
   cl_object v11;
   v11 = v8;
   {
    cl_object v12n;
    {
     cl_object v13param_and_offset;
     cl_object v14offset;
     cl_object v15param;
     {
      cl_object v16;
      v16 = v11;
      {
       cl_object v17;
       v17 = v16;
       {
        bool v18;
        v18 = ECL_LISTP(v17);
        if (ecl_unlikely(!(v18)))
         FEwrong_type_argument(VV[106],v17);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v16)){
       goto L63;
      }
      {
       cl_object v17;
       v17 = ECL_CONS_CDR(v16);
       v11 = v17;
       v16 = ECL_CONS_CAR(v16);
      }
L63:;
      v13param_and_offset = v16;
     }
     v14offset = ecl_car(v13param_and_offset);
     v15param = ecl_cdr(v13param_and_offset);
     if (!((v15param)==(VV[33]))){
      goto L71;
     }
     if (!(v5args==ECL_NIL)){
      goto L76;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v14offset);
L76:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L78;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L78:;
     {
      cl_object v16;
      v16 = v5args;
      {
       cl_object v17;
       v17 = v16;
       {
        bool v18;
        v18 = ECL_LISTP(v17);
        if (ecl_unlikely(!(v18)))
         FEwrong_type_argument(VV[106],v17);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v16)){
       goto L84;
      }
      {
       cl_object v17;
       v17 = ECL_CONS_CDR(v16);
       v5args = v17;
       v16 = ECL_CONS_CAR(v16);
      }
L84:;
      value0 = v16;
     }
     if (value0!=ECL_NIL) {
      goto L74;
     }
     v12n = ecl_make_int8_t(1);
     goto L57;
L74:;
     v12n = value0;
     goto L57;
L71:;
     if (!((v15param)==(VV[34]))){
      goto L90;
     }
     v12n = ecl_make_fixnum(ecl_length(v5args));
     goto L57;
L90:;
     if (!((v15param)==(ECL_NIL))){
      goto L92;
     }
     v12n = ecl_make_int8_t(1);
     goto L57;
L92:;
     v12n = v15param;
    }
L57:;
    if (Null(v11)){
     goto L95;
    }
    T0 = ecl_list1(ecl_make_int8_t(1));
    T1 = ecl_caar(v11);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L95:;
    {
     cl_object v13cur_posn;
     cl_object v14arg_ptr;
     v13cur_posn = ecl_make_int8_t(0);
     v14arg_ptr = v4orig_args;
     goto L101;
L100:;
     v13cur_posn = ecl_one_plus(v13cur_posn);
     v14arg_ptr = ecl_cdr(v14arg_ptr);
L101:;
     if ((v14arg_ptr)==(v5args)) {
      goto L106;
     }
     goto L100;
L106:;
     {
      cl_object v15new_posn;
      v15new_posn = ecl_minus(v13cur_posn,v12n);
      {
       cl_fixnum v16;
       v16 = ecl_length(v4orig_args);
       if (Null(cl_LE(3, ecl_make_int8_t(0), v15new_posn, ecl_make_fixnum(v16)))){
        goto L109;
       }
      }
      v5args = ecl_nthcdr(ecl_to_size(v15new_posn),v4orig_args);
      goto L5;
L109:;
      {
       cl_fixnum v16;
       v16 = ecl_length(v4orig_args);
       T0 = cl_list(2, v15new_posn, ecl_make_fixnum(v16));
       cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[326], VV[110], T0);
       goto L5;
      }
     }
    }
   }
  }
L54:;
  {
   cl_object v16;
   v16 = v8;
   {
    cl_object v17n;
    {
     cl_object v18param_and_offset;
     cl_object v19offset;
     cl_object v20param;
     {
      cl_object v21;
      v21 = v16;
      {
       cl_object v22;
       v22 = v21;
       {
        bool v23;
        v23 = ECL_LISTP(v22);
        if (ecl_unlikely(!(v23)))
         FEwrong_type_argument(VV[106],v22);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v21)){
       goto L119;
      }
      {
       cl_object v22;
       v22 = ECL_CONS_CDR(v21);
       v16 = v22;
       v21 = ECL_CONS_CAR(v21);
      }
L119:;
      v18param_and_offset = v21;
     }
     v19offset = ecl_car(v18param_and_offset);
     v20param = ecl_cdr(v18param_and_offset);
     if (!((v20param)==(VV[33]))){
      goto L127;
     }
     if (!(v5args==ECL_NIL)){
      goto L132;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v19offset);
L132:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L134;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L134:;
     {
      cl_object v21;
      v21 = v5args;
      {
       cl_object v22;
       v22 = v21;
       {
        bool v23;
        v23 = ECL_LISTP(v22);
        if (ecl_unlikely(!(v23)))
         FEwrong_type_argument(VV[106],v22);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v21)){
       goto L140;
      }
      {
       cl_object v22;
       v22 = ECL_CONS_CDR(v21);
       v5args = v22;
       v21 = ECL_CONS_CAR(v21);
      }
L140:;
      value0 = v21;
     }
     if (value0!=ECL_NIL) {
      goto L130;
     }
     v17n = ecl_make_int8_t(1);
     goto L113;
L130:;
     v17n = value0;
     goto L113;
L127:;
     if (!((v20param)==(VV[34]))){
      goto L146;
     }
     v17n = ecl_make_fixnum(ecl_length(v5args));
     goto L113;
L146:;
     if (!((v20param)==(ECL_NIL))){
      goto L148;
     }
     v17n = ecl_make_int8_t(1);
     goto L113;
L148:;
     v17n = v20param;
    }
L113:;
    if (Null(v16)){
     goto L151;
    }
    T0 = ecl_list1(ecl_make_int8_t(1));
    T1 = ecl_caar(v16);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L151:;
    {
     cl_object v18i;
     v18i = ecl_make_int8_t(0);
     goto L155;
L154:;
     if (!(v5args==ECL_NIL)){
      goto L158;
     }
     cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L158:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L160;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L160:;
     {
      cl_object v19;
      v19 = v5args;
      {
       cl_object v20;
       v20 = v19;
       {
        bool v21;
        v21 = ECL_LISTP(v20);
        if (ecl_unlikely(!(v21)))
         FEwrong_type_argument(VV[106],v20);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v19)){
       goto L166;
      }
      {
       cl_object v20;
       v20 = ECL_CONS_CDR(v19);
       v5args = v20;
       v19 = ECL_CONS_CAR(v19);
      }
L166:;
     }
     v18i = ecl_one_plus(v18i);
L155:;
     if (!(ecl_lower(v18i,v17n))){
      goto L174;
     }
     goto L154;
L174:;
    }
   }
  }
L5:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC594__lambda2714_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[324]);
 {
  return LC594__lambda2714(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function QUESTION_MARK-FORMAT-DIRECTIVE-EXPANDER                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC595question_mark_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  v6 = (cl_env_copy->function=(VV[328]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-STRING */;
  v7 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-END */;
  if (Null(v3)){
   goto L7;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[329]);
L7:;
  if (Null(v5)){
   goto L10;
  }
  T1 = ecl_caar(v5);
  cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[125], ECL_SYM("OFFSET",1316), T1);
L10:;
  T1 = ecl_one_minus(v7);
  T2 = cl_list(12, ECL_SYM("ERROR",339), VV[64], VV[29], VV[331], VV[110], VV[332], VV[333], ECL_NIL, ECL_SYM("CONTROL-STRING",1242), v6, ECL_SYM("OFFSET",1316), T1);
  T3 = cl_list(3, ECL_SYM("LAMBDA",454), VV[330], T2);
  T4 = cl_list(2, ECL_SYM("FUNCTION",398), T3);
  T5 = cl_list(2, ECL_SYM("FORMAT-ERROR",1084), T4);
  T6 = ecl_list1(T5);
  if (Null(v4)){
   goto L13;
  }
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[48]))){
   goto L15;
  }
  T8 = L527expand_next_arg(0);
  T9 = cl_listX(4, ECL_SYM("FORMATTER-AUX",1085), ECL_SYM("STREAM",802), T8, VV[334]);
  T7 = cl_list(3, ECL_SYM("SETF",753), VV[67], T9);
  goto L12;
L15:;
  cl_env_copy->values[0] = ECL_NIL;
  cl_env_copy->nvalues = 1;
  cl_throw(VV[62]);
L13:;
  T8 = L527expand_next_arg(0);
  T9 = L527expand_next_arg(0);
  T7 = cl_list(4, ECL_SYM("FORMATTER-AUX",1085), ECL_SYM("STREAM",802), T8, T9);
L12:;
  T0 = cl_list(3, ECL_SYM("HANDLER-BIND",419), T6, T7);
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC595question_mark_format_directive_expander_va(cl_narg narg, cl_object v8, cl_object v9, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[327]);
 {
  return LC595question_mark_format_directive_expander(v8, v9);
 }
}
/* local function LAMBDA2793                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC597__lambda2793(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  cl_object v9;
  cl_object v10;
  cl_object env1 = env0;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  v9 = (cl_env_copy->function=(VV[328]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-STRING */;
  v10 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-END */;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(v9,env1);                    /*  STRING                  */
  CLV1 = env1 = CONS(v10,env1);                   /*  END                     */
  if (Null(v6)){
   goto L7;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[329]);
L7:;
  if (Null(v8)){
   goto L10;
  }
  T0 = ecl_list1(ecl_make_int8_t(0));
  T1 = ecl_caar(v8);
  cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L10:;
  {
   cl_object v11;
   v11 = ecl_make_cclosure_va((cl_objectfn)LC596__lambda2801,env1,Cblock,1);
   T0 = v11;
  }
  T1 = CONS(ECL_SYM("FORMAT-ERROR",1084),T0);
  T2 = ecl_list1(T1);
  T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
  ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
  if (Null(v7)){
   goto L13;
  }
  if (!(v5args==ECL_NIL)){
   goto L16;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L16:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L18;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L18:;
  {
   cl_object v11;
   v11 = v5args;
   {
    cl_object v12;
    v12 = v11;
    {
     bool v13;
     v13 = ECL_LISTP(v12);
     if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(VV[106],v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v11)){
    goto L25;
   }
   {
    cl_object v12;
    v12 = ECL_CONS_CDR(v11);
    v5args = v12;
    v11 = ECL_CONS_CAR(v11);
   }
L25:;
   T0 = v11;
  }
  v5args = L520formatter_aux(4, v1stream, T0, v4orig_args, v5args);
  ecl_bds_unwind1(cl_env_copy);
  goto L9;
L13:;
  if (!(v5args==ECL_NIL)){
   goto L31;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L31:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L33;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L33:;
  {
   cl_object v11;
   v11 = v5args;
   {
    cl_object v12;
    v12 = v11;
    {
     bool v13;
     v13 = ECL_LISTP(v12);
     if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(VV[106],v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v11)){
    goto L40;
   }
   {
    cl_object v12;
    v12 = ECL_CONS_CDR(v11);
    v5args = v12;
    v11 = ECL_CONS_CAR(v11);
   }
L40:;
   T0 = v11;
  }
  if (!(v5args==ECL_NIL)){
   goto L46;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L46:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L48;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L48:;
  {
   cl_object v11;
   v11 = v5args;
   {
    cl_object v12;
    v12 = v11;
    {
     bool v13;
     v13 = ECL_LISTP(v12);
     if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(VV[106],v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v11)){
    goto L55;
   }
   {
    cl_object v12;
    v12 = ECL_CONS_CDR(v11);
    v5args = v12;
    v11 = ECL_CONS_CAR(v11);
   }
L55:;
   T1 = v11;
  }
  L520formatter_aux(3, v1stream, T0, T1);
  ecl_bds_unwind1(cl_env_copy);
L9:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC597__lambda2793_va(cl_narg narg, cl_object v11stream, cl_object v12, cl_object v13, cl_object v14orig_args, cl_object v15args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[335]);
 {
  return LC597__lambda2793(v11stream, v12, v13, v14orig_args, v15args);
 }
}
/* function definition for NSTRING-CAPITALIZE-FIRST                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L598nstring_capitalize_first(cl_object v1s)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 cl_nstring_downcase(1, v1s);
 {
  cl_object v2where;
  T0 = (ECL_SYM("ALPHA-CHAR-P",87)->symbol.gfdef);
  v2where = cl_position_if(2, T0, v1s);
  if (Null(v2where)){
   goto L5;
  }
  T0 = ecl_one_plus(v2where);
  cl_nstring_capitalize(5, v1s, ECL_SYM("START",1347), ecl_make_int8_t(0), ECL_SYM("END",1256), T0);
L5:;
  value0 = v1s;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L598nstring_capitalize_first_va(cl_narg narg, cl_object v3s, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[337]);
 {
  return L598nstring_capitalize_first(v3s);
 }
}
/* local function LEFT_PARENTHESIS-FORMAT-DIRECTIVE-EXPANDER                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC599left_parenthesis_format_directive_expander(cl_object v1, cl_object v2directives)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  {
   cl_object v6close;
   v6close = L534find_directive(v2directives, ECL_CODE_CHAR(41), ECL_NIL);
   if (v6close!=ECL_NIL) {
    goto L6;
   }
   cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[340]);
L6:;
   {
    cl_object v7posn;
    cl_object v8before;
    cl_object v9after;
    v7posn = cl_position(2, v6close, v2directives);
    v8before = cl_subseq(3, v2directives, ecl_make_int8_t(0), v7posn);
    T0 = ecl_one_plus(v7posn);
    v9after = ecl_nthcdr(ecl_to_size(T0),v2directives);
    if (Null(v5)){
     goto L12;
    }
    T1 = ecl_caar(v5);
    cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[125], ECL_SYM("OFFSET",1316), T1);
L12:;
    T1 = L525expand_directive_list(v8before);
    T2 = cl_listX(3, ECL_SYM("WITH-OUTPUT-TO-STRING",917), VV[342], T1);
    if (Null(v3)){
     goto L15;
    }
    if (Null(v4)){
     goto L17;
    }
    T3 = ECL_SYM("NSTRING-UPCASE",596);
    goto L14;
L17:;
    T3 = ECL_SYM("NSTRING-CAPITALIZE",594);
    goto L14;
L15:;
    if (Null(v4)){
     goto L19;
    }
    T3 = VV[337];
    goto L14;
L19:;
    T3 = ECL_SYM("NSTRING-DOWNCASE",595);
L14:;
    T4 = cl_list(2, T3, ECL_SYM("STRING",808));
    T5 = cl_list(3, ECL_SYM("PRINC",663), T4, ECL_SYM("STREAM",802));
    T6 = cl_list(3, ECL_SYM("UNWIND-PROTECT",892), T2, T5);
    T0 = cl_list(3, ECL_SYM("LET",479), VV[341], T6);
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = v9after;
    cl_env_copy->values[0] = T0;
    return cl_env_copy->values[0];
   }
  }
 }
}
static cl_object LC599left_parenthesis_format_directive_expander_va(cl_narg narg, cl_object v10, cl_object v11directives, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[339]);
 {
  return LC599left_parenthesis_format_directive_expander(v10, v11directives);
 }
}
/* local function LAMBDA2818                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC600__lambda2818(cl_object volatile v1stream, cl_object volatile v2, cl_object volatile v3directives, cl_object volatile v4orig_args, cl_object volatile v5args)
{
 cl_object T0, T1, T2;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v6;
  volatile cl_object v7;
  volatile cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  {
   volatile cl_object v9close;
   v9close = L534find_directive(v3directives, ECL_CODE_CHAR(41), ECL_NIL);
   if (v9close!=ECL_NIL) {
    goto L7;
   }
   cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[340]);
L7:;
   if (Null(v8)){
    goto L9;
   }
   T1 = ecl_list1(ecl_make_int8_t(0));
   T2 = ecl_caar(v8);
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T1, ECL_SYM("OFFSET",1316), T2);
L9:;
   {
    volatile cl_object v10posn;
    volatile cl_object v11before;
    volatile cl_object v12after;
    volatile cl_object v13string;
    v10posn = cl_position(2, v9close, v3directives);
    v11before = cl_subseq(3, v3directives, ecl_make_int8_t(0), v10posn);
    T1 = ecl_one_plus(v10posn);
    v12after = ecl_nthcdr(ecl_to_size(T1),v3directives);
    v13string = si_make_vector(ECL_SYM("CHARACTER",224), ecl_make_int8_t(10), ECL_T, ecl_make_int8_t(0), ECL_NIL, ecl_make_int8_t(0));
    {
     struct ecl_stack_frame _ecl_inner_frame_aux;
     volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
     volatile bool unwinding = FALSE;
     ecl_frame_ptr next_fr;
     {
      ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
      if (__ecl_frs_push_result!=0) {
        unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
      } else {
      {
       volatile cl_object v14;
       v14 = si_make_string_output_stream_from_string(v13string);
       {
        struct ecl_stack_frame _ecl_inner_frame_aux;
        volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
        volatile bool unwinding = FALSE;
        ecl_frame_ptr next_fr;
        {
         ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
         if (__ecl_frs_push_result!=0) {
           unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
         } else {
         v5args = L521interpret_directive_list(v14, v11before, v4orig_args, v5args);
         cl_env_copy->values[0] = v5args;
         cl_env_copy->nvalues = 1;
         }
        }
        ecl_frs_pop(cl_env_copy);
        ecl_stack_frame_push_values(_ecl_inner_frame);
        cl_close(1, v14);
        ecl_stack_frame_pop_values(_ecl_inner_frame);
        if (unwinding) ecl_unwind(cl_env_copy,next_fr);
        ecl_stack_frame_close(_ecl_inner_frame);
       }
      }
      }
     }
     ecl_frs_pop(cl_env_copy);
     ecl_stack_frame_push_values(_ecl_inner_frame);
     if (Null(v6)){
      goto L24;
     }
     if (Null(v7)){
      goto L26;
     }
     T2 = ECL_SYM("NSTRING-UPCASE",596);
     goto L23;
L26:;
     T2 = ECL_SYM("NSTRING-CAPITALIZE",594);
     goto L23;
L24:;
     if (Null(v7)){
      goto L28;
     }
     T2 = VV[337];
     goto L23;
L28:;
     T2 = ECL_SYM("NSTRING-DOWNCASE",595);
L23:;
     T1 = ecl_function_dispatch(cl_env_copy,T2)(1, v13string);
     ecl_princ(T1,v1stream);
     ecl_stack_frame_pop_values(_ecl_inner_frame);
     if (unwinding) ecl_unwind(cl_env_copy,next_fr);
     ecl_stack_frame_close(_ecl_inner_frame);
    }
    T0 = v12after;
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC600__lambda2818_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11directives, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[343]);
 {
  return LC600__lambda2818(v9stream, v10, v11directives, v12orig_args, v13args);
 }
}
/* local function RIGHT_PARENTHESIS-FORMAT-DIRECTIVE-EXPANDER                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC601right_parenthesis_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[345]);
 return value0;
}
static cl_object LC601right_parenthesis_format_directive_expander_va(cl_narg narg, cl_object v3, cl_object v4, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[344]);
 {
  return LC601right_parenthesis_format_directive_expander(v3, v4);
 }
}
/* local function LAMBDA2849                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC602__lambda2849(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[345]);
 return value0;
}
static cl_object LC602__lambda2849_va(cl_narg narg, cl_object v6stream, cl_object v7, cl_object v8, cl_object v9orig_args, cl_object v10args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[346]);
 {
  return LC602__lambda2849(v6stream, v7, v8, v9orig_args, v10args);
 }
}
/* function definition for PARSE-CONDITIONAL-DIRECTIVE                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L603parse_conditional_directive(cl_object v1directives)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2sublists;
  cl_object v3last_semi_with_colon_p;
  cl_object v4remaining;
  v2sublists = ECL_NIL;
  v3last_semi_with_colon_p = ECL_NIL;
  v4remaining = v1directives;
L6:;
  {
   cl_object v5close_or_semi;
   v5close_or_semi = L534find_directive(v4remaining, ECL_CODE_CHAR(93), ECL_T);
   if (v5close_or_semi!=ECL_NIL) {
    goto L9;
   }
   cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[348]);
L9:;
   {
    cl_object v6posn;
    v6posn = cl_position(2, v5close_or_semi, v4remaining);
    T0 = cl_subseq(3, v4remaining, ecl_make_int8_t(0), v6posn);
    v2sublists = CONS(T0,v2sublists);
    T0 = ecl_one_plus(v6posn);
    v4remaining = ecl_nthcdr(ecl_to_size(T0),v4remaining);
    T0 = (cl_env_copy->function=(VV[55]->symbol.gfdef))->cfun.entry(1, v5close_or_semi) /*  FORMAT-DIRECTIVE-CHARACTER */;
    if (!(ecl_char_code(T0)==ecl_char_code(ECL_CODE_CHAR(93)))){
     goto L16;
    }
    goto L5;
L16:;
    v3last_semi_with_colon_p = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v5close_or_semi) /*  FORMAT-DIRECTIVE-COLONP */;
   }
  }
  goto L6;
L5:;
  cl_env_copy->nvalues = 3;
  cl_env_copy->values[2] = v4remaining;
  cl_env_copy->values[1] = v3last_semi_with_colon_p;
  cl_env_copy->values[0] = v2sublists;
  return cl_env_copy->values[0];
 }
}
/* local function LEFT_SQUARE_BRACKET-FORMAT-DIRECTIVE-EXPANDER               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC604left_square_bracket_format_directive_expander(cl_object v1, cl_object v2directives)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  {
   cl_object v6;                                  /*  SUBLISTS                */
   cl_object v7;                                  /*  LAST-SEMI-WITH-COLON-P  */
   cl_object v8;                                  /*  REMAINING               */
   value0 = L603parse_conditional_directive(v2directives);
   {
    const int v9 = cl_env_copy->nvalues;
    v6 = value0;
    cl_object v10;
    v10 = (v9<=1)? ECL_NIL : cl_env_copy->values[1];
    v7 = v10;
    v10 = (v9<=2)? ECL_NIL : cl_env_copy->values[2];
    v8 = v10;
   }
   if (Null(v4)){
    goto L7;
   }
   if (Null(v3)){
    goto L9;
   }
   T0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[350]);
   goto L6;
L9:;
   if (Null(ecl_cdr(v6))){
    goto L11;
   }
   T0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[351]);
   goto L6;
L11:;
   if (Null(v5)){
    goto L13;
   }
   T1 = ecl_caar(v5);
   cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[125], ECL_SYM("OFFSET",1316), T1);
L13:;
   T1 = ecl_car(v6);
   T0 = L606expand_maybe_conditional(T1);
   goto L6;
L7:;
   if (Null(v3)){
    goto L15;
   }
   {
    cl_fixnum v9;
    v9 = ecl_length(v6);
    if (!((v9)==((cl_fixnum)(2)))){
     goto L17;
    }
   }
   if (Null(v5)){
    goto L19;
   }
   T1 = ecl_caar(v5);
   cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[125], ECL_SYM("OFFSET",1316), T1);
L19:;
   T1 = ecl_car(v6);
   T2 = ecl_cadr(v6);
   T0 = L608expand_true_false_conditional(T1, T2);
   goto L6;
L17:;
   T0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[354]);
   goto L6;
L15:;
   {
    cl_object v9;
    v9 = v5;
    {
     cl_object v10param_and_offset;
     cl_object v11offset;
     cl_object v12param;
     {
      cl_object v13;
      v13 = v9;
      {
       cl_object v14;
       v14 = v13;
       {
        bool v15;
        v15 = ECL_LISTP(v14);
        if (ecl_unlikely(!(v15)))
         FEwrong_type_argument(VV[106],v14);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v13)){
       goto L28;
      }
      {
       cl_object v14;
       v14 = ECL_CONS_CDR(v13);
       v9 = v14;
       v13 = ECL_CONS_CAR(v13);
      }
L28:;
      v10param_and_offset = v13;
     }
     v11offset = ecl_car(v10param_and_offset);
     v12param = ecl_cdr(v10param_and_offset);
     if (!((v12param)==(VV[33]))){
      goto L36;
     }
     T2 = L527expand_next_arg(1, v11offset);
     T1 = cl_list(3, ECL_SYM("OR",616), T2, ECL_NIL);
     goto L22;
L36:;
     if (!((v12param)==(VV[34]))){
      goto L38;
     }
     T2 = ECL_NIL;
     ecl_cmp_setq(cl_env_copy,VV[47],T2);
     T1 = VV[107];
     goto L22;
L38:;
     if (!((v12param)==(ECL_NIL))){
      goto L42;
     }
     T1 = ECL_NIL;
     goto L22;
L42:;
     T1 = v12param;
    }
L22:;
    T2 = cl_list(2, VV[355], T1);
    T3 = ecl_list1(T2);
    if (Null(v9)){
     goto L46;
    }
    T5 = ecl_list1(ecl_make_int8_t(1));
    T6 = ecl_caar(v9);
    T4 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T5, ECL_SYM("OFFSET",1316), T6);
    goto L45;
L46:;
    T4 = ECL_NIL;
L45:;
    T5 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T5);
    {
     cl_object v10clauses;
     cl_object v11case;
     v10clauses = ECL_NIL;
     T6 = L527expand_next_arg(0);
     v11case = cl_list(3, ECL_SYM("OR",616), VV[355], T6);
     if (Null(v7)){
      goto L52;
     }
     {
      cl_object v12;
      v12 = v6;
      {
       cl_object v13;
       v13 = v12;
       {
        bool v14;
        v14 = ECL_LISTP(v13);
        if (ecl_unlikely(!(v14)))
         FEwrong_type_argument(VV[106],v13);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v12)){
       goto L60;
      }
      {
       cl_object v13;
       v13 = ECL_CONS_CDR(v12);
       v6 = v13;
       v12 = ECL_CONS_CAR(v12);
      }
L60:;
      T6 = v12;
     }
     T7 = L525expand_directive_list(T6);
     T8 = CONS(ECL_T,T7);
     v10clauses = CONS(T8,v10clauses);
L52:;
     {
      cl_object v12count;
      v12count = ecl_make_fixnum(ecl_length(v6));
      {
       cl_object v13;
       v13 = v6;
       goto L71;
L70:;
       {
        cl_object v14sublist;
        v14sublist = ecl_car(v13);
        v12count = ecl_minus(v12count,ecl_make_int8_t(1));
        T6 = v12count;
        T7 = L525expand_directive_list(v14sublist);
        T8 = CONS(T6,T7);
        v10clauses = CONS(T8,v10clauses);
       }
       v13 = ecl_cdr(v13);
L71:;
       if (Null(v13)){
        goto L81;
       }
       goto L70;
L81:;
      }
     }
     T5 = cl_listX(3, ECL_SYM("CASE",183), v11case, v10clauses);
    }
    T6 = cl_list(2, ECL_NIL, T5);
    T7 = ecl_append(T4,T6);
    T0 = cl_listX(3, ECL_SYM("LET",479), T3, T7);
   }
L6:;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = v8;
   cl_env_copy->values[0] = T0;
   return cl_env_copy->values[0];
  }
 }
}
static cl_object LC604left_square_bracket_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7directives, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[349]);
 {
  return LC604left_square_bracket_format_directive_expander(v6, v7directives);
 }
}
/* function definition for EXPAND-MAYBE-CONDITIONAL                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L606expand_maybe_conditional(cl_object v1sublist)
{
 cl_object T0, T1;
 volatile cl_object lex0[1];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 lex0[0] = v1sublist;                             /*  SUBLIST                 */
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[47]))){
  goto L2;
 }
 {
  cl_object v2;                                   /*  GUTS                    */
  cl_object v3;                                   /*  NEW-ARGS                */
  ecl_bds_push(cl_env_copy,VV[49]);               /*  *SIMPLE-ARGS*           */
  T0 = L525expand_directive_list(lex0[0]);
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = ecl_cmp_symbol_value(cl_env_copy,VV[49]);
  cl_env_copy->values[0] = T0;
  value0 = cl_env_copy->values[0];
  ecl_bds_unwind1(cl_env_copy);
  {
   v2 = value0;
   v3 = cl_env_copy->values[1];
  }
  if (Null(v3)){
   goto L5;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,VV[49]);
  T1 = ecl_cdr(v3);
  if (!((T0)==(T1))){
   goto L5;
  }
  T0 = v3;
  ecl_cmp_setq(cl_env_copy,VV[49],T0);
  T0 = ecl_caar(v3);
  value0 = cl_listX(3, ECL_SYM("WHEN",909), T0, v2);
  return value0;
L5:;
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[47],T0);
  value0 = LC605hairy(lex0);
  return value0;
 }
L2:;
 value0 = LC605hairy(lex0);
 return value0;
}
/* function definition for EXPAND-TRUE-FALSE-CONDITIONAL                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L608expand_true_false_conditional(cl_object v1true, cl_object v2false)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 volatile cl_object lex0[3];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 lex0[0] = v1true;                                /*  TRUE                    */
 lex0[1] = v2false;                               /*  FALSE                   */
L1:;
 T0 = L527expand_next_arg(0);
 lex0[2] = T0;                                    /*  ARG                     */
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[47]))){
  goto L2;
 }
 {
  cl_object v3;                                   /*  TRUE-GUTS               */
  cl_object v4;                                   /*  TRUE-ARGS               */
  cl_object v5;                                   /*  TRUE-SIMPLE             */
  {
   cl_object v6;
   v6 = ecl_cmp_symbol_value(cl_env_copy,VV[49]);
   ecl_bds_bind(cl_env_copy,VV[49],v6);           /*  *SIMPLE-ARGS*           */
   ecl_bds_bind(cl_env_copy,VV[47],ECL_T);        /*  *ONLY-SIMPLE-ARGS*      */
   T0 = L525expand_directive_list(lex0[0]);
   cl_env_copy->nvalues = 3;
   cl_env_copy->values[2] = ecl_cmp_symbol_value(cl_env_copy,VV[47]);
   cl_env_copy->values[1] = ecl_cmp_symbol_value(cl_env_copy,VV[49]);
   cl_env_copy->values[0] = T0;
   value0 = cl_env_copy->values[0];
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
  }
  {
   v3 = value0;
   v4 = cl_env_copy->values[1];
   v5 = cl_env_copy->values[2];
  }
  {
   cl_object v6;                                  /*  FALSE-GUTS              */
   cl_object v7;                                  /*  FALSE-ARGS              */
   cl_object v8;                                  /*  FALSE-SIMPLE            */
   {
    cl_object v9;
    v9 = ecl_cmp_symbol_value(cl_env_copy,VV[49]);
    ecl_bds_bind(cl_env_copy,VV[49],v9);          /*  *SIMPLE-ARGS*           */
    ecl_bds_bind(cl_env_copy,VV[47],ECL_T);       /*  *ONLY-SIMPLE-ARGS*      */
    T0 = L525expand_directive_list(lex0[1]);
    cl_env_copy->nvalues = 3;
    cl_env_copy->values[2] = ecl_cmp_symbol_value(cl_env_copy,VV[47]);
    cl_env_copy->values[1] = ecl_cmp_symbol_value(cl_env_copy,VV[49]);
    cl_env_copy->values[0] = T0;
    value0 = cl_env_copy->values[0];
    ecl_bds_unwind1(cl_env_copy);
    ecl_bds_unwind1(cl_env_copy);
   }
   {
    v6 = value0;
    v7 = cl_env_copy->values[1];
    v8 = cl_env_copy->values[2];
   }
   {
    cl_fixnum v9;
    v9 = ecl_length(v4);
    {
     cl_fixnum v10;
     v10 = ecl_length(v7);
     if (!((v9)==(v10))){
      goto L8;
     }
    }
   }
   T0 = CONS(ECL_SYM("PROGN",674),v3);
   {
    cl_object v9false;
    cl_object v10true;
    cl_object v11bindings;
    v9false = v7;
    v10true = v4;
    v11bindings = ECL_NIL;
    goto L16;
L15:;
    T2 = ecl_cdr(v9false);
    T3 = ecl_cdr(v10true);
    T4 = ecl_caar(v9false);
    T5 = ecl_caar(v10true);
    T6 = cl_list(2, T4, T5);
    v11bindings = CONS(T6,v11bindings);
    v10true = T3;
    v9false = T2;
L16:;
    if ((v10true)==(ecl_cmp_symbol_value(cl_env_copy,VV[49]))) {
     goto L22;
    }
    goto L15;
L22:;
    T2 = v4;
    ecl_cmp_setq(cl_env_copy,VV[49],T2);
    if (Null(v5)){
     goto L29;
    }
    T2 = v8;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    goto L27;
L29:;
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    goto L27;
L27:;
    if (Null(v11bindings)){
     goto L31;
    }
    T1 = cl_listX(3, ECL_SYM("LET",479), v11bindings, v6);
    goto L10;
L31:;
    T1 = CONS(ECL_SYM("PROGN",674),v6);
   }
L10:;
   value0 = cl_list(4, ECL_SYM("IF",950), lex0[2], T0, T1);
   return value0;
L8:;
   T0 = ECL_NIL;
   ecl_cmp_setq(cl_env_copy,VV[47],T0);
   value0 = LC607hairy(lex0);
   return value0;
  }
 }
L2:;
 value0 = LC607hairy(lex0);
 return value0;
}
/* local function LAMBDA2911                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC609__lambda2911(cl_object v1stream, cl_object v2, cl_object v3directives, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  {
   cl_object v9;                                  /*  SUBLISTS                */
   cl_object v10;                                 /*  LAST-SEMI-WITH-COLON-P  */
   cl_object v11;                                 /*  REMAINING               */
   value0 = L603parse_conditional_directive(v3directives);
   {
    const int v12 = cl_env_copy->nvalues;
    v9 = value0;
    cl_object v13;
    v13 = (v12<=1)? ECL_NIL : cl_env_copy->values[1];
    v10 = v13;
    v13 = (v12<=2)? ECL_NIL : cl_env_copy->values[2];
    v11 = v13;
   }
   if (Null(v7)){
    goto L9;
   }
   if (Null(v6)){
    goto L11;
   }
   v5args = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[350]);
   goto L8;
L11:;
   if (Null(ecl_cdr(v9))){
    goto L13;
   }
   v5args = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[351]);
   goto L8;
L13:;
   if (Null(v8)){
    goto L15;
   }
   T1 = ecl_list1(ecl_make_int8_t(0));
   T2 = ecl_caar(v8);
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T1, ECL_SYM("OFFSET",1316), T2);
L15:;
   {
    cl_object v12;
    cl_object v13;
    v12 = v5args;
    if (!(v5args==ECL_NIL)){
     goto L19;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L19:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L21;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L21:;
    {
     cl_object v14;
     v14 = v5args;
     {
      cl_object v15;
      v15 = v14;
      {
       bool v16;
       v16 = ECL_LISTP(v15);
       if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v14)){
      goto L27;
     }
     {
      cl_object v15;
      v15 = ECL_CONS_CDR(v14);
      v5args = v15;
      v14 = ECL_CONS_CAR(v14);
     }
L27:;
     v13 = v14;
    }
    if (Null(v13)){
     goto L33;
    }
    T1 = ecl_car(v9);
    v5args = L521interpret_directive_list(v1stream, T1, v4orig_args, v12);
    goto L8;
L33:;
    goto L8;
   }
L9:;
   if (Null(v6)){
    goto L35;
   }
   {
    cl_fixnum v14;
    v14 = ecl_length(v9);
    if (!((v14)==((cl_fixnum)(2)))){
     goto L37;
    }
   }
   if (Null(v8)){
    goto L39;
   }
   T1 = ecl_list1(ecl_make_int8_t(0));
   T2 = ecl_caar(v8);
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T1, ECL_SYM("OFFSET",1316), T2);
L39:;
   if (!(v5args==ECL_NIL)){
    goto L43;
   }
   cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L43:;
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
    goto L45;
   }
   ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L45:;
   {
    cl_object v14;
    v14 = v5args;
    {
     cl_object v15;
     v15 = v14;
     {
      bool v16;
      v16 = ECL_LISTP(v15);
      if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v14)){
     goto L51;
    }
    {
     cl_object v15;
     v15 = ECL_CONS_CDR(v14);
     v5args = v15;
     v14 = ECL_CONS_CAR(v14);
    }
L51:;
    if (Null(v14)){
     goto L41;
    }
   }
   T1 = ecl_car(v9);
   v5args = L521interpret_directive_list(v1stream, T1, v4orig_args, v5args);
   goto L8;
L41:;
   T1 = ecl_cadr(v9);
   v5args = L521interpret_directive_list(v1stream, T1, v4orig_args, v5args);
   goto L8;
L37:;
   v5args = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[354]);
   goto L8;
L35:;
   {
    cl_object v14;
    v14 = v8;
    {
     cl_object v15index;
     {
      cl_object v16param_and_offset;
      cl_object v17offset;
      cl_object v18param;
      {
       cl_object v19;
       v19 = v14;
       {
        cl_object v20;
        v20 = v19;
        {
         bool v21;
         v21 = ECL_LISTP(v20);
         if (ecl_unlikely(!(v21)))
         FEwrong_type_argument(VV[106],v20);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
       }
       if (Null(v19)){
        goto L64;
       }
       {
        cl_object v20;
        v20 = ECL_CONS_CDR(v19);
        v14 = v20;
        v19 = ECL_CONS_CAR(v19);
       }
L64:;
       v16param_and_offset = v19;
      }
      v17offset = ecl_car(v16param_and_offset);
      v18param = ecl_cdr(v16param_and_offset);
      if (!((v18param)==(VV[33]))){
       goto L72;
      }
      if (!(v5args==ECL_NIL)){
       goto L77;
      }
      cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v17offset);
L77:;
      if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
       goto L79;
      }
      ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L79:;
      {
       cl_object v19;
       v19 = v5args;
       {
        cl_object v20;
        v20 = v19;
        {
         bool v21;
         v21 = ECL_LISTP(v20);
         if (ecl_unlikely(!(v21)))
         FEwrong_type_argument(VV[106],v20);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
       }
       if (Null(v19)){
        goto L85;
       }
       {
        cl_object v20;
        v20 = ECL_CONS_CDR(v19);
        v5args = v20;
        v19 = ECL_CONS_CAR(v19);
       }
L85:;
       value0 = v19;
      }
      if (value0!=ECL_NIL) {
       goto L75;
      }
      if (!(v5args==ECL_NIL)){
       goto L91;
      }
      cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L91:;
      if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
       goto L93;
      }
      ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L93:;
      {
       cl_object v19;
       v19 = v5args;
       {
        cl_object v20;
        v20 = v19;
        {
         bool v21;
         v21 = ECL_LISTP(v20);
         if (ecl_unlikely(!(v21)))
         FEwrong_type_argument(VV[106],v20);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
       }
       if (Null(v19)){
        goto L99;
       }
       {
        cl_object v20;
        v20 = ECL_CONS_CDR(v19);
        v5args = v20;
        v19 = ECL_CONS_CAR(v19);
       }
L99:;
       v15index = v19;
       goto L58;
      }
L75:;
      v15index = value0;
      goto L58;
L72:;
      if (!((v18param)==(VV[34]))){
       goto L105;
      }
      v15index = ecl_make_fixnum(ecl_length(v5args));
      goto L58;
L105:;
      if (!((v18param)==(ECL_NIL))){
       goto L107;
      }
      if (!(v5args==ECL_NIL)){
       goto L110;
      }
      cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L110:;
      if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
       goto L112;
      }
      ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L112:;
      {
       cl_object v20;
       v20 = v5args;
       {
        cl_object v21;
        v21 = v20;
        {
         bool v22;
         v22 = ECL_LISTP(v21);
         if (ecl_unlikely(!(v22)))
         FEwrong_type_argument(VV[106],v21);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
       }
       if (Null(v20)){
        goto L118;
       }
       {
        cl_object v21;
        v21 = ECL_CONS_CDR(v20);
        v5args = v21;
        v20 = ECL_CONS_CAR(v20);
       }
L118:;
       v15index = v20;
       goto L58;
      }
L107:;
      v15index = v18param;
     }
L58:;
     if (Null(v14)){
      goto L124;
     }
     T1 = ecl_list1(ecl_make_int8_t(1));
     T2 = ecl_caar(v14);
     cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T1, ECL_SYM("OFFSET",1316), T2);
L124:;
     {
      cl_object v16default;
      cl_object v17last;
      cl_object v18sublist;
      if (Null(v10)){
       goto L128;
      }
      {
       cl_object v19;
       v19 = v9;
       {
        cl_object v20;
        v20 = v19;
        {
         bool v21;
         v21 = ECL_LISTP(v20);
         if (ecl_unlikely(!(v21)))
         FEwrong_type_argument(VV[106],v20);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
       }
       if (Null(v19)){
        goto L134;
       }
       {
        cl_object v20;
        v20 = ECL_CONS_CDR(v19);
        v9 = v20;
        v19 = ECL_CONS_CAR(v19);
       }
L134:;
       v16default = v19;
       goto L126;
      }
L128:;
      v16default = ECL_NIL;
      goto L126;
L126:;
      {
       cl_fixnum v19;
       v19 = ecl_length(v9);
       v17last = ecl_make_integer((v19)-1);
      }
      if (Null(cl_LE(3, ecl_make_int8_t(0), v15index, v17last))){
       goto L142;
      }
      T1 = ecl_minus(v17last,v15index);
      v18sublist = ecl_nth(ecl_to_size(T1),v9);
      goto L141;
L142:;
      v18sublist = v16default;
L141:;
      v5args = L521interpret_directive_list(v1stream, v18sublist, v4orig_args, v5args);
     }
    }
   }
L8:;
   T0 = v11;
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC609__lambda2911_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11directives, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[359]);
 {
  return LC609__lambda2911(v9stream, v10, v11directives, v12orig_args, v13args);
 }
}
/* local function SEMICOLON-FORMAT-DIRECTIVE-EXPANDER                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC610semicolon_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[361]);
 return value0;
}
static cl_object LC610semicolon_format_directive_expander_va(cl_narg narg, cl_object v3, cl_object v4, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[360]);
 {
  return LC610semicolon_format_directive_expander(v3, v4);
 }
}
/* local function LAMBDA2952                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC611__lambda2952(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[361]);
 return value0;
}
static cl_object LC611__lambda2952_va(cl_narg narg, cl_object v6stream, cl_object v7, cl_object v8, cl_object v9orig_args, cl_object v10args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[362]);
 {
  return LC611__lambda2952(v6stream, v7, v8, v9orig_args, v10args);
 }
}
/* local function LAMBDA2956                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC612__lambda2956(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[364]);
 return value0;
}
static cl_object LC612__lambda2956_va(cl_narg narg, cl_object v6stream, cl_object v7, cl_object v8, cl_object v9orig_args, cl_object v10args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[363]);
 {
  return LC612__lambda2956(v6stream, v7, v8, v9orig_args, v10args);
 }
}
/* local function RIGHT_SQUARE_BRACKET-FORMAT-DIRECTIVE-EXPANDER              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC613right_square_bracket_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[364]);
 return value0;
}
static cl_object LC613right_square_bracket_format_directive_expander_va(cl_narg narg, cl_object v3, cl_object v4, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[365]);
 {
  return LC613right_square_bracket_format_directive_expander(v3, v4);
 }
}
/* local function CIRCUMFLEX_ACCENT-FORMAT-DIRECTIVE-EXPANDER                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC614circumflex_accent_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v4)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[368]);
L5:;
  if (Null(v3)){
   goto L7;
  }
  if (ecl_cmp_symbol_value(cl_env_copy,VV[43])!=ECL_NIL) {
   goto L7;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[369]);
L7:;
  {
   cl_object v6;
   v6 = v5;
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L18;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L18:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L26;
    }
    T2 = L527expand_next_arg(1, v8offset);
    T1 = cl_list(3, ECL_SYM("OR",616), T2, ECL_NIL);
    goto L12;
L26:;
    if (!((v9param)==(VV[34]))){
     goto L28;
    }
    T2 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T2);
    T1 = VV[107];
    goto L12;
L28:;
    if (!((v9param)==(ECL_NIL))){
     goto L32;
    }
    T1 = ECL_NIL;
    goto L12;
L32:;
    T1 = v9param;
   }
L12:;
   T2 = cl_list(2, VV[370], T1);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L41;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L41:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L49;
    }
    T4 = L527expand_next_arg(1, v8offset);
    T3 = cl_list(3, ECL_SYM("OR",616), T4, ECL_NIL);
    goto L35;
L49:;
    if (!((v9param)==(VV[34]))){
     goto L51;
    }
    T4 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T4);
    T3 = VV[107];
    goto L35;
L51:;
    if (!((v9param)==(ECL_NIL))){
     goto L55;
    }
    T3 = ECL_NIL;
    goto L35;
L55:;
    T3 = v9param;
   }
L35:;
   T4 = cl_list(2, VV[371], T3);
   {
    cl_object v7param_and_offset;
    cl_object v8offset;
    cl_object v9param;
    {
     cl_object v10;
     v10 = v6;
     {
      cl_object v11;
      v11 = v10;
      {
       bool v12;
       v12 = ECL_LISTP(v11);
       if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[106],v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v10)){
      goto L64;
     }
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v10);
      v6 = v11;
      v10 = ECL_CONS_CAR(v10);
     }
L64:;
     v7param_and_offset = v10;
    }
    v8offset = ecl_car(v7param_and_offset);
    v9param = ecl_cdr(v7param_and_offset);
    if (!((v9param)==(VV[33]))){
     goto L72;
    }
    T6 = L527expand_next_arg(1, v8offset);
    T5 = cl_list(3, ECL_SYM("OR",616), T6, ECL_NIL);
    goto L58;
L72:;
    if (!((v9param)==(VV[34]))){
     goto L74;
    }
    T6 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T6);
    T5 = VV[107];
    goto L58;
L74:;
    if (!((v9param)==(ECL_NIL))){
     goto L78;
    }
    T5 = ECL_NIL;
    goto L58;
L78:;
    T5 = v9param;
   }
L58:;
   T6 = cl_list(2, VV[372], T5);
   T7 = cl_list(3, T2, T4, T6);
   if (Null(v6)){
    goto L82;
   }
   T9 = ecl_list1(ecl_make_int8_t(3));
   T10 = ecl_caar(v6);
   T8 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T9, ECL_SYM("OFFSET",1316), T10);
   goto L81;
L82:;
   T8 = ECL_NIL;
L81:;
   T9 = cl_list(4, ECL_SYM("<=",75), VV[370], VV[371], VV[372]);
   T10 = cl_list(2, VV[372], T9);
   T11 = cl_list(3, ECL_SYM("EQL",336), VV[370], VV[371]);
   T12 = cl_list(2, VV[371], T11);
   T13 = cl_list(3, ECL_SYM("EQL",336), VV[370], ecl_make_int8_t(0));
   T14 = cl_list(2, VV[370], T13);
   if (Null(v3)){
    goto L85;
   }
   T15 = VV[373];
   goto L84;
L85:;
   T16 = ECL_NIL;
   ecl_cmp_setq(cl_env_copy,VV[47],T16);
   T15 = VV[81];
L84:;
   T16 = cl_list(2, ECL_T, T15);
   T17 = cl_list(5, ECL_SYM("COND",249), T10, T12, T14, T16);
   T18 = ecl_list1(T17);
   T19 = ecl_append(T8,T18);
   T0 = cl_listX(3, ECL_SYM("LET",479), T7, T19);
  }
  if (Null(v3)){
   goto L90;
  }
  T1 = VV[374];
  goto L89;
L90:;
  T1 = VV[375];
L89:;
  T2 = cl_list(3, ECL_SYM("WHEN",909), T0, T1);
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T2;
  return cl_env_copy->values[0];
 }
}
static cl_object LC614circumflex_accent_format_directive_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[367]);
 {
  return LC614circumflex_accent_format_directive_expander(v6, v7);
 }
}
/* local function LAMBDA3019                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC615__lambda3019(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  if (Null(v7)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[377]);
L5:;
  if (Null(v6)){
   goto L7;
  }
  if (ecl_cmp_symbol_value(cl_env_copy,VV[43])!=ECL_NIL) {
   goto L7;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[369]);
L7:;
  {
   cl_object v9;
   v9 = v8;
   {
    cl_object v10arg1;
    cl_object v11arg2;
    cl_object v12arg3;
    {
     cl_object v13param_and_offset;
     cl_object v14offset;
     cl_object v15param;
     {
      cl_object v16;
      v16 = v9;
      {
       cl_object v17;
       v17 = v16;
       {
        bool v18;
        v18 = ECL_LISTP(v17);
        if (ecl_unlikely(!(v18)))
         FEwrong_type_argument(VV[106],v17);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v16)){
       goto L19;
      }
      {
       cl_object v17;
       v17 = ECL_CONS_CDR(v16);
       v9 = v17;
       v16 = ECL_CONS_CAR(v16);
      }
L19:;
      v13param_and_offset = v16;
     }
     v14offset = ecl_car(v13param_and_offset);
     v15param = ecl_cdr(v13param_and_offset);
     if (!((v15param)==(VV[33]))){
      goto L27;
     }
     if (!(v5args==ECL_NIL)){
      goto L32;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v14offset);
L32:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L34;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L34:;
     {
      cl_object v16;
      v16 = v5args;
      {
       cl_object v17;
       v17 = v16;
       {
        bool v18;
        v18 = ECL_LISTP(v17);
        if (ecl_unlikely(!(v18)))
         FEwrong_type_argument(VV[106],v17);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v16)){
       goto L40;
      }
      {
       cl_object v17;
       v17 = ECL_CONS_CDR(v16);
       v5args = v17;
       v16 = ECL_CONS_CAR(v16);
      }
L40:;
      value0 = v16;
     }
     if (value0!=ECL_NIL) {
      goto L30;
     }
     v10arg1 = ECL_NIL;
     goto L13;
L30:;
     v10arg1 = value0;
     goto L13;
L27:;
     if (!((v15param)==(VV[34]))){
      goto L46;
     }
     v10arg1 = ecl_make_fixnum(ecl_length(v5args));
     goto L13;
L46:;
     if (!((v15param)==(ECL_NIL))){
      goto L48;
     }
     v10arg1 = ECL_NIL;
     goto L13;
L48:;
     v10arg1 = v15param;
    }
L13:;
    {
     cl_object v13param_and_offset;
     cl_object v14offset;
     cl_object v15param;
     {
      cl_object v16;
      v16 = v9;
      {
       cl_object v17;
       v17 = v16;
       {
        bool v18;
        v18 = ECL_LISTP(v17);
        if (ecl_unlikely(!(v18)))
         FEwrong_type_argument(VV[106],v17);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v16)){
       goto L57;
      }
      {
       cl_object v17;
       v17 = ECL_CONS_CDR(v16);
       v9 = v17;
       v16 = ECL_CONS_CAR(v16);
      }
L57:;
      v13param_and_offset = v16;
     }
     v14offset = ecl_car(v13param_and_offset);
     v15param = ecl_cdr(v13param_and_offset);
     if (!((v15param)==(VV[33]))){
      goto L65;
     }
     if (!(v5args==ECL_NIL)){
      goto L70;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v14offset);
L70:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L72;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L72:;
     {
      cl_object v16;
      v16 = v5args;
      {
       cl_object v17;
       v17 = v16;
       {
        bool v18;
        v18 = ECL_LISTP(v17);
        if (ecl_unlikely(!(v18)))
         FEwrong_type_argument(VV[106],v17);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v16)){
       goto L78;
      }
      {
       cl_object v17;
       v17 = ECL_CONS_CDR(v16);
       v5args = v17;
       v16 = ECL_CONS_CAR(v16);
      }
L78:;
      value0 = v16;
     }
     if (value0!=ECL_NIL) {
      goto L68;
     }
     v11arg2 = ECL_NIL;
     goto L51;
L68:;
     v11arg2 = value0;
     goto L51;
L65:;
     if (!((v15param)==(VV[34]))){
      goto L84;
     }
     v11arg2 = ecl_make_fixnum(ecl_length(v5args));
     goto L51;
L84:;
     if (!((v15param)==(ECL_NIL))){
      goto L86;
     }
     v11arg2 = ECL_NIL;
     goto L51;
L86:;
     v11arg2 = v15param;
    }
L51:;
    {
     cl_object v13param_and_offset;
     cl_object v14offset;
     cl_object v15param;
     {
      cl_object v16;
      v16 = v9;
      {
       cl_object v17;
       v17 = v16;
       {
        bool v18;
        v18 = ECL_LISTP(v17);
        if (ecl_unlikely(!(v18)))
         FEwrong_type_argument(VV[106],v17);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v16)){
       goto L95;
      }
      {
       cl_object v17;
       v17 = ECL_CONS_CDR(v16);
       v9 = v17;
       v16 = ECL_CONS_CAR(v16);
      }
L95:;
      v13param_and_offset = v16;
     }
     v14offset = ecl_car(v13param_and_offset);
     v15param = ecl_cdr(v13param_and_offset);
     if (!((v15param)==(VV[33]))){
      goto L103;
     }
     if (!(v5args==ECL_NIL)){
      goto L108;
     }
     cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v14offset);
L108:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
      goto L110;
     }
     ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L110:;
     {
      cl_object v16;
      v16 = v5args;
      {
       cl_object v17;
       v17 = v16;
       {
        bool v18;
        v18 = ECL_LISTP(v17);
        if (ecl_unlikely(!(v18)))
         FEwrong_type_argument(VV[106],v17);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v16)){
       goto L116;
      }
      {
       cl_object v17;
       v17 = ECL_CONS_CDR(v16);
       v5args = v17;
       v16 = ECL_CONS_CAR(v16);
      }
L116:;
      value0 = v16;
     }
     if (value0!=ECL_NIL) {
      goto L106;
     }
     v12arg3 = ECL_NIL;
     goto L89;
L106:;
     v12arg3 = value0;
     goto L89;
L103:;
     if (!((v15param)==(VV[34]))){
      goto L122;
     }
     v12arg3 = ecl_make_fixnum(ecl_length(v5args));
     goto L89;
L122:;
     if (!((v15param)==(ECL_NIL))){
      goto L124;
     }
     v12arg3 = ECL_NIL;
     goto L89;
L124:;
     v12arg3 = v15param;
    }
L89:;
    if (Null(v9)){
     goto L127;
    }
    T0 = ecl_list1(ecl_make_int8_t(3));
    T1 = ecl_caar(v9);
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L127:;
    if (Null(v12arg3)){
     goto L129;
    }
    if (Null(cl_LE(3, v10arg1, v11arg2, v12arg3))){
     goto L10;
    }
    goto L11;
L129:;
    if (Null(v11arg2)){
     goto L131;
    }
    if (!(ecl_eql(v10arg1,v11arg2))){
     goto L10;
    }
    goto L11;
L131:;
    if (Null(v10arg1)){
     goto L133;
    }
    if (!((v10arg1)==(ecl_make_int8_t(0)))){
     goto L10;
    }
    goto L11;
L133:;
    if (Null(v6)){
     goto L135;
    }
    if (!(ecl_cmp_symbol_value(cl_env_copy,VV[366])==ECL_NIL)){
     goto L10;
    }
    goto L11;
L135:;
    if (!(v5args==ECL_NIL)){
     goto L10;
    }
   }
  }
L11:;
  if (Null(v6)){
   goto L138;
  }
  T0 = VV[378];
  goto L137;
L138:;
  T0 = VV[50];
L137:;
  cl_env_copy->values[0] = v5args;
  cl_env_copy->nvalues = 1;
  cl_throw(T0);
L10:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC615__lambda3019_va(cl_narg narg, cl_object v9stream, cl_object v10, cl_object v11, cl_object v12orig_args, cl_object v13args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[376]);
 {
  return LC615__lambda3019(v9stream, v10, v11, v12orig_args, v13args);
 }
}
/* local function LEFT_CURLY_BRACKET-FORMAT-DIRECTIVE-EXPANDER                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC620left_curly_bracket_format_directive_expander(cl_object v1, cl_object v2directives)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9;
 volatile cl_object lex0[7];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 lex0[0] = v2directives;                          /*  DIRECTIVES              */
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  v6 = (cl_env_copy->function=(VV[328]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-STRING */;
  v7 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-END */;
  lex0[1] = v3;                                   /*  COLONP                  */
  lex0[2] = v4;                                   /*  ATSIGNP                 */
  lex0[3] = v6;                                   /*  STRING                  */
  lex0[4] = v7;                                   /*  END                     */
  {
   cl_object v8close;
   v8close = L534find_directive(lex0[0], ECL_CODE_CHAR(125), ECL_NIL);
   if (v8close!=ECL_NIL) {
    goto L8;
   }
   cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[380]);
L8:;
   T0 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v8close) /*  FORMAT-DIRECTIVE-COLONP */;
   lex0[5] = T0;                                  /*  CLOSED-WITH-COLON       */
   T0 = cl_position(2, v8close, lex0[0]);
   lex0[6] = T0;                                  /*  POSN                    */
   if (Null(v5)){
    goto L11;
   }
   {
    cl_object v9;
    v9 = v5;
    {
     cl_object v10param_and_offset;
     cl_object v11offset;
     cl_object v12param;
     {
      cl_object v13;
      v13 = v9;
      {
       cl_object v14;
       v14 = v13;
       {
        bool v15;
        v15 = ECL_LISTP(v14);
        if (ecl_unlikely(!(v15)))
         FEwrong_type_argument(VV[106],v14);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v13)){
       goto L20;
      }
      {
       cl_object v14;
       v14 = ECL_CONS_CDR(v13);
       v9 = v14;
       v13 = ECL_CONS_CAR(v13);
      }
L20:;
      v10param_and_offset = v13;
     }
     v11offset = ecl_car(v10param_and_offset);
     v12param = ecl_cdr(v10param_and_offset);
     if (!((v12param)==(VV[33]))){
      goto L28;
     }
     T2 = L527expand_next_arg(1, v11offset);
     T1 = cl_list(3, ECL_SYM("OR",616), T2, ECL_NIL);
     goto L14;
L28:;
     if (!((v12param)==(VV[34]))){
      goto L30;
     }
     T2 = ECL_NIL;
     ecl_cmp_setq(cl_env_copy,VV[47],T2);
     T1 = VV[107];
     goto L14;
L30:;
     if (!((v12param)==(ECL_NIL))){
      goto L34;
     }
     T1 = ECL_NIL;
     goto L14;
L34:;
     T1 = v12param;
    }
L14:;
    T2 = cl_list(2, VV[393], T1);
    T3 = ecl_list1(T2);
    if (Null(v9)){
     goto L38;
    }
    T5 = ecl_list1(ecl_make_int8_t(1));
    T6 = ecl_caar(v9);
    T4 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T5, ECL_SYM("OFFSET",1316), T6);
    goto L37;
L38:;
    T4 = ECL_NIL;
L37:;
    if (!(ecl_zerop(lex0[6]))){
     goto L41;
    }
    T6 = L527expand_next_arg(0);
    T7 = cl_list(2, VV[394], T6);
    T8 = ecl_list1(T7);
    T9 = LC619compute_bindings(lex0, VV[393]);
    T5 = cl_list(3, ECL_SYM("LET",479), T8, T9);
    goto L40;
L41:;
    T5 = LC619compute_bindings(lex0, VV[393]);
L40:;
    T6 = ecl_list1(T5);
    T7 = ecl_append(T4,T6);
    T0 = cl_listX(3, ECL_SYM("LET",479), T3, T7);
    goto L10;
   }
L11:;
   if (!(ecl_zerop(lex0[6]))){
    goto L44;
   }
   T1 = L527expand_next_arg(0);
   T2 = cl_list(2, VV[394], T1);
   T3 = ecl_list1(T2);
   T4 = LC619compute_bindings(lex0, ECL_NIL);
   T0 = cl_list(3, ECL_SYM("LET",479), T3, T4);
   goto L10;
L44:;
   T0 = LC619compute_bindings(lex0, ECL_NIL);
L10:;
   T1 = ecl_one_plus(lex0[6]);
   T2 = ecl_nthcdr(ecl_to_size(T1),lex0[0]);
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = T2;
   cl_env_copy->values[0] = T0;
   return cl_env_copy->values[0];
  }
 }
}
static cl_object LC620left_curly_bracket_format_directive_expander_va(cl_narg narg, cl_object v9, cl_object v10directives, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[379]);
 {
  return LC620left_curly_bracket_format_directive_expander(v9, v10directives);
 }
}
/* local function LAMBDA3105                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC625__lambda3105(cl_object volatile v1stream, cl_object volatile v2, cl_object volatile v3directives, cl_object volatile v4orig_args, cl_object volatile v5args)
{
 cl_object T0, T1, T2;
 cl_object volatile env0 = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1stream,env0);               /*  STREAM                  */
 {
  volatile cl_object v6;
  volatile cl_object v7;
  volatile cl_object v8;
  volatile cl_object v9;
  volatile cl_object v10;
  volatile cl_object env1 = env0;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  v9 = (cl_env_copy->function=(VV[328]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-STRING */;
  v10 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-END */;
  CLV1 = env1 = CONS(v6,env1);                    /*  COLONP                  */
  CLV2 = env1 = CONS(v9,env1);                    /*  STRING                  */
  CLV3 = env1 = CONS(v10,env1);                   /*  END                     */
  {
   volatile cl_object v11close;
   v11close = L534find_directive(v3directives, ECL_CODE_CHAR(125), ECL_NIL);
   if (v11close!=ECL_NIL) {
    goto L8;
   }
   cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[396]);
L8:;
   {
    volatile cl_object v12;
    v12 = v8;
    {
     volatile cl_object env2 = env1;
     {
      cl_object v13param_and_offset;
      cl_object v14offset;
      cl_object v15param;
      {
       cl_object v16;
       v16 = v12;
       {
        cl_object v17;
        v17 = v16;
        {
         bool v18;
         v18 = ECL_LISTP(v17);
         if (ecl_unlikely(!(v18)))
         FEwrong_type_argument(VV[106],v17);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
       }
       if (Null(v16)){
        goto L17;
       }
       {
        cl_object v17;
        v17 = ECL_CONS_CDR(v16);
        v12 = v17;
        v16 = ECL_CONS_CAR(v16);
       }
L17:;
       v13param_and_offset = v16;
      }
      v14offset = ecl_car(v13param_and_offset);
      v15param = ecl_cdr(v13param_and_offset);
      if (!((v15param)==(VV[33]))){
       goto L25;
      }
      if (!(v5args==ECL_NIL)){
       goto L30;
      }
      cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v14offset);
L30:;
      if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
       goto L32;
      }
      ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L32:;
      {
       cl_object v16;
       v16 = v5args;
       {
        cl_object v17;
        v17 = v16;
        {
         bool v18;
         v18 = ECL_LISTP(v17);
         if (ecl_unlikely(!(v18)))
         FEwrong_type_argument(VV[106],v17);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
       }
       if (Null(v16)){
        goto L38;
       }
       {
        cl_object v17;
        v17 = ECL_CONS_CDR(v16);
        v5args = v17;
        v16 = ECL_CONS_CAR(v16);
       }
L38:;
       value0 = v16;
      }
      if (value0!=ECL_NIL) {
       goto L28;
      }
      T1 = ECL_NIL;
      goto L11;
L28:;
      T1 = value0;
      goto L11;
L25:;
      if (!((v15param)==(VV[34]))){
       goto L44;
      }
      T1 = ecl_make_fixnum(ecl_length(v5args));
      goto L11;
L44:;
      if (!((v15param)==(ECL_NIL))){
       goto L46;
      }
      T1 = ECL_NIL;
      goto L11;
L46:;
      T1 = v15param;
     }
L11:;
     CLV4 = env2 = CONS(T1,env2);                 /*  MAX-COUNT               */
     if (Null(v12)){
      goto L49;
     }
     T1 = ecl_list1(ecl_make_int8_t(1));
     T2 = ecl_caar(v12);
     cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T1, ECL_SYM("OFFSET",1316), T2);
L49:;
     {
      volatile cl_object env3 = env2;
      T1 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v11close) /*  FORMAT-DIRECTIVE-COLONP */;
      CLV5 = env3 = CONS(T1,env3);                /*  CLOSED-WITH-COLON       */
      T1 = cl_position(2, v11close, v3directives);
      CLV6 = env3 = CONS(T1,env3);                /*  POSN                    */
      if (!(ecl_zerop(ECL_CONS_CAR(CLV6)))){
       goto L52;
      }
      if (!(v5args==ECL_NIL)){
       goto L54;
      }
      cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L54:;
      if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
       goto L56;
      }
      ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L56:;
      {
       cl_object v13;
       v13 = v5args;
       {
        cl_object v14;
        v14 = v13;
        {
         bool v15;
         v15 = ECL_LISTP(v14);
         if (ecl_unlikely(!(v15)))
         FEwrong_type_argument(VV[106],v14);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
       }
       if (Null(v13)){
        goto L62;
       }
       {
        cl_object v14;
        v14 = ECL_CONS_CDR(v13);
        v5args = v14;
        v13 = ECL_CONS_CAR(v13);
       }
L62:;
       T1 = v13;
       goto L51;
      }
L52:;
      T1 = cl_subseq(3, v3directives, ecl_make_int8_t(0), ECL_CONS_CAR(CLV6));
L51:;
      CLV7 = env3 = CONS(T1,env3);                /*  INSIDES                 */
      ecl_bds_bind(cl_env_copy,VV[43],ECL_CONS_CAR(CLV1)); /*  *UP-UP-AND-OUT-ALLOWED* */
      if (Null(v7)){
       goto L69;
      }
      v5args = (aux_closure.env=env3,cl_env_copy->function=(cl_object)&aux_closure,LC624do_loop(2, v4orig_args, v5args));
      goto L68;
L69:;
      {
       cl_object v13;
       if (!(v5args==ECL_NIL)){
        goto L73;
       }
       cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L73:;
       if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
        goto L75;
       }
       ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L75:;
       {
        cl_object v14;
        v14 = v5args;
        {
         cl_object v15;
         v15 = v14;
         {
          bool v16;
          v16 = ECL_LISTP(v15);
          if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[106],v15);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
         }
        }
        if (Null(v14)){
         goto L81;
        }
        {
         cl_object v15;
         v15 = ECL_CONS_CDR(v14);
         v5args = v15;
         v14 = ECL_CONS_CAR(v14);
        }
L81:;
        v13 = v14;
       }
       ecl_bds_bind(cl_env_copy,VV[44],ECL_NIL);  /*  *LOGICAL-BLOCK-POPPER*  */
       (aux_closure.env=env3,cl_env_copy->function=(cl_object)&aux_closure,LC624do_loop(2, v13, v13));
       ecl_bds_unwind1(cl_env_copy);
      }
L68:;
      T1 = ecl_one_plus(ECL_CONS_CAR(CLV6));
      T0 = ecl_nthcdr(ecl_to_size(T1),v3directives);
      ecl_bds_unwind1(cl_env_copy);
     }
    }
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC625__lambda3105_va(cl_narg narg, cl_object v11stream, cl_object v12, cl_object v13directives, cl_object v14orig_args, cl_object v15args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[395]);
 {
  return LC625__lambda3105(v11stream, v12, v13directives, v14orig_args, v15args);
 }
}
/* local function RIGHT_CURLY_BRACKET-FORMAT-DIRECTIVE-EXPANDER               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC626right_curly_bracket_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[402]);
 return value0;
}
static cl_object LC626right_curly_bracket_format_directive_expander_va(cl_narg narg, cl_object v3, cl_object v4, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[401]);
 {
  return LC626right_curly_bracket_format_directive_expander(v3, v4);
 }
}
/* local function LAMBDA3151                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC627__lambda3151(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[402]);
 return value0;
}
static cl_object LC627__lambda3151_va(cl_narg narg, cl_object v6stream, cl_object v7, cl_object v8, cl_object v9orig_args, cl_object v10args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[403]);
 {
  return LC627__lambda3151(v6stream, v7, v8, v9orig_args, v10args);
 }
}
/* local function LAMBDA3158                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC628__lambda3158(cl_object v1x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = L519parse_directive(v1x, ecl_make_int8_t(0));
 return value0;
}
static cl_object LC628__lambda3158_va(cl_narg narg, cl_object v2x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[405]);
 {
  return LC628__lambda3158(v2x);
 }
}
/* function definition for CHECK-OUTPUT-LAYOUT-MODE                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L629check_output_layout_mode(cl_object v1mode)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[24]))){
  goto L2;
 }
 if (ecl_eql(ecl_cmp_symbol_value(cl_env_copy,VV[24]),v1mode)) {
  goto L2;
 }
 cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[411]);
L2:;
 T0 = v1mode;
 ecl_cmp_setq(cl_env_copy,VV[24],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[24]);
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for ILLEGAL-INSIDE-JUSTIFICATION-P                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L631illegal_inside_justification_p(cl_object v1directive)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3;
  v2 = ecl_cmp_symbol_value(cl_env_copy,VV[404]);
  {
   cl_object v4;
   v4 = ecl_make_cfun_va((cl_objectfn)LC630__lambda3177_va,ECL_NIL,Cblock,2);
   v3 = v4;
  }
  {
   cl_object v4;
   v4 = v2;
   goto L7;
L6:;
   {
    cl_object v5;
    cl_object v6;
    {
     cl_object v7;
     v7 = v4;
     if (ecl_unlikely(ECL_ATOM(v7))) FEtype_error_cons(v7);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v7;
    }
    v6 = ECL_CONS_CAR(v5);
    if (Null((cl_env_copy->function=(VV[14]->symbol.gfdef))->cfun.entry(1, v1directive) /*  FORMAT-DIRECTIVE-P */)){
     goto L9;
    }
    if (Null((cl_env_copy->function=(VV[14]->symbol.gfdef))->cfun.entry(1, v6) /*  FORMAT-DIRECTIVE-P */)){
     goto L9;
    }
    T0 = (cl_env_copy->function=(VV[55]->symbol.gfdef))->cfun.entry(1, v1directive) /*  FORMAT-DIRECTIVE-CHARACTER */;
    T1 = (cl_env_copy->function=(VV[55]->symbol.gfdef))->cfun.entry(1, v6) /*  FORMAT-DIRECTIVE-CHARACTER */;
    if (!(ecl_eql(T0,T1))){
     goto L9;
    }
    T0 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1directive) /*  FORMAT-DIRECTIVE-COLONP */;
    T1 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v6) /*  FORMAT-DIRECTIVE-COLONP */;
    if (!(ecl_eql(T0,T1))){
     goto L9;
    }
    T0 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1directive) /*  FORMAT-DIRECTIVE-ATSIGNP */;
    T1 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v6) /*  FORMAT-DIRECTIVE-ATSIGNP */;
    if (!(ecl_eql(T0,T1))){
     goto L9;
    }
    value0 = v5;
    cl_env_copy->nvalues = 1;
    return value0;
   }
L9:;
   v4 = ECL_CONS_CDR(v4);
L7:;
   if (v4==ECL_NIL) {
    goto L21;
   }
   goto L6;
L21:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L631illegal_inside_justification_p_va(cl_narg narg, cl_object v5directive, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[412]);
 {
  return L631illegal_inside_justification_p(v5directive);
 }
}
/* local function LESS-THAN_SIGN-FORMAT-DIRECTIVE-EXPANDER                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC633less_than_sign_format_directive_expander(cl_object v1, cl_object v2directives)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  v3 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v4 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v5 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  v6 = (cl_env_copy->function=(VV[328]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-STRING */;
  v7 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-END */;
  {
   cl_object v8;                                  /*  SEGMENTS                */
   cl_object v9;                                  /*  FIRST-SEMI              */
   cl_object v10;                                 /*  CLOSE                   */
   cl_object v11;                                 /*  REMAINING               */
   value0 = L636parse_format_justification(v2directives);
   {
    const int v12 = cl_env_copy->nvalues;
    v8 = value0;
    cl_object v13;
    v13 = (v12<=1)? ECL_NIL : cl_env_copy->values[1];
    v9 = v13;
    v13 = (v12<=2)? ECL_NIL : cl_env_copy->values[2];
    v10 = v13;
    v13 = (v12<=3)? ECL_NIL : cl_env_copy->values[3];
    v11 = v13;
   }
   if (Null((cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v10) /*  FORMAT-DIRECTIVE-COLONP */)){
    goto L9;
   }
   {
    cl_object v12;                                /*  PREFIX                  */
    cl_object v13;                                /*  PER-LINE-P              */
    cl_object v14;                                /*  INSIDES                 */
    cl_object v15;                                /*  SUFFIX                  */
    value0 = L642parse_format_logical_block(v8, v3, v9, v10, v5, v6, v7);
    {
     const int v16 = cl_env_copy->nvalues;
     v12 = value0;
     cl_object v17;
     v17 = (v16<=1)? ECL_NIL : cl_env_copy->values[1];
     v13 = v17;
     v17 = (v16<=2)? ECL_NIL : cl_env_copy->values[2];
     v14 = v17;
     v17 = (v16<=3)? ECL_NIL : cl_env_copy->values[3];
     v15 = v17;
    }
    T0 = L645expand_format_logical_block(v12, v13, v14, v15, v4);
    goto L8;
   }
L9:;
   {
    cl_object v12count;
    T1 = (ECL_SYM("+",16)->symbol.gfdef);
    {
     cl_object v13;
     {
      cl_object v14;
      v14 = ecl_make_cfun_va((cl_objectfn)LC632__lambda3195_va,ECL_NIL,Cblock,1);
      v13 = v14;
     }
     {
      cl_object v14;
      cl_object v15;
      cl_object v16;
      {
       cl_object v17;
       v17 = v8;
       if (ecl_unlikely(!ECL_LISTP(v17))) FEtype_error_list(v17);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v14 = v17;
      }
      v15 = ECL_NIL;
      v16 = v14;
      {
       cl_object v17;
       cl_object v18;
       v17 = ecl_list1(ECL_NIL);
       v18 = v17;
L23:;
       if (!(ecl_endp(v16))){
        goto L25;
       }
       goto L24;
L25:;
       v15 = ECL_CONS_CAR(v16);
       {
        cl_object v19;
        v19 = ECL_CONS_CDR(v16);
        if (ecl_unlikely(!ECL_LISTP(v19))) FEtype_error_list(v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v16 = v19;
       }
       {
        cl_object v19;
        v19 = v18;
        if (ecl_unlikely(ECL_ATOM(v19))) FEtype_error_cons(v19);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T3 = v19;
       }
       T4 = ecl_function_dispatch(cl_env_copy,v13)(1, v15);
       v18 = ecl_list1(T4);
       (ECL_CONS_CDR(T3)=v18,T3);
       goto L23;
L24:;
       T2 = ecl_cdr(v17);
       goto L14;
      }
     }
    }
L14:;
    v12count = cl_reduce(2, T1, T2);
    if (!(ecl_greater(v12count,ecl_make_int8_t(0)))){
     goto L41;
    }
    T1 = ecl_list1(v12count);
    cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[421], VV[110], T1);
L41:;
    T0 = L638expand_format_justification(v8, v3, v4, v9, v5);
   }
L8:;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = v11;
   cl_env_copy->values[0] = T0;
   return cl_env_copy->values[0];
  }
 }
}
static cl_object LC633less_than_sign_format_directive_expander_va(cl_narg narg, cl_object v8, cl_object v9directives, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[416]);
 {
  return LC633less_than_sign_format_directive_expander(v8, v9directives);
 }
}
/* local function LAMBDA3200                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC635__lambda3200(cl_object v1stream, cl_object v2, cl_object v3directives, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  cl_object v9;
  cl_object v10;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  v9 = (cl_env_copy->function=(VV[328]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-STRING */;
  v10 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-END */;
  {
   cl_object v11;                                 /*  SEGMENTS                */
   cl_object v12;                                 /*  FIRST-SEMI              */
   cl_object v13;                                 /*  CLOSE                   */
   cl_object v14;                                 /*  REMAINING               */
   value0 = L636parse_format_justification(v3directives);
   {
    const int v15 = cl_env_copy->nvalues;
    v11 = value0;
    cl_object v16;
    v16 = (v15<=1)? ECL_NIL : cl_env_copy->values[1];
    v12 = v16;
    v16 = (v15<=2)? ECL_NIL : cl_env_copy->values[2];
    v13 = v16;
    v16 = (v15<=3)? ECL_NIL : cl_env_copy->values[3];
    v14 = v16;
   }
   if (Null((cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v13) /*  FORMAT-DIRECTIVE-COLONP */)){
    goto L11;
   }
   {
    cl_object v15;                                /*  PREFIX                  */
    cl_object v16;                                /*  PER-LINE-P              */
    cl_object v17;                                /*  INSIDES                 */
    cl_object v18;                                /*  SUFFIX                  */
    value0 = L642parse_format_logical_block(v11, v6, v12, v13, v8, v9, v10);
    {
     const int v19 = cl_env_copy->nvalues;
     v15 = value0;
     cl_object v20;
     v20 = (v19<=1)? ECL_NIL : cl_env_copy->values[1];
     v16 = v20;
     v20 = (v19<=2)? ECL_NIL : cl_env_copy->values[2];
     v17 = v20;
     v20 = (v19<=3)? ECL_NIL : cl_env_copy->values[3];
     v18 = v20;
    }
    v5args = L650interpret_format_logical_block(v1stream, v4orig_args, v5args, v15, v16, v17, v18, v7);
    goto L10;
   }
L11:;
   {
    cl_object v15count;
    T1 = (ECL_SYM("+",16)->symbol.gfdef);
    {
     cl_object v16;
     {
      cl_object v17;
      v17 = ecl_make_cfun_va((cl_objectfn)LC634__lambda3213_va,ECL_NIL,Cblock,1);
      v16 = v17;
     }
     {
      cl_object v17;
      cl_object v18;
      cl_object v19;
      {
       cl_object v20;
       v20 = v11;
       if (ecl_unlikely(!ECL_LISTP(v20))) FEtype_error_list(v20);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v17 = v20;
      }
      v18 = ECL_NIL;
      v19 = v17;
      {
       cl_object v20;
       cl_object v21;
       v20 = ecl_list1(ECL_NIL);
       v21 = v20;
L25:;
       if (!(ecl_endp(v19))){
        goto L27;
       }
       goto L26;
L27:;
       v18 = ECL_CONS_CAR(v19);
       {
        cl_object v22;
        v22 = ECL_CONS_CDR(v19);
        if (ecl_unlikely(!ECL_LISTP(v22))) FEtype_error_list(v22);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v19 = v22;
       }
       {
        cl_object v22;
        v22 = v21;
        if (ecl_unlikely(ECL_ATOM(v22))) FEtype_error_cons(v22);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T3 = v22;
       }
       T4 = ecl_function_dispatch(cl_env_copy,v16)(1, v18);
       v21 = ecl_list1(T4);
       (ECL_CONS_CDR(T3)=v21,T3);
       goto L25;
L26:;
       T2 = ecl_cdr(v20);
       goto L16;
      }
     }
    }
L16:;
    v15count = cl_reduce(2, T1, T2);
    if (!(ecl_greater(v15count,ecl_make_int8_t(0)))){
     goto L43;
    }
    T1 = ecl_list1(v15count);
    cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[421], VV[110], T1);
L43:;
    v5args = L639interpret_format_justification(v1stream, v4orig_args, v5args, v11, v6, v7, v12, v8);
   }
L10:;
   T0 = v14;
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC635__lambda3200_va(cl_narg narg, cl_object v11stream, cl_object v12, cl_object v13directives, cl_object v14orig_args, cl_object v15args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[423]);
 {
  return LC635__lambda3200(v11stream, v12, v13directives, v14orig_args, v15args);
 }
}
/* function definition for PARSE-FORMAT-JUSTIFICATION                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L636parse_format_justification(cl_object v1directives)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2first_semi;
  cl_object v3close;
  cl_object v4remaining;
  v2first_semi = ECL_NIL;
  v3close = ECL_NIL;
  v4remaining = v1directives;
  {
   cl_object v5;
   cl_object v6;
   v5 = ECL_NIL;
   v6 = ECL_NIL;
L8:;
   {
    cl_object v7close_or_semi;
    v7close_or_semi = L534find_directive(v4remaining, ECL_CODE_CHAR(62), ECL_T);
    if (v7close_or_semi!=ECL_NIL) {
     goto L11;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[348]);
L11:;
    {
     cl_object v8posn;
     v8posn = cl_position(2, v7close_or_semi, v4remaining);
     {
      cl_object v9;
      T0 = cl_subseq(3, v4remaining, ecl_make_int8_t(0), v8posn);
      v9 = CONS(T0,ECL_NIL);
      if (Null(v6)){
       goto L18;
      }
      {
       cl_object v10;
       v10 = v6;
       if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v10;
      }
      (ECL_CONS_CDR(T0)=v9,T0);
      v6 = v9;
      goto L16;
L18:;
      v6 = v9;
      v5 = v9;
     }
L16:;
     T0 = ecl_one_plus(v8posn);
     v4remaining = ecl_nthcdr(ecl_to_size(T0),v4remaining);
    }
    T0 = (cl_env_copy->function=(VV[55]->symbol.gfdef))->cfun.entry(1, v7close_or_semi) /*  FORMAT-DIRECTIVE-CHARACTER */;
    if (!(ecl_char_code(T0)==ecl_char_code(ECL_CODE_CHAR(62)))){
     goto L29;
    }
    v3close = v7close_or_semi;
    goto L7;
L29:;
    if (v2first_semi!=ECL_NIL) {
     goto L9;
    }
    v2first_semi = v7close_or_semi;
   }
L9:;
   goto L8;
L7:;
   cl_env_copy->nvalues = 4;
   cl_env_copy->values[3] = v4remaining;
   cl_env_copy->values[2] = v3close;
   cl_env_copy->values[1] = v2first_semi;
   cl_env_copy->values[0] = v5;
   return cl_env_copy->values[0];
  }
 }
}
/* function definition for EXPAND-FORMAT-JUSTIFICATION                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L638expand_format_justification(cl_object v1segments, cl_object v2colonp, cl_object v3atsignp, cl_object v4first_semi, cl_object v5params)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22, T23, T24, T25, T26;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6newline_segment_p;
  if (Null(v4first_semi)){
   goto L4;
  }
  v6newline_segment_p = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v4first_semi) /*  FORMAT-DIRECTIVE-COLONP */;
  goto L2;
L4:;
  v6newline_segment_p = ECL_NIL;
  goto L2;
L2:;
  if (Null(v6newline_segment_p)){
   goto L6;
  }
  L629check_output_layout_mode(ecl_make_int8_t(2));
L6:;
  {
   cl_object v7;
   v7 = v5params;
   {
    cl_object v8param_and_offset;
    cl_object v9offset;
    cl_object v10param;
    {
     cl_object v11;
     v11 = v7;
     {
      cl_object v12;
      v12 = v11;
      {
       bool v13;
       v13 = ECL_LISTP(v12);
       if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(VV[106],v12);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v11)){
      goto L15;
     }
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v11);
      v7 = v12;
      v11 = ECL_CONS_CAR(v11);
     }
L15:;
     v8param_and_offset = v11;
    }
    v9offset = ecl_car(v8param_and_offset);
    v10param = ecl_cdr(v8param_and_offset);
    if (!((v10param)==(VV[33]))){
     goto L23;
    }
    T1 = L527expand_next_arg(1, v9offset);
    T0 = cl_list(3, ECL_SYM("OR",616), T1, ecl_make_int8_t(0));
    goto L9;
L23:;
    if (!((v10param)==(VV[34]))){
     goto L25;
    }
    T1 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T1);
    T0 = VV[107];
    goto L9;
L25:;
    if (!((v10param)==(ECL_NIL))){
     goto L29;
    }
    T0 = ecl_make_int8_t(0);
    goto L9;
L29:;
    T0 = v10param;
   }
L9:;
   T1 = cl_list(2, VV[428], T0);
   {
    cl_object v8param_and_offset;
    cl_object v9offset;
    cl_object v10param;
    {
     cl_object v11;
     v11 = v7;
     {
      cl_object v12;
      v12 = v11;
      {
       bool v13;
       v13 = ECL_LISTP(v12);
       if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(VV[106],v12);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v11)){
      goto L38;
     }
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v11);
      v7 = v12;
      v11 = ECL_CONS_CAR(v11);
     }
L38:;
     v8param_and_offset = v11;
    }
    v9offset = ecl_car(v8param_and_offset);
    v10param = ecl_cdr(v8param_and_offset);
    if (!((v10param)==(VV[33]))){
     goto L46;
    }
    T3 = L527expand_next_arg(1, v9offset);
    T2 = cl_list(3, ECL_SYM("OR",616), T3, ecl_make_int8_t(1));
    goto L32;
L46:;
    if (!((v10param)==(VV[34]))){
     goto L48;
    }
    T3 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T3);
    T2 = VV[107];
    goto L32;
L48:;
    if (!((v10param)==(ECL_NIL))){
     goto L52;
    }
    T2 = ecl_make_int8_t(1);
    goto L32;
L52:;
    T2 = v10param;
   }
L32:;
   T3 = cl_list(2, VV[429], T2);
   {
    cl_object v8param_and_offset;
    cl_object v9offset;
    cl_object v10param;
    {
     cl_object v11;
     v11 = v7;
     {
      cl_object v12;
      v12 = v11;
      {
       bool v13;
       v13 = ECL_LISTP(v12);
       if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(VV[106],v12);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v11)){
      goto L61;
     }
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v11);
      v7 = v12;
      v11 = ECL_CONS_CAR(v11);
     }
L61:;
     v8param_and_offset = v11;
    }
    v9offset = ecl_car(v8param_and_offset);
    v10param = ecl_cdr(v8param_and_offset);
    if (!((v10param)==(VV[33]))){
     goto L69;
    }
    T5 = L527expand_next_arg(1, v9offset);
    T4 = cl_list(3, ECL_SYM("OR",616), T5, ecl_make_int8_t(0));
    goto L55;
L69:;
    if (!((v10param)==(VV[34]))){
     goto L71;
    }
    T5 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T5);
    T4 = VV[107];
    goto L55;
L71:;
    if (!((v10param)==(ECL_NIL))){
     goto L75;
    }
    T4 = ecl_make_int8_t(0);
    goto L55;
L75:;
    T4 = v10param;
   }
L55:;
   T5 = cl_list(2, VV[430], T4);
   {
    cl_object v8param_and_offset;
    cl_object v9offset;
    cl_object v10param;
    {
     cl_object v11;
     v11 = v7;
     {
      cl_object v12;
      v12 = v11;
      {
       bool v13;
       v13 = ECL_LISTP(v12);
       if (ecl_unlikely(!(v13)))
         FEwrong_type_argument(VV[106],v12);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v11)){
      goto L84;
     }
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v11);
      v7 = v12;
      v11 = ECL_CONS_CAR(v11);
     }
L84:;
     v8param_and_offset = v11;
    }
    v9offset = ecl_car(v8param_and_offset);
    v10param = ecl_cdr(v8param_and_offset);
    if (!((v10param)==(VV[33]))){
     goto L92;
    }
    T7 = L527expand_next_arg(1, v9offset);
    T6 = cl_list(3, ECL_SYM("OR",616), T7, ECL_CODE_CHAR(32));
    goto L78;
L92:;
    if (!((v10param)==(VV[34]))){
     goto L94;
    }
    T7 = ECL_NIL;
    ecl_cmp_setq(cl_env_copy,VV[47],T7);
    T6 = VV[107];
    goto L78;
L94:;
    if (!((v10param)==(ECL_NIL))){
     goto L98;
    }
    T6 = ECL_CODE_CHAR(32);
    goto L78;
L98:;
    T6 = v10param;
   }
L78:;
   T7 = cl_list(2, VV[431], T6);
   T8 = cl_list(4, T1, T3, T5, T7);
   if (Null(v7)){
    goto L102;
   }
   T10 = ecl_list1(ecl_make_int8_t(4));
   T11 = ecl_caar(v7);
   T9 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T10, ECL_SYM("OFFSET",1316), T11);
   goto L101;
L102:;
   T9 = ECL_NIL;
L101:;
   if (Null(v6newline_segment_p)){
    goto L105;
   }
   T10 = VV[433];
   goto L104;
L105:;
   T10 = ECL_NIL;
L104:;
   T11 = CONS(VV[432],T10);
   if (Null(v6newline_segment_p)){
    goto L108;
   }
   {
    cl_object v8;
    v8 = v1segments;
    {
     cl_object v9;
     v9 = v8;
     {
      bool v10;
      v10 = ECL_LISTP(v9);
      if (ecl_unlikely(!(v10)))
         FEwrong_type_argument(VV[106],v9);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v8)){
     goto L115;
    }
    {
     cl_object v9;
     v9 = ECL_CONS_CDR(v8);
     v1segments = v9;
     v8 = ECL_CONS_CAR(v8);
    }
L115:;
    T13 = v8;
   }
   T14 = L525expand_directive_list(T13);
   T15 = cl_listX(3, ECL_SYM("WITH-OUTPUT-TO-STRING",917), VV[435], T14);
   T16 = cl_list(3, ECL_SYM("SETF",753), VV[434], T15);
   {
    cl_object v8;
    v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v4first_semi) /*  FORMAT-DIRECTIVE-PARAMS */;
    {
     cl_object v9param_and_offset;
     cl_object v10offset;
     cl_object v11param;
     {
      cl_object v12;
      v12 = v8;
      {
       cl_object v13;
       v13 = v12;
       {
        bool v14;
        v14 = ECL_LISTP(v13);
        if (ecl_unlikely(!(v14)))
         FEwrong_type_argument(VV[106],v13);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v12)){
       goto L129;
      }
      {
       cl_object v13;
       v13 = ECL_CONS_CDR(v12);
       v8 = v13;
       v12 = ECL_CONS_CAR(v12);
      }
L129:;
      v9param_and_offset = v12;
     }
     v10offset = ecl_car(v9param_and_offset);
     v11param = ecl_cdr(v9param_and_offset);
     if (!((v11param)==(VV[33]))){
      goto L137;
     }
     T19 = L527expand_next_arg(1, v10offset);
     T18 = cl_list(3, ECL_SYM("OR",616), T19, ecl_make_int8_t(0));
     goto L123;
L137:;
     if (!((v11param)==(VV[34]))){
      goto L139;
     }
     T19 = ECL_NIL;
     ecl_cmp_setq(cl_env_copy,VV[47],T19);
     T18 = VV[107];
     goto L123;
L139:;
     if (!((v11param)==(ECL_NIL))){
      goto L143;
     }
     T18 = ecl_make_int8_t(0);
     goto L123;
L143:;
     T18 = v11param;
    }
L123:;
    T19 = cl_list(2, VV[436], T18);
    {
     cl_object v9param_and_offset;
     cl_object v10offset;
     cl_object v11param;
     {
      cl_object v12;
      v12 = v8;
      {
       cl_object v13;
       v13 = v12;
       {
        bool v14;
        v14 = ECL_LISTP(v13);
        if (ecl_unlikely(!(v14)))
         FEwrong_type_argument(VV[106],v13);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
       }
      }
      if (Null(v12)){
       goto L152;
      }
      {
       cl_object v13;
       v13 = ECL_CONS_CDR(v12);
       v8 = v13;
       v12 = ECL_CONS_CAR(v12);
      }
L152:;
      v9param_and_offset = v12;
     }
     v10offset = ecl_car(v9param_and_offset);
     v11param = ecl_cdr(v9param_and_offset);
     if (!((v11param)==(VV[33]))){
      goto L160;
     }
     T21 = L527expand_next_arg(1, v10offset);
     T20 = cl_list(3, ECL_SYM("OR",616), T21, VV[438]);
     goto L146;
L160:;
     if (!((v11param)==(VV[34]))){
      goto L162;
     }
     T21 = ECL_NIL;
     ecl_cmp_setq(cl_env_copy,VV[47],T21);
     T20 = VV[107];
     goto L146;
L162:;
     if (!((v11param)==(ECL_NIL))){
      goto L166;
     }
     T20 = VV[438];
     goto L146;
L166:;
     T20 = v11param;
    }
L146:;
    T21 = cl_list(2, VV[437], T20);
    T22 = cl_list(2, T19, T21);
    if (Null(v8)){
     goto L170;
    }
    T24 = ecl_list1(ecl_make_int8_t(2));
    T25 = ecl_caar(v8);
    T23 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T24, ECL_SYM("OFFSET",1316), T25);
    goto L169;
L170:;
    T23 = ECL_NIL;
L169:;
    T24 = cl_list(5, ECL_SYM("SETF",753), VV[439], VV[436], VV[440], VV[437]);
    T25 = ecl_list1(T24);
    T26 = ecl_append(T23,T25);
    T17 = cl_listX(3, ECL_SYM("LET",479), T22, T26);
   }
   T12 = cl_list(2, T16, T17);
   goto L107;
L108:;
   T12 = ECL_NIL;
L107:;
   {
    cl_object v8;
    {
     cl_object v9;
     v9 = ecl_make_cfun_va((cl_objectfn)LC637__lambda3338_va,ECL_NIL,Cblock,1);
     v8 = v9;
    }
    {
     cl_object v9;
     cl_object v10;
     cl_object v11;
     {
      cl_object v12;
      v12 = v1segments;
      if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v9 = v12;
     }
     v10 = ECL_NIL;
     v11 = v9;
     {
      cl_object v12;
      cl_object v13;
      v12 = ecl_list1(ECL_NIL);
      v13 = v12;
L181:;
      if (!(ecl_endp(v11))){
       goto L183;
      }
      goto L182;
L183:;
      v10 = ECL_CONS_CAR(v11);
      {
       cl_object v14;
       v14 = ECL_CONS_CDR(v11);
       if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v11 = v14;
      }
      {
       cl_object v14;
       v14 = v13;
       if (ecl_unlikely(ECL_ATOM(v14))) FEtype_error_cons(v14);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T14 = v14;
      }
      T15 = ecl_function_dispatch(cl_env_copy,v8)(1, v10);
      v13 = ecl_list1(T15);
      (ECL_CONS_CDR(T14)=v13,T14);
      goto L181;
L182:;
      T13 = ecl_cdr(v12);
      goto L172;
     }
    }
   }
L172:;
   T14 = ecl_append(T12,T13);
   T15 = cl_listX(3, ECL_SYM("BLOCK",139), ECL_NIL, T14);
   if (Null(v6newline_segment_p)){
    goto L200;
   }
   T16 = VV[443];
   goto L199;
L200:;
   T16 = VV[444];
L199:;
   T17 = cl_list(7, VV[427], v2colonp, v3atsignp, VV[428], VV[429], VV[430], VV[431]);
   T18 = ecl_append(T16,T17);
   T19 = cl_listX(3, VV[442], ECL_SYM("STREAM",802), T18);
   T20 = cl_list(4, ECL_SYM("LET",479), T11, T15, T19);
   T21 = ecl_list1(T20);
   T22 = ecl_append(T9,T21);
   value0 = cl_listX(3, ECL_SYM("LET",479), T8, T22);
   return value0;
  }
 }
}
/* function definition for INTERPRET-FORMAT-JUSTIFICATION                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L639interpret_format_justification(cl_object volatile v1stream, cl_object volatile v2orig_args, cl_object volatile v3args, cl_object volatile v4segments, cl_object volatile v5colonp, cl_object volatile v6atsignp, cl_object volatile v7first_semi, cl_object volatile v8params)
{
 cl_object T0, T1;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v9;
  v9 = v8params;
  {
   volatile cl_object v10mincol;
   volatile cl_object v11colinc;
   volatile cl_object v12minpad;
   volatile cl_object v13padchar;
   {
    cl_object v14param_and_offset;
    cl_object v15offset;
    cl_object v16param;
    {
     cl_object v17;
     v17 = v9;
     {
      cl_object v18;
      v18 = v17;
      {
       bool v19;
       v19 = ECL_LISTP(v18);
       if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v17)){
      goto L10;
     }
     {
      cl_object v18;
      v18 = ECL_CONS_CDR(v17);
      v9 = v18;
      v17 = ECL_CONS_CAR(v17);
     }
L10:;
     v14param_and_offset = v17;
    }
    v15offset = ecl_car(v14param_and_offset);
    v16param = ecl_cdr(v14param_and_offset);
    if (!((v16param)==(VV[33]))){
     goto L18;
    }
    if (!(v3args==ECL_NIL)){
     goto L23;
    }
    cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L23:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L25;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L25:;
    {
     cl_object v17;
     v17 = v3args;
     {
      cl_object v18;
      v18 = v17;
      {
       bool v19;
       v19 = ECL_LISTP(v18);
       if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v17)){
      goto L31;
     }
     {
      cl_object v18;
      v18 = ECL_CONS_CDR(v17);
      v3args = v18;
      v17 = ECL_CONS_CAR(v17);
     }
L31:;
     value0 = v17;
    }
    if (value0!=ECL_NIL) {
     goto L21;
    }
    v10mincol = ecl_make_int8_t(0);
    goto L4;
L21:;
    v10mincol = value0;
    goto L4;
L18:;
    if (!((v16param)==(VV[34]))){
     goto L37;
    }
    v10mincol = ecl_make_fixnum(ecl_length(v3args));
    goto L4;
L37:;
    if (!((v16param)==(ECL_NIL))){
     goto L39;
    }
    v10mincol = ecl_make_int8_t(0);
    goto L4;
L39:;
    v10mincol = v16param;
   }
L4:;
   {
    cl_object v14param_and_offset;
    cl_object v15offset;
    cl_object v16param;
    {
     cl_object v17;
     v17 = v9;
     {
      cl_object v18;
      v18 = v17;
      {
       bool v19;
       v19 = ECL_LISTP(v18);
       if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v17)){
      goto L48;
     }
     {
      cl_object v18;
      v18 = ECL_CONS_CDR(v17);
      v9 = v18;
      v17 = ECL_CONS_CAR(v17);
     }
L48:;
     v14param_and_offset = v17;
    }
    v15offset = ecl_car(v14param_and_offset);
    v16param = ecl_cdr(v14param_and_offset);
    if (!((v16param)==(VV[33]))){
     goto L56;
    }
    if (!(v3args==ECL_NIL)){
     goto L61;
    }
    cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L61:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L63;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L63:;
    {
     cl_object v17;
     v17 = v3args;
     {
      cl_object v18;
      v18 = v17;
      {
       bool v19;
       v19 = ECL_LISTP(v18);
       if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v17)){
      goto L69;
     }
     {
      cl_object v18;
      v18 = ECL_CONS_CDR(v17);
      v3args = v18;
      v17 = ECL_CONS_CAR(v17);
     }
L69:;
     value0 = v17;
    }
    if (value0!=ECL_NIL) {
     goto L59;
    }
    v11colinc = ecl_make_int8_t(1);
    goto L42;
L59:;
    v11colinc = value0;
    goto L42;
L56:;
    if (!((v16param)==(VV[34]))){
     goto L75;
    }
    v11colinc = ecl_make_fixnum(ecl_length(v3args));
    goto L42;
L75:;
    if (!((v16param)==(ECL_NIL))){
     goto L77;
    }
    v11colinc = ecl_make_int8_t(1);
    goto L42;
L77:;
    v11colinc = v16param;
   }
L42:;
   {
    cl_object v14param_and_offset;
    cl_object v15offset;
    cl_object v16param;
    {
     cl_object v17;
     v17 = v9;
     {
      cl_object v18;
      v18 = v17;
      {
       bool v19;
       v19 = ECL_LISTP(v18);
       if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v17)){
      goto L86;
     }
     {
      cl_object v18;
      v18 = ECL_CONS_CDR(v17);
      v9 = v18;
      v17 = ECL_CONS_CAR(v17);
     }
L86:;
     v14param_and_offset = v17;
    }
    v15offset = ecl_car(v14param_and_offset);
    v16param = ecl_cdr(v14param_and_offset);
    if (!((v16param)==(VV[33]))){
     goto L94;
    }
    if (!(v3args==ECL_NIL)){
     goto L99;
    }
    cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L99:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L101;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L101:;
    {
     cl_object v17;
     v17 = v3args;
     {
      cl_object v18;
      v18 = v17;
      {
       bool v19;
       v19 = ECL_LISTP(v18);
       if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v17)){
      goto L107;
     }
     {
      cl_object v18;
      v18 = ECL_CONS_CDR(v17);
      v3args = v18;
      v17 = ECL_CONS_CAR(v17);
     }
L107:;
     value0 = v17;
    }
    if (value0!=ECL_NIL) {
     goto L97;
    }
    v12minpad = ecl_make_int8_t(0);
    goto L80;
L97:;
    v12minpad = value0;
    goto L80;
L94:;
    if (!((v16param)==(VV[34]))){
     goto L113;
    }
    v12minpad = ecl_make_fixnum(ecl_length(v3args));
    goto L80;
L113:;
    if (!((v16param)==(ECL_NIL))){
     goto L115;
    }
    v12minpad = ecl_make_int8_t(0);
    goto L80;
L115:;
    v12minpad = v16param;
   }
L80:;
   {
    cl_object v14param_and_offset;
    cl_object v15offset;
    cl_object v16param;
    {
     cl_object v17;
     v17 = v9;
     {
      cl_object v18;
      v18 = v17;
      {
       bool v19;
       v19 = ECL_LISTP(v18);
       if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v17)){
      goto L124;
     }
     {
      cl_object v18;
      v18 = ECL_CONS_CDR(v17);
      v9 = v18;
      v17 = ECL_CONS_CAR(v17);
     }
L124:;
     v14param_and_offset = v17;
    }
    v15offset = ecl_car(v14param_and_offset);
    v16param = ecl_cdr(v14param_and_offset);
    if (!((v16param)==(VV[33]))){
     goto L132;
    }
    if (!(v3args==ECL_NIL)){
     goto L137;
    }
    cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v15offset);
L137:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L139;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L139:;
    {
     cl_object v17;
     v17 = v3args;
     {
      cl_object v18;
      v18 = v17;
      {
       bool v19;
       v19 = ECL_LISTP(v18);
       if (ecl_unlikely(!(v19)))
         FEwrong_type_argument(VV[106],v18);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v17)){
      goto L145;
     }
     {
      cl_object v18;
      v18 = ECL_CONS_CDR(v17);
      v3args = v18;
      v17 = ECL_CONS_CAR(v17);
     }
L145:;
     value0 = v17;
    }
    if (value0!=ECL_NIL) {
     goto L135;
    }
    v13padchar = ECL_CODE_CHAR(32);
    goto L118;
L135:;
    v13padchar = value0;
    goto L118;
L132:;
    if (!((v16param)==(VV[34]))){
     goto L151;
    }
    v13padchar = ecl_make_fixnum(ecl_length(v3args));
    goto L118;
L151:;
    if (!((v16param)==(ECL_NIL))){
     goto L153;
    }
    v13padchar = ECL_CODE_CHAR(32);
    goto L118;
L153:;
    v13padchar = v16param;
   }
L118:;
   if (Null(v9)){
    goto L156;
   }
   T0 = ecl_list1(ecl_make_int8_t(4));
   T1 = ecl_caar(v9);
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L156:;
   {
    volatile cl_object v14newline_string;
    volatile cl_object v15strings;
    volatile cl_object v16extra_space;
    volatile cl_object v17line_len;
    v14newline_string = ECL_NIL;
    v15strings = ECL_NIL;
    v16extra_space = ecl_make_int8_t(0);
    v17line_len = ecl_make_int8_t(0);
    value0 = VV[50];                              /*  BEGIN CATCH CATCH3599   */
    {
     ecl_frs_push(cl_env_copy,value0);
     if (__ecl_frs_push_result!=0) {
      value0 = cl_env_copy->values[0];
     } else {
      if (Null(v7first_semi)){
       goto L167;
      }
      if (Null((cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v7first_semi) /*  FORMAT-DIRECTIVE-COLONP */)){
       goto L167;
      }
      L629check_output_layout_mode(ecl_make_int8_t(2));
      {
       volatile cl_object v18;
       v18 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v7first_semi) /*  FORMAT-DIRECTIVE-PARAMS */;
       {
        volatile cl_object v19extra;
        volatile cl_object v20len;
        {
         cl_object v21param_and_offset;
         cl_object v22offset;
         cl_object v23param;
         {
          cl_object v24;
          v24 = v18;
          {
          cl_object v25;
          v25 = v24;
          {
          bool v26;
          v26 = ECL_LISTP(v25);
          if (ecl_unlikely(!(v26)))
         FEwrong_type_argument(VV[106],v25);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          }
          }
          if (Null(v24)){
          goto L178;
          }
          {
          cl_object v25;
          v25 = ECL_CONS_CDR(v24);
          v18 = v25;
          v24 = ECL_CONS_CAR(v24);
          }
L178:;
          v21param_and_offset = v24;
         }
         v22offset = ecl_car(v21param_and_offset);
         v23param = ecl_cdr(v21param_and_offset);
         if (!((v23param)==(VV[33]))){
          goto L186;
         }
         if (!(v3args==ECL_NIL)){
          goto L191;
         }
         cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v22offset);
L191:;
         if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
          goto L193;
         }
         ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L193:;
         {
          cl_object v24;
          v24 = v3args;
          {
          cl_object v25;
          v25 = v24;
          {
          bool v26;
          v26 = ECL_LISTP(v25);
          if (ecl_unlikely(!(v26)))
         FEwrong_type_argument(VV[106],v25);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          }
          }
          if (Null(v24)){
          goto L199;
          }
          {
          cl_object v25;
          v25 = ECL_CONS_CDR(v24);
          v3args = v25;
          v24 = ECL_CONS_CAR(v24);
          }
L199:;
          value0 = v24;
         }
         if (value0!=ECL_NIL) {
          goto L189;
         }
         v19extra = ecl_make_int8_t(0);
         goto L172;
L189:;
         v19extra = value0;
         goto L172;
L186:;
         if (!((v23param)==(VV[34]))){
          goto L205;
         }
         v19extra = ecl_make_fixnum(ecl_length(v3args));
         goto L172;
L205:;
         if (!((v23param)==(ECL_NIL))){
          goto L207;
         }
         v19extra = ecl_make_int8_t(0);
         goto L172;
L207:;
         v19extra = v23param;
        }
L172:;
        {
         cl_object v21param_and_offset;
         cl_object v22offset;
         cl_object v23param;
         {
          cl_object v24;
          v24 = v18;
          {
          cl_object v25;
          v25 = v24;
          {
          bool v26;
          v26 = ECL_LISTP(v25);
          if (ecl_unlikely(!(v26)))
         FEwrong_type_argument(VV[106],v25);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          }
          }
          if (Null(v24)){
          goto L216;
          }
          {
          cl_object v25;
          v25 = ECL_CONS_CDR(v24);
          v18 = v25;
          v24 = ECL_CONS_CAR(v24);
          }
L216:;
          v21param_and_offset = v24;
         }
         v22offset = ecl_car(v21param_and_offset);
         v23param = ecl_cdr(v21param_and_offset);
         if (!((v23param)==(VV[33]))){
          goto L224;
         }
         if (!(v3args==ECL_NIL)){
          goto L229;
         }
         cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78], ECL_SYM("OFFSET",1316), v22offset);
L229:;
         if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
          goto L231;
         }
         ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L231:;
         {
          cl_object v24;
          v24 = v3args;
          {
          cl_object v25;
          v25 = v24;
          {
          bool v26;
          v26 = ECL_LISTP(v25);
          if (ecl_unlikely(!(v26)))
         FEwrong_type_argument(VV[106],v25);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          }
          }
          if (Null(v24)){
          goto L237;
          }
          {
          cl_object v25;
          v25 = ECL_CONS_CDR(v24);
          v3args = v25;
          v24 = ECL_CONS_CAR(v24);
          }
L237:;
          value0 = v24;
         }
         if (value0!=ECL_NIL) {
          goto L227;
         }
         value0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PRINT-RIGHT-MARGIN*",60));
         if (value0!=ECL_NIL) {
          goto L244;
         }
         value0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-LINE-LENGTH",1707)))->cfun.entry(1, v1stream) /*  STREAM-LINE-LENGTH */;
         if (value0!=ECL_NIL) {
          goto L244;
         }
         v20len = ecl_make_int8_t(80);
         goto L210;
L244:;
         v20len = value0;
         goto L210;
L227:;
         v20len = value0;
         goto L210;
L224:;
         if (!((v23param)==(VV[34]))){
          goto L247;
         }
         v20len = ecl_make_fixnum(ecl_length(v3args));
         goto L210;
L247:;
         if (!((v23param)==(ECL_NIL))){
          goto L249;
         }
         value0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PRINT-RIGHT-MARGIN*",60));
         if (value0!=ECL_NIL) {
          goto L253;
         }
         value0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("STREAM-LINE-LENGTH",1707)))->cfun.entry(1, v1stream) /*  STREAM-LINE-LENGTH */;
         if (value0!=ECL_NIL) {
          goto L253;
         }
         v20len = ecl_make_int8_t(80);
         goto L210;
L253:;
         v20len = value0;
         goto L210;
L249:;
         v20len = v23param;
        }
L210:;
        if (Null(v18)){
         goto L256;
        }
        T0 = ecl_list1(ecl_make_int8_t(2));
        T1 = ecl_caar(v18);
        cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[109], VV[110], T0, ECL_SYM("OFFSET",1316), T1);
L256:;
        {
         volatile cl_object v21stream;
         v21stream = cl_make_string_output_stream(0);
         {
          struct ecl_stack_frame _ecl_inner_frame_aux;
          volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
          volatile bool unwinding = FALSE;
          ecl_frame_ptr next_fr;
          {
          ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
          if (__ecl_frs_push_result!=0) {
            unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
          } else {
          {
          cl_object v22;
          v22 = v4segments;
          {
          cl_object v23;
          v23 = v22;
          {
          bool v24;
          v24 = ECL_LISTP(v23);
          if (ecl_unlikely(!(v24)))
         FEwrong_type_argument(VV[106],v23);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          }
          }
          if (Null(v22)){
          goto L269;
          }
          {
          cl_object v23;
          v23 = ECL_CONS_CDR(v22);
          v4segments = v23;
          v22 = ECL_CONS_CAR(v22);
          }
L269:;
          T0 = v22;
          }
          v3args = L521interpret_directive_list(v21stream, T0, v2orig_args, v3args);
          cl_env_copy->values[0] = cl_get_output_stream_string(v21stream);
          }
          }
          ecl_frs_pop(cl_env_copy);
          ecl_stack_frame_push_values(_ecl_inner_frame);
          cl_close(1, v21stream);
          ecl_stack_frame_pop_values(_ecl_inner_frame);
          if (unwinding) ecl_unwind(cl_env_copy,next_fr);
          v14newline_string = cl_env_copy->values[0];
          ecl_stack_frame_close(_ecl_inner_frame);
         }
        }
        v16extra_space = v19extra;
        v17line_len = v20len;
       }
      }
L167:;
      {
       volatile cl_object v18;
       v18 = v4segments;
       goto L283;
L282:;
       {
        volatile cl_object v19segment;
        v19segment = ecl_car(v18);
        {
         volatile cl_object v20stream;
         v20stream = cl_make_string_output_stream(0);
         {
          struct ecl_stack_frame _ecl_inner_frame_aux;
          volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
          volatile bool unwinding = FALSE;
          ecl_frame_ptr next_fr;
          {
          ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
          if (__ecl_frs_push_result!=0) {
            unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
          } else {
          v3args = L521interpret_directive_list(v20stream, v19segment, v2orig_args, v3args);
          cl_env_copy->values[0] = cl_get_output_stream_string(v20stream);
          }
          }
          ecl_frs_pop(cl_env_copy);
          ecl_stack_frame_push_values(_ecl_inner_frame);
          cl_close(1, v20stream);
          ecl_stack_frame_pop_values(_ecl_inner_frame);
          if (unwinding) ecl_unwind(cl_env_copy,next_fr);
          T0 = cl_env_copy->values[0];
          ecl_stack_frame_close(_ecl_inner_frame);
         }
        }
        v15strings = CONS(T0,v15strings);
       }
       v18 = ecl_cdr(v18);
L283:;
       if (Null(v18)){
        goto L297;
       }
       goto L282;
L297:;
      }
      value0 = v3args;
      cl_env_copy->nvalues = 1;
     }
    }
    ecl_frs_pop(cl_env_copy);                     /*  END CATCH CATCH3599     */
    v3args = value0;
    si_format_justification(v1stream, v14newline_string, v16extra_space, v17line_len, v15strings, v5colonp, v6atsignp, v10mincol, v11colinc, v12minpad, v13padchar);
   }
  }
 }
 value0 = v3args;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for FORMAT-JUSTIFICATION                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_format_justification(cl_object v1stream, cl_object v2newline_prefix, cl_object v3extra_space, cl_object v4line_len, cl_object v5strings, cl_object v6pad_left, cl_object v7pad_right, cl_object v8mincol, cl_object v9colinc, cl_object v10minpad, cl_object v11padchar)
{
 cl_object T0, T1, T2;
 volatile cl_object lex0[5];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 lex0[0] = v1stream;                              /*  STREAM                  */
 lex0[1] = v10minpad;                             /*  MINPAD                  */
 lex0[2] = v11padchar;                            /*  PADCHAR                 */
L1:;
 {
  cl_object v12;
  v12 = cl_reverse(v5strings);
  if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  v5strings = v12;
 }
 if (v6pad_left!=ECL_NIL) {
  goto L6;
 }
 if (v7pad_right!=ECL_NIL) {
  goto L6;
 }
 T0 = ecl_cdr(v5strings);
 if (!(T0==ECL_NIL)){
  goto L6;
 }
 v6pad_left = ECL_T;
L6:;
 {
  cl_object v12chars;
  cl_object v13length;
  {
   cl_fixnum v14;
   v14 = ecl_length(v5strings);
   T0 = ecl_make_integer((v14)-1);
   lex0[3] = T0;                                  /*  NUM-GAPS                */
  }
  T0 = lex0[3];
  T1 = ecl_times(T0,lex0[1]);
  {
   cl_object v14string;
   cl_object v15;
   v14string = ECL_NIL;
   v15 = v5strings;
   {
    cl_object v16;
    v16 = ecl_make_int8_t(0);
L17:;
    if (!(ecl_endp(v15))){
     goto L19;
    }
    goto L18;
L19:;
    v14string = ECL_CONS_CAR(v15);
    {
     cl_object v17;
     v17 = ECL_CONS_CDR(v15);
     if (ecl_unlikely(!ECL_LISTP(v17))) FEtype_error_list(v17);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v15 = v17;
    }
    {
     cl_fixnum v17;
     v17 = ecl_length(v14string);
     v16 = ecl_plus(v16,ecl_make_fixnum(v17));
    }
    goto L17;
L18:;
    T2 = v16;
    goto L13;
   }
  }
L13:;
  v12chars = ecl_plus(T1,T2);
  if (!(ecl_greater(v12chars,v8mincol))){
   goto L32;
  }
  T0 = ecl_minus(v12chars,v8mincol);
  T1 = ecl_ceiling2(T0,v9colinc);
  T2 = ecl_times(T1,v9colinc);
  v13length = ecl_plus(v8mincol,T2);
  goto L31;
L32:;
  v13length = v8mincol;
L31:;
  T0 = ecl_minus(v13length,v12chars);
  lex0[4] = T0;                                   /*  PADDING                 */
  if (Null(v2newline_prefix)){
   goto L34;
  }
  value0 = si_file_column(lex0[0]);
  if (value0!=ECL_NIL) {
   goto L39;
  }
  T0 = ecl_make_int8_t(0);
  goto L37;
L39:;
  T0 = value0;
  goto L37;
L37:;
  T1 = ecl_plus(T0,v13length);
  T2 = ecl_plus(T1,v3extra_space);
  if (!(ecl_greater(T2,v4line_len))){
   goto L34;
  }
  cl_write_string(2, v2newline_prefix, lex0[0]);
L34:;
  if (Null(v6pad_left)){
   goto L41;
  }
  T0 = lex0[3];
  lex0[3] = ecl_plus(T0,ecl_make_int8_t(1));
L41:;
  if (Null(v7pad_right)){
   goto L45;
  }
  T0 = lex0[3];
  lex0[3] = ecl_plus(T0,ecl_make_int8_t(1));
L45:;
  if (!(ecl_zerop(lex0[3]))){
   goto L49;
  }
  T0 = lex0[3];
  lex0[3] = ecl_plus(T0,ecl_make_int8_t(1));
  v6pad_left = ECL_T;
L49:;
  if (Null(v6pad_left)){
   goto L55;
  }
  LC640do_padding(lex0, ECL_T);
L55:;
  if (Null(v5strings)){
   goto L57;
  }
  T0 = ecl_car(v5strings);
  cl_write_string(2, T0, lex0[0]);
  {
   cl_object v14;
   v14 = ecl_cdr(v5strings);
   goto L63;
L62:;
   {
    cl_object v15string;
    v15string = ecl_car(v14);
    LC640do_padding(lex0, ECL_NIL);
    cl_write_string(2, v15string, lex0[0]);
   }
   v14 = ecl_cdr(v14);
L63:;
   if (Null(v14)){
    goto L71;
   }
   goto L62;
L71:;
  }
L57:;
  if (Null(v7pad_right)){
   goto L73;
  }
  value0 = LC640do_padding(lex0, ECL_T);
  return value0;
L73:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
cl_object si_format_justification_va(cl_narg narg, cl_object v14stream, cl_object v15newline_prefix, cl_object v16extra_space, cl_object v17line_len, cl_object v18strings, cl_object v19pad_left, cl_object v20pad_right, cl_object v21mincol, cl_object v22colinc, cl_object v23minpad, cl_object v24padchar, ...)
{
 if (ecl_unlikely(narg!=11)) FEwrong_num_arguments(VV[442]);
 {
  return si_format_justification(v14stream, v15newline_prefix, v16extra_space, v17line_len, v18strings, v19pad_left, v20pad_right, v21mincol, v22colinc, v23minpad, v24padchar);
 }
}
/* function definition for PARSE-FORMAT-LOGICAL-BLOCK                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L642parse_format_logical_block(cl_object v1segments, cl_object v2colonp, cl_object v3first_semi, cl_object v4close, cl_object v5params, cl_object v6string, cl_object v7end)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 L629check_output_layout_mode(ecl_make_int8_t(1));
 if (Null(v5params)){
  goto L3;
 }
 T0 = ecl_caar(v5params);
 cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[447], ECL_SYM("OFFSET",1316), T0);
L3:;
 {
  cl_object v8;                                   /*  PREFIX                  */
  cl_object v9;                                   /*  INSIDES                 */
  cl_object v10;                                  /*  SUFFIX                  */
  {
   cl_object v11;                                 /*  PREFIX-DEFAULT          */
   cl_object v12;                                 /*  SUFFIX-DEFAULT          */
   if (Null(v2colonp)){
    goto L7;
   }
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = VV[449];
   cl_env_copy->values[0] = VV[448];
   value0 = cl_env_copy->values[0];
   goto L6;
L7:;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = VV[251];
   cl_env_copy->values[0] = VV[251];
   value0 = cl_env_copy->values[0];
L6:;
   {
    v11 = value0;
    v12 = cl_env_copy->values[1];
   }
   {
    cl_object v13;
    v13 = ecl_make_fixnum(ecl_length(v1segments));
    if (!((ecl_fixnum(v13))==((cl_fixnum)(0)))){
     goto L10;
    }
    cl_env_copy->nvalues = 3;
    cl_env_copy->values[2] = v12;
    cl_env_copy->values[1] = ECL_NIL;
    cl_env_copy->values[0] = v11;
    value0 = cl_env_copy->values[0];
    goto L5;
L10:;
    if (!((ecl_fixnum(v13))==((cl_fixnum)(1)))){
     goto L12;
    }
    T0 = ecl_car(v1segments);
    cl_env_copy->nvalues = 3;
    cl_env_copy->values[2] = v12;
    cl_env_copy->values[1] = T0;
    cl_env_copy->values[0] = v11;
    value0 = cl_env_copy->values[0];
    goto L5;
L12:;
    if (!((ecl_fixnum(v13))==((cl_fixnum)(2)))){
     goto L14;
    }
    T1 = ecl_car(v1segments);
    T0 = LC641extract_string(T1, ECL_T);
    T1 = ecl_cadr(v1segments);
    cl_env_copy->nvalues = 3;
    cl_env_copy->values[2] = v12;
    cl_env_copy->values[1] = T1;
    cl_env_copy->values[0] = T0;
    value0 = cl_env_copy->values[0];
    goto L5;
L14:;
    if (!((ecl_fixnum(v13))==((cl_fixnum)(3)))){
     goto L17;
    }
    T1 = ecl_car(v1segments);
    T0 = LC641extract_string(T1, ECL_T);
    T1 = ecl_cadr(v1segments);
    T3 = ecl_caddr(v1segments);
    T2 = LC641extract_string(T3, ECL_NIL);
    cl_env_copy->nvalues = 3;
    cl_env_copy->values[2] = T2;
    cl_env_copy->values[1] = T1;
    cl_env_copy->values[0] = T0;
    value0 = cl_env_copy->values[0];
    goto L5;
L17:;
    value0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[452]);
   }
  }
L5:;
  {
   const int v11 = cl_env_copy->nvalues;
   v8 = value0;
   cl_object v12;
   v12 = (v11<=1)? ECL_NIL : cl_env_copy->values[1];
   v9 = v12;
   v12 = (v11<=2)? ECL_NIL : cl_env_copy->values[2];
   v10 = v12;
  }
  if (Null((cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v4close) /*  FORMAT-DIRECTIVE-ATSIGNP */)){
   goto L21;
  }
  if (Null(v3first_semi)){
   goto L25;
  }
  T0 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v3first_semi) /*  FORMAT-DIRECTIVE-END */;
  goto L24;
L25:;
  T0 = v7end;
L24:;
  v9 = L643add_fill_style_newlines(3, v9, v6string, T0);
L21:;
  if (Null(v3first_semi)){
   goto L29;
  }
  T0 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v3first_semi) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  goto L27;
L29:;
  T0 = ECL_NIL;
  goto L27;
L27:;
  cl_env_copy->nvalues = 4;
  cl_env_copy->values[3] = v10;
  cl_env_copy->values[2] = v9;
  cl_env_copy->values[1] = T0;
  cl_env_copy->values[0] = v8;
  return cl_env_copy->values[0];
 }
}
/* function definition for ADD-FILL-STYLE-NEWLINES                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L643add_fill_style_newlines(cl_narg narg, cl_object v1list, cl_object v2string, cl_object v3offset, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[453]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[453]);
 {
  cl_object v4previous_directive_is_newline;
  va_list args; va_start(args,v3offset);
  {
   int i = 3;
   if (i >= narg) {
    v4previous_directive_is_newline = ECL_NIL;
   } else {
    i++;
    v4previous_directive_is_newline = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(v1list)){
   goto L2;
  }
  {
   cl_object v5directive;
   v5directive = ecl_car(v1list);
   if (Null(cl_simple_string_p(v5directive))){
    goto L5;
   }
   if (v4previous_directive_is_newline!=ECL_NIL) {
    goto L5;
   }
   T0 = L644add_fill_style_newlines_aux(v5directive, v2string, v3offset);
   T1 = ecl_cdr(v1list);
   {
    cl_fixnum v6;
    v6 = ecl_length(v5directive);
    T2 = ecl_plus(v3offset,ecl_make_fixnum(v6));
    T3 = L643add_fill_style_newlines(4, T1, v2string, T2, ECL_NIL);
    value0 = ecl_nconc(T0,T3);
    cl_env_copy->nvalues = 1;
    return value0;
   }
L5:;
   T0 = ecl_cdr(v1list);
   T1 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v5directive) /*  FORMAT-DIRECTIVE-END */;
   T2 = (cl_env_copy->function=(VV[55]->symbol.gfdef))->cfun.entry(1, v5directive) /*  FORMAT-DIRECTIVE-CHARACTER */;
   {
    bool v6;
    v6 = ecl_char_code(T2)==ecl_char_code(ECL_CODE_CHAR(10));
    T3 = L643add_fill_style_newlines(4, T0, v2string, T1, ecl_make_bool(v6));
    value0 = CONS(v5directive,T3);
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
L2:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for ADD-FILL-STYLE-NEWLINES-AUX                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L644add_fill_style_newlines_aux(cl_object v1literal, cl_object v2string, cl_object v3offset)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  cl_object v5posn;
  v4 = ecl_make_fixnum(ecl_length(v1literal));
  v5posn = ecl_make_int8_t(0);
  {
   cl_object v6;
   cl_object v7;
   v6 = ECL_NIL;
   v7 = ECL_NIL;
L7:;
   {
    cl_object v8blank;
    v8blank = cl_position(4, ECL_CODE_CHAR(32), v1literal, ECL_SYM("START",1347), v5posn);
    if (!(v8blank==ECL_NIL)){
     goto L10;
    }
    {
     cl_object v9;
     T0 = cl_subseq(2, v1literal, v5posn);
     v9 = CONS(T0,ECL_NIL);
     if (Null(v7)){
      goto L15;
     }
     {
      cl_object v10;
      v10 = v7;
      if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v10;
     }
     (ECL_CONS_CDR(T0)=v9,T0);
     v7 = v9;
     goto L13;
L15:;
     v7 = v9;
     v6 = v9;
    }
L13:;
    goto L6;
L10:;
    {
     cl_object v9non_blank;
     T0 = (ECL_SYM("CHAR/=",218)->symbol.gfdef);
     value0 = cl_position(6, ECL_CODE_CHAR(32), v1literal, ECL_SYM("START",1347), v8blank, ECL_SYM("TEST",1353), T0);
     if (value0!=ECL_NIL) {
      goto L28;
     }
     v9non_blank = v4;
     goto L26;
L28:;
     v9non_blank = value0;
     goto L26;
L26:;
     {
      cl_object v10;
      T0 = cl_subseq(3, v1literal, v5posn, v9non_blank);
      v10 = CONS(T0,ECL_NIL);
      if (Null(v7)){
       goto L34;
      }
      {
       cl_object v11;
       v11 = v7;
       if (ecl_unlikely(ECL_ATOM(v11))) FEtype_error_cons(v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v11;
      }
      (ECL_CONS_CDR(T0)=v10,T0);
      v7 = v10;
      goto L32;
L34:;
      v7 = v10;
      v6 = v10;
     }
L32:;
     {
      cl_object v10;
      T0 = ecl_plus(v3offset,v9non_blank);
      T1 = ecl_plus(v3offset,v9non_blank);
      T2 = L516make_format_directive(14, VV[38], v2string, VV[39], ECL_CODE_CHAR(95), ECL_SYM("START",1347), T0, ECL_SYM("END",1256), T1, VV[40], ECL_T, VV[41], ECL_NIL, VV[42], ECL_NIL);
      v10 = CONS(T2,ECL_NIL);
      if (Null(v7)){
       goto L47;
      }
      {
       cl_object v11;
       v11 = v7;
       if (ecl_unlikely(ECL_ATOM(v11))) FEtype_error_cons(v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v11;
      }
      (ECL_CONS_CDR(T0)=v10,T0);
      v7 = v10;
      goto L45;
L47:;
      v7 = v10;
      v6 = v10;
     }
L45:;
     v5posn = v9non_blank;
    }
    if (!(ecl_number_equalp(v5posn,v4))){
     goto L8;
    }
    goto L6;
   }
L8:;
   goto L7;
L6:;
   value0 = v6;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for EXPAND-FORMAT-LOGICAL-BLOCK                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L645expand_format_logical_block(cl_object v1prefix, cl_object v2per_line_p, cl_object v3insides, cl_object v4suffix, cl_object v5atsignp)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v5atsignp)){
  goto L3;
 }
 T0 = VV[67];
 goto L2;
L3:;
 T0 = L527expand_next_arg(0);
L2:;
 T1 = cl_list(2, VV[121], T0);
 T2 = ecl_list1(T1);
 if (Null(v5atsignp)){
  goto L6;
 }
 T4 = ECL_NIL;
 ecl_cmp_setq(cl_env_copy,VV[47],T4);
 T3 = VV[456];
 goto L5;
L6:;
 T3 = ECL_NIL;
L5:;
 if (Null(v2per_line_p)){
  goto L11;
 }
 T4 = VV[457];
 goto L10;
L11:;
 T4 = VV[458];
L10:;
 T5 = cl_list(6, ECL_SYM("STREAM",802), VV[121], T4, v1prefix, VV[459], v4suffix);
 if (v5atsignp!=ECL_NIL) {
  goto L14;
 }
 T6 = VV[461];
 goto L13;
L14:;
 T6 = ECL_NIL;
L13:;
 T7 = CONS(VV[460],T6);
 if (v5atsignp!=ECL_NIL) {
  goto L17;
 }
 T8 = VV[462];
 goto L16;
L17:;
 T8 = ECL_NIL;
L16:;
 T9 = cl_listX(3, ECL_SYM("IGNORABLE",429), VV[67], T8);
 T10 = cl_list(2, ECL_SYM("DECLARE",276), T9);
 ecl_bds_bind(cl_env_copy,VV[45],VV[80]);         /*  *EXPANDER-NEXT-ARG-MACRO* */
 ecl_bds_bind(cl_env_copy,VV[47],ECL_NIL);        /*  *ONLY-SIMPLE-ARGS*      */
 ecl_bds_bind(cl_env_copy,VV[48],ECL_T);          /*  *ORIG-ARGS-AVAILABLE*   */
 T11 = L525expand_directive_list(v3insides);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 T12 = cl_listX(3, ECL_SYM("BLOCK",139), ECL_NIL, T11);
 T13 = cl_list(4, ECL_SYM("LET",479), T7, T10, T12);
 T14 = cl_list(3, ECL_SYM("PPRINT-LOGICAL-BLOCK",656), T5, T13);
 T15 = ecl_list1(T14);
 T16 = ecl_append(T3,T15);
 value0 = cl_listX(3, ECL_SYM("LET",479), T2, T16);
 return value0;
}
static cl_object L645expand_format_logical_block_va(cl_narg narg, cl_object v6prefix, cl_object v7per_line_p, cl_object v8insides, cl_object v9suffix, cl_object v10atsignp, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[419]);
 {
  return L645expand_format_logical_block(v6prefix, v7per_line_p, v8insides, v9suffix, v10atsignp);
 }
}
/* function definition for INTERPRET-FORMAT-LOGICAL-BLOCK                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L650interpret_format_logical_block(cl_object volatile v1stream, cl_object volatile v2orig_args, cl_object volatile v3args, cl_object volatile v4prefix, cl_object volatile v5per_line_p, cl_object volatile v6insides, cl_object volatile v7suffix, cl_object volatile v8atsignp)
{
 cl_object T0;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v2orig_args,env0);            /*  ORIG-ARGS               */
 CLV1 = env0 = CONS(v6insides,env0);              /*  INSIDES                 */
 CLV2 = env0 = CONS(v8atsignp,env0);              /*  ATSIGNP                 */
 {
  volatile cl_object env1 = env0;
  if (Null(ECL_CONS_CAR(CLV2))){
   goto L3;
  }
  T0 = v3args;
  goto L2;
L3:;
  if (!(v3args==ECL_NIL)){
   goto L5;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L5:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
   goto L7;
  }
  ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L7:;
  {
   cl_object v9;
   v9 = v3args;
   {
    cl_object v10;
    v10 = v9;
    {
     bool v11;
     v11 = ECL_LISTP(v10);
     if (ecl_unlikely(!(v11)))
         FEwrong_type_argument(VV[106],v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v9)){
    goto L13;
   }
   {
    cl_object v10;
    v10 = ECL_CONS_CDR(v9);
    v3args = v10;
    v9 = ECL_CONS_CAR(v9);
   }
L13:;
   T0 = v9;
  }
L2:;
  CLV3 = env1 = CONS(T0,env1);                    /*  ARG                     */
  if (Null(v5per_line_p)){
   goto L19;
  }
  {
   cl_object volatile v9;
   v9 = ecl_make_cclosure_va((cl_objectfn)LC647__pprint_logical_block_3508,env1,Cblock,2);
   T0 = v9;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV3), v1stream, v4prefix, ECL_T, v7suffix);
  goto L1;
L19:;
  {
   cl_object volatile v9;
   v9 = ecl_make_cclosure_va((cl_objectfn)LC649__pprint_logical_block_3524,env1,Cblock,2);
   T0 = v9;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV3), v1stream, v4prefix, ECL_NIL, v7suffix);
 }
L1:;
 if (Null(ECL_CONS_CAR(CLV2))){
  goto L23;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L23:;
 value0 = v3args;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* local function GREATER-THAN_SIGN-FORMAT-DIRECTIVE-EXPANDER                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC651greater_than_sign_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[364]);
 return value0;
}
static cl_object LC651greater_than_sign_format_directive_expander_va(cl_narg narg, cl_object v3, cl_object v4, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[470]);
 {
  return LC651greater_than_sign_format_directive_expander(v3, v4);
 }
}
/* local function SOLIDUS-FORMAT-DIRECTIVE-EXPANDER                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC652solidus_format_directive_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  cl_object v8;
  v3 = (cl_env_copy->function=(VV[328]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-STRING */;
  v4 = (cl_env_copy->function=(VV[472]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-START */;
  v5 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-END */;
  v6 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-COLONP */;
  v7 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v8 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v1) /*  FORMAT-DIRECTIVE-PARAMS */;
  {
   cl_object v9symbol;
   v9symbol = L654extract_user_function_name(v3, v4, v5);
   {
    cl_object v10;
    cl_object v11;
    cl_object v12;
    cl_object v13;
    v10 = ECL_NIL;
    v11 = ECL_NIL;
    v12 = ECL_NIL;
    v13 = ECL_NIL;
    {
     cl_object v14;
     v14 = v8;
     goto L18;
L17:;
     {
      cl_object v15param_and_offset;
      v15param_and_offset = ecl_car(v14);
      {
       cl_object v16param;
       v16param = ecl_cdr(v15param_and_offset);
       {
        cl_object v17param_name;
        v17param_name = cl_gensym(0);
        {
         cl_object v18;
         v18 = CONS(v17param_name,ECL_NIL);
         if (Null(v11)){
          goto L28;
         }
         {
          cl_object v19;
          v19 = v11;
          if (ecl_unlikely(ECL_ATOM(v19))) FEtype_error_cons(v19);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T1 = v19;
         }
         (ECL_CONS_CDR(T1)=v18,T1);
         v11 = v18;
         goto L26;
L28:;
         v11 = v18;
         v10 = v18;
        }
L26:;
        {
         cl_object v18;
         if (!((v16param)==(VV[33]))){
          goto L41;
         }
         T1 = L527expand_next_arg(0);
         goto L40;
L41:;
         if (!((v16param)==(VV[34]))){
          goto L43;
         }
         T1 = VV[107];
         goto L40;
L43:;
         T1 = v16param;
L40:;
         T2 = cl_list(2, v17param_name, T1);
         v18 = CONS(T2,ECL_NIL);
         if (Null(v13)){
          goto L45;
         }
         {
          cl_object v19;
          v19 = v13;
          if (ecl_unlikely(ECL_ATOM(v19))) FEtype_error_cons(v19);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T1 = v19;
         }
         (ECL_CONS_CDR(T1)=v18,T1);
         v13 = v18;
         goto L38;
L45:;
         v13 = v18;
         v12 = v18;
        }
L38:;
       }
      }
     }
     v14 = ecl_cdr(v14);
L18:;
     if (Null(v14)){
      goto L57;
     }
     goto L17;
L57:;
    }
    T1 = L527expand_next_arg(0);
    T2 = cl_listX(6, v9symbol, ECL_SYM("STREAM",802), T1, v6, v7, v10);
    T0 = cl_list(3, ECL_SYM("LET",479), v12, T2);
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v2;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object LC652solidus_format_directive_expander_va(cl_narg narg, cl_object v9, cl_object v10, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[471]);
 {
  return LC652solidus_format_directive_expander(v9, v10);
 }
}
/* local function LAMBDA3571                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC653__lambda3571(cl_object v1stream, cl_object v2, cl_object v3, cl_object v4orig_args, cl_object v5args)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  cl_object v7;
  cl_object v8;
  cl_object v9;
  cl_object v10;
  cl_object v11;
  v6 = (cl_env_copy->function=(VV[328]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-STRING */;
  v7 = (cl_env_copy->function=(VV[472]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-START */;
  v8 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-END */;
  v9 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-COLONP */;
  v10 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-ATSIGNP */;
  v11 = (cl_env_copy->function=(VV[98]->symbol.gfdef))->cfun.entry(1, v2) /*  FORMAT-DIRECTIVE-PARAMS */;
  {
   cl_object v12symbol;
   v12symbol = L654extract_user_function_name(v6, v7, v8);
   {
    cl_object v13;
    cl_object v14;
    v13 = ECL_NIL;
    v14 = ECL_NIL;
    {
     cl_object v15;
     v15 = v11;
     goto L16;
L15:;
     {
      cl_object v16param_and_offset;
      v16param_and_offset = ecl_car(v15);
      {
       cl_object v17param;
       v17param = ecl_cdr(v16param_and_offset);
       if (!((v17param)==(VV[33]))){
        goto L22;
       }
       {
        cl_object v18;
        if (!(v5args==ECL_NIL)){
         goto L26;
        }
        cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L26:;
        if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
         goto L28;
        }
        ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L28:;
        {
         cl_object v19;
         v19 = v5args;
         {
          cl_object v20;
          v20 = v19;
          {
          bool v21;
          v21 = ECL_LISTP(v20);
          if (ecl_unlikely(!(v21)))
         FEwrong_type_argument(VV[106],v20);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          }
         }
         if (Null(v19)){
          goto L35;
         }
         {
          cl_object v20;
          v20 = ECL_CONS_CDR(v19);
          v5args = v20;
          v19 = ECL_CONS_CAR(v19);
         }
L35:;
         T0 = v19;
        }
        v18 = CONS(T0,ECL_NIL);
        if (Null(v14)){
         goto L41;
        }
        {
         cl_object v19;
         v19 = v14;
         if (ecl_unlikely(ECL_ATOM(v19))) FEtype_error_cons(v19);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         T0 = v19;
        }
        (ECL_CONS_CDR(T0)=v18,T0);
        v14 = v18;
        goto L24;
L41:;
        v14 = v18;
        v13 = v18;
       }
L24:;
       goto L20;
L22:;
       if (!((v17param)==(VV[34]))){
        goto L51;
       }
       {
        cl_object v18;
        {
         cl_fixnum v19;
         v19 = ecl_length(v5args);
         v18 = CONS(ecl_make_fixnum(v19),ECL_NIL);
        }
        if (Null(v14)){
         goto L55;
        }
        {
         cl_object v19;
         v19 = v14;
         if (ecl_unlikely(ECL_ATOM(v19))) FEtype_error_cons(v19);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         T0 = v19;
        }
        (ECL_CONS_CDR(T0)=v18,T0);
        v14 = v18;
        goto L53;
L55:;
        v14 = v18;
        v13 = v18;
       }
L53:;
       goto L20;
L51:;
       {
        cl_object v18;
        v18 = CONS(v17param,ECL_NIL);
        if (Null(v14)){
         goto L67;
        }
        {
         cl_object v19;
         v19 = v14;
         if (ecl_unlikely(ECL_ATOM(v19))) FEtype_error_cons(v19);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         T0 = v19;
        }
        (ECL_CONS_CDR(T0)=v18,T0);
        v14 = v18;
        goto L65;
L67:;
        v14 = v18;
        v13 = v18;
       }
L65:;
      }
L20:;
     }
     v15 = ecl_cdr(v15);
L16:;
     if (Null(v15)){
      goto L79;
     }
     goto L15;
L79:;
    }
    T0 = cl_fdefinition(v12symbol);
    if (!(v5args==ECL_NIL)){
     goto L81;
    }
    cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L81:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
     goto L83;
    }
    ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L83:;
    {
     cl_object v15;
     v15 = v5args;
     {
      cl_object v16;
      v16 = v15;
      {
       bool v17;
       v17 = ECL_LISTP(v16);
       if (ecl_unlikely(!(v17)))
         FEwrong_type_argument(VV[106],v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
      }
     }
     if (Null(v15)){
      goto L90;
     }
     {
      cl_object v16;
      v16 = ECL_CONS_CDR(v15);
      v5args = v16;
      v15 = ECL_CONS_CAR(v15);
     }
L90:;
     T1 = v15;
    }
    cl_apply(6, T0, v1stream, T1, v9, v10, v13);
   }
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5args;
  cl_env_copy->values[0] = v3;
  return cl_env_copy->values[0];
 }
}
static cl_object LC653__lambda3571_va(cl_narg narg, cl_object v12stream, cl_object v13, cl_object v14, cl_object v15orig_args, cl_object v16args, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[476]);
 {
  return LC653__lambda3571(v12stream, v13, v14, v15orig_args, v16args);
 }
}
/* function definition for EXTRACT-USER-FUNCTION-NAME                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L654extract_user_function_name(cl_object v1string, cl_object v2start, cl_object v3end)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4slash;
  T0 = ecl_one_minus(v3end);
  v4slash = cl_position(8, ECL_CODE_CHAR(47), v1string, ECL_SYM("START",1347), v2start, ECL_SYM("END",1256), T0, VV[477], ECL_T);
  if (v4slash!=ECL_NIL) {
   goto L3;
  }
  cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[478]);
L3:;
  {
   cl_object v5name;
   cl_object v6first_colon;
   cl_object v7second_colon;
   cl_object v8package_name;
   cl_object v9package;
   T1 = ecl_one_plus(v4slash);
   T2 = ecl_one_minus(v3end);
   T0 = cl_subseq(3, v1string, T1, T2);
   v5name = cl_string_upcase(1, T0);
   v6first_colon = cl_position(2, ECL_CODE_CHAR(58), v5name);
   if (Null(v6first_colon)){
    goto L9;
   }
   T0 = ecl_one_plus(v6first_colon);
   v7second_colon = cl_position(4, ECL_CODE_CHAR(58), v5name, ECL_SYM("START",1347), T0);
   goto L8;
L9:;
   v7second_colon = ECL_NIL;
L8:;
   if (Null(v6first_colon)){
    goto L12;
   }
   v8package_name = cl_subseq(3, v5name, ecl_make_int8_t(0), v6first_colon);
   goto L11;
L12:;
   v8package_name = VV[479];
L11:;
   v9package = cl_find_package(v8package_name);
   if (v9package!=ECL_NIL) {
    goto L15;
   }
   T0 = ecl_list1(v8package_name);
   cl_error(5, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[480], VV[110], T0);
L15:;
   if (Null(v7second_colon)){
    goto L18;
   }
   T1 = ecl_one_plus(v6first_colon);
   if (!(ecl_number_equalp(v7second_colon,T1))){
    goto L18;
   }
   T1 = ecl_one_plus(v7second_colon);
   T0 = cl_subseq(2, v5name, T1);
   goto L17;
L18:;
   if (Null(v6first_colon)){
    goto L21;
   }
   T1 = ecl_one_plus(v6first_colon);
   T0 = cl_subseq(2, v5name, T1);
   goto L17;
L21:;
   T0 = v5name;
L17:;
   value0 = cl_intern(2, T0, v9package);
   return value0;
  }
 }
}
/* local function GET-CHAR                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC518get_char(volatile cl_object *lex0)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ecl_number_equalp(lex0[2],lex0[3]))){
  goto L2;
 }
 value0 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[30], ECL_SYM("CONTROL-STRING",1242), lex0[0], ECL_SYM("OFFSET",1316), lex0[1]);
 return value0;
L2:;
 value0 = ecl_elt(lex0[0],ecl_to_size(lex0[2]));
 cl_env_copy->nvalues = 1;
 return value0;
}
/* local function AFTER                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC533after(volatile cl_object *lex0, cl_object v1char)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  T0 = ecl_cdr(lex0[0]);
  v2 = L534find_directive(T0, v1char, ECL_NIL);
  v3 = v2;
  v4 = lex0[0];
  value0 = ecl_memql(v3,v4);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* closure LAMBDA2801                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC596__lambda2801(cl_narg narg, cl_object v1condition, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  END                     */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[336]);
 {
L1:;
  T0 = ecl_list1(v1condition);
  T1 = ecl_one_minus(ECL_CONS_CAR(CLV1));
  value0 = cl_error(11, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[331], VV[110], T0, VV[333], ECL_NIL, ECL_SYM("CONTROL-STRING",1242), ECL_CONS_CAR(CLV0), ECL_SYM("OFFSET",1316), T1);
  return value0;
 }
 }
}
/* local function HAIRY                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC605hairy(volatile cl_object *lex0)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = L527expand_next_arg(0);
 T1 = cl_list(2, VV[121], T0);
 T2 = cl_list(2, VV[357], T1);
 T3 = L525expand_directive_list(lex0[0]);
 T4 = cl_listX(4, ECL_SYM("WHEN",909), VV[121], VV[358], T3);
 value0 = cl_list(3, ECL_SYM("LET",479), T2, T4);
 return value0;
}
/* local function HAIRY                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC607hairy(volatile cl_object *lex0)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = L525expand_directive_list(lex0[0]);
 T1 = CONS(ECL_SYM("PROGN",674),T0);
 T2 = L525expand_directive_list(lex0[1]);
 T3 = CONS(ECL_SYM("PROGN",674),T2);
 value0 = cl_list(4, ECL_SYM("IF",950), lex0[2], T1, T3);
 return value0;
}
/* local function COMPUTE-BINDINGS                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC619compute_bindings(volatile cl_object *lex0, cl_object v1count)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(lex0[2])){
  goto L2;
 }
 value0 = LC618compute_block(lex0, v1count);
 return value0;
L2:;
 T0 = L527expand_next_arg(0);
 T1 = cl_list(2, VV[312], T0);
 T2 = cl_list(2, T1, VV[391]);
 ecl_bds_bind(cl_env_copy,VV[45],VV[46]);         /*  *EXPANDER-NEXT-ARG-MACRO* */
 ecl_bds_bind(cl_env_copy,VV[47],ECL_NIL);        /*  *ONLY-SIMPLE-ARGS*      */
 ecl_bds_bind(cl_env_copy,VV[48],ECL_T);          /*  *ORIG-ARGS-AVAILABLE*   */
 T3 = LC618compute_block(lex0, v1count);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 value0 = cl_list(4, ECL_SYM("LET*",480), T2, VV[392], T3);
 return value0;
}
/* local function COMPUTE-BLOCK                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC618compute_block(volatile cl_object *lex0, cl_object v1count)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(lex0[1])){
  goto L2;
 }
 T0 = LC617compute_loop(lex0, v1count);
 value0 = cl_list(3, ECL_SYM("BLOCK",139), VV[389], T0);
 return value0;
L2:;
 value0 = LC617compute_loop(lex0, v1count);
 return value0;
}
/* local function COMPUTE-LOOP                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC617compute_loop(volatile cl_object *lex0, cl_object v1count)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(lex0[2])){
  goto L2;
 }
 T0 = ECL_NIL;
 ecl_cmp_setq(cl_env_copy,VV[47],T0);
L2:;
 if (lex0[5]!=ECL_NIL) {
  goto L6;
 }
 T0 = VV[385];
 goto L5;
L6:;
 T0 = ECL_NIL;
L5:;
 if (Null(v1count)){
  goto L9;
 }
 T2 = cl_list(2, ECL_SYM("DECF",273), v1count);
 T3 = cl_list(2, ECL_SYM("MINUSP",560), T2);
 T4 = cl_list(3, ECL_SYM("AND",89), v1count, T3);
 T5 = cl_list(3, ECL_SYM("WHEN",909), T4, VV[375]);
 T1 = ecl_list1(T5);
 goto L8;
L9:;
 T1 = ECL_NIL;
L8:;
 if (Null(lex0[1])){
  goto L12;
 }
 ecl_bds_bind(cl_env_copy,VV[45],VV[46]);         /*  *EXPANDER-NEXT-ARG-MACRO* */
 ecl_bds_bind(cl_env_copy,VV[47],ECL_NIL);        /*  *ONLY-SIMPLE-ARGS*      */
 ecl_bds_bind(cl_env_copy,VV[48],ECL_T);          /*  *ORIG-ARGS-AVAILABLE*   */
 T3 = L527expand_next_arg(0);
 T4 = cl_list(2, VV[312], T3);
 T5 = CONS(T4,VV[386]);
 T6 = LC616compute_insides(lex0);
 T7 = cl_listX(3, ECL_SYM("BLOCK",139), ECL_NIL, T6);
 T8 = cl_list(4, ECL_SYM("LET*",480), T5, VV[387], T7);
 T2 = ecl_list1(T8);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 goto L11;
L12:;
 T2 = LC616compute_insides(lex0);
L11:;
 if (Null(lex0[5])){
  goto L16;
 }
 T3 = VV[385];
 goto L15;
L16:;
 T3 = ECL_NIL;
L15:;
 T4 = cl_append(4, T0, T1, T2, T3);
 value0 = CONS(ECL_SYM("LOOP",514),T4);
 cl_env_copy->nvalues = 1;
 return value0;
}
/* local function COMPUTE-INSIDES                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC616compute_insides(volatile cl_object *lex0)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ecl_zerop(lex0[6]))){
  goto L2;
 }
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[48]))){
  goto L4;
 }
 T0 = ecl_one_minus(lex0[4]);
 T1 = cl_list(12, ECL_SYM("ERROR",339), VV[64], VV[29], VV[331], VV[382], VV[332], VV[333], ECL_NIL, ECL_SYM("CONTROL-STRING",1242), lex0[3], ECL_SYM("OFFSET",1316), T0);
 T2 = cl_list(3, ECL_SYM("LAMBDA",454), VV[330], T1);
 T3 = cl_list(2, ECL_SYM("FORMAT-ERROR",1084), T2);
 T4 = ecl_list1(T3);
 T5 = cl_list(3, ECL_SYM("HANDLER-BIND",419), T4, VV[383]);
 value0 = ecl_list1(T5);
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 cl_env_copy->values[0] = ECL_NIL;
 cl_env_copy->nvalues = 1;
 cl_throw(VV[62]);
L2:;
 ecl_bds_bind(cl_env_copy,VV[43],lex0[1]);        /*  *UP-UP-AND-OUT-ALLOWED* */
 T0 = cl_subseq(3, lex0[0], ecl_make_int8_t(0), lex0[6]);
 value0 = L525expand_directive_list(T0);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
/* closure DO-LOOP                                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC624do_loop(volatile cl_narg narg, cl_object volatile v1orig_args, cl_object volatile v2args, ...)
{
 cl_object T0, T1;
 volatile struct ecl_cclosure aux_closure;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV7 = env0;                                     /*  INSIDES                 */
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[400]);
 {
L1:;
  if (Null(ECL_CONS_CAR(CLV1))){
   goto L3;
  }
  value0 = VV[378];
  goto L2;
L3:;
  value0 = VV[50];
L2:;                                              /*  BEGIN CATCH CATCH3600   */
  {
   ecl_frs_push(cl_env_copy,value0);
   if (__ecl_frs_push_result!=0) {
    value0 = cl_env_copy->values[0];
   } else {
L8:;
    if (ECL_CONS_CAR(CLV5)!=ECL_NIL) {
     goto L10;
    }
    if (!(v2args==ECL_NIL)){
     goto L10;
    }
    goto L7;
L10:;
    if (Null(ECL_CONS_CAR(CLV4))){
     goto L13;
    }
    T1 = ECL_CONS_CAR(CLV4);
    ECL_CONS_CAR(CLV4) = ecl_minus(T1,ecl_make_int8_t(1));
    T0 = ECL_CONS_CAR(CLV4);
    if (!(ecl_minusp(T0))){
     goto L13;
    }
    goto L7;
L13:;
    v2args = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC623bind_args(2, v1orig_args, v2args));
    if (Null(ECL_CONS_CAR(CLV5))){
     goto L9;
    }
    if (!(v2args==ECL_NIL)){
     goto L9;
    }
    goto L7;
L9:;
    goto L8;
L7:;
    value0 = v2args;
    cl_env_copy->nvalues = 1;
   }
  }
  ecl_frs_pop(cl_env_copy);                       /*  END CATCH CATCH3600     */
  return value0;
 }
 }
}
/* closure BIND-ARGS                                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC623bind_args(volatile cl_narg narg, cl_object volatile v1orig_args, cl_object volatile v2args, ...)
{
 volatile struct ecl_cclosure aux_closure;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV7 = env0;                                     /*  INSIDES                 */
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[399]);
 {
L1:;
  if (Null(ECL_CONS_CAR(CLV1))){
   goto L2;
  }
  {
   volatile cl_object v3arg;
   if (!(v2args==ECL_NIL)){
    goto L5;
   }
   cl_error(3, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[78]);
L5:;
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[44]))){
    goto L7;
   }
   ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[44]))(0);
L7:;
   {
    cl_object v4;
    v4 = v2args;
    {
     cl_object v5;
     v5 = v4;
     {
      bool v6;
      v6 = ECL_LISTP(v5);
      if (ecl_unlikely(!(v6)))
         FEwrong_type_argument(VV[106],v5);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v4)){
     goto L13;
    }
    {
     cl_object v5;
     v5 = ECL_CONS_CDR(v4);
     v2args = v5;
     v4 = ECL_CONS_CAR(v4);
    }
L13:;
    v3arg = v4;
   }
   ecl_bds_bind(cl_env_copy,VV[44],ECL_NIL);      /*  *LOGICAL-BLOCK-POPPER*  */
   ecl_bds_bind(cl_env_copy,VV[366],v2args);      /*  *OUTSIDE-ARGS*          */
   value0 = VV[50];                               /*  BEGIN CATCH CATCH3601   */
   {
    ecl_frs_push(cl_env_copy,value0);
    if (__ecl_frs_push_result!=0) {
    } else {
     (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC622do_guts(2, v3arg, v3arg));
    }
   }
   ecl_frs_pop(cl_env_copy);                      /*  END CATCH CATCH3601     */
   value0 = v2args;
   cl_env_copy->nvalues = 1;
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   return value0;
  }
L2:;
  value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC622do_guts(2, v1orig_args, v2args));
  return value0;
 }
 }
}
/* closure DO-GUTS                                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC622do_guts(cl_narg narg, cl_object v1orig_args, cl_object v2args, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV7 = env0;                                     /*  INSIDES                 */
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[397]);
 {
L1:;
  if (!(ecl_zerop(ECL_CONS_CAR(CLV6)))){
   goto L2;
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC621__lambda3133,env0,Cblock,1);
   T0 = v3;
  }
  T1 = CONS(ECL_SYM("FORMAT-ERROR",1084),T0);
  T2 = ecl_list1(T1);
  T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
  ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
  value0 = L520formatter_aux(4, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV7), v1orig_args, v2args);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L2:;
  value0 = L521interpret_directive_list(ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV7), v1orig_args, v2args);
  return value0;
 }
 }
}
/* local function LAMBDA3177                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC630__lambda3177(cl_object v1x, cl_object v2y)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=(VV[14]->symbol.gfdef))->cfun.entry(1, v1x) /*  FORMAT-DIRECTIVE-P */)){
  goto L3;
 }
 if (Null((cl_env_copy->function=(VV[14]->symbol.gfdef))->cfun.entry(1, v2y) /*  FORMAT-DIRECTIVE-P */)){
  goto L3;
 }
 T0 = (cl_env_copy->function=(VV[55]->symbol.gfdef))->cfun.entry(1, v1x) /*  FORMAT-DIRECTIVE-CHARACTER */;
 T1 = (cl_env_copy->function=(VV[55]->symbol.gfdef))->cfun.entry(1, v2y) /*  FORMAT-DIRECTIVE-CHARACTER */;
 if (!(ecl_eql(T0,T1))){
  goto L3;
 }
 T0 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v1x) /*  FORMAT-DIRECTIVE-COLONP */;
 T1 = (cl_env_copy->function=(VV[96]->symbol.gfdef))->cfun.entry(1, v2y) /*  FORMAT-DIRECTIVE-COLONP */;
 if (!(ecl_eql(T0,T1))){
  goto L3;
 }
 T0 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v1x) /*  FORMAT-DIRECTIVE-ATSIGNP */;
 T1 = (cl_env_copy->function=(VV[97]->symbol.gfdef))->cfun.entry(1, v2y) /*  FORMAT-DIRECTIVE-ATSIGNP */;
 value0 = ecl_make_bool(ecl_eql(T0,T1));
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC630__lambda3177_va(cl_narg narg, cl_object v3x, cl_object v4y, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[413]);
 {
  return LC630__lambda3177(v3x, v4y);
 }
}
/* local function LAMBDA3195                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC632__lambda3195(cl_object v1x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (VV[412]->symbol.gfdef);
 value0 = cl_count_if(2, T0, v1x);
 return value0;
}
static cl_object LC632__lambda3195_va(cl_narg narg, cl_object v2x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[420]);
 {
  return LC632__lambda3195(v2x);
 }
}
/* local function LAMBDA3213                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC634__lambda3213(cl_object v1x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (VV[412]->symbol.gfdef);
 value0 = cl_count_if(2, T0, v1x);
 return value0;
}
static cl_object LC634__lambda3213_va(cl_narg narg, cl_object v2x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[425]);
 {
  return LC634__lambda3213(v2x);
 }
}
/* local function LAMBDA3338                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC637__lambda3338(cl_object v1segment)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = L525expand_directive_list(v1segment);
 T1 = cl_listX(3, ECL_SYM("WITH-OUTPUT-TO-STRING",917), VV[435], T0);
 value0 = cl_list(3, ECL_SYM("PUSH",680), T1, VV[427]);
 return value0;
}
static cl_object LC637__lambda3338_va(cl_narg narg, cl_object v2segment, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[441]);
 {
  return LC637__lambda3338(v2segment);
 }
}
/* local function DO-PADDING                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC640do_padding(volatile cl_object *lex0, cl_object v1border)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2pad_len;
  T0 = lex0[4];
  v2pad_len = ecl_truncate2(T0,lex0[3]);
  T0 = lex0[4];
  lex0[4] = ecl_minus(T0,v2pad_len);
  T0 = lex0[3];
  lex0[3] = ecl_minus(T0,ecl_make_int8_t(1));
  if (v1border!=ECL_NIL) {
   goto L10;
  }
  v2pad_len = ecl_plus(v2pad_len,lex0[1]);
L10:;
  {
   cl_object v3i;
   v3i = ecl_make_int8_t(0);
   goto L15;
L14:;
   cl_write_char(2, lex0[2], lex0[0]);
   v3i = ecl_one_plus(v3i);
L15:;
   if (!(ecl_lower(v3i,v2pad_len))){
    goto L20;
   }
   goto L14;
L20:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function EXTRACT-STRING                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC641extract_string(cl_object v1list, cl_object v2prefix_p)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3directive;
  T0 = (VV[14]->symbol.gfdef);
  v3directive = cl_find_if(2, T0, v1list);
  if (Null(v3directive)){
   goto L4;
  }
  T0 = ecl_list1(v2prefix_p);
  T1 = (cl_env_copy->function=(VV[27]->symbol.gfdef))->cfun.entry(1, v3directive) /*  FORMAT-DIRECTIVE-END */;
  T2 = ecl_one_minus(T1);
  value0 = cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[451], VV[110], T0, ECL_SYM("OFFSET",1316), T2);
  return value0;
L4:;
  T0 = (ECL_SYM("CONCATENATE",246)->symbol.gfdef);
  value0 = cl_apply(3, T0, ECL_SYM("STRING",808), v1list);
  return value0;
 }
}
static cl_object LC641extract_string_va(cl_narg narg, cl_object v4list, cl_object v5prefix_p, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[450]);
 {
  return LC641extract_string(v4list, v5prefix_p);
 }
}
/* closure PPRINT-LOGICAL-BLOCK-3508                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC647__pprint_logical_block_3508(volatile cl_narg narg, cl_object volatile v1, cl_object volatile v2stream, ...)
{
 cl_object T0;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  ARG                     */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[465]);
 {
  CLV4 = env0 = CONS(v1,env0);
  CLV5 = env0 = CONS(v2stream,env0);              /*  STREAM                  */
  {
   volatile cl_object env1 = env0;
   CLV6 = env1 = CONS(ecl_make_int8_t(0),env1);
   {
    CLV7 = env1 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env1);
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV7));
     if (__ecl_frs_push_result!=0) {
     ecl_frs_pop_n(cl_env_copy, 1);
     return cl_env_copy->values[0];
     } else {
     {
      cl_object volatile v3;
      v3 = ecl_make_cclosure_va((cl_objectfn)LC646__lambda3517,env1,Cblock,0);
      T0 = v3;
     }
     ecl_bds_bind(cl_env_copy,VV[44],T0);         /*  *LOGICAL-BLOCK-POPPER*  */
     value0 = VV[50];                             /*  BEGIN CATCH CATCH3602   */
     {
      ecl_frs_push(cl_env_copy,value0);
      if (__ecl_frs_push_result!=0) {
       value0 = cl_env_copy->values[0];
      } else {
       if (Null(ECL_CONS_CAR(CLV2))){
        goto L6;
       }
       T0 = ECL_CONS_CAR(CLV0);
       goto L5;
L6:;
       T0 = ECL_CONS_CAR(CLV3);
L5:;
       value0 = L521interpret_directive_list(ECL_CONS_CAR(CLV5), ECL_CONS_CAR(CLV1), T0, ECL_CONS_CAR(CLV3));
      }
     }
     ecl_frs_pop(cl_env_copy);                    /*  END CATCH CATCH3602     */
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     return value0;
     }
    }
   }
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-3524                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC649__pprint_logical_block_3524(volatile cl_narg narg, cl_object volatile v1, cl_object volatile v2stream, ...)
{
 cl_object T0;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  ARG                     */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[468]);
 {
  CLV4 = env0 = CONS(v1,env0);
  CLV5 = env0 = CONS(v2stream,env0);              /*  STREAM                  */
  {
   volatile cl_object env1 = env0;
   CLV6 = env1 = CONS(ecl_make_int8_t(0),env1);
   {
    CLV7 = env1 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env1);
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV7));
     if (__ecl_frs_push_result!=0) {
     ecl_frs_pop_n(cl_env_copy, 1);
     return cl_env_copy->values[0];
     } else {
     {
      cl_object volatile v3;
      v3 = ecl_make_cclosure_va((cl_objectfn)LC648__lambda3533,env1,Cblock,0);
      T0 = v3;
     }
     ecl_bds_bind(cl_env_copy,VV[44],T0);         /*  *LOGICAL-BLOCK-POPPER*  */
     value0 = VV[50];                             /*  BEGIN CATCH CATCH3603   */
     {
      ecl_frs_push(cl_env_copy,value0);
      if (__ecl_frs_push_result!=0) {
       value0 = cl_env_copy->values[0];
      } else {
       if (Null(ECL_CONS_CAR(CLV2))){
        goto L6;
       }
       T0 = ECL_CONS_CAR(CLV0);
       goto L5;
L6:;
       T0 = ECL_CONS_CAR(CLV3);
L5:;
       value0 = L521interpret_directive_list(ECL_CONS_CAR(CLV5), ECL_CONS_CAR(CLV1), T0, ECL_CONS_CAR(CLV3));
      }
     }
     ecl_frs_pop(cl_env_copy);                    /*  END CATCH CATCH3603     */
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     return value0;
     }
    }
   }
  }
 }
 }
}
/* closure LAMBDA3133                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC621__lambda3133(cl_narg narg, cl_object v1condition, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV7 = env0;
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);                           /*  END                     */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[398]);
 {
L1:;
  T0 = ecl_list1(v1condition);
  T1 = ecl_one_minus(ECL_CONS_CAR(CLV3));
  value0 = cl_error(11, ECL_SYM("FORMAT-ERROR",1084), VV[29], VV[331], VV[110], T0, VV[333], ECL_NIL, ECL_SYM("CONTROL-STRING",1242), ECL_CONS_CAR(CLV2), ECL_SYM("OFFSET",1316), T1);
  return value0;
 }
 }
}
/* closure LAMBDA3517                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC646__lambda3517(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV7 = env0;
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[466]);
 {
L1:;
  T0 = ECL_CONS_CAR(CLV4);
  T1 = ECL_CONS_CAR(CLV6);
  if (si_pprint_pop_helper(T0, T1, ECL_CONS_CAR(CLV5))!=ECL_NIL) {
   goto L2;
  }
  cl_env_copy->values[0] = ECL_NIL;
  cl_env_copy->nvalues = 1;
  cl_return_from(ECL_CONS_CAR(CLV7),VV[465]);
L2:;
  T0 = ECL_CONS_CAR(CLV6);
  ECL_CONS_CAR(CLV6) = ecl_plus(T0,ecl_make_int8_t(1));
  {
   cl_object v1;
   v1 = ECL_CONS_CAR(CLV4);
   {
    cl_object v2;
    v2 = v1;
    {
     bool v3;
     v3 = ECL_LISTP(v2);
     if (ecl_unlikely(!(v3)))
         FEwrong_type_argument(VV[106],v2);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v1)){
    goto L14;
   }
   {
    cl_object v2;
    v2 = ECL_CONS_CDR(v1);
    ECL_CONS_CAR(CLV4) = v2;
    v1 = ECL_CONS_CAR(v1);
   }
L14:;
   value0 = v1;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
 }
}
/* closure LAMBDA3533                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC648__lambda3533(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV7 = env0;
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[469]);
 {
L1:;
  T0 = ECL_CONS_CAR(CLV4);
  T1 = ECL_CONS_CAR(CLV6);
  if (si_pprint_pop_helper(T0, T1, ECL_CONS_CAR(CLV5))!=ECL_NIL) {
   goto L2;
  }
  cl_env_copy->values[0] = ECL_NIL;
  cl_env_copy->nvalues = 1;
  cl_return_from(ECL_CONS_CAR(CLV7),VV[468]);
L2:;
  T0 = ECL_CONS_CAR(CLV6);
  ECL_CONS_CAR(CLV6) = ecl_plus(T0,ecl_make_int8_t(1));
  {
   cl_object v1;
   v1 = ECL_CONS_CAR(CLV4);
   {
    cl_object v2;
    v2 = v1;
    {
     bool v3;
     v3 = ECL_LISTP(v2);
     if (ecl_unlikely(!(v3)))
         FEwrong_type_argument(VV[106],v2);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v1)){
    goto L14;
   }
   {
    cl_object v2;
    v2 = ECL_CONS_CDR(v1);
    ECL_CONS_CAR(CLV4) = v2;
    v1 = ECL_CONS_CAR(v1);
   }
L14:;
   value0 = v1;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
 }
}
#include "lsp/format.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecl3jeOprGpXN8m9_qAtzL881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:LSP;FORMAT.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecl3jeOprGpXN8m9_qAtzL881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0, T1;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  T0 = cl_adjoin(2, VV[0], ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36)));
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*FEATURES*",36),T0);
  T0 = cl_adjoin(2, VV[1], ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36)));
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*FEATURES*",36),T0);
  si_Xmake_special(VV[2]);
  T0 = VVtemp[1];
  ecl_cmp_setq(cl_env_copy,VV[2],T0);
  ecl_cmp_defun(VV[481]);                         /*  FLOAT-TO-DIGITS*        */
  ecl_cmp_defun(VV[482]);                         /*  FLONUM-TO-STRING        */
  ecl_cmp_defun(VV[483]);                         /*  EXPONENT-IN-BASE10      */
  si_define_structure(VV[12], _ecl_static_0, ECL_SYM("VECTOR",902), ECL_T, VVtemp[2], VVtemp[3], VV[13], ECL_NIL, ECL_NIL, ECL_NIL, VVtemp[4], ecl_make_int8_t(8), ecl_make_int8_t(0), ECL_NIL, VV[14]);
  ecl_cmp_defun(VV[484]);                         /*  MAKE-FORMAT-DIRECTIVE   */
  si_do_deftype(3, VV[12], VVtemp[5], ECL_SYM("VECTOR",902));
  si_Xmake_constant(VV[18], ecl_make_int8_t(80));
  {
   cl_fixnum v1;
   v1 = (ecl_character)(126);
   T0 = ecl_make_integer((v1)+1);
   si_Xmake_constant(VV[19], T0);
  }
  si_Xmake_special(VV[20]);
  T0 = si_make_vector(ECL_T, ecl_make_int8_t(127), ECL_NIL, ECL_NIL, ECL_NIL, ecl_make_int8_t(0));
  T1 = si_fill_array_with_elt(T0, ECL_NIL, ecl_make_int8_t(0), ECL_NIL);
  ecl_cmp_setq(cl_env_copy,VV[20],T1);
  si_Xmake_special(VV[21]);
  T0 = si_make_vector(ECL_T, ecl_make_int8_t(127), ECL_NIL, ECL_NIL, ECL_NIL, ecl_make_int8_t(0));
  T1 = si_fill_array_with_elt(T0, ECL_NIL, ecl_make_int8_t(0), ECL_NIL);
  ecl_cmp_setq(cl_env_copy,VV[21],T1);
  si_Xmake_special(VV[22]);
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[22],T0);
  si_Xmake_special(VV[23]);
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[23],T0);
  si_Xmake_special(VV[24]);
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[24],T0);
  (void)0; /* No entry created for TOKENIZE-CONTROL-STRING */
  (void)0; /* No entry created for PARSE-DIRECTIVE */
  si_Xmake_special(VV[43]);
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[43],T0);
  si_Xmake_special(VV[44]);
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[44],T0);
  si_Xmake_special(VV[45]);
  T0 = VV[46];
  ecl_cmp_setq(cl_env_copy,VV[45],T0);
  si_Xmake_special(VV[47]);
  si_Xmake_special(VV[48]);
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[48],T0);
  si_Xmake_special(VV[49]);
  ecl_cmp_defun(VV[485]);                         /*  FORMATTER-AUX           */
  (void)0; /* No entry created for INTERPRET-DIRECTIVE-LIST */
  ecl_cmp_defmacro(VV[486]);                      /*  FORMATTER               */
  (void)0; /* No entry created for %FORMATTER */
  (void)0; /* No entry created for EXPAND-CONTROL-STRING */
  (void)0; /* No entry created for EXPAND-DIRECTIVE-LIST */
  (void)0; /* No entry created for EXPAND-DIRECTIVE */
  (void)0; /* No entry created for EXPAND-NEXT-ARG */
  (void)0; /* No entry created for NEED-HAIRY-ARGS */
  ecl_cmp_defmacro(VV[487]);                      /*  EXPANDER-NEXT-ARG       */
  ecl_cmp_defmacro(VV[488]);                      /*  EXPANDER-PPRINT-NEXT-ARG */
  ecl_cmp_defun(VV[489]);                         /*  %SET-FORMAT-DIRECTIVE-EXPANDER */
  (void)0; /* No entry created for %SET-FORMAT-DIRECTIVE-INTERPRETER */
  (void)0; /* No entry created for FIND-DIRECTIVE */
  (void)0; /* No entry created for FORMAT-WRITE-FIELD */
  ecl_cmp_defun(VV[490]);                         /*  FORMAT-PRINC            */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC536latin_capital_letter_a_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(65), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC537__lambda418_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(65), T0);
  ecl_cmp_defun(VV[491]);                         /*  FORMAT-PRIN1            */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC538latin_capital_letter_s_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(83), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC539__lambda564_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(83), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC540latin_capital_letter_c_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(67), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC541__lambda645_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(67), T0);
  (void)0; /* No entry created for CHAR-PRINTING-P */
  ecl_cmp_defun(VV[492]);                         /*  FORMAT-PRINT-NAMED-CHARACTER */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC543latin_capital_letter_w_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(87), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC544__lambda668_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(87), T0);
  ecl_cmp_defun(VV[493]);                         /*  FORMAT-PRINT-INTEGER    */
  (void)0; /* No entry created for FORMAT-ADD-COMMAS */
  ecl_cmp_defun(VV[494]);                         /*  EXPAND-FORMAT-INTEGER   */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC547latin_capital_letter_d_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(68), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC548__lambda769_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(68), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC549latin_capital_letter_b_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(66), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC550__lambda847_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(66), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC551latin_capital_letter_o_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(79), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC552__lambda925_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(79), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC553latin_capital_letter_x_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(88), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC554__lambda1003_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(88), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC555latin_capital_letter_r_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(82), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC556__lambda1162_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(82), T0);
  si_Xmake_constant(VV[167], VV[168]);
  si_Xmake_constant(VV[169], VV[170]);
  si_Xmake_constant(VV[171], VV[172]);
  si_Xmake_constant(VV[173], VV[174]);
  si_Xmake_constant(VV[175], VV[176]);
  si_Xmake_constant(VV[177], VV[178]);
  (void)0; /* No entry created for FORMAT-PRINT-SMALL-CARDINAL */
  ecl_cmp_defun(VV[495]);                         /*  FORMAT-PRINT-CARDINAL   */
  (void)0; /* No entry created for FORMAT-PRINT-CARDINAL-AUX */
  ecl_cmp_defun(VV[496]);                         /*  FORMAT-PRINT-ORDINAL    */
  ecl_cmp_defun(VV[497]);                         /*  FORMAT-PRINT-OLD-ROMAN  */
  ecl_cmp_defun(VV[498]);                         /*  FORMAT-PRINT-ROMAN      */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC559latin_capital_letter_p_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(80), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC560__lambda1291_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(80), T0);
  (void)0; /* No entry created for DECIMAL-STRING */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC562latin_capital_letter_f_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(70), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC563__lambda1391_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(70), T0);
  ecl_cmp_defun(VV[499]);                         /*  FORMAT-FIXED            */
  (void)0; /* No entry created for FORMAT-FIXED-AUX */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC565latin_capital_letter_e_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(69), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC566__lambda1615_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(69), T0);
  ecl_cmp_defun(VV[500]);                         /*  FORMAT-EXPONENTIAL      */
  (void)0; /* No entry created for FORMAT-EXPONENT-MARKER */
  (void)0; /* No entry created for FORMAT-EXP-AUX */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC569latin_capital_letter_g_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(71), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC570__lambda1887_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(71), T0);
  ecl_cmp_defun(VV[501]);                         /*  FORMAT-GENERAL          */
  (void)0; /* No entry created for FORMAT-GENERAL-AUX */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC572dollar_sign_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(36), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC573__lambda2080_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(36), T0);
  ecl_cmp_defun(VV[502]);                         /*  FORMAT-DOLLARS          */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC574percent_sign_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(37), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC575__lambda2183_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(37), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC576ampersand_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(38), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC577__lambda2233_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(38), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC578vertical_line_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(124), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC579__lambda2283_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(124), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC580tilde_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(126), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC581__lambda2333_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(126), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC582_newline_format_directive_expander__va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(10), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC583__lambda2366_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(10), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC584_return_format_directive_expander__va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(13), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC585__lambda2379_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(13), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC586latin_capital_letter_t_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(84), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC587__lambda2492_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(84), T0);
  (void)0; /* No entry created for OUTPUT-SPACES */
  ecl_cmp_defun(VV[503]);                         /*  FORMAT-RELATIVE-TAB     */
  ecl_cmp_defun(VV[504]);                         /*  FORMAT-ABSOLUTE-TAB     */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC589low_line_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(95), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC590__lambda2605_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(95), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC591latin_capital_letter_i_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(73), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC592__lambda2635_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(73), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC593asterisk_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(42), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC594__lambda2714_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(42), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC595question_mark_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(63), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC597__lambda2793_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(63), T0);
  ecl_cmp_defun(VV[505]);                         /*  NSTRING-CAPITALIZE-FIRST */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC599left_parenthesis_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(40), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC600__lambda2818_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(40), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC601right_parenthesis_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(41), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC602__lambda2849_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(41), T0);
  (void)0; /* No entry created for PARSE-CONDITIONAL-DIRECTIVE */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC604left_square_bracket_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(91), T0);
  (void)0; /* No entry created for EXPAND-MAYBE-CONDITIONAL */
  (void)0; /* No entry created for EXPAND-TRUE-FALSE-CONDITIONAL */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC609__lambda2911_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(91), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC610semicolon_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(59), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC611__lambda2952_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(59), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC612__lambda2956_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(93), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC613right_square_bracket_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(93), T0);
  si_Xmake_special(VV[366]);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC614circumflex_accent_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(94), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC615__lambda3019_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(94), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC620left_curly_bracket_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(123), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC625__lambda3105_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(123), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC626right_curly_bracket_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(125), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC627__lambda3151_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(125), T0);
  si_Xmake_special(VV[404]);
  {
   cl_object v1;
   {
    cl_object v2;
    v2 = ecl_make_cfun_va((cl_objectfn)LC628__lambda3158_va,ECL_NIL,Cblock,1);
    v1 = v2;
   }
   {
    cl_object v2;
    cl_object v3;
    v2 = ECL_NIL;
    v3 = VVtemp[6];
    {
     cl_object v4;
     cl_object v5;
     v4 = ecl_list1(ECL_NIL);
     v5 = v4;
L405:;
     v2 = ECL_CONS_CAR(v3);
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v3);
      if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v3 = v6;
     }
     {
      cl_object v6;
      v6 = v5;
      if (ecl_unlikely(ECL_ATOM(v6))) FEtype_error_cons(v6);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v6;
     }
     T1 = ecl_function_dispatch(cl_env_copy,v1)(1, v2);
     v5 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v5,T0);
     if (!(ecl_endp(v3))){
      goto L419;
     }
     goto L406;
L419:;
     goto L405;
L406:;
     T0 = ecl_cdr(v4);
     ecl_cmp_setq(cl_env_copy,VV[404],T0);
     goto L399;
    }
   }
  }
L399:;
  (void)0; /* No entry created for CHECK-OUTPUT-LAYOUT-MODE */
  ecl_cmp_defun(VV[506]);                         /*  ILLEGAL-INSIDE-JUSTIFICATION-P */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC633less_than_sign_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(60), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC635__lambda3200_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(60), T0);
  (void)0; /* No entry created for PARSE-FORMAT-JUSTIFICATION */
  (void)0; /* No entry created for EXPAND-FORMAT-JUSTIFICATION */
  (void)0; /* No entry created for INTERPRET-FORMAT-JUSTIFICATION */
  ecl_cmp_defun(VV[507]);                         /*  FORMAT-JUSTIFICATION    */
  (void)0; /* No entry created for PARSE-FORMAT-LOGICAL-BLOCK */
  (void)0; /* No entry created for ADD-FILL-STYLE-NEWLINES */
  (void)0; /* No entry created for ADD-FILL-STYLE-NEWLINES-AUX */
  ecl_cmp_defun(VV[508]);                         /*  EXPAND-FORMAT-LOGICAL-BLOCK */
  (void)0; /* No entry created for INTERPRET-FORMAT-LOGICAL-BLOCK */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC651greater_than_sign_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(62), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC652solidus_format_directive_expander_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  L531_set_format_directive_expander(ECL_CODE_CHAR(47), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC653__lambda3571_va,ECL_NIL,Cblock,5);
   T0 = v1;
  }
  L532_set_format_directive_interpreter(ECL_CODE_CHAR(47), T0);
  (void)0; /* No entry created for EXTRACT-USER-FUNCTION-NAME */
 }
}
