/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/contrib/asdf/asdf.lisp                  */
#include <ecl/ecl-cmp.h>
#include "ext/asdf.eclh"
/* function definition for FIND-PACKAGE*                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4197find_package_(cl_narg narg, cl_object v1uiop_package__package_designator, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1]);
 {
  cl_object v2error;
  va_list args; va_start(args,v1uiop_package__package_designator);
  {
   int i = 1;
   if (i >= narg) {
    v2error = ECL_T;
   } else {
    i++;
    v2error = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v3package;
   v3package = cl_find_package(v1uiop_package__package_designator);
   if (Null(v3package)){
    goto L3;
   }
   value0 = v3package;
   cl_env_copy->nvalues = 1;
   return value0;
L3:;
   if (Null(v2error)){
    goto L5;
   }
   T0 = cl_string(v1uiop_package__package_designator);
   value0 = cl_error(2, VV[2], T0);
   return value0;
L5:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for FIND-SYMBOL*                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4198find_symbol_(cl_narg narg, cl_object v1uiop_package__name, cl_object v2uiop_package__package_designator, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[4]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[4]);
 {
  cl_object v3error;
  va_list args; va_start(args,v2uiop_package__package_designator);
  {
   int i = 2;
   if (i >= narg) {
    v3error = ECL_T;
   } else {
    i++;
    v3error = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v4package;
   v4package = L4197find_package_(2, v2uiop_package__package_designator, v3error);
   if (Null(v4package)){
    goto L3;
   }
   {
    cl_object v5;                                 /*  SYMBOL                  */
    cl_object v6;                                 /*  STATUS                  */
    T0 = cl_string(v1uiop_package__name);
    value0 = cl_find_symbol(2, T0, v4package);
    {
     v5 = value0;
     v6 = cl_env_copy->values[1];
    }
    if (Null(v6)){
     goto L6;
    }
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = v6;
    cl_env_copy->values[0] = v5;
    return cl_env_copy->values[0];
L6:;
    if (Null(v3error)){
     goto L3;
    }
    T0 = cl_package_name(v4package);
    cl_error(3, VV[5], v1uiop_package__name, T0);
   }
L3:;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = ECL_NIL;
   cl_env_copy->values[0] = ECL_NIL;
   return cl_env_copy->values[0];
  }
 }
}
/* function definition for SYMBOL-CALL                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4199symbol_call(cl_narg narg, cl_object v1package, cl_object v2uiop_package__name, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[7]);
 {
  cl_object v3uiop_package__args;
  ecl_va_list args; ecl_va_start(args,v2uiop_package__name,narg,2);
  v3uiop_package__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  T0 = L4198find_symbol_(2, v2uiop_package__name, v1package);
  value0 = cl_apply(2, T0, v3uiop_package__args);
  return value0;
 }
}
/* function definition for INTERN*                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4200intern_(cl_narg narg, cl_object v1uiop_package__name, cl_object v2uiop_package__package_designator, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[9]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[9]);
 {
  cl_object v3error;
  va_list args; va_start(args,v2uiop_package__package_designator);
  {
   int i = 2;
   if (i >= narg) {
    v3error = ECL_T;
   } else {
    i++;
    v3error = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = cl_string(v1uiop_package__name);
  T1 = L4197find_package_(2, v2uiop_package__package_designator, v3error);
  value0 = cl_intern(2, T0, T1);
  return value0;
 }
}
/* function definition for EXPORT*                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4201export_(cl_object v1uiop_package__name, cl_object v2uiop_package__package_designator)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3package;
  cl_object v4symbol;
  v3package = L4197find_package_(1, v2uiop_package__package_designator);
  v4symbol = L4200intern_(2, v1uiop_package__name, v3package);
  value0 = v4symbol;
  if (value0!=ECL_NIL) {
   goto L6;
  }
  T0 = ecl_list1(v4symbol);
  goto L4;
L6:;
  T0 = value0;
  goto L4;
L4:;
  value0 = cl_export(2, T0, v3package);
  return value0;
 }
}
static cl_object L4201export__va(cl_narg narg, cl_object v5uiop_package__name, cl_object v6uiop_package__package_designator, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[11]);
 {
  return L4201export_(v5uiop_package__name, v6uiop_package__package_designator);
 }
}
/* function definition for IMPORT*                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4202import_(cl_object v1symbol, cl_object v2uiop_package__package_designator)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = v1symbol;
 if (value0!=ECL_NIL) {
  goto L4;
 }
 T0 = ecl_list1(v1symbol);
 goto L2;
L4:;
 T0 = value0;
 goto L2;
L2:;
 T1 = L4197find_package_(1, v2uiop_package__package_designator);
 value0 = cl_import(2, T0, T1);
 return value0;
}
static cl_object L4202import__va(cl_narg narg, cl_object v3symbol, cl_object v4uiop_package__package_designator, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[13]);
 {
  return L4202import_(v3symbol, v4uiop_package__package_designator);
 }
}
/* function definition for SHADOWING-IMPORT*                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4203shadowing_import_(cl_object v1symbol, cl_object v2uiop_package__package_designator)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = v1symbol;
 if (value0!=ECL_NIL) {
  goto L4;
 }
 T0 = ecl_list1(v1symbol);
 goto L2;
L4:;
 T0 = value0;
 goto L2;
L2:;
 T1 = L4197find_package_(1, v2uiop_package__package_designator);
 value0 = cl_shadowing_import(2, T0, T1);
 return value0;
}
static cl_object L4203shadowing_import__va(cl_narg narg, cl_object v3symbol, cl_object v4uiop_package__package_designator, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[15]);
 {
  return L4203shadowing_import_(v3symbol, v4uiop_package__package_designator);
 }
}
/* function definition for SHADOW*                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4204shadow_(cl_object v1uiop_package__name, cl_object v2uiop_package__package_designator)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_string(v1uiop_package__name);
 T1 = ecl_list1(T0);
 T2 = L4197find_package_(1, v2uiop_package__package_designator);
 value0 = cl_shadow(2, T1, T2);
 return value0;
}
static cl_object L4204shadow__va(cl_narg narg, cl_object v3uiop_package__name, cl_object v4uiop_package__package_designator, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[17]);
 {
  return L4204shadow_(v3uiop_package__name, v4uiop_package__package_designator);
 }
}
/* function definition for MAKE-SYMBOL*                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4205make_symbol_(cl_object v1uiop_package__name)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_STRINGP(v1uiop_package__name))){
  goto L2;
 }
 value0 = cl_make_symbol(v1uiop_package__name);
 return value0;
L2:;
 if (!(ECL_SYMBOLP(v1uiop_package__name))){
  goto L4;
 }
 value0 = cl_copy_symbol(1, v1uiop_package__name);
 return value0;
L4:;
 value0 = si_etypecase_error(v1uiop_package__name, VV[20]);
 return value0;
}
static cl_object L4205make_symbol__va(cl_narg narg, cl_object v2uiop_package__name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[19]);
 {
  return L4205make_symbol_(v2uiop_package__name);
 }
}
/* function definition for UNINTERN*                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4206unintern_(cl_narg narg, cl_object v1uiop_package__name, cl_object v2uiop_package__package_designator, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[22]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[22]);
 {
  cl_object v3error;
  va_list args; va_start(args,v2uiop_package__package_designator);
  {
   int i = 2;
   if (i >= narg) {
    v3error = ECL_T;
   } else {
    i++;
    v3error = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v4package;
   v4package = L4197find_package_(2, v2uiop_package__package_designator, v3error);
   if (Null(v4package)){
    goto L3;
   }
   {
    cl_object v5;                                 /*  SYMBOL                  */
    cl_object v6;                                 /*  STATUS                  */
    value0 = L4198find_symbol_(3, v1uiop_package__name, v4package, v3error);
    {
     const int v7 = cl_env_copy->nvalues;
     v5 = value0;
     cl_object v8;
     v8 = (v7<=1)? ECL_NIL : cl_env_copy->values[1];
     v6 = v8;
    }
    if (Null(v6)){
     goto L6;
    }
    cl_unintern(2, v5, v4package);
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = v6;
    cl_env_copy->values[0] = v5;
    return cl_env_copy->values[0];
L6:;
    if (Null(v3error)){
     goto L3;
    }
    T0 = cl_string(v5);
    T1 = cl_package_name(v4package);
    cl_error(3, VV[23], T0, T1);
   }
L3:;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = ECL_NIL;
   cl_env_copy->values[0] = ECL_NIL;
   return cl_env_copy->values[0];
  }
 }
}
/* function definition for SYMBOL-SHADOWING-P                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4207symbol_shadowing_p(cl_object v1symbol, cl_object v2package)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = cl_package_shadowing_symbols(v2package);
  v4 = v1symbol;
  v5 = v3;
  if (Null(ecl_memql(v4,v5))){
   goto L3;
  }
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4207symbol_shadowing_p_va(cl_narg narg, cl_object v3symbol, cl_object v4package, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[25]);
 {
  return L4207symbol_shadowing_p(v3symbol, v4package);
 }
}
/* function definition for HOME-PACKAGE-P                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4208home_package_p(cl_object v1symbol, cl_object v2package)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v2package)){
  goto L3;
 }
 {
  cl_object v3uiop_package__sp;
  v3uiop_package__sp = cl_symbol_package(v1symbol);
  if (Null(v3uiop_package__sp)){
   goto L7;
  }
  {
   cl_object v4uiop_package__pp;
   v4uiop_package__pp = L4197find_package_(1, v2package);
   if (Null(v4uiop_package__pp)){
    goto L11;
   }
   value0 = ecl_make_bool((v3uiop_package__sp)==(v4uiop_package__pp));
   cl_env_copy->nvalues = 1;
   return value0;
L11:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L7:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4208home_package_p_va(cl_narg narg, cl_object v5symbol, cl_object v6package, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[27]);
 {
  return L4208home_package_p(v5symbol, v6package);
 }
}
/* function definition for SYMBOL-PACKAGE-NAME                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4209symbol_package_name(cl_object v1symbol)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2package;
  v2package = cl_symbol_package(v1symbol);
  if (Null(v2package)){
   goto L4;
  }
  value0 = cl_package_name(v2package);
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4209symbol_package_name_va(cl_narg narg, cl_object v3symbol, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[29]);
 {
  return L4209symbol_package_name(v3symbol);
 }
}
/* function definition for STANDARD-COMMON-LISP-SYMBOL-P                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4210standard_common_lisp_symbol_p(cl_object v1symbol)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;                                   /*  SYM                     */
  cl_object v3;                                   /*  STATUS                  */
  value0 = L4198find_symbol_(3, v1symbol, VV[32], ECL_NIL);
  {
   const int v4 = cl_env_copy->nvalues;
   v2 = value0;
   cl_object v5;
   v5 = (v4<=1)? ECL_NIL : cl_env_copy->values[1];
   v3 = v5;
  }
  if (!((v2)==(v1symbol))){
   goto L4;
  }
  value0 = ecl_make_bool((v3)==(ECL_SYM("EXTERNAL",1266)));
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4210standard_common_lisp_symbol_p_va(cl_narg narg, cl_object v2symbol, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[31]);
 {
  return L4210standard_common_lisp_symbol_p(v2symbol);
 }
}
/* function definition for REIFY-PACKAGE                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4211reify_package(cl_narg narg, cl_object v1package, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[34]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[34]);
 {
  cl_object v2uiop_package__package_context;
  va_list args; va_start(args,v1package);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_package__package_context = ECL_NIL;
   } else {
    i++;
    v2uiop_package__package_context = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (!((v1package)==(v2uiop_package__package_context))){
   goto L2;
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  if (!(v1package==ECL_NIL)){
   goto L4;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  if (Null(cl_typep(2, v1package, VV[35]))){
   goto L6;
  }
  value0 = VV[36];
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  if (Null(cl_packagep(v1package))){
   goto L8;
  }
  value0 = cl_package_name(v1package);
  return value0;
L8:;
  value0 = si_etypecase_error(v1package, VV[37]);
  return value0;
 }
}
/* function definition for UNREIFY-PACKAGE                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4212unreify_package(cl_narg narg, cl_object v1package, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[39]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[39]);
 {
  cl_object v2uiop_package__package_context;
  va_list args; va_start(args,v1package);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_package__package_context = ECL_NIL;
   } else {
    i++;
    v2uiop_package__package_context = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (!(v1package==ECL_NIL)){
   goto L2;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  if (Null(cl_typep(2, v1package, VV[40]))){
   goto L4;
  }
  value0 = v2uiop_package__package_context;
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  if (ECL_SYMBOLP(v1package)) {
   goto L8;
  }
  if (!(ECL_STRINGP(v1package))){
   goto L6;
  }
  goto L7;
L8:;
L7:;
  value0 = cl_find_package(v1package);
  return value0;
L6:;
  value0 = si_etypecase_error(v1package, VV[41]);
  return value0;
 }
}
/* function definition for REIFY-SYMBOL                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4213reify_symbol(cl_narg narg, cl_object v1symbol, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[43]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[43]);
 {
  cl_object v2uiop_package__package_context;
  va_list args; va_start(args,v1symbol);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_package__package_context = ECL_NIL;
   } else {
    i++;
    v2uiop_package__package_context = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (cl_keywordp(v1symbol)!=ECL_NIL) {
   goto L4;
  }
  if (Null(L4210standard_common_lisp_symbol_p(v1symbol))){
   goto L2;
  }
  goto L3;
L4:;
L3:;
  value0 = v1symbol;
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  if (!(ECL_SYMBOLP(v1symbol))){
   goto L6;
  }
  T0 = ecl_symbol_name(v1symbol);
  T1 = cl_symbol_package(v1symbol);
  T2 = L4211reify_package(2, T1, v2uiop_package__package_context);
  value0 = cl_vector(2, T0, T2);
  return value0;
L6:;
  value0 = si_etypecase_error(v1symbol, VV[44]);
  return value0;
 }
}
/* function definition for UNREIFY-SYMBOL                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4214unreify_symbol(cl_narg narg, cl_object v1symbol, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[46]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[46]);
 {
  cl_object v2uiop_package__package_context;
  va_list args; va_start(args,v1symbol);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_package__package_context = ECL_NIL;
   } else {
    i++;
    v2uiop_package__package_context = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (!(ECL_SYMBOLP(v1symbol))){
   goto L2;
  }
  value0 = v1symbol;
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  if (Null(cl_typep(2, v1symbol, VV[47]))){
   goto L4;
  }
  {
   cl_object v3symbol_name;
   cl_object v4uiop_package__package_foo;
   cl_object v5package;
   v3symbol_name = ecl_aref1(v1symbol,(cl_fixnum)(0));
   v4uiop_package__package_foo = ecl_aref1(v1symbol,(cl_fixnum)(1));
   v5package = L4212unreify_package(2, v4uiop_package__package_foo, v2uiop_package__package_context);
   if (Null(v5package)){
    goto L9;
   }
   value0 = L4200intern_(2, v3symbol_name, v5package);
   return value0;
L9:;
   value0 = L4205make_symbol_(v3symbol_name);
   return value0;
  }
L4:;
  value0 = si_etypecase_error(v1symbol, VV[48]);
  return value0;
 }
}
/* function definition for RECORD-FISHY                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4215record_fishy(cl_object v1uiop_package__info)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = CONS(v1uiop_package__info,ecl_cmp_symbol_value(cl_env_copy,VV[51]));
 ecl_cmp_setq(cl_env_copy,VV[51],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[51]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4215record_fishy_va(cl_narg narg, cl_object v2uiop_package__info, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[52]);
 {
  return L4215record_fishy(v2uiop_package__info);
 }
}
/* local function WHEN-PACKAGE-FISHINESS                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4216when_package_fishiness(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  value0 = cl_listX(3, ECL_SYM("WHEN",909), VV[51], v3);
  return value0;
 }
}
static cl_object LC4216when_package_fishiness_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[54]);
 {
  return LC4216when_package_fishiness(v4, v5);
 }
}
/* local function NOTE-PACKAGE-FISHINESS                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4217note_package_fishiness(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  T0 = CONS(ECL_SYM("LIST",483),v3);
  T1 = cl_list(2, VV[52], T0);
  value0 = cl_list(2, VV[54], T1);
  return value0;
 }
}
static cl_object LC4217note_package_fishiness_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[56]);
 {
  return LC4217note_package_fishiness(v4, v5);
 }
}
/* function definition for SET-DUMMY-SYMBOL                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4218set_dummy_symbol(cl_object v1symbol, cl_object v2uiop_package__reason, cl_object v3uiop_package__other_symbol)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  v4 = CONS(v2uiop_package__reason,v3uiop_package__other_symbol);
  value0 = si_putprop(v1symbol, v4, VV[59]);
  return value0;
 }
}
static cl_object L4218set_dummy_symbol_va(cl_narg narg, cl_object v5symbol, cl_object v6uiop_package__reason, cl_object v7uiop_package__other_symbol, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[58]);
 {
  return L4218set_dummy_symbol(v5symbol, v6uiop_package__reason, v7uiop_package__other_symbol);
 }
}
/* function definition for MAKE-DUMMY-SYMBOL                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4219make_dummy_symbol(cl_object v1symbol)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_package__dummy;
  v2uiop_package__dummy = cl_copy_symbol(1, v1symbol);
  L4218set_dummy_symbol(v2uiop_package__dummy, VV[62], v1symbol);
  L4218set_dummy_symbol(v1symbol, VV[63], v2uiop_package__dummy);
  value0 = v2uiop_package__dummy;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4219make_dummy_symbol_va(cl_narg narg, cl_object v3symbol, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[61]);
 {
  return L4219make_dummy_symbol(v3symbol);
 }
}
/* function definition for DUMMY-SYMBOL                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4220dummy_symbol(cl_object v1symbol)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_get(v1symbol,VV[59],ECL_NIL);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4220dummy_symbol_va(cl_narg narg, cl_object v2symbol, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[59]);
 {
  return L4220dummy_symbol(v2symbol);
 }
}
/* function definition for GET-DUMMY-SYMBOL                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4221get_dummy_symbol(cl_object v1symbol)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_package__existing;
  v2uiop_package__existing = L4220dummy_symbol(v1symbol);
  if (Null(v2uiop_package__existing)){
   goto L3;
  }
  T0 = ecl_cdr(v2uiop_package__existing);
  T1 = ecl_car(v2uiop_package__existing);
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = T1;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
L3:;
  value0 = L4219make_dummy_symbol(v1symbol);
  return value0;
 }
}
static cl_object L4221get_dummy_symbol_va(cl_narg narg, cl_object v3symbol, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[66]);
 {
  return L4221get_dummy_symbol(v3symbol);
 }
}
/* function definition for NUKE-SYMBOL-IN-PACKAGE                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4222nuke_symbol_in_package(cl_object v1symbol, cl_object v2uiop_package__package_designator)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = L4197find_package_(1, v2uiop_package__package_designator);
  v4 = ecl_symbol_name(v1symbol);
  {
   cl_object v5;                                  /*  SYM                     */
   cl_object v6;                                  /*  STAT                    */
   value0 = cl_find_symbol(2, v4, v3);
   {
    v5 = value0;
    v6 = cl_env_copy->values[1];
   }
   if (!((v6)==(ECL_SYM("INTERNAL",1293)))){
    goto L11;
   }
   goto L8;
L11:;
   goto L9;
L9:;
   if (!((v6)==(ECL_SYM("EXTERNAL",1266)))){
    goto L5;
   }
   goto L7;
L8:;
L7:;
   if (!((v1symbol)==(v5))){
    goto L5;
   }
   if (Null(L4207symbol_shadowing_p(v1symbol, v3))){
    goto L14;
   }
   T0 = L4221get_dummy_symbol(v1symbol);
   value0 = L4203shadowing_import_(T0, v3);
   return value0;
L14:;
   value0 = L4206unintern_(2, v1symbol, v3);
   return value0;
L5:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4222nuke_symbol_in_package_va(cl_narg narg, cl_object v5symbol, cl_object v6uiop_package__package_designator, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[68]);
 {
  return L4222nuke_symbol_in_package(v5symbol, v6uiop_package__package_designator);
 }
}
/* function definition for NUKE-SYMBOL                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4223nuke_symbol(cl_narg narg, cl_object v1symbol, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[72]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[72]);
 {
  cl_object v2uiop_package__packages;
  va_list args; va_start(args,v1symbol);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_package__packages = cl_list_all_packages();
   } else {
    i++;
    v2uiop_package__packages = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v3;
   cl_object v4uiop_package__p;
   cl_object v5;
   {
    cl_object v6;
    v6 = v2uiop_package__packages;
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v6;
   }
   v4uiop_package__p = ECL_NIL;
   v5 = v3;
L7:;
   if (!(ecl_endp(v5))){
    goto L9;
   }
   goto L8;
L9:;
   v4uiop_package__p = ECL_CONS_CAR(v5);
   {
    cl_object v6;
    v6 = ECL_CONS_CDR(v5);
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v6;
   }
   L4222nuke_symbol_in_package(v1symbol, v4uiop_package__p);
   goto L7;
L8:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for REHOME-SYMBOL                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4224rehome_symbol(cl_object v1symbol, cl_object v2uiop_package__package_designator)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3uiop_package__name;
  cl_object v4package;
  cl_object v5uiop_package__old_package;
  cl_object v6uiop_package__old_status;
  cl_object v7uiop_package__shadowing;
  v3uiop_package__name = ecl_symbol_name(v1symbol);
  v4package = L4197find_package_(1, v2uiop_package__package_designator);
  v5uiop_package__old_package = cl_symbol_package(v1symbol);
  if (Null(v5uiop_package__old_package)){
   goto L7;
  }
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   cl_env_copy->values[0] = cl_find_symbol(2, v3uiop_package__name, v5uiop_package__old_package);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   T0 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
   ecl_stack_frame_close(_ecl_inner_frame);
  }
  v6uiop_package__old_status = ecl_cadr(T0);
  goto L5;
L7:;
  v6uiop_package__old_status = ECL_NIL;
  goto L5;
L5:;
  if (Null(v5uiop_package__old_package)){
   goto L13;
  }
  if (Null(L4207symbol_shadowing_p(v1symbol, v5uiop_package__old_package))){
   goto L13;
  }
  v7uiop_package__shadowing = cl_make_symbol(v3uiop_package__name);
  goto L11;
L13:;
  v7uiop_package__shadowing = ECL_NIL;
  goto L11;
L11:;
  {
   cl_object v8;                                  /*  OVERWRITTEN-SYMBOL      */
   cl_object v9;                                  /*  OVERWRITTEN-SYMBOL-STATUS */
   value0 = cl_find_symbol(2, v3uiop_package__name, v4package);
   {
    v8 = value0;
    v9 = cl_env_copy->values[1];
   }
   if ((v4package)==(v5uiop_package__old_package)) {
    goto L17;
   }
   {
    cl_object v10uiop_package__overwritten_symbol_shadowing_p;
    if (Null(v9)){
     goto L21;
    }
    v10uiop_package__overwritten_symbol_shadowing_p = L4207symbol_shadowing_p(v8, v4package);
    goto L19;
L21:;
    v10uiop_package__overwritten_symbol_shadowing_p = ECL_NIL;
    goto L19;
L19:;
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
     goto L23;
    }
    if (Null(v5uiop_package__old_package)){
     goto L26;
    }
    T0 = cl_package_name(v5uiop_package__old_package);
    goto L25;
L26:;
    T0 = ECL_NIL;
L25:;
    if (Null(v7uiop_package__shadowing)){
     goto L30;
    }
    T1 = ECL_T;
    goto L28;
L30:;
    T1 = ECL_NIL;
    goto L28;
L28:;
    T2 = cl_package_name(v4package);
    T3 = cl_list(8, VV[77], v3uiop_package__name, T0, v6uiop_package__old_status, T1, T2, v9, v10uiop_package__overwritten_symbol_shadowing_p);
    L4215record_fishy(T3);
L23:;
    if (Null(v5uiop_package__old_package)){
     goto L32;
    }
    if (Null(v7uiop_package__shadowing)){
     goto L34;
    }
    L4203shadowing_import_(v7uiop_package__shadowing, v5uiop_package__old_package);
L34:;
    L4206unintern_(2, v1symbol, v5uiop_package__old_package);
L32:;
    if (Null(v10uiop_package__overwritten_symbol_shadowing_p)){
     goto L37;
    }
    L4203shadowing_import_(v1symbol, v4package);
    goto L36;
L37:;
    if (Null(v9)){
     goto L39;
    }
    L4206unintern_(2, v8, v4package);
L39:;
    L4202import_(v1symbol, v4package);
L36:;
    if (Null(v7uiop_package__shadowing)){
     goto L42;
    }
    L4203shadowing_import_(v1symbol, v5uiop_package__old_package);
    goto L41;
L42:;
    L4202import_(v1symbol, v5uiop_package__old_package);
L41:;
    if (!((v6uiop_package__old_status)==(ECL_SYM("EXTERNAL",1266)))){
     goto L44;
    }
    L4201export_(v1symbol, v5uiop_package__old_package);
L44:;
    if (!((v9)==(ECL_SYM("EXTERNAL",1266)))){
     goto L17;
    }
    L4201export_(v1symbol, v4package);
   }
L17:;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = v9;
   cl_env_copy->values[0] = v8;
   return cl_env_copy->values[0];
  }
 }
}
static cl_object L4224rehome_symbol_va(cl_narg narg, cl_object v8symbol, cl_object v9uiop_package__package_designator, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[76]);
 {
  return L4224rehome_symbol(v8symbol, v9uiop_package__package_designator);
 }
}
/* function definition for ENSURE-PACKAGE-UNUSED                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4225ensure_package_unused(cl_object v1package)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3uiop_package__p;
  cl_object v4;
  v2 = cl_package_used_by_list(v1package);
  v3uiop_package__p = ECL_NIL;
  v4 = v2;
L5:;
  if (!(ecl_endp(v4))){
   goto L7;
  }
  goto L6;
L7:;
  v3uiop_package__p = ECL_CONS_CAR(v4);
  {
   cl_object v5;
   v5 = ECL_CONS_CDR(v4);
   if (ecl_unlikely(!ECL_LISTP(v5))) FEtype_error_list(v5);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v4 = v5;
  }
  cl_unuse_package(2, v1package, v3uiop_package__p);
  goto L5;
L6:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4225ensure_package_unused_va(cl_narg narg, cl_object v5package, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[79]);
 {
  return L4225ensure_package_unused(v5package);
 }
}
/* function definition for DELETE-PACKAGE*                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4226delete_package_(cl_narg narg, cl_object v1package, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[81]);
 {
  cl_object v2uiop_package__nuke;
  ecl_va_list args; ecl_va_start(args,v1package,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4226delete_package_keys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2uiop_package__nuke = keyvars[0];
  }
  {
   cl_object v3uiop_package__p;
   v3uiop_package__p = cl_find_package(v1package);
   if (Null(v3uiop_package__p)){
    goto L2;
   }
   if (Null(v2uiop_package__nuke)){
    goto L4;
   }
   {
    cl_object v4;
    cl_object v5;
    cl_object v6uiop_package__s;
    v4 = si_packages_iterator(v3uiop_package__p, VV[83], ECL_T);
    v5 = ECL_NIL;
    v6uiop_package__s = ECL_NIL;
    goto L11;
L10:;
    value0 = ecl_function_dispatch(cl_env_copy,v4)(0);
    {
     const int v7 = cl_env_copy->nvalues;
     v5 = value0;
     cl_object v8;
     v8 = (v7<=1)? ECL_NIL : cl_env_copy->values[1];
     v6uiop_package__s = v8;
    }
    if (v5!=ECL_NIL) {
     goto L15;
    }
    goto L4;
L15:;
    if (Null(L4208home_package_p(v6uiop_package__s, v3uiop_package__p))){
     goto L17;
    }
    L4223nuke_symbol(1, v6uiop_package__s);
L17:;
L11:;
    goto L10;
   }
L4:;
   L4225ensure_package_unused(v3uiop_package__p);
   value0 = cl_delete_package(v1package);
   return value0;
L2:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for PACKAGE-NAMES                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4227package_names(cl_object v1package)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_package_name(v1package);
 T1 = cl_package_nicknames(v1package);
 value0 = CONS(T0,T1);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4227package_names_va(cl_narg narg, cl_object v2package, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[85]);
 {
  return L4227package_names(v2package);
 }
}
/* function definition for PACKAGES-FROM-NAMES                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4228packages_from_names(cl_object v1uiop_package__names)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = (ECL_SYM("FIND-PACKAGE",369)->symbol.gfdef);
  {
   cl_object v3;
   cl_object v4;
   cl_object v5;
   {
    cl_object v6;
    v6 = v1uiop_package__names;
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v6;
   }
   v4 = ECL_NIL;
   v5 = v3;
   {
    cl_object v6;
    cl_object v7;
    v6 = ecl_list1(ECL_NIL);
    v7 = v6;
L11:;
    if (!(ecl_endp(v5))){
     goto L13;
    }
    goto L12;
L13:;
    v4 = ECL_CONS_CAR(v5);
    {
     cl_object v8;
     v8 = ECL_CONS_CDR(v5);
     if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v8;
    }
    {
     cl_object v8;
     v8 = v7;
     if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T1 = v8;
    }
    T2 = ecl_function_dispatch(cl_env_copy,v2)(1, v4);
    v7 = ecl_list1(T2);
    (ECL_CONS_CDR(T1)=v7,T1);
    goto L11;
L12:;
    T0 = ecl_cdr(v6);
    goto L2;
   }
  }
 }
L2:;
 T1 = cl_remove(2, ECL_NIL, T0);
 value0 = cl_remove_duplicates(3, T1, VV[91], ECL_T);
 return value0;
}
static cl_object L4228packages_from_names_va(cl_narg narg, cl_object v2uiop_package__names, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[87]);
 {
  return L4228packages_from_names(v2uiop_package__names);
 }
}
/* function definition for FRESH-PACKAGE-NAME                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4229fresh_package_name(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_package__prefix;
  cl_object v2uiop_package__separator;
  cl_object v3uiop_package__index;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L4229fresh_package_namekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[3])) {
    v1uiop_package__prefix = VV[93];
   } else {
    v1uiop_package__prefix = keyvars[0];
   }
   v2uiop_package__separator = keyvars[1];
   if (Null(keyvars[5])) {
    v3uiop_package__index = cl_random(1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("MOST-POSITIVE-FIXNUM",569)));
   } else {
    v3uiop_package__index = keyvars[2];
   }
  }
  {
   cl_object v4uiop_package__i;
   {
    cl_object v5;
    v5 = v3uiop_package__index;
    {
     bool v6;
     v6 = ecl_numberp(v5);
     if (ecl_unlikely(!(v6)))
         FEwrong_type_argument(ECL_SYM("NUMBER",608),v5);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
    v4uiop_package__i = v5;
   }
   {
    cl_object v5uiop_package__n;
    v5uiop_package__n = ECL_NIL;
    {
     cl_object v6;
     v6 = ECL_NIL;
L8:;
     if (!(ecl_plusp(v4uiop_package__i))){
      goto L13;
     }
     value0 = v2uiop_package__separator;
     if (value0!=ECL_NIL) {
      goto L16;
     }
     T0 = VV[96];
     goto L11;
L16:;
     T0 = value0;
     goto L11;
L13:;
     T0 = ECL_NIL;
     goto L11;
L11:;
     v5uiop_package__n = cl_format(5, ECL_NIL, VV[95], v1uiop_package__prefix, T0, v4uiop_package__i);
     if (cl_find_package(v5uiop_package__n)!=ECL_NIL) {
      goto L22;
     }
     v6 = v5uiop_package__n;
     goto L20;
L22:;
     v6 = ECL_NIL;
     goto L20;
L20:;
     if (Null(v6)){
      goto L18;
     }
     value0 = v6;
     cl_env_copy->nvalues = 1;
     return value0;
L18:;
     v4uiop_package__i = ecl_one_plus(v4uiop_package__i);
     goto L8;
    }
   }
  }
 }
}
/* function definition for RENAME-PACKAGE-AWAY                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4230rename_package_away(cl_narg narg, cl_object v1uiop_package__p, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[99]);
 {
  cl_object v2uiop_package__keys;
  cl_object v3uiop_package__prefix;
  ecl_va_list args; ecl_va_start(args,v1uiop_package__p,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4230rename_package_awaykeys,keyvars,(cl_object*)&v2uiop_package__keys,TRUE);
   ecl_va_end(args);
   v3uiop_package__prefix = keyvars[0];
  }
  {
   cl_object v4uiop_package__new_name;
   value0 = v3uiop_package__prefix;
   if (value0!=ECL_NIL) {
    goto L4;
   }
   T1 = cl_package_name(v1uiop_package__p);
   T0 = cl_format(3, ECL_NIL, VV[101], T1);
   goto L2;
L4:;
   T0 = value0;
   goto L2;
L2:;
   v4uiop_package__new_name = cl_apply(4, VV[94], VV[100], T0, v2uiop_package__keys);
   T0 = L4227package_names(v1uiop_package__p);
   T1 = cl_list(3, VV[102], T0, v4uiop_package__new_name);
   L4215record_fishy(T1);
   value0 = cl_rename_package(2, v1uiop_package__p, v4uiop_package__new_name);
   return value0;
  }
 }
}
/* function definition for PACKAGE-DEFINITION-FORM                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4235package_definition_form(cl_narg narg, cl_object v1uiop_package__package_designator, ...)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[104]);
 {
  cl_object v2uiop_package__nicknamesp;
  cl_object v3uiop_package__usep;
  cl_object v4uiop_package__shadowp;
  cl_object v5uiop_package__shadowing_import_p;
  cl_object v6uiop_package__exportp;
  cl_object v7uiop_package__importp;
  cl_object v8uiop_package__internp;
  cl_object v9error;
  ecl_va_list args; ecl_va_start(args,v1uiop_package__package_designator,narg,1);
  {
   cl_object keyvars[16];
   cl_parse_key(args,8,L4235package_definition_formkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[8])) {
    v2uiop_package__nicknamesp = ECL_T;
   } else {
    v2uiop_package__nicknamesp = keyvars[0];
   }
   if (Null(keyvars[9])) {
    v3uiop_package__usep = ECL_T;
   } else {
    v3uiop_package__usep = keyvars[1];
   }
   if (Null(keyvars[10])) {
    v4uiop_package__shadowp = ECL_T;
   } else {
    v4uiop_package__shadowp = keyvars[2];
   }
   if (Null(keyvars[11])) {
    v5uiop_package__shadowing_import_p = ECL_T;
   } else {
    v5uiop_package__shadowing_import_p = keyvars[3];
   }
   if (Null(keyvars[12])) {
    v6uiop_package__exportp = ECL_T;
   } else {
    v6uiop_package__exportp = keyvars[4];
   }
   if (Null(keyvars[13])) {
    v7uiop_package__importp = ECL_T;
   } else {
    v7uiop_package__importp = keyvars[5];
   }
   v8uiop_package__internp = keyvars[6];
   if (Null(keyvars[15])) {
    v9error = ECL_T;
   } else {
    v9error = keyvars[7];
   }
  }
  {
   cl_object v10package;
   cl_object v11uiop_package__name;
   cl_object v12uiop_package__nicknames;
   cl_object v13uiop_package__use;
   cl_object v14shadow;
   cl_object v15shadowing_import;
   cl_object v16import;
   cl_object v17export;
   cl_object v18intern;
   value0 = L4197find_package_(2, v1uiop_package__package_designator, v9error);
   if (value0!=ECL_NIL) {
    goto L10;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L10:;
   v10package = value0;
   goto L8;
L8:;
   v11uiop_package__name = cl_package_name(v10package);
   v12uiop_package__nicknames = cl_package_nicknames(v10package);
   {
    cl_object v19;
    v19 = (ECL_SYM("PACKAGE-NAME",622)->symbol.gfdef);
    {
     cl_object v20;
     cl_object v21;
     cl_object v22;
     v20 = cl_package_use_list(v10package);
     v21 = ECL_NIL;
     v22 = v20;
     {
      cl_object v23;
      cl_object v24;
      v23 = ecl_list1(ECL_NIL);
      v24 = v23;
L21:;
      if (!(ecl_endp(v22))){
       goto L23;
      }
      goto L22;
L23:;
      v21 = ECL_CONS_CAR(v22);
      {
       cl_object v25;
       v25 = ECL_CONS_CDR(v22);
       if (ecl_unlikely(!ECL_LISTP(v25))) FEtype_error_list(v25);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v22 = v25;
      }
      {
       cl_object v25;
       v25 = v24;
       if (ecl_unlikely(ECL_ATOM(v25))) FEtype_error_cons(v25);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v25;
      }
      T1 = ecl_function_dispatch(cl_env_copy,v19)(1, v21);
      v24 = ecl_list1(T1);
      (ECL_CONS_CDR(T0)=v24,T0);
      goto L21;
L22:;
      v13uiop_package__use = ecl_cdr(v23);
      goto L14;
     }
    }
   }
L14:;
   v14shadow = ECL_NIL;
   v15shadowing_import = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
   v16import = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
   v17export = ECL_NIL;
   v18intern = ECL_NIL;
   if (Null(v10package)){
    goto L44;
   }
   {
    cl_object v19;
    cl_object v20uiop_package__sym;
    v19 = ECL_NIL;
    v20uiop_package__sym = ECL_NIL;
    {
     cl_object v21;
     v21 = si_packages_iterator(v10package, VV[105], ECL_T);
     {
      cl_object v22uiop_package__status;
      v22uiop_package__status = ECL_NIL;
L51:;
      value0 = ecl_function_dispatch(cl_env_copy,v21)(0);
      {
       const int v23 = cl_env_copy->nvalues;
       v19 = value0;
       cl_object v24;
       v24 = (v23<=1)? ECL_NIL : cl_env_copy->values[1];
       v20uiop_package__sym = v24;
      }
      if (value0!=ECL_NIL) {
       goto L53;
      }
      goto L52;
L53:;
      {
       struct ecl_stack_frame _ecl_inner_frame_aux;
       cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
       cl_env_copy->values[0] = L4198find_symbol_(2, v20uiop_package__sym, v10package);
       ecl_stack_frame_push_values(_ecl_inner_frame);
       T0 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
       ecl_stack_frame_close(_ecl_inner_frame);
      }
      v22uiop_package__status = ecl_cadr(T0);
      if (!((v22uiop_package__status)==(ECL_NIL))){
       goto L64;
      }
      goto L60;
L64:;
      goto L62;
L62:;
      if (!((v22uiop_package__status)==(ECL_SYM("INHERITED",1285)))){
       goto L67;
      }
      goto L60;
L67:;
      goto L61;
L61:;
      if (!((v22uiop_package__status)==(ECL_SYM("INTERNAL",1293)))){
       goto L74;
      }
      goto L71;
L74:;
      goto L72;
L72:;
      if (!((v22uiop_package__status)==(ECL_SYM("EXTERNAL",1266)))){
       goto L69;
      }
      goto L70;
L71:;
L70:;
      {
       cl_object v23uiop_package__name;
       cl_object v24uiop_package__external;
       cl_object v25uiop_package__home;
       cl_object v26uiop_package__home_name;
       cl_object v27uiop_package__imported;
       cl_object v28uiop_package__shadowing;
       v23uiop_package__name = ecl_symbol_name(v20uiop_package__sym);
       v24uiop_package__external = ecl_make_bool((v22uiop_package__status)==(ECL_SYM("EXTERNAL",1266)));
       v25uiop_package__home = cl_symbol_package(v20uiop_package__sym);
       v26uiop_package__home_name = cl_package_name(v25uiop_package__home);
       {
        bool v29;
        v29 = (v25uiop_package__home)==(v10package);
        v27uiop_package__imported = (v29)?ECL_NIL:ECL_T;
       }
       v28uiop_package__shadowing = L4207symbol_shadowing_p(v20uiop_package__sym, v10package);
       if (Null(v28uiop_package__shadowing)){
        goto L84;
       }
       if (Null(v27uiop_package__imported)){
        goto L84;
       }
       {
        cl_object v29;
        T0 = ecl_gethash_safe(v26uiop_package__home_name,v15shadowing_import,ECL_NIL);
        v29 = CONS(v23uiop_package__name,T0);
        si_hash_set(v26uiop_package__home_name, v15shadowing_import, v29);
        goto L83;
       }
L84:;
       if (Null(v28uiop_package__shadowing)){
        goto L88;
       }
       v14shadow = CONS(v23uiop_package__name,v14shadow);
       goto L83;
L88:;
       if (Null(v27uiop_package__imported)){
        goto L83;
       }
       {
        cl_object v30;
        T0 = ecl_gethash_safe(v26uiop_package__home_name,v16import,ECL_NIL);
        v30 = CONS(v23uiop_package__name,T0);
        si_hash_set(v26uiop_package__home_name, v16import, v30);
       }
L83:;
       if (Null(v24uiop_package__external)){
        goto L93;
       }
       v17export = CONS(v23uiop_package__name,v17export);
       goto L60;
L93:;
       if (Null(v27uiop_package__imported)){
        goto L96;
       }
       goto L60;
L96:;
       v18intern = CONS(v23uiop_package__name,v18intern);
       goto L60;
      }
L69:;
      si_ecase_error(v22uiop_package__status, VV[109]);
L60:;
      goto L51;
L52:;
     }
    }
   }
   if (Null(v2uiop_package__nicknamesp)){
    goto L103;
   }
   T1 = LC4231sort_names(v12uiop_package__nicknames);
   goto L101;
L103:;
   T1 = ECL_NIL;
   goto L101;
L101:;
   T0 = LC4233when_relevant(ECL_SYM("NICKNAMES",1313), T1);
   if (Null(v3uiop_package__usep)){
    goto L107;
   }
   T1 = LC4231sort_names(v13uiop_package__use);
   goto L105;
L107:;
   T1 = ECL_NIL;
   goto L105;
L105:;
   T2 = CONS(ECL_SYM("USE",1361),T1);
   if (Null(v4uiop_package__shadowp)){
    goto L112;
   }
   T4 = LC4231sort_names(v14shadow);
   goto L110;
L112:;
   T4 = ECL_NIL;
   goto L110;
L110:;
   T3 = LC4233when_relevant(ECL_SYM("SHADOW",1343), T4);
   if (Null(v5uiop_package__shadowing_import_p)){
    goto L117;
   }
   T5 = v15shadowing_import;
   goto L115;
L117:;
   T5 = ECL_NIL;
   goto L115;
L115:;
   T4 = LC4234import_options(VV[115], T5);
   if (Null(v7uiop_package__importp)){
    goto L122;
   }
   T6 = v16import;
   goto L120;
L122:;
   T6 = ECL_NIL;
   goto L120;
L120:;
   T5 = LC4234import_options(ECL_SYM("IMPORT-FROM",1283), T6);
   if (Null(v6uiop_package__exportp)){
    goto L127;
   }
   T7 = LC4231sort_names(v17export);
   goto L125;
L127:;
   T7 = ECL_NIL;
   goto L125;
L125:;
   T6 = LC4233when_relevant(ECL_SYM("EXPORT",1264), T7);
   if (Null(v8uiop_package__internp)){
    goto L132;
   }
   T8 = LC4231sort_names(v18intern);
   goto L130;
L132:;
   T8 = ECL_NIL;
   goto L130;
L130:;
   T7 = LC4233when_relevant(ECL_SYM("INTERN",1292), T8);
   T8 = cl_append(5, T3, T4, T5, T6, T7);
   T9 = CONS(T2,T8);
   T10 = ecl_append(T0,T9);
   value0 = cl_listX(3, ECL_SYM("DEFPACKAGE",286), v11uiop_package__name, T10);
   return value0;
L44:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for ENSURE-SHADOWING-IMPORT                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4236ensure_shadowing_import(cl_object v1uiop_package__name, cl_object v2uiop_package__to_package, cl_object v3uiop_package__from_package, cl_object v4uiop_package__shadowed, cl_object v5uiop_package__imported)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  v6 = v1uiop_package__name;
  if (ECL_STRINGP(v6)) {
   goto L4;
  }
  v1uiop_package__name = si_do_check_type(v6, ECL_SYM("STRING",808), ECL_NIL, VV[118]);
L4:;
 }
 {
  cl_object v6;
  v6 = v2uiop_package__to_package;
  if (cl_packagep(v6)!=ECL_NIL) {
   goto L9;
  }
  v2uiop_package__to_package = si_do_check_type(v6, ECL_SYM("PACKAGE",619), ECL_NIL, VV[119]);
L9:;
 }
 {
  cl_object v6;
  v6 = v3uiop_package__from_package;
  if (cl_packagep(v6)!=ECL_NIL) {
   goto L14;
  }
  v3uiop_package__from_package = si_do_check_type(v6, ECL_SYM("PACKAGE",619), ECL_NIL, VV[120]);
L14:;
 }
 {
  cl_object v6;
  v6 = v4uiop_package__shadowed;
  if (cl_hash_table_p(v6)!=ECL_NIL) {
   goto L19;
  }
  v4uiop_package__shadowed = si_do_check_type(v6, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[121]);
L19:;
 }
 {
  cl_object v6;
  v6 = v5uiop_package__imported;
  if (cl_hash_table_p(v6)!=ECL_NIL) {
   goto L24;
  }
  v5uiop_package__imported = si_do_check_type(v6, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[122]);
L24:;
 }
 {
  cl_object v6uiop_package__import_me;
  v6uiop_package__import_me = L4198find_symbol_(2, v1uiop_package__name, v3uiop_package__from_package);
  {
   cl_object v7;                                  /*  EXISTING                */
   cl_object v8;                                  /*  STATUS                  */
   value0 = cl_find_symbol(2, v1uiop_package__name, v2uiop_package__to_package);
   {
    v7 = value0;
    v8 = cl_env_copy->values[1];
   }
   if (Null(ecl_gethash_safe(v1uiop_package__name,v4uiop_package__shadowed,ECL_NIL))){
    goto L29;
   }
   if ((v6uiop_package__import_me)==(v7)) {
    goto L31;
   }
   value0 = cl_error(2, VV[123], v1uiop_package__name);
   return value0;
L31:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L29:;
   si_hash_set(v1uiop_package__name, v4uiop_package__shadowed, ECL_T);
   si_hash_set(v1uiop_package__name, v5uiop_package__imported, ECL_T);
   if (v8==ECL_NIL) {
    goto L35;
   }
   if (!((v8)==(ECL_SYM("INTERNAL",1293)))){
    goto L44;
   }
   goto L41;
L44:;
   goto L42;
L42:;
   if (!((v8)==(ECL_SYM("EXTERNAL",1266)))){
    goto L39;
   }
   goto L40;
L41:;
L40:;
   if (!((v7)==(v6uiop_package__import_me))){
    goto L39;
   }
   if (L4207symbol_shadowing_p(v7, v2uiop_package__to_package)!=ECL_NIL) {
    goto L35;
   }
   goto L36;
L39:;
   goto L36;
L36:;
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
    goto L35;
   }
   T0 = cl_package_name(v3uiop_package__from_package);
   value0 = L4208home_package_p(v6uiop_package__import_me, v3uiop_package__from_package);
   if (value0!=ECL_NIL) {
    goto L51;
   }
   T1 = L4209symbol_package_name(v6uiop_package__import_me);
   goto L49;
L51:;
   T1 = value0;
   goto L49;
L49:;
   T2 = cl_package_name(v2uiop_package__to_package);
   if (Null(v8)){
    goto L55;
   }
   value0 = L4208home_package_p(v7, v2uiop_package__to_package);
   if (value0!=ECL_NIL) {
    goto L58;
   }
   T3 = L4209symbol_package_name(v7);
   goto L53;
L58:;
   T3 = value0;
   goto L53;
L55:;
   T3 = ECL_NIL;
   goto L53;
L53:;
   T4 = cl_list(7, ECL_SYM("SHADOWING-IMPORT",1344), v1uiop_package__name, T0, T1, T2, v8, T3);
   L4215record_fishy(T4);
L35:;
   value0 = L4203shadowing_import_(v6uiop_package__import_me, v2uiop_package__to_package);
   return value0;
  }
 }
}
static cl_object L4236ensure_shadowing_import_va(cl_narg narg, cl_object v7uiop_package__name, cl_object v8uiop_package__to_package, cl_object v9uiop_package__from_package, cl_object v10uiop_package__shadowed, cl_object v11uiop_package__imported, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[117]);
 {
  return L4236ensure_shadowing_import(v7uiop_package__name, v8uiop_package__to_package, v9uiop_package__from_package, v10uiop_package__shadowed, v11uiop_package__imported);
 }
}
/* function definition for ENSURE-IMPORTED                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4237ensure_imported(cl_narg narg, cl_object v1uiop_package__import_me, cl_object v2uiop_package__into_package, ...)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[125]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[125]);
 {
  cl_object v3uiop_package__from_package;
  va_list args; va_start(args,v2uiop_package__into_package);
  {
   int i = 2;
   if (i >= narg) {
    v3uiop_package__from_package = ECL_NIL;
   } else {
    i++;
    v3uiop_package__from_package = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v4;
   v4 = v1uiop_package__import_me;
   if (ECL_SYMBOLP(v4)) {
    goto L4;
   }
   v1uiop_package__import_me = si_do_check_type(v4, ECL_SYM("SYMBOL",843), ECL_NIL, VV[126]);
L4:;
  }
  {
   cl_object v4;
   v4 = v2uiop_package__into_package;
   if (cl_packagep(v4)!=ECL_NIL) {
    goto L9;
   }
   v2uiop_package__into_package = si_do_check_type(v4, ECL_SYM("PACKAGE",619), ECL_NIL, VV[127]);
L9:;
  }
  {
   cl_object v4;
   v4 = v3uiop_package__from_package;
   if (v4==ECL_NIL) {
    goto L14;
   }
   if (cl_packagep(v4)!=ECL_NIL) {
    goto L14;
   }
   v3uiop_package__from_package = si_do_check_type(v4, VV[128], ECL_NIL, VV[120]);
L14:;
  }
  {
   cl_object v4uiop_package__name;
   v4uiop_package__name = ecl_symbol_name(v1uiop_package__import_me);
   {
    cl_object v5;                                 /*  EXISTING                */
    cl_object v6;                                 /*  STATUS                  */
    value0 = cl_find_symbol(2, v4uiop_package__name, v2uiop_package__into_package);
    {
     v5 = value0;
     v6 = cl_env_copy->values[1];
    }
    if (v6!=ECL_NIL) {
     goto L21;
    }
    L4202import_(v1uiop_package__import_me, v2uiop_package__into_package);
    goto L18;
L21:;
    {
     cl_object v7;
     v7 = ecl_make_bool((v1uiop_package__import_me)==(v5));
     if (Null(v7)){
      goto L24;
     }
     goto L18;
L24:;
     {
      cl_object v8uiop_package__shadowing_p;
      v8uiop_package__shadowing_p = L4207symbol_shadowing_p(v5, v2uiop_package__into_package);
      if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
       goto L27;
      }
      if (Null(v3uiop_package__from_package)){
       goto L31;
      }
      T0 = cl_package_name(v3uiop_package__from_package);
      goto L29;
L31:;
      T0 = ECL_NIL;
      goto L29;
L29:;
      value0 = L4208home_package_p(v1uiop_package__import_me, v3uiop_package__from_package);
      if (value0!=ECL_NIL) {
       goto L35;
      }
      T1 = L4209symbol_package_name(v1uiop_package__import_me);
      goto L33;
L35:;
      T1 = value0;
      goto L33;
L33:;
      T2 = cl_package_name(v2uiop_package__into_package);
      if (Null(v6)){
       goto L39;
      }
      value0 = L4208home_package_p(v5, v2uiop_package__into_package);
      if (value0!=ECL_NIL) {
       goto L42;
      }
      T3 = L4209symbol_package_name(v5);
      goto L37;
L42:;
      T3 = value0;
      goto L37;
L39:;
      T3 = ECL_NIL;
      goto L37;
L37:;
      T4 = cl_list(8, VV[129], v4uiop_package__name, T0, T1, T2, v6, T3, v8uiop_package__shadowing_p);
      L4215record_fishy(T4);
L27:;
      if (v8uiop_package__shadowing_p!=ECL_NIL) {
       goto L46;
      }
      if (!((v6)==(ECL_SYM("INHERITED",1285)))){
       goto L44;
      }
      goto L45;
L46:;
L45:;
      L4203shadowing_import_(v1uiop_package__import_me, v2uiop_package__into_package);
      goto L18;
L44:;
      L4206unintern_(2, v5, v2uiop_package__into_package);
      L4202import_(v1uiop_package__import_me, v2uiop_package__into_package);
     }
    }
   }
  }
L18:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
}
/* function definition for ENSURE-IMPORT                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4238ensure_import(cl_object v1uiop_package__name, cl_object v2uiop_package__to_package, cl_object v3uiop_package__from_package, cl_object v4uiop_package__shadowed, cl_object v5uiop_package__imported)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6;
  v6 = v1uiop_package__name;
  if (ECL_STRINGP(v6)) {
   goto L4;
  }
  v1uiop_package__name = si_do_check_type(v6, ECL_SYM("STRING",808), ECL_NIL, VV[118]);
L4:;
 }
 {
  cl_object v6;
  v6 = v2uiop_package__to_package;
  if (cl_packagep(v6)!=ECL_NIL) {
   goto L9;
  }
  v2uiop_package__to_package = si_do_check_type(v6, ECL_SYM("PACKAGE",619), ECL_NIL, VV[119]);
L9:;
 }
 {
  cl_object v6;
  v6 = v3uiop_package__from_package;
  if (cl_packagep(v6)!=ECL_NIL) {
   goto L14;
  }
  v3uiop_package__from_package = si_do_check_type(v6, ECL_SYM("PACKAGE",619), ECL_NIL, VV[120]);
L14:;
 }
 {
  cl_object v6;
  v6 = v4uiop_package__shadowed;
  if (cl_hash_table_p(v6)!=ECL_NIL) {
   goto L19;
  }
  v4uiop_package__shadowed = si_do_check_type(v6, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[121]);
L19:;
 }
 {
  cl_object v6;
  v6 = v5uiop_package__imported;
  if (cl_hash_table_p(v6)!=ECL_NIL) {
   goto L24;
  }
  v5uiop_package__imported = si_do_check_type(v6, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[122]);
L24:;
 }
 {
  cl_object v6;                                   /*  IMPORT-ME               */
  cl_object v7;                                   /*  IMPORT-STATUS           */
  value0 = cl_find_symbol(2, v1uiop_package__name, v3uiop_package__from_package);
  {
   v6 = value0;
   v7 = cl_env_copy->values[1];
  }
  if (!(v7==ECL_NIL)){
   goto L28;
  }
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
   goto L30;
  }
  T0 = cl_package_name(v3uiop_package__from_package);
  T1 = cl_package_name(v2uiop_package__to_package);
  T2 = cl_list(4, VV[132], v1uiop_package__name, T0, T1);
  L4215record_fishy(T2);
L30:;
  v6 = L4200intern_(2, v1uiop_package__name, v3uiop_package__from_package);
L28:;
  {
   cl_object v8;                                  /*  EXISTING                */
   cl_object v9;                                  /*  STATUS                  */
   value0 = cl_find_symbol(2, v1uiop_package__name, v2uiop_package__to_package);
   {
    v8 = value0;
    v9 = cl_env_copy->values[1];
   }
   if (Null(v5uiop_package__imported)){
    goto L35;
   }
   if (Null(ecl_gethash_safe(v1uiop_package__name,v5uiop_package__imported,ECL_NIL))){
    goto L35;
   }
   if (Null(v9)){
    goto L40;
   }
   if ((v6)==(v8)) {
    goto L33;
   }
   goto L38;
L40:;
   goto L38;
L38:;
   T0 = cl_symbol_package(v8);
   T1 = cl_package_name(T0);
   T2 = cl_package_name(v3uiop_package__from_package);
   cl_error(4, VV[133], v1uiop_package__name, T1, T2);
   goto L33;
L35:;
   if (Null(ecl_gethash_safe(v1uiop_package__name,v4uiop_package__shadowed,ECL_NIL))){
    goto L42;
   }
   T0 = cl_package_name(v3uiop_package__from_package);
   cl_error(3, VV[134], v1uiop_package__name, T0);
   goto L33;
L42:;
   si_hash_set(v1uiop_package__name, v5uiop_package__imported, ECL_T);
  }
L33:;
  value0 = L4237ensure_imported(3, v6, v2uiop_package__to_package, v3uiop_package__from_package);
  return value0;
 }
}
static cl_object L4238ensure_import_va(cl_narg narg, cl_object v6uiop_package__name, cl_object v7uiop_package__to_package, cl_object v8uiop_package__from_package, cl_object v9uiop_package__shadowed, cl_object v10uiop_package__imported, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[131]);
 {
  return L4238ensure_import(v6uiop_package__name, v7uiop_package__to_package, v8uiop_package__from_package, v9uiop_package__shadowed, v10uiop_package__imported);
 }
}
/* function definition for ENSURE-INHERITED                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4239ensure_inherited(cl_object v1uiop_package__name, cl_object v2symbol, cl_object v3uiop_package__to_package, cl_object v4uiop_package__from_package, cl_object v5uiop_package__mixp, cl_object v6uiop_package__shadowed, cl_object v7uiop_package__imported, cl_object v8uiop_package__inherited)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v9;
  v9 = v1uiop_package__name;
  if (ECL_STRINGP(v9)) {
   goto L4;
  }
  v1uiop_package__name = si_do_check_type(v9, ECL_SYM("STRING",808), ECL_NIL, VV[118]);
L4:;
 }
 {
  cl_object v9;
  v9 = v2symbol;
  if (ECL_SYMBOLP(v9)) {
   goto L9;
  }
  v2symbol = si_do_check_type(v9, ECL_SYM("SYMBOL",843), ECL_NIL, ECL_SYM("SYMBOL",843));
L9:;
 }
 {
  cl_object v9;
  v9 = v3uiop_package__to_package;
  if (cl_packagep(v9)!=ECL_NIL) {
   goto L14;
  }
  v3uiop_package__to_package = si_do_check_type(v9, ECL_SYM("PACKAGE",619), ECL_NIL, VV[119]);
L14:;
 }
 {
  cl_object v9;
  v9 = v4uiop_package__from_package;
  if (cl_packagep(v9)!=ECL_NIL) {
   goto L19;
  }
  v4uiop_package__from_package = si_do_check_type(v9, ECL_SYM("PACKAGE",619), ECL_NIL, VV[120]);
L19:;
 }
 {
  cl_object v9;
  v9 = v5uiop_package__mixp;
  if (!((v9)==(ECL_NIL))){
   goto L28;
  }
  goto L24;
L28:;
  goto L26;
L26:;
  if (!((v9)==(ECL_T))){
   goto L31;
  }
  goto L24;
L31:;
  goto L25;
L25:;
  v5uiop_package__mixp = si_do_check_type(v9, VV[139], ECL_NIL, VV[140]);
L24:;
 }
 {
  cl_object v9;
  v9 = v6uiop_package__shadowed;
  if (cl_hash_table_p(v9)!=ECL_NIL) {
   goto L36;
  }
  v6uiop_package__shadowed = si_do_check_type(v9, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[121]);
L36:;
 }
 {
  cl_object v9;
  v9 = v7uiop_package__imported;
  if (cl_hash_table_p(v9)!=ECL_NIL) {
   goto L41;
  }
  v7uiop_package__imported = si_do_check_type(v9, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[122]);
L41:;
 }
 {
  cl_object v9;
  v9 = v8uiop_package__inherited;
  if (cl_hash_table_p(v9)!=ECL_NIL) {
   goto L46;
  }
  v8uiop_package__inherited = si_do_check_type(v9, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[141]);
L46:;
 }
 {
  cl_object v9;                                   /*  EXISTING                */
  cl_object v10;                                  /*  STATUS                  */
  value0 = cl_find_symbol(2, v1uiop_package__name, v3uiop_package__to_package);
  {
   v9 = value0;
   v10 = cl_env_copy->values[1];
  }
  {
   cl_object v11uiop_package__sp;
   cl_object v12uiop_package__in;
   cl_object v13uiop_package__xp;
   v11uiop_package__sp = cl_symbol_package(v2symbol);
   v12uiop_package__in = ecl_gethash_safe(v1uiop_package__name,v8uiop_package__inherited,ECL_NIL);
   if (Null(v10)){
    goto L54;
   }
   v13uiop_package__xp = cl_symbol_package(v9);
   goto L52;
L54:;
   v13uiop_package__xp = ECL_NIL;
   goto L52;
L52:;
   if (!(v11uiop_package__sp==ECL_NIL)){
    goto L56;
   }
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
    goto L58;
   }
   T0 = cl_package_name(v4uiop_package__from_package);
   T1 = cl_package_name(v3uiop_package__to_package);
   T2 = cl_list(5, VV[132], v1uiop_package__name, T0, T1, v5uiop_package__mixp);
   L4215record_fishy(T2);
L58:;
   L4202import_(v2symbol, v4uiop_package__from_package);
   v11uiop_package__sp = cl_package_name(v4uiop_package__from_package);
L56:;
   {
    cl_object v14;
    v14 = ecl_gethash_safe(v1uiop_package__name,v6uiop_package__shadowed,ECL_NIL);
    if (Null(v14)){
     goto L63;
    }
    value0 = v14;
    cl_env_copy->nvalues = 1;
    return value0;
L63:;
    if (Null(v12uiop_package__in)){
     goto L65;
    }
    T0 = ecl_car(v12uiop_package__in);
    if (ecl_equal(v11uiop_package__sp,T0)) {
     goto L67;
    }
    if (Null(v5uiop_package__mixp)){
     goto L69;
    }
    T0 = ecl_cadr(v12uiop_package__in);
    value0 = L4236ensure_shadowing_import(v1uiop_package__name, v3uiop_package__to_package, T0, v6uiop_package__shadowed, v7uiop_package__imported);
    return value0;
L69:;
    T0 = cl_package_name(v11uiop_package__sp);
    T1 = ecl_car(v12uiop_package__in);
    T2 = cl_package_name(T1);
    value0 = cl_error(4, VV[142], v1uiop_package__name, T0, T2);
    return value0;
L67:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L65:;
    if (Null(ecl_gethash_safe(v1uiop_package__name,v7uiop_package__imported,ECL_NIL))){
     goto L71;
    }
    if ((v2symbol)==(v9)) {
     goto L73;
    }
    T0 = cl_package_name(v11uiop_package__sp);
    T1 = cl_package_name(v13uiop_package__xp);
    value0 = cl_error(4, VV[143], v1uiop_package__name, T0, T1);
    return value0;
L73:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L71:;
    T0 = cl_list(2, v11uiop_package__sp, v4uiop_package__from_package);
    si_hash_set(v1uiop_package__name, v8uiop_package__inherited, T0);
    if (Null(v10)){
     goto L76;
    }
    if ((v11uiop_package__sp)==(v13uiop_package__xp)) {
     goto L76;
    }
    {
     cl_object v15uiop_package__shadowing;
     v15uiop_package__shadowing = L4207symbol_shadowing_p(v9, v3uiop_package__to_package);
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
      goto L80;
     }
     T0 = cl_package_name(v4uiop_package__from_package);
     value0 = L4208home_package_p(v2symbol, v4uiop_package__from_package);
     if (value0!=ECL_NIL) {
      goto L84;
     }
     T1 = L4209symbol_package_name(v2symbol);
     goto L82;
L84:;
     T1 = value0;
     goto L82;
L82:;
     T2 = cl_package_name(v3uiop_package__to_package);
     value0 = L4208home_package_p(v9, v3uiop_package__to_package);
     if (value0!=ECL_NIL) {
      goto L88;
     }
     T3 = L4209symbol_package_name(v9);
     goto L86;
L88:;
     T3 = value0;
     goto L86;
L86:;
     T4 = cl_list(6, ECL_SYM("INHERITED",1285), v1uiop_package__name, T0, T1, T2, T3);
     L4215record_fishy(T4);
L80:;
     if (Null(v15uiop_package__shadowing)){
      goto L90;
     }
     value0 = L4236ensure_shadowing_import(v1uiop_package__name, v3uiop_package__to_package, v4uiop_package__from_package, v6uiop_package__shadowed, v7uiop_package__imported);
     return value0;
L90:;
     value0 = L4206unintern_(2, v9, v3uiop_package__to_package);
     return value0;
    }
L76:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
static cl_object L4239ensure_inherited_va(cl_narg narg, cl_object v9uiop_package__name, cl_object v10symbol, cl_object v11uiop_package__to_package, cl_object v12uiop_package__from_package, cl_object v13uiop_package__mixp, cl_object v14uiop_package__shadowed, cl_object v15uiop_package__imported, cl_object v16uiop_package__inherited, ...)
{
 if (ecl_unlikely(narg!=8)) FEwrong_num_arguments(VV[136]);
 {
  return L4239ensure_inherited(v9uiop_package__name, v10symbol, v11uiop_package__to_package, v12uiop_package__from_package, v13uiop_package__mixp, v14uiop_package__shadowed, v15uiop_package__imported, v16uiop_package__inherited);
 }
}
/* function definition for ENSURE-MIX                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4240ensure_mix(cl_object v1uiop_package__name, cl_object v2symbol, cl_object v3uiop_package__to_package, cl_object v4uiop_package__from_package, cl_object v5uiop_package__shadowed, cl_object v6uiop_package__imported, cl_object v7uiop_package__inherited)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v8;
  v8 = v1uiop_package__name;
  if (ECL_STRINGP(v8)) {
   goto L4;
  }
  v1uiop_package__name = si_do_check_type(v8, ECL_SYM("STRING",808), ECL_NIL, VV[118]);
L4:;
 }
 {
  cl_object v8;
  v8 = v2symbol;
  if (ECL_SYMBOLP(v8)) {
   goto L9;
  }
  v2symbol = si_do_check_type(v8, ECL_SYM("SYMBOL",843), ECL_NIL, ECL_SYM("SYMBOL",843));
L9:;
 }
 {
  cl_object v8;
  v8 = v3uiop_package__to_package;
  if (cl_packagep(v8)!=ECL_NIL) {
   goto L14;
  }
  v3uiop_package__to_package = si_do_check_type(v8, ECL_SYM("PACKAGE",619), ECL_NIL, VV[119]);
L14:;
 }
 {
  cl_object v8;
  v8 = v4uiop_package__from_package;
  if (cl_packagep(v8)!=ECL_NIL) {
   goto L19;
  }
  v4uiop_package__from_package = si_do_check_type(v8, ECL_SYM("PACKAGE",619), ECL_NIL, VV[120]);
L19:;
 }
 {
  cl_object v8;
  v8 = v5uiop_package__shadowed;
  if (cl_hash_table_p(v8)!=ECL_NIL) {
   goto L24;
  }
  v5uiop_package__shadowed = si_do_check_type(v8, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[121]);
L24:;
 }
 {
  cl_object v8;
  v8 = v6uiop_package__imported;
  if (cl_hash_table_p(v8)!=ECL_NIL) {
   goto L29;
  }
  v6uiop_package__imported = si_do_check_type(v8, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[122]);
L29:;
 }
 {
  cl_object v8;
  v8 = v7uiop_package__inherited;
  if (cl_hash_table_p(v8)!=ECL_NIL) {
   goto L34;
  }
  v7uiop_package__inherited = si_do_check_type(v8, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[141]);
L34:;
 }
 if (ecl_gethash_safe(v1uiop_package__name,v5uiop_package__shadowed,ECL_NIL)!=ECL_NIL) {
  goto L37;
 }
 {
  cl_object v8;                                   /*  EXISTING                */
  cl_object v9;                                   /*  STATUS                  */
  value0 = cl_find_symbol(2, v1uiop_package__name, v3uiop_package__to_package);
  {
   v8 = value0;
   v9 = cl_env_copy->values[1];
  }
  {
   cl_object v10uiop_package__sp;
   cl_object v11uiop_package__im;
   cl_object v12uiop_package__in;
   v10uiop_package__sp = cl_symbol_package(v2symbol);
   v11uiop_package__im = ecl_gethash_safe(v1uiop_package__name,v6uiop_package__imported,ECL_NIL);
   v12uiop_package__in = ecl_gethash_safe(v1uiop_package__name,v7uiop_package__inherited,ECL_NIL);
   if (v9==ECL_NIL) {
    goto L45;
   }
   if (Null(v9)){
    goto L49;
   }
   if ((v2symbol)==(v8)) {
    goto L45;
   }
   goto L47;
L49:;
   goto L47;
L47:;
   if (Null(v12uiop_package__in)){
    goto L43;
   }
   T0 = ecl_car(v12uiop_package__in);
   if (!((v10uiop_package__sp)==(T0))){
    goto L43;
   }
   goto L44;
L45:;
L44:;
   value0 = L4239ensure_inherited(v1uiop_package__name, v2symbol, v3uiop_package__to_package, v4uiop_package__from_package, ECL_T, v5uiop_package__shadowed, v6uiop_package__imported, v7uiop_package__inherited);
   return value0;
L43:;
   if (Null(v12uiop_package__in)){
    goto L52;
   }
   cl_remhash(v1uiop_package__name, v7uiop_package__inherited);
   T0 = ecl_cadr(v12uiop_package__in);
   value0 = L4236ensure_shadowing_import(v1uiop_package__name, v3uiop_package__to_package, T0, v5uiop_package__shadowed, v6uiop_package__imported);
   return value0;
L52:;
   if (Null(v11uiop_package__im)){
    goto L55;
   }
   T0 = cl_package_name(v4uiop_package__from_package);
   T1 = L4208home_package_p(v2symbol, v4uiop_package__from_package);
   T2 = L4209symbol_package_name(v2symbol);
   T3 = cl_package_name(v3uiop_package__to_package);
   T4 = L4208home_package_p(v8, v3uiop_package__to_package);
   T5 = L4209symbol_package_name(v8);
   value0 = cl_error(8, VV[146], v1uiop_package__name, T0, T1, T2, T3, T4, T5);
   return value0;
L55:;
   value0 = L4239ensure_inherited(v1uiop_package__name, v2symbol, v3uiop_package__to_package, v4uiop_package__from_package, ECL_T, v5uiop_package__shadowed, v6uiop_package__imported, v7uiop_package__inherited);
   return value0;
  }
 }
L37:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4240ensure_mix_va(cl_narg narg, cl_object v8uiop_package__name, cl_object v9symbol, cl_object v10uiop_package__to_package, cl_object v11uiop_package__from_package, cl_object v12uiop_package__shadowed, cl_object v13uiop_package__imported, cl_object v14uiop_package__inherited, ...)
{
 if (ecl_unlikely(narg!=7)) FEwrong_num_arguments(VV[145]);
 {
  return L4240ensure_mix(v8uiop_package__name, v9symbol, v10uiop_package__to_package, v11uiop_package__from_package, v12uiop_package__shadowed, v13uiop_package__imported, v14uiop_package__inherited);
 }
}
/* function definition for RECYCLE-SYMBOL                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4241recycle_symbol(cl_object v1uiop_package__name, cl_object v2uiop_package__recycle, cl_object v3uiop_package__exported)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  v4 = v1uiop_package__name;
  if (ECL_STRINGP(v4)) {
   goto L4;
  }
  v1uiop_package__name = si_do_check_type(v4, ECL_SYM("STRING",808), ECL_NIL, VV[118]);
L4:;
 }
 {
  cl_object v4;
  v4 = v2uiop_package__recycle;
  if (ECL_LISTP(v4)) {
   goto L9;
  }
  v2uiop_package__recycle = si_do_check_type(v4, ECL_SYM("LIST",483), ECL_NIL, VV[149]);
L9:;
 }
 {
  cl_object v4;
  v4 = v3uiop_package__exported;
  if (cl_hash_table_p(v4)!=ECL_NIL) {
   goto L14;
  }
  v3uiop_package__exported = si_do_check_type(v4, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[150]);
L14:;
 }
 if (Null(ecl_gethash_safe(v1uiop_package__name,v3uiop_package__exported,ECL_NIL))){
  goto L17;
 }
 {
  cl_object v4uiop_package__recycled;
  cl_object v5uiop_package__foundp;
  v4uiop_package__recycled = ECL_NIL;
  v5uiop_package__foundp = ECL_NIL;
  {
   cl_object v6;
   v6 = v2uiop_package__recycle;
   goto L24;
L23:;
   {
    cl_object v7uiop_package__r;
    v7uiop_package__r = ecl_car(v6);
    {
     cl_object v8;                                /*  SYMBOL                  */
     cl_object v9;                                /*  STATUS                  */
     value0 = cl_find_symbol(2, v1uiop_package__name, v7uiop_package__r);
     {
      v8 = value0;
      v9 = cl_env_copy->values[1];
     }
     if (Null(v9)){
      goto L28;
     }
     if (Null(L4208home_package_p(v8, v7uiop_package__r))){
      goto L28;
     }
     if (Null(v5uiop_package__foundp)){
      goto L32;
     }
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
      goto L28;
     }
     T0 = cl_package_name(v5uiop_package__foundp);
     T1 = cl_package_name(v7uiop_package__r);
     T2 = cl_list(4, VV[151], v1uiop_package__name, T0, T1);
     L4215record_fishy(T2);
     goto L28;
L32:;
     v4uiop_package__recycled = v8;
     v5uiop_package__foundp = v7uiop_package__r;
    }
L28:;
   }
   v6 = ecl_cdr(v6);
L24:;
   if (Null(v6)){
    goto L40;
   }
   goto L23;
L40:;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = v5uiop_package__foundp;
   cl_env_copy->values[0] = v4uiop_package__recycled;
   return cl_env_copy->values[0];
  }
 }
L17:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4241recycle_symbol_va(cl_narg narg, cl_object v7uiop_package__name, cl_object v8uiop_package__recycle, cl_object v9uiop_package__exported, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[148]);
 {
  return L4241recycle_symbol(v7uiop_package__name, v8uiop_package__recycle, v9uiop_package__exported);
 }
}
/* function definition for SYMBOL-RECYCLED-P                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4242symbol_recycled_p(cl_object v1uiop_package__sym, cl_object v2uiop_package__recycle)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = v1uiop_package__sym;
  if (ECL_SYMBOLP(v3)) {
   goto L4;
  }
  v1uiop_package__sym = si_do_check_type(v3, ECL_SYM("SYMBOL",843), ECL_NIL, VV[154]);
L4:;
 }
 {
  cl_object v3;
  v3 = v2uiop_package__recycle;
  if (ECL_LISTP(v3)) {
   goto L9;
  }
  v2uiop_package__recycle = si_do_check_type(v3, ECL_SYM("LIST",483), ECL_NIL, VV[149]);
L9:;
 }
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v3 = cl_symbol_package(v1uiop_package__sym);
  v4 = v3;
  v5 = v2uiop_package__recycle;
  if (Null(ecl_memql(v4,v5))){
   goto L13;
  }
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L13:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4242symbol_recycled_p_va(cl_narg narg, cl_object v3uiop_package__sym, cl_object v4uiop_package__recycle, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[153]);
 {
  return L4242symbol_recycled_p(v3uiop_package__sym, v4uiop_package__recycle);
 }
}
/* function definition for ENSURE-SYMBOL                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4243ensure_symbol(cl_object v1uiop_package__name, cl_object v2package, cl_object v3intern, cl_object v4uiop_package__recycle, cl_object v5uiop_package__shadowed, cl_object v6uiop_package__imported, cl_object v7uiop_package__inherited, cl_object v8uiop_package__exported)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v9;
  v9 = v1uiop_package__name;
  if (ECL_STRINGP(v9)) {
   goto L4;
  }
  v1uiop_package__name = si_do_check_type(v9, ECL_SYM("STRING",808), ECL_NIL, VV[118]);
L4:;
 }
 {
  cl_object v9;
  v9 = v2package;
  if (cl_packagep(v9)!=ECL_NIL) {
   goto L9;
  }
  v2package = si_do_check_type(v9, ECL_SYM("PACKAGE",619), ECL_NIL, ECL_SYM("PACKAGE",619));
L9:;
 }
 {
  cl_object v9;
  v9 = v3intern;
  if (!((v9)==(ECL_NIL))){
   goto L18;
  }
  goto L14;
L18:;
  goto L16;
L16:;
  if (!((v9)==(ECL_T))){
   goto L21;
  }
  goto L14;
L21:;
  goto L15;
L15:;
  v3intern = si_do_check_type(v9, VV[139], ECL_NIL, ECL_SYM("INTERN",444));
L14:;
 }
 {
  cl_object v9;
  v9 = v5uiop_package__shadowed;
  if (cl_hash_table_p(v9)!=ECL_NIL) {
   goto L26;
  }
  v5uiop_package__shadowed = si_do_check_type(v9, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[121]);
L26:;
 }
 {
  cl_object v9;
  v9 = v6uiop_package__imported;
  if (cl_hash_table_p(v9)!=ECL_NIL) {
   goto L31;
  }
  v6uiop_package__imported = si_do_check_type(v9, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[122]);
L31:;
 }
 {
  cl_object v9;
  v9 = v7uiop_package__inherited;
  if (cl_hash_table_p(v9)!=ECL_NIL) {
   goto L36;
  }
  v7uiop_package__inherited = si_do_check_type(v9, ECL_SYM("HASH-TABLE",420), ECL_NIL, VV[141]);
L36:;
 }
 if (ecl_gethash_safe(v1uiop_package__name,v5uiop_package__shadowed,ECL_NIL)!=ECL_NIL) {
  goto L39;
 }
 if (ecl_gethash_safe(v1uiop_package__name,v6uiop_package__imported,ECL_NIL)!=ECL_NIL) {
  goto L39;
 }
 if (ecl_gethash_safe(v1uiop_package__name,v7uiop_package__inherited,ECL_NIL)!=ECL_NIL) {
  goto L39;
 }
 {
  cl_object v9;                                   /*  EXISTING                */
  cl_object v10;                                  /*  STATUS                  */
  value0 = cl_find_symbol(2, v1uiop_package__name, v2package);
  {
   v9 = value0;
   v10 = cl_env_copy->values[1];
  }
  {
   cl_object v11;                                 /*  RECYCLED                */
   cl_object v12;                                 /*  PREVIOUS                */
   value0 = L4241recycle_symbol(v1uiop_package__name, v4uiop_package__recycle, v8uiop_package__exported);
   {
    const int v13 = cl_env_copy->nvalues;
    v11 = value0;
    cl_object v14;
    v14 = (v13<=1)? ECL_NIL : cl_env_copy->values[1];
    v12 = v14;
   }
   {
    cl_object v13;
    if (Null(v10)){
     goto L47;
    }
    if (!((v9)==(v11))){
     goto L47;
    }
    v13 = ecl_make_bool((v12)==(v2package));
    goto L45;
L47:;
    v13 = ECL_NIL;
    goto L45;
L45:;
    if (Null(v13)){
     goto L50;
    }
    value0 = v13;
    cl_env_copy->nvalues = 1;
    return value0;
L50:;
    if (Null(v12)){
     goto L52;
    }
    value0 = L4224rehome_symbol(v11, v2package);
    return value0;
L52:;
    {
     cl_object v14;
     if (Null(v10)){
      goto L56;
     }
     T0 = cl_symbol_package(v9);
     v14 = ecl_make_bool((v2package)==(T0));
     goto L54;
L56:;
     v14 = ECL_NIL;
     goto L54;
L54:;
     if (Null(v14)){
      goto L58;
     }
     value0 = v14;
     cl_env_copy->nvalues = 1;
     return value0;
L58:;
     if (Null(v10)){
      goto L60;
     }
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
      goto L62;
     }
     T0 = cl_symbol_package(v9);
     T1 = L4211reify_package(2, T0, v2package);
     T2 = cl_list(5, VV[157], v1uiop_package__name, T1, v10, v3intern);
     L4215record_fishy(T2);
L62:;
     cl_unintern(1, v9);
L60:;
     if (Null(v3intern)){
      goto L64;
     }
     value0 = L4200intern_(2, v1uiop_package__name, v2package);
     return value0;
L64:;
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
L39:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4243ensure_symbol_va(cl_narg narg, cl_object v9uiop_package__name, cl_object v10package, cl_object v11intern, cl_object v12uiop_package__recycle, cl_object v13uiop_package__shadowed, cl_object v14uiop_package__imported, cl_object v15uiop_package__inherited, cl_object v16uiop_package__exported, ...)
{
 if (ecl_unlikely(narg!=8)) FEwrong_num_arguments(VV[156]);
 {
  return L4243ensure_symbol(v9uiop_package__name, v10package, v11intern, v12uiop_package__recycle, v13uiop_package__shadowed, v14uiop_package__imported, v15uiop_package__inherited, v16uiop_package__exported);
 }
}
/* function definition for ENSURE-EXPORTED-TO-USER                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4244ensure_exported_to_user(cl_narg narg, cl_object v1uiop_package__name, cl_object v2symbol, cl_object v3uiop_package__to_package, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[159]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[159]);
 {
  cl_object v4uiop_package__recycle;
  va_list args; va_start(args,v3uiop_package__to_package);
  {
   int i = 3;
   if (i >= narg) {
    v4uiop_package__recycle = ECL_NIL;
   } else {
    i++;
    v4uiop_package__recycle = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v5;
   v5 = v1uiop_package__name;
   if (ECL_STRINGP(v5)) {
    goto L4;
   }
   v1uiop_package__name = si_do_check_type(v5, ECL_SYM("STRING",808), ECL_NIL, VV[118]);
L4:;
  }
  {
   cl_object v5;
   v5 = v2symbol;
   if (ECL_SYMBOLP(v5)) {
    goto L9;
   }
   v2symbol = si_do_check_type(v5, ECL_SYM("SYMBOL",843), ECL_NIL, ECL_SYM("SYMBOL",843));
L9:;
  }
  {
   cl_object v5;
   v5 = v3uiop_package__to_package;
   if (cl_packagep(v5)!=ECL_NIL) {
    goto L14;
   }
   v3uiop_package__to_package = si_do_check_type(v5, ECL_SYM("PACKAGE",619), ECL_NIL, VV[119]);
L14:;
  }
  {
   cl_object v5;
   v5 = v4uiop_package__recycle;
   if (ECL_LISTP(v5)) {
    goto L19;
   }
   v4uiop_package__recycle = si_do_check_type(v5, ECL_SYM("LIST",483), ECL_NIL, VV[149]);
L19:;
  }
  goto L24;
L23:;
  si_assert_failure(1, VV[160]);
L24:;
  T0 = ecl_symbol_name(v2symbol);
  if (ecl_equal(v1uiop_package__name,T0)) {
   goto L27;
  }
  goto L23;
L27:;
  {
   cl_object v5;                                  /*  EXISTING                */
   cl_object v6;                                  /*  STATUS                  */
   value0 = cl_find_symbol(2, v1uiop_package__name, v3uiop_package__to_package);
   {
    v5 = value0;
    v6 = cl_env_copy->values[1];
   }
   if (Null(v6)){
    goto L33;
   }
   if ((v2symbol)==(v5)) {
    goto L30;
   }
   goto L31;
L33:;
   goto L31;
L31:;
   {
    cl_object v7uiop_package__accessible;
    value0 = ecl_make_bool(v6==ECL_NIL);
    if (value0!=ECL_NIL) {
     goto L37;
    }
    {
     cl_object v8;
     cl_object v9;
     v8 = L4207symbol_shadowing_p(v5, v3uiop_package__to_package);
     v9 = L4242symbol_recycled_p(v5, v4uiop_package__recycle);
     if (Null(v8)){
      goto L44;
     }
     if (Null(v9)){
      goto L41;
     }
     goto L42;
L44:;
     goto L42;
L42:;
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
      goto L46;
     }
     T0 = L4209symbol_package_name(v2symbol);
     T1 = cl_package_name(v3uiop_package__to_package);
     value0 = L4208home_package_p(v5, v3uiop_package__to_package);
     if (value0!=ECL_NIL) {
      goto L50;
     }
     T2 = L4209symbol_package_name(v5);
     goto L48;
L50:;
     T2 = value0;
     goto L48;
L48:;
     T3 = cl_list(7, VV[161], v1uiop_package__name, T0, T1, T2, v6, v8);
     L4215record_fishy(T3);
L46:;
     if ((v6)==(ECL_SYM("INHERITED",1285))) {
      goto L55;
     }
     if (Null(v8)){
      goto L53;
     }
     goto L54;
L55:;
L54:;
     L4203shadowing_import_(v2symbol, v3uiop_package__to_package);
     goto L52;
L53:;
     cl_unintern(2, v5, v3uiop_package__to_package);
L52:;
     v7uiop_package__accessible = ECL_T;
     goto L35;
L41:;
     v7uiop_package__accessible = ECL_NIL;
     goto L35;
    }
L37:;
    v7uiop_package__accessible = value0;
    goto L35;
L35:;
    if (Null(v7uiop_package__accessible)){
     goto L57;
    }
    if (!((v6)==(ECL_SYM("EXTERNAL",1266)))){
     goto L57;
    }
    value0 = L4245ensure_exported(4, v1uiop_package__name, v2symbol, v3uiop_package__to_package, v4uiop_package__recycle);
    return value0;
L57:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
   }
L30:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for ENSURE-EXPORTED                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4245ensure_exported(cl_narg narg, cl_object v1uiop_package__name, cl_object v2symbol, cl_object v3uiop_package__from_package, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[162]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[162]);
 {
  cl_object v4uiop_package__recycle;
  va_list args; va_start(args,v3uiop_package__from_package);
  {
   int i = 3;
   if (i >= narg) {
    v4uiop_package__recycle = ECL_NIL;
   } else {
    i++;
    v4uiop_package__recycle = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v5;
   v5 = cl_package_used_by_list(v3uiop_package__from_package);
   goto L6;
L5:;
   {
    cl_object v6uiop_package__to_package;
    v6uiop_package__to_package = ecl_car(v5);
    L4244ensure_exported_to_user(4, v1uiop_package__name, v2symbol, v6uiop_package__to_package, v4uiop_package__recycle);
   }
   v5 = ecl_cdr(v5);
L6:;
   if (Null(v5)){
    goto L13;
   }
   goto L5;
L13:;
  }
  T0 = cl_symbol_package(v2symbol);
  if ((v3uiop_package__from_package)==(T0)) {
   goto L15;
  }
  L4237ensure_imported(2, v2symbol, v3uiop_package__from_package);
L15:;
  value0 = L4201export_(v1uiop_package__name, v3uiop_package__from_package);
  return value0;
 }
}
/* function definition for ENSURE-EXPORT                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4246ensure_export(cl_narg narg, cl_object v1uiop_package__name, cl_object v2uiop_package__from_package, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[165]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[165]);
 {
  cl_object v3uiop_package__recycle;
  va_list args; va_start(args,v2uiop_package__from_package);
  {
   int i = 2;
   if (i >= narg) {
    v3uiop_package__recycle = ECL_NIL;
   } else {
    i++;
    v3uiop_package__recycle = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v4;                                  /*  SYMBOL                  */
   cl_object v5;                                  /*  STATUS                  */
   value0 = L4198find_symbol_(2, v1uiop_package__name, v2uiop_package__from_package);
   {
    const int v6 = cl_env_copy->nvalues;
    v4 = value0;
    cl_object v7;
    v7 = (v6<=1)? ECL_NIL : cl_env_copy->values[1];
    v5 = v7;
   }
   if ((v5)==(ECL_SYM("EXTERNAL",1266))) {
    goto L3;
   }
   value0 = L4245ensure_exported(4, v1uiop_package__name, v4, v2uiop_package__from_package, v3uiop_package__recycle);
   return value0;
L3:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for ENSURE-PACKAGE                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4248ensure_package(cl_narg narg, cl_object v1uiop_package__name, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[167]);
 {
  cl_object v2uiop_package__nicknames;
  cl_object v3documentation;
  cl_object v4uiop_package__use;
  cl_object v5shadow;
  cl_object v6uiop_package__shadowing_import_from;
  cl_object v7uiop_package__import_from;
  cl_object v8export;
  cl_object v9intern;
  cl_object v10uiop_package__recycle;
  cl_object v11uiop_package__mix;
  cl_object v12uiop_package__reexport;
  cl_object v13unintern;
  ecl_va_list args; ecl_va_start(args,v1uiop_package__name,narg,1);
  {
   cl_object keyvars[24];
   cl_parse_key(args,12,L4248ensure_packagekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2uiop_package__nicknames = keyvars[0];
   v3documentation = keyvars[1];
   v4uiop_package__use = keyvars[2];
   v5shadow = keyvars[3];
   v6uiop_package__shadowing_import_from = keyvars[4];
   v7uiop_package__import_from = keyvars[5];
   v8export = keyvars[6];
   v9intern = keyvars[7];
   v10uiop_package__recycle = keyvars[8];
   v11uiop_package__mix = keyvars[9];
   v12uiop_package__reexport = keyvars[10];
   v13unintern = keyvars[11];
  }
  {
   cl_object v14package_name;
   cl_object v15uiop_package__nicknames;
   cl_object v16uiop_package__previous;
   cl_object v17uiop_package__discarded;
   cl_object v18uiop_package__to_delete;
   cl_object v19package;
   cl_object v20uiop_package__recycle;
   cl_object v21uiop_package__use;
   cl_object v22uiop_package__mix;
   cl_object v23uiop_package__reexport;
   cl_object v24shadow;
   cl_object v25export;
   cl_object v26intern;
   cl_object v27unintern;
   cl_object v28uiop_package__shadowed;
   cl_object v29uiop_package__imported;
   cl_object v30uiop_package__exported;
   cl_object v31uiop_package__inherited;
   cl_object env1 = env0;
   v14package_name = cl_string(v1uiop_package__name);
   {
    cl_object v32;
    v32 = (ECL_SYM("STRING",808)->symbol.gfdef);
    {
     cl_object v33;
     cl_object v34;
     cl_object v35;
     {
      cl_object v36;
      v36 = v2uiop_package__nicknames;
      if (ecl_unlikely(!ECL_LISTP(v36))) FEtype_error_list(v36);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v33 = v36;
     }
     v34 = ECL_NIL;
     v35 = v33;
     {
      cl_object v36;
      cl_object v37;
      v36 = ecl_list1(ECL_NIL);
      v37 = v36;
L11:;
      if (!(ecl_endp(v35))){
       goto L13;
      }
      goto L12;
L13:;
      v34 = ECL_CONS_CAR(v35);
      {
       cl_object v38;
       v38 = ECL_CONS_CDR(v35);
       if (ecl_unlikely(!ECL_LISTP(v38))) FEtype_error_list(v38);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v35 = v38;
      }
      {
       cl_object v38;
       v38 = v37;
       if (ecl_unlikely(ECL_ATOM(v38))) FEtype_error_cons(v38);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v38;
      }
      T1 = ecl_function_dispatch(cl_env_copy,v32)(1, v34);
      v37 = ecl_list1(T1);
      (ECL_CONS_CDR(T0)=v37,T0);
      goto L11;
L12:;
      v15uiop_package__nicknames = ecl_cdr(v36);
      goto L2;
     }
    }
   }
L2:;
   T0 = CONS(v14package_name,v15uiop_package__nicknames);
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(T0,env1);                   /*  NAMES                   */
   v16uiop_package__previous = L4228packages_from_names(ECL_CONS_CAR(CLV0));
   v17uiop_package__discarded = ecl_cdr(v16uiop_package__previous);
   v18uiop_package__to_delete = ECL_NIL;
   value0 = ecl_car(v16uiop_package__previous);
   if (value0!=ECL_NIL) {
    goto L34;
   }
   v19package = cl_make_package(3, v14package_name, ECL_SYM("NICKNAMES",1313), v15uiop_package__nicknames);
   goto L32;
L34:;
   v19package = value0;
   goto L32;
L32:;
   v20uiop_package__recycle = L4228packages_from_names(v10uiop_package__recycle);
   {
    cl_object v32;
    cl_object v33;
    cl_object v34;
    {
     cl_object v35;
     v35 = v4uiop_package__use;
     if (ecl_unlikely(!ECL_LISTP(v35))) FEtype_error_list(v35);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v32 = v35;
    }
    v33 = ECL_NIL;
    v34 = v32;
    {
     cl_object v35;
     cl_object v36;
     v35 = ecl_list1(ECL_NIL);
     v36 = v35;
L45:;
     if (!(ecl_endp(v34))){
      goto L47;
     }
     goto L46;
L47:;
     v33 = ECL_CONS_CAR(v34);
     {
      cl_object v37;
      v37 = ECL_CONS_CDR(v34);
      if (ecl_unlikely(!ECL_LISTP(v37))) FEtype_error_list(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v34 = v37;
     }
     {
      cl_object v37;
      v37 = v36;
      if (ecl_unlikely(ECL_ATOM(v37))) FEtype_error_cons(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v37;
     }
     T1 = ecl_function_dispatch(cl_env_copy,VV[1])(1, v33);
     v36 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v36,T0);
     goto L45;
L46:;
     v21uiop_package__use = ecl_cdr(v35);
     goto L37;
    }
   }
L37:;
   {
    cl_object v32;
    cl_object v33;
    cl_object v34;
    {
     cl_object v35;
     v35 = v11uiop_package__mix;
     if (ecl_unlikely(!ECL_LISTP(v35))) FEtype_error_list(v35);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v32 = v35;
    }
    v33 = ECL_NIL;
    v34 = v32;
    {
     cl_object v35;
     cl_object v36;
     v35 = ecl_list1(ECL_NIL);
     v36 = v35;
L71:;
     if (!(ecl_endp(v34))){
      goto L73;
     }
     goto L72;
L73:;
     v33 = ECL_CONS_CAR(v34);
     {
      cl_object v37;
      v37 = ECL_CONS_CDR(v34);
      if (ecl_unlikely(!ECL_LISTP(v37))) FEtype_error_list(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v34 = v37;
     }
     {
      cl_object v37;
      v37 = v36;
      if (ecl_unlikely(ECL_ATOM(v37))) FEtype_error_cons(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v37;
     }
     T1 = ecl_function_dispatch(cl_env_copy,VV[1])(1, v33);
     v36 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v36,T0);
     goto L71;
L72:;
     v22uiop_package__mix = ecl_cdr(v35);
     goto L63;
    }
   }
L63:;
   {
    cl_object v32;
    cl_object v33;
    cl_object v34;
    {
     cl_object v35;
     v35 = v12uiop_package__reexport;
     if (ecl_unlikely(!ECL_LISTP(v35))) FEtype_error_list(v35);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v32 = v35;
    }
    v33 = ECL_NIL;
    v34 = v32;
    {
     cl_object v35;
     cl_object v36;
     v35 = ecl_list1(ECL_NIL);
     v36 = v35;
L97:;
     if (!(ecl_endp(v34))){
      goto L99;
     }
     goto L98;
L99:;
     v33 = ECL_CONS_CAR(v34);
     {
      cl_object v37;
      v37 = ECL_CONS_CDR(v34);
      if (ecl_unlikely(!ECL_LISTP(v37))) FEtype_error_list(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v34 = v37;
     }
     {
      cl_object v37;
      v37 = v36;
      if (ecl_unlikely(ECL_ATOM(v37))) FEtype_error_cons(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v37;
     }
     T1 = ecl_function_dispatch(cl_env_copy,VV[1])(1, v33);
     v36 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v36,T0);
     goto L97;
L98:;
     v23uiop_package__reexport = ecl_cdr(v35);
     goto L89;
    }
   }
L89:;
   {
    cl_object v32;
    cl_object v33;
    cl_object v34;
    {
     cl_object v35;
     v35 = v5shadow;
     if (ecl_unlikely(!ECL_LISTP(v35))) FEtype_error_list(v35);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v32 = v35;
    }
    v33 = ECL_NIL;
    v34 = v32;
    {
     cl_object v35;
     cl_object v36;
     v35 = ecl_list1(ECL_NIL);
     v36 = v35;
L123:;
     if (!(ecl_endp(v34))){
      goto L125;
     }
     goto L124;
L125:;
     v33 = ECL_CONS_CAR(v34);
     {
      cl_object v37;
      v37 = ECL_CONS_CDR(v34);
      if (ecl_unlikely(!ECL_LISTP(v37))) FEtype_error_list(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v34 = v37;
     }
     {
      cl_object v37;
      v37 = v36;
      if (ecl_unlikely(ECL_ATOM(v37))) FEtype_error_cons(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v37;
     }
     T1 = ecl_function_dispatch(cl_env_copy,ECL_SYM("STRING",808))(1, v33);
     v36 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v36,T0);
     goto L123;
L124:;
     v24shadow = ecl_cdr(v35);
     goto L115;
    }
   }
L115:;
   {
    cl_object v32;
    cl_object v33;
    cl_object v34;
    {
     cl_object v35;
     v35 = v8export;
     if (ecl_unlikely(!ECL_LISTP(v35))) FEtype_error_list(v35);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v32 = v35;
    }
    v33 = ECL_NIL;
    v34 = v32;
    {
     cl_object v35;
     cl_object v36;
     v35 = ecl_list1(ECL_NIL);
     v36 = v35;
L149:;
     if (!(ecl_endp(v34))){
      goto L151;
     }
     goto L150;
L151:;
     v33 = ECL_CONS_CAR(v34);
     {
      cl_object v37;
      v37 = ECL_CONS_CDR(v34);
      if (ecl_unlikely(!ECL_LISTP(v37))) FEtype_error_list(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v34 = v37;
     }
     {
      cl_object v37;
      v37 = v36;
      if (ecl_unlikely(ECL_ATOM(v37))) FEtype_error_cons(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v37;
     }
     T1 = ecl_function_dispatch(cl_env_copy,ECL_SYM("STRING",808))(1, v33);
     v36 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v36,T0);
     goto L149;
L150:;
     v25export = ecl_cdr(v35);
     goto L141;
    }
   }
L141:;
   {
    cl_object v32;
    cl_object v33;
    cl_object v34;
    {
     cl_object v35;
     v35 = v9intern;
     if (ecl_unlikely(!ECL_LISTP(v35))) FEtype_error_list(v35);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v32 = v35;
    }
    v33 = ECL_NIL;
    v34 = v32;
    {
     cl_object v35;
     cl_object v36;
     v35 = ecl_list1(ECL_NIL);
     v36 = v35;
L175:;
     if (!(ecl_endp(v34))){
      goto L177;
     }
     goto L176;
L177:;
     v33 = ECL_CONS_CAR(v34);
     {
      cl_object v37;
      v37 = ECL_CONS_CDR(v34);
      if (ecl_unlikely(!ECL_LISTP(v37))) FEtype_error_list(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v34 = v37;
     }
     {
      cl_object v37;
      v37 = v36;
      if (ecl_unlikely(ECL_ATOM(v37))) FEtype_error_cons(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v37;
     }
     T1 = ecl_function_dispatch(cl_env_copy,ECL_SYM("STRING",808))(1, v33);
     v36 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v36,T0);
     goto L175;
L176:;
     v26intern = ecl_cdr(v35);
     goto L167;
    }
   }
L167:;
   {
    cl_object v32;
    cl_object v33;
    cl_object v34;
    {
     cl_object v35;
     v35 = v13unintern;
     if (ecl_unlikely(!ECL_LISTP(v35))) FEtype_error_list(v35);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v32 = v35;
    }
    v33 = ECL_NIL;
    v34 = v32;
    {
     cl_object v35;
     cl_object v36;
     v35 = ecl_list1(ECL_NIL);
     v36 = v35;
L201:;
     if (!(ecl_endp(v34))){
      goto L203;
     }
     goto L202;
L203:;
     v33 = ECL_CONS_CAR(v34);
     {
      cl_object v37;
      v37 = ECL_CONS_CDR(v34);
      if (ecl_unlikely(!ECL_LISTP(v37))) FEtype_error_list(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v34 = v37;
     }
     {
      cl_object v37;
      v37 = v36;
      if (ecl_unlikely(ECL_ATOM(v37))) FEtype_error_cons(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v37;
     }
     T1 = ecl_function_dispatch(cl_env_copy,ECL_SYM("STRING",808))(1, v33);
     v36 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v36,T0);
     goto L201;
L202:;
     v27unintern = ecl_cdr(v35);
     goto L193;
    }
   }
L193:;
   v28uiop_package__shadowed = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
   v29uiop_package__imported = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
   v30uiop_package__exported = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
   v31uiop_package__inherited = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
    goto L223;
   }
   L4215record_fishy(v14package_name);
L223:;
   if (Null(v3documentation)){
    goto L225;
   }
   (cl_env_copy->function=ECL_CONS_CAR(VV[3179]))->cfun.entry(3, v3documentation, v19package, ECL_T) /*  (SETF DOCUMENTATION) */;
L225:;
   {
    cl_object v32;
    cl_object v33uiop_package__p;
    cl_object v34;
    T0 = cl_package_use_list(v19package);
    T1 = ecl_append(v22uiop_package__mix,v21uiop_package__use);
    v32 = cl_set_difference(2, T0, T1);
    v33uiop_package__p = ECL_NIL;
    v34 = v32;
L231:;
    if (!(ecl_endp(v34))){
     goto L233;
    }
    goto L232;
L233:;
    v33uiop_package__p = ECL_CONS_CAR(v34);
    {
     cl_object v35;
     v35 = ECL_CONS_CDR(v34);
     if (ecl_unlikely(!ECL_LISTP(v35))) FEtype_error_list(v35);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v34 = v35;
    }
    if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
     goto L242;
    }
    T0 = L4227package_names(v33uiop_package__p);
    T1 = cl_list(3, VV[169], v1uiop_package__name, T0);
    L4215record_fishy(T1);
L242:;
    cl_unuse_package(2, v33uiop_package__p, v19package);
    goto L231;
L232:;
   }
   {
    cl_object v32;
    cl_object v33uiop_package__p;
    cl_object v34;
    {
     cl_object v35;
     v35 = v17uiop_package__discarded;
     if (ecl_unlikely(!ECL_LISTP(v35))) FEtype_error_list(v35);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v32 = v35;
    }
    v33uiop_package__p = ECL_NIL;
    v34 = v32;
    {
     cl_object v35uiop_package__n;
     v35uiop_package__n = ECL_NIL;
L252:;
     if (!(ecl_endp(v34))){
      goto L254;
     }
     goto L253;
L254:;
     v33uiop_package__p = ECL_CONS_CAR(v34);
     {
      cl_object v36;
      v36 = ECL_CONS_CDR(v34);
      if (ecl_unlikely(!ECL_LISTP(v36))) FEtype_error_list(v36);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v34 = v36;
     }
     {
      cl_object v36;
      v36 = ecl_make_cclosure_va((cl_objectfn)LC4247__lambda820,env1,Cblock,1);
      T0 = v36;
     }
     T1 = L4227package_names(v33uiop_package__p);
     v35uiop_package__n = cl_remove_if(2, T0, T1);
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
      goto L266;
     }
     T0 = L4227package_names(v33uiop_package__p);
     T1 = cl_list(3, VV[171], v1uiop_package__name, T0);
     L4215record_fishy(T1);
L266:;
     if (Null(v35uiop_package__n)){
      goto L268;
     }
     T0 = ecl_car(v35uiop_package__n);
     T1 = ecl_cdr(v35uiop_package__n);
     cl_rename_package(3, v33uiop_package__p, T0, T1);
     goto L265;
L268:;
     L4230rename_package_away(1, v33uiop_package__p);
     v18uiop_package__to_delete = CONS(v33uiop_package__p,v18uiop_package__to_delete);
L265:;
     goto L252;
L253:;
    }
   }
   cl_rename_package(3, v19package, v14package_name, v15uiop_package__nicknames);
   {
    cl_object v32;
    v32 = v27unintern;
    goto L278;
L277:;
    {
     cl_object v33uiop_package__name;
     v33uiop_package__name = ecl_car(v32);
     {
      cl_object v34;                              /*  EXISTING                */
      cl_object v35;                              /*  STATUS                  */
      value0 = cl_find_symbol(2, v33uiop_package__name, v19package);
      {
       v34 = value0;
       v35 = cl_env_copy->values[1];
      }
      if (Null(v35)){
       goto L282;
      }
      if ((v35)==(ECL_SYM("INHERITED",1285))) {
       goto L282;
      }
      if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
       goto L286;
      }
      T0 = cl_package_name(v19package);
      T1 = L4209symbol_package_name(v34);
      T2 = cl_list(5, VV[172], T0, v33uiop_package__name, T1, v35);
      L4215record_fishy(T2);
L286:;
      L4206unintern_(3, v33uiop_package__name, v19package, ECL_NIL);
     }
L282:;
    }
    v32 = ecl_cdr(v32);
L278:;
    if (Null(v32)){
     goto L290;
    }
    goto L277;
L290:;
   }
   {
    cl_object v32;
    v32 = v25export;
    goto L296;
L295:;
    {
     cl_object v33uiop_package__name;
     v33uiop_package__name = ecl_car(v32);
     si_hash_set(v33uiop_package__name, v30uiop_package__exported, ECL_T);
    }
    v32 = ecl_cdr(v32);
L296:;
    if (Null(v32)){
     goto L303;
    }
    goto L295;
L303:;
   }
   {
    cl_object v32;
    v32 = v23uiop_package__reexport;
    goto L309;
L308:;
    {
     cl_object v33uiop_package__p;
     v33uiop_package__p = ecl_car(v32);
     {
      cl_object v34;
      cl_object v35;
      cl_object v36uiop_package__sym;
      v34 = si_packages_iterator(v33uiop_package__p, VV[70], ECL_T);
      v35 = ECL_NIL;
      v36uiop_package__sym = ECL_NIL;
      goto L319;
L318:;
      value0 = ecl_function_dispatch(cl_env_copy,v34)(0);
      {
       const int v37 = cl_env_copy->nvalues;
       v35 = value0;
       cl_object v38;
       v38 = (v37<=1)? ECL_NIL : cl_env_copy->values[1];
       v36uiop_package__sym = v38;
      }
      if (v35!=ECL_NIL) {
       goto L323;
      }
      goto L313;
L323:;
      T0 = cl_string(v36uiop_package__sym);
      si_hash_set(T0, v30uiop_package__exported, ECL_T);
L319:;
      goto L318;
     }
L313:;
    }
    v32 = ecl_cdr(v32);
L309:;
    if (Null(v32)){
     goto L329;
    }
    goto L308;
L329:;
   }
   {
    cl_object v32;
    cl_object v33;
    cl_object v34uiop_package__sym;
    v32 = si_packages_iterator(v19package, VV[70], ECL_T);
    v33 = ECL_NIL;
    v34uiop_package__sym = ECL_NIL;
    goto L337;
L336:;
    value0 = ecl_function_dispatch(cl_env_copy,v32)(0);
    {
     const int v35 = cl_env_copy->nvalues;
     v33 = value0;
     cl_object v36;
     v36 = (v35<=1)? ECL_NIL : cl_env_copy->values[1];
     v34uiop_package__sym = v36;
    }
    if (v33!=ECL_NIL) {
     goto L341;
    }
    goto L331;
L341:;
    {
     cl_object v35uiop_package__name;
     v35uiop_package__name = ecl_symbol_name(v34uiop_package__sym);
     if (ecl_gethash_safe(v35uiop_package__name,v30uiop_package__exported,ECL_NIL)!=ECL_NIL) {
      goto L343;
     }
     if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
      goto L346;
     }
     T0 = cl_package_name(v19package);
     value0 = L4208home_package_p(v34uiop_package__sym, v19package);
     if (value0!=ECL_NIL) {
      goto L350;
     }
     T1 = L4209symbol_package_name(v34uiop_package__sym);
     goto L348;
L350:;
     T1 = value0;
     goto L348;
L348:;
     T2 = cl_list(4, VV[173], T0, v35uiop_package__name, T1);
     L4215record_fishy(T2);
L346:;
     cl_unexport(2, v34uiop_package__sym, v19package);
    }
L343:;
L337:;
    goto L336;
   }
L331:;
   {
    cl_object v32;
    v32 = v24shadow;
    goto L357;
L356:;
    {
     cl_object v33uiop_package__name;
     v33uiop_package__name = ecl_car(v32);
     si_hash_set(v33uiop_package__name, v28uiop_package__shadowed, ECL_T);
     {
      cl_object v34;                              /*  EXISTING                */
      cl_object v35;                              /*  STATUS                  */
      value0 = cl_find_symbol(2, v33uiop_package__name, v19package);
      {
       v34 = value0;
       v35 = cl_env_copy->values[1];
      }
      {
       cl_object v36;                             /*  RECYCLED                */
       cl_object v37;                             /*  PREVIOUS                */
       value0 = L4241recycle_symbol(v33uiop_package__name, v20uiop_package__recycle, v30uiop_package__exported);
       {
        const int v38 = cl_env_copy->nvalues;
        v36 = value0;
        cl_object v39;
        v39 = (v38<=1)? ECL_NIL : cl_env_copy->values[1];
        v37 = v39;
       }
       {
        cl_object v38uiop_package__shadowing;
        if (Null(v35)){
         goto L367;
        }
        v38uiop_package__shadowing = L4207symbol_shadowing_p(v34, v19package);
        goto L365;
L367:;
        v38uiop_package__shadowing = ECL_NIL;
        goto L365;
L365:;
        {
         cl_object v39;
         v39 = ecl_make_bool((v37)==(v19package));
         if (Null(v39)){
          goto L370;
         }
         goto L362;
L370:;
         if (Null(v37)){
          goto L372;
         }
         L4224rehome_symbol(v36, v19package);
         goto L362;
L372:;
         {
          cl_object v40;
          if (!((v35)==(ECL_NIL))){
          goto L382;
          }
          value0 = VV[107];
          goto L380;
L382:;
          value0 = ECL_NIL;
          goto L380;
L380:;
          if (value0!=ECL_NIL) {
          goto L379;
          }
          if (!((v35)==(ECL_SYM("INHERITED",1285)))){
          goto L385;
          }
          value0 = VV[108];
          goto L377;
L385:;
          value0 = ECL_NIL;
          goto L377;
L379:;
          goto L377;
L377:;
          if (value0!=ECL_NIL) {
          goto L376;
          }
          v40 = L4208home_package_p(v34, v19package);
          goto L374;
L376:;
          v40 = value0;
          goto L374;
L374:;
          if (Null(v40)){
          goto L387;
          }
          goto L362;
L387:;
          {
          cl_object v41uiop_package__dummy;
          v41uiop_package__dummy = cl_make_symbol(v33uiop_package__name);
          if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[51]))){
          goto L390;
          }
          T0 = cl_package_name(v19package);
          T1 = L4209symbol_package_name(v34);
          T2 = cl_list(6, VV[174], T0, v33uiop_package__name, T1, v35, v38uiop_package__shadowing);
          L4215record_fishy(T2);
L390:;
          L4203shadowing_import_(v41uiop_package__dummy, v19package);
          L4202import_(v41uiop_package__dummy, v19package);
          }
         }
        }
       }
      }
     }
L362:;
     L4204shadow_(v33uiop_package__name, v19package);
    }
    v32 = ecl_cdr(v32);
L357:;
    if (Null(v32)){
     goto L396;
    }
    goto L356;
L396:;
   }
   {
    cl_object v32;
    cl_object v33uiop_package__p;
    cl_object v34uiop_package__syms;
    cl_object v35;
    {
     cl_object v36;
     v36 = v6uiop_package__shadowing_import_from;
     if (ecl_unlikely(!ECL_LISTP(v36))) FEtype_error_list(v36);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v32 = v36;
    }
    v33uiop_package__p = ECL_NIL;
    v34uiop_package__syms = ECL_NIL;
    v35 = v32;
    {
     cl_object v36uiop_package__pp;
     v36uiop_package__pp = ECL_NIL;
L406:;
     if (!(ecl_endp(v35))){
      goto L408;
     }
     goto L407;
L408:;
     {
      cl_object v37;
      v37 = ECL_CONS_CAR(v35);
      v33uiop_package__p = ecl_car(v37);
      v37 = ecl_cdr(v37);
      v34uiop_package__syms = v37;
     }
     {
      cl_object v37;
      v37 = ECL_CONS_CDR(v35);
      if (ecl_unlikely(!ECL_LISTP(v37))) FEtype_error_list(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v35 = v37;
     }
     v36uiop_package__pp = L4197find_package_(1, v33uiop_package__p);
     {
      cl_object v37;
      v37 = v34uiop_package__syms;
      goto L427;
L426:;
      {
       cl_object v38uiop_package__sym;
       v38uiop_package__sym = ecl_car(v37);
       T0 = cl_string(v38uiop_package__sym);
       L4236ensure_shadowing_import(T0, v19package, v36uiop_package__pp, v28uiop_package__shadowed, v29uiop_package__imported);
      }
      v37 = ecl_cdr(v37);
L427:;
      if (Null(v37)){
       goto L434;
      }
      goto L426;
L434:;
     }
     goto L406;
L407:;
    }
   }
   {
    cl_object v32;
    cl_object v33uiop_package__p;
    cl_object v34;
    {
     cl_object v35;
     v35 = v22uiop_package__mix;
     if (ecl_unlikely(!ECL_LISTP(v35))) FEtype_error_list(v35);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v32 = v35;
    }
    v33uiop_package__p = ECL_NIL;
    v34 = v32;
    {
     cl_object v35uiop_package__pp;
     v35uiop_package__pp = ECL_NIL;
L444:;
     if (!(ecl_endp(v34))){
      goto L446;
     }
     goto L445;
L446:;
     v33uiop_package__p = ECL_CONS_CAR(v34);
     {
      cl_object v36;
      v36 = ECL_CONS_CDR(v34);
      if (ecl_unlikely(!ECL_LISTP(v36))) FEtype_error_list(v36);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v34 = v36;
     }
     v35uiop_package__pp = L4197find_package_(1, v33uiop_package__p);
     {
      cl_object v36;
      cl_object v37;
      cl_object v38uiop_package__sym;
      v36 = si_packages_iterator(v35uiop_package__pp, VV[70], ECL_T);
      v37 = ECL_NIL;
      v38uiop_package__sym = ECL_NIL;
      goto L462;
L461:;
      value0 = ecl_function_dispatch(cl_env_copy,v36)(0);
      {
       const int v39 = cl_env_copy->nvalues;
       v37 = value0;
       cl_object v40;
       v40 = (v39<=1)? ECL_NIL : cl_env_copy->values[1];
       v38uiop_package__sym = v40;
      }
      if (v37!=ECL_NIL) {
       goto L466;
      }
      goto L456;
L466:;
      T0 = ecl_symbol_name(v38uiop_package__sym);
      L4240ensure_mix(T0, v38uiop_package__sym, v19package, v35uiop_package__pp, v28uiop_package__shadowed, v29uiop_package__imported, v31uiop_package__inherited);
L462:;
      goto L461;
     }
L456:;
     goto L444;
L445:;
    }
   }
   {
    cl_object v32;
    cl_object v33uiop_package__p;
    cl_object v34uiop_package__syms;
    cl_object v35;
    {
     cl_object v36;
     v36 = v7uiop_package__import_from;
     if (ecl_unlikely(!ECL_LISTP(v36))) FEtype_error_list(v36);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v32 = v36;
    }
    v33uiop_package__p = ECL_NIL;
    v34uiop_package__syms = ECL_NIL;
    v35 = v32;
    {
     cl_object v36uiop_package__pp;
     v36uiop_package__pp = ECL_NIL;
L479:;
     if (!(ecl_endp(v35))){
      goto L481;
     }
     goto L480;
L481:;
     {
      cl_object v37;
      v37 = ECL_CONS_CAR(v35);
      v33uiop_package__p = ecl_car(v37);
      v37 = ecl_cdr(v37);
      v34uiop_package__syms = v37;
     }
     {
      cl_object v37;
      v37 = ECL_CONS_CDR(v35);
      if (ecl_unlikely(!ECL_LISTP(v37))) FEtype_error_list(v37);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v35 = v37;
     }
     v36uiop_package__pp = cl_find_package(v33uiop_package__p);
     {
      cl_object v37;
      v37 = v34uiop_package__syms;
      goto L500;
L499:;
      {
       cl_object v38uiop_package__sym;
       v38uiop_package__sym = ecl_car(v37);
       T0 = ecl_symbol_name(v38uiop_package__sym);
       L4238ensure_import(T0, v19package, v36uiop_package__pp, v28uiop_package__shadowed, v29uiop_package__imported);
      }
      v37 = ecl_cdr(v37);
L500:;
      if (Null(v37)){
       goto L507;
      }
      goto L499;
L507:;
     }
     goto L479;
L480:;
    }
   }
   {
    cl_object v32;
    v32 = ecl_append(v21uiop_package__use,v22uiop_package__mix);
    goto L514;
L513:;
    {
     cl_object v33uiop_package__p;
     v33uiop_package__p = ecl_car(v32);
     {
      cl_object v34;
      cl_object v35;
      cl_object v36uiop_package__sym;
      v34 = si_packages_iterator(v33uiop_package__p, VV[70], ECL_T);
      v35 = ECL_NIL;
      v36uiop_package__sym = ECL_NIL;
      goto L524;
L523:;
      value0 = ecl_function_dispatch(cl_env_copy,v34)(0);
      {
       const int v37 = cl_env_copy->nvalues;
       v35 = value0;
       cl_object v38;
       v38 = (v37<=1)? ECL_NIL : cl_env_copy->values[1];
       v36uiop_package__sym = v38;
      }
      if (v35!=ECL_NIL) {
       goto L528;
      }
      goto L518;
L528:;
      T0 = cl_string(v36uiop_package__sym);
      L4239ensure_inherited(T0, v36uiop_package__sym, v19package, v33uiop_package__p, ECL_NIL, v28uiop_package__shadowed, v29uiop_package__imported, v31uiop_package__inherited);
L524:;
      goto L523;
     }
L518:;
     cl_use_package(2, v33uiop_package__p, v19package);
    }
    v32 = ecl_cdr(v32);
L514:;
    if (Null(v32)){
     goto L535;
    }
    goto L513;
L535:;
   }
   {
    cl_object v32;
    cl_object v33uiop_package__name;
    cl_object v34;
    v32 = ECL_NIL;
    v33uiop_package__name = ECL_NIL;
    v34 = ECL_NIL;
    {
     cl_object v35;
     v35 = si_hash_table_iterator(v30uiop_package__exported);
L542:;
     {
      cl_object v36;
      cl_object v37;
      cl_object v38;
      value0 = ecl_function_dispatch(cl_env_copy,v35)(0);
      {
       const int v39 = cl_env_copy->nvalues;
       v36 = value0;
       cl_object v40;
       v40 = (v39<=1)? ECL_NIL : cl_env_copy->values[1];
       v37 = v40;
       v40 = (v39<=2)? ECL_NIL : cl_env_copy->values[2];
       v38 = v40;
      }
      if (Null(v36)){
       goto L547;
      }
      v34 = v38;
      v33uiop_package__name = v37;
L547:;
      v32 = v36;
      if (v32!=ECL_NIL) {
       goto L544;
      }
     }
     goto L543;
L544:;
     L4243ensure_symbol(v33uiop_package__name, v19package, ECL_T, v20uiop_package__recycle, v28uiop_package__shadowed, v29uiop_package__imported, v31uiop_package__inherited, v30uiop_package__exported);
     L4246ensure_export(3, v33uiop_package__name, v19package, v20uiop_package__recycle);
     goto L542;
L543:;
    }
   }
   {
    cl_object v32;
    v32 = v26intern;
    goto L560;
L559:;
    {
     cl_object v33uiop_package__name;
     v33uiop_package__name = ecl_car(v32);
     L4243ensure_symbol(v33uiop_package__name, v19package, ECL_T, v20uiop_package__recycle, v28uiop_package__shadowed, v29uiop_package__imported, v31uiop_package__inherited, v30uiop_package__exported);
    }
    v32 = ecl_cdr(v32);
L560:;
    if (Null(v32)){
     goto L567;
    }
    goto L559;
L567:;
   }
   {
    cl_object v32;
    cl_object v33;
    cl_object v34uiop_package__sym;
    v32 = si_packages_iterator(v19package, VV[83], ECL_T);
    v33 = ECL_NIL;
    v34uiop_package__sym = ECL_NIL;
    goto L575;
L574:;
    value0 = ecl_function_dispatch(cl_env_copy,v32)(0);
    {
     const int v35 = cl_env_copy->nvalues;
     v33 = value0;
     cl_object v36;
     v36 = (v35<=1)? ECL_NIL : cl_env_copy->values[1];
     v34uiop_package__sym = v36;
    }
    if (v33!=ECL_NIL) {
     goto L579;
    }
    goto L569;
L579:;
    T0 = ecl_symbol_name(v34uiop_package__sym);
    L4243ensure_symbol(T0, v19package, ECL_NIL, v20uiop_package__recycle, v28uiop_package__shadowed, v29uiop_package__imported, v31uiop_package__inherited, v30uiop_package__exported);
L575:;
    goto L574;
   }
L569:;
   cl_map(3, ECL_NIL, VV[81], v18uiop_package__to_delete);
   value0 = v19package;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for PARSE-DEFINE-PACKAGE-FORM                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4249parse_define_package_form(cl_object v1package, cl_object v2uiop_package__clauses)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3uiop_package__use_p;
  v3uiop_package__use_p = ECL_NIL;
  {
   cl_object v4uiop_package__recycle_p;
   v4uiop_package__recycle_p = ECL_NIL;
   {
    cl_object v5documentation;
    v5documentation = ECL_NIL;
    {
     cl_object v6;
     cl_object v7uiop_package__kw;
     cl_object v8uiop_package__args;
     cl_object v9;
     {
      cl_object v10;
      v10 = v2uiop_package__clauses;
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v6 = v10;
     }
     v7uiop_package__kw = ECL_NIL;
     v8uiop_package__args = ECL_NIL;
     v9 = v6;
     {
      cl_object v10;
      cl_object v11;
      cl_object v12uiop_package__nicknames;
      v10 = ecl_list1(ECL_NIL);
      v11 = v10;
      v12uiop_package__nicknames = ECL_NIL;
      {
       cl_object v13;
       cl_object v14;
       cl_object v15uiop_package__use;
       v13 = ecl_list1(ECL_NIL);
       v14 = v13;
       v15uiop_package__use = ECL_NIL;
       {
        cl_object v16;
        cl_object v17;
        cl_object v18shadow;
        v16 = ecl_list1(ECL_NIL);
        v17 = v16;
        v18shadow = ECL_NIL;
        {
         cl_object v19;
         cl_object v20;
         cl_object v21uiop_package__shadowing_import_from;
         v19 = ecl_list1(ECL_NIL);
         v20 = v19;
         v21uiop_package__shadowing_import_from = ECL_NIL;
         {
          cl_object v22;
          cl_object v23;
          cl_object v24uiop_package__import_from;
          v22 = ecl_list1(ECL_NIL);
          v23 = v22;
          v24uiop_package__import_from = ECL_NIL;
          {
          cl_object v25;
          cl_object v26;
          cl_object v27export;
          v25 = ecl_list1(ECL_NIL);
          v26 = v25;
          v27export = ECL_NIL;
          {
          cl_object v28;
          cl_object v29;
          cl_object v30intern;
          v28 = ecl_list1(ECL_NIL);
          v29 = v28;
          v30intern = ECL_NIL;
          {
          cl_object v31;
          cl_object v32;
          cl_object v33uiop_package__recycle;
          v31 = ecl_list1(ECL_NIL);
          v32 = v31;
          v33uiop_package__recycle = ECL_NIL;
          {
          cl_object v34;
          cl_object v35;
          cl_object v36uiop_package__mix;
          v34 = ecl_list1(ECL_NIL);
          v35 = v34;
          v36uiop_package__mix = ECL_NIL;
          {
          cl_object v37;
          cl_object v38;
          cl_object v39uiop_package__reexport;
          v37 = ecl_list1(ECL_NIL);
          v38 = v37;
          v39uiop_package__reexport = ECL_NIL;
          {
          cl_object v40;
          cl_object v41;
          cl_object v42unintern;
          v40 = ecl_list1(ECL_NIL);
          v41 = v40;
          v42unintern = ECL_NIL;
L44:;
          if (!(ecl_endp(v9))){
          goto L46;
          }
          goto L45;
L46:;
          {
          cl_object v43;
          v43 = ECL_CONS_CAR(v9);
          v7uiop_package__kw = ecl_car(v43);
          v43 = ecl_cdr(v43);
          v8uiop_package__args = v43;
          }
          {
          cl_object v43;
          v43 = ECL_CONS_CDR(v9);
          if (ecl_unlikely(!ECL_LISTP(v43))) FEtype_error_list(v43);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          v9 = v43;
          }
          if (!((v7uiop_package__kw)==(ECL_SYM("NICKNAMES",1313)))){
          goto L60;
          }
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v11;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L62;
          }
          }
          T0 = ecl_cdr(v11);
          v11 = ecl_last(T0,1);
L62:;
          v12uiop_package__nicknames = ecl_cdr(v10);
          goto L59;
L60:;
          if (!((v7uiop_package__kw)==(ECL_SYM("DOCUMENTATION",1253)))){
          goto L71;
          }
          if (Null(v5documentation)){
          goto L73;
          }
          cl_error(1, VV[178]);
          goto L59;
L73:;
          if (ECL_ATOM(v8uiop_package__args)) {
          goto L77;
          }
          if (Null(ecl_cdr(v8uiop_package__args))){
          goto L75;
          }
          goto L76;
L77:;
L76:;
          cl_error(1, VV[179]);
          goto L59;
L75:;
          v5documentation = ecl_car(v8uiop_package__args);
          goto L59;
L71:;
          if (!((v7uiop_package__kw)==(ECL_SYM("USE",1361)))){
          goto L80;
          }
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v14;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L83;
          }
          }
          T0 = ecl_cdr(v14);
          v14 = ecl_last(T0,1);
L83:;
          v15uiop_package__use = ecl_cdr(v13);
          v3uiop_package__use_p = ECL_T;
          goto L59;
L80:;
          if (!((v7uiop_package__kw)==(ECL_SYM("SHADOW",1343)))){
          goto L93;
          }
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v17;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L95;
          }
          }
          T0 = ecl_cdr(v17);
          v17 = ecl_last(T0,1);
L95:;
          v18shadow = ecl_cdr(v16);
          goto L59;
L93:;
          if (!((v7uiop_package__kw)==(VV[115]))){
          goto L104;
          }
          {
          cl_object v43;
          v43 = v20;
          if (ecl_unlikely(ECL_ATOM(v43))) FEtype_error_cons(v43);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v43;
          }
          v20 = ecl_list1(v8uiop_package__args);
          (ECL_CONS_CDR(T0)=v20,T0);
          v21uiop_package__shadowing_import_from = ecl_cdr(v19);
          goto L59;
L104:;
          if (!((v7uiop_package__kw)==(ECL_SYM("IMPORT-FROM",1283)))){
          goto L112;
          }
          {
          cl_object v43;
          v43 = v23;
          if (ecl_unlikely(ECL_ATOM(v43))) FEtype_error_cons(v43);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v43;
          }
          v23 = ecl_list1(v8uiop_package__args);
          (ECL_CONS_CDR(T0)=v23,T0);
          v24uiop_package__import_from = ecl_cdr(v22);
          goto L59;
L112:;
          if (!((v7uiop_package__kw)==(ECL_SYM("EXPORT",1264)))){
          goto L120;
          }
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v26;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L122;
          }
          }
          T0 = ecl_cdr(v26);
          v26 = ecl_last(T0,1);
L122:;
          v27export = ecl_cdr(v25);
          goto L59;
L120:;
          if (!((v7uiop_package__kw)==(ECL_SYM("INTERN",1292)))){
          goto L131;
          }
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v29;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L133;
          }
          }
          T0 = ecl_cdr(v29);
          v29 = ecl_last(T0,1);
L133:;
          v30intern = ecl_cdr(v28);
          goto L59;
L131:;
          if (!((v7uiop_package__kw)==(VV[180]))){
          goto L142;
          }
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v32;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L145;
          }
          }
          T0 = ecl_cdr(v32);
          v32 = ecl_last(T0,1);
L145:;
          v33uiop_package__recycle = ecl_cdr(v31);
          v4uiop_package__recycle_p = ECL_T;
          goto L59;
L142:;
          if (!((v7uiop_package__kw)==(VV[181]))){
          goto L155;
          }
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v35;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L157;
          }
          }
          T0 = ecl_cdr(v35);
          v35 = ecl_last(T0,1);
L157:;
          v36uiop_package__mix = ecl_cdr(v34);
          goto L59;
L155:;
          if (!((v7uiop_package__kw)==(VV[182]))){
          goto L166;
          }
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v38;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L168;
          }
          }
          T0 = ecl_cdr(v38);
          v38 = ecl_last(T0,1);
L168:;
          v39uiop_package__reexport = ecl_cdr(v37);
          goto L59;
L166:;
          if (!((v7uiop_package__kw)==(VV[183]))){
          goto L177;
          }
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v14;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L180;
          }
          }
          T0 = ecl_cdr(v14);
          v14 = ecl_last(T0,1);
L180:;
          v15uiop_package__use = ecl_cdr(v13);
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v38;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L190;
          }
          }
          T0 = ecl_cdr(v38);
          v38 = ecl_last(T0,1);
L190:;
          v39uiop_package__reexport = ecl_cdr(v37);
          v3uiop_package__use_p = ECL_T;
          goto L59;
L177:;
          if (!((v7uiop_package__kw)==(VV[184]))){
          goto L200;
          }
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v35;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L203;
          }
          }
          T0 = ecl_cdr(v35);
          v35 = ecl_last(T0,1);
L203:;
          v36uiop_package__mix = ecl_cdr(v34);
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v38;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L213;
          }
          }
          T0 = ecl_cdr(v38);
          v38 = ecl_last(T0,1);
L213:;
          v39uiop_package__reexport = ecl_cdr(v37);
          v3uiop_package__use_p = ECL_T;
          goto L59;
L200:;
          if (!((v7uiop_package__kw)==(VV[172]))){
          goto L223;
          }
          {
          cl_object v43;
          v43 = cl_copy_list(v8uiop_package__args);
          {
          cl_object v44;
          v44 = v41;
          if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v44;
          }
          (ECL_CONS_CDR(T0)=v43,T0);
          if (Null(v43)){
          goto L225;
          }
          }
          T0 = ecl_cdr(v41);
          v41 = ecl_last(T0,1);
L225:;
          v42unintern = ecl_cdr(v40);
          goto L59;
L223:;
          cl_error(2, VV[185], v7uiop_package__kw);
L59:;
          goto L44;
L45:;
          if (Null(v3uiop_package__use_p)){
          goto L237;
          }
          T0 = v15uiop_package__use;
          goto L236;
L237:;
          T0 = VV[186];
L236:;
          if (Null(v4uiop_package__recycle_p)){
          goto L240;
          }
          T1 = v33uiop_package__recycle;
          goto L239;
L240:;
          T1 = CONS(v1package,v12uiop_package__nicknames);
L239:;
          value0 = cl_list(25, v1package, ECL_SYM("NICKNAMES",1313), v12uiop_package__nicknames, ECL_SYM("DOCUMENTATION",1253), v5documentation, ECL_SYM("USE",1361), T0, ECL_SYM("SHADOW",1343), v18shadow, VV[115], v21uiop_package__shadowing_import_from, ECL_SYM("IMPORT-FROM",1283), v24uiop_package__import_from, ECL_SYM("EXPORT",1264), v27export, ECL_SYM("INTERN",1292), v30intern, VV[180], T1, VV[181], v36uiop_package__mix, VV[182], v39uiop_package__reexport, VV[172], v42unintern);
          return value0;
          }
          }
          }
          }
          }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 }
}
static cl_object L4249parse_define_package_form_va(cl_narg narg, cl_object v43package, cl_object v44uiop_package__clauses, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[177]);
 {
  return L4249parse_define_package_form(v43package, v44uiop_package__clauses);
 }
}
/* local function DEFINE-PACKAGE                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4250define_package(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4package;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4package = v5;
  }
  {
   cl_object v5uiop_package__ensure_form;
   T0 = L4249parse_define_package_form(v4package, v3);
   T1 = cl_list(2, ECL_SYM("QUOTE",682), T0);
   v5uiop_package__ensure_form = cl_list(3, ECL_SYM("APPLY",91), VV[190], T1);
   T0 = cl_list(3, ECL_SYM("DEFPACKAGE",286), v4package, VV[191]);
   T1 = cl_list(3, ECL_SYM("EVAL-WHEN",342), VV[192], v5uiop_package__ensure_form);
   value0 = cl_list(3, ECL_SYM("PROGN",674), T0, T1);
   return value0;
  }
 }
}
static cl_object LC4250define_package_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[189]);
 {
  return LC4250define_package(v6, v7);
 }
}
/* function definition for USE-ECL-BYTE-COMPILER-P                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4251use_ecl_byte_compiler_p()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  v1 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
  v2 = VV[197];
  v3 = v1;
  if (Null(ecl_memql(v2,v3))){
   goto L3;
  }
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4251use_ecl_byte_compiler_p_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[196]);
 {
  return L4251use_ecl_byte_compiler_p();
 }
}
/* local function LOOP*                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4252loop_(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  value0 = CONS(ECL_SYM("LOOP",514),v3);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4252loop__va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[200]);
 {
  return LC4252loop_(v4, v5);
 }
}
/* function definition for FROB-SUBSTRINGS                                    */
/* optimize speed 0, debug 3, space 1, safety 3                               */
static cl_object L4256frob_substrings(volatile cl_narg narg, cl_object volatile v1string, cl_object volatile v2uiop_common_lisp__substrings, ...)
{
 struct ecl_ihs_frame ihs;
 const cl_object _ecl_debug_env = ECL_NIL;
 cl_object volatile env0 = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[202]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[202]);
 {
  va_list args; va_start(args,v2uiop_common_lisp__substrings);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1string,env0);              /*  STRING                  */
  {
   static const struct ecl_var_debug_info _ecl_descriptors[]={
   {"UIOP/COMMON-LISP::SUBSTRINGS",_ecl_object_loc}};
   const cl_index _ecl_debug_info_raw[]={
   (cl_index)(ECL_NIL),(cl_index)(_ecl_descriptors),(cl_index)(&v2uiop_common_lisp__substrings)};
   ecl_def_ct_vector(_ecl_debug_env,ecl_aet_index,_ecl_debug_info_raw,3,,);
   ecl_ihs_push(cl_env_copy,&ihs,VV[202],ECL_NIL,_ecl_debug_env);
   {
    int i = 2;
    if (i >= narg) {
     CLV1 = env0 = CONS(ECL_NIL,env0);            /*  FROB                    */
    } else {
     i++;
     CLV1 = env0 = CONS(va_arg(args,cl_object),env0); /*  FROB                */
    }
   }
   va_end(args);
   {
    cl_object volatile env1 = env0;
    CLV2 = env1 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env1); /*  FROB-SUBSTRINGS */
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV2));
     if (__ecl_frs_push_result!=0) {
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_ihs_pop(cl_env_copy);
     return cl_env_copy->values[0];
     } else {
     {
      cl_object v3;
      cl_object env2 = env1;
      v3 = ecl_make_fixnum(ecl_length(ECL_CONS_CAR(CLV0)));
      CLV3 = env2 = CONS(v3,env2);                /*  LENGTH                  */
      CLV4 = env2 = CONS(ECL_NIL,env2);           /*  STREAM                  */
      {
       static const struct ecl_var_debug_info _ecl_descriptors[]={
       {"#:LET1133",_ecl_object_loc}};
       const cl_index _ecl_debug_info_raw[]={
       (cl_index)(_ecl_debug_env),(cl_index)(_ecl_descriptors),(cl_index)(&v3)};
       ecl_def_ct_vector(_ecl_debug_env,ecl_aet_index,_ecl_debug_info_raw,3,,);
       ihs.lcl_env = _ecl_debug_env;
       {cl_object env3 = env2;
        CLV5 = env3 = CONS(ECL_NIL,env3);
        ECL_CONS_CAR(CLV5) = ecl_make_cclosure_va((cl_objectfn)LC4253emit_string,env3,Cblock,1);
        (aux_closure.env=env3,cl_env_copy->function=(cl_object)&aux_closure,LC4255recurse(3, v2uiop_common_lisp__substrings, ecl_make_int8_t(0), ECL_CONS_CAR(CLV3)));
       }
       if (Null(ECL_CONS_CAR(CLV4))){
        goto L3;
       }
       value0 = cl_get_output_stream_string(ECL_CONS_CAR(CLV4));
       ecl_frs_pop_n(cl_env_copy, 1);
       ecl_ihs_pop(cl_env_copy);
       return value0;
L3:;
       value0 = VV[96];
       cl_env_copy->nvalues = 1;
       ecl_frs_pop_n(cl_env_copy, 1);
       ecl_ihs_pop(cl_env_copy);
       return value0;
       ihs.lcl_env = _ecl_debug_env;
      }
     }
     }
    }
   }
  }
 }
}
/* local function COMPATFMT                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4257compatfmt(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4format;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4format = v5;
  }
  if (Null(v3)){
   goto L9;
  }
  si_dm_too_many_arguments(v1);
L9:;
  value0 = v4format;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4257compatfmt_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[208]);
 {
  return LC4257compatfmt(v5, v6);
 }
}
/* function definition for UNDEFINE-FUNCTION                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4258undefine_function(cl_object v1uiop_utility__function_spec)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_SYMBOLP(v1uiop_utility__function_spec))){
  goto L2;
 }
 value0 = cl_fmakunbound(v1uiop_utility__function_spec);
 return value0;
L2:;
 if (!(ECL_CONSP(v1uiop_utility__function_spec))){
  goto L4;
 }
 T0 = ecl_car(v1uiop_utility__function_spec);
 if (!((T0)==(ECL_SYM("SETF",753)))){
  goto L4;
 }
 T0 = ecl_cdr(v1uiop_utility__function_spec);
 if (!(ECL_CONSP(T0))){
  goto L4;
 }
 T0 = ecl_cddr(v1uiop_utility__function_spec);
 if (!(T0==ECL_NIL)){
  goto L4;
 }
 value0 = cl_fmakunbound(v1uiop_utility__function_spec);
 return value0;
L4:;
 value0 = cl_error(2, VV[212], v1uiop_utility__function_spec);
 return value0;
}
static cl_object L4258undefine_function_va(cl_narg narg, cl_object v2uiop_utility__function_spec, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[211]);
 {
  return L4258undefine_function(v2uiop_utility__function_spec);
 }
}
/* function definition for UNDEFINE-FUNCTIONS                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4259undefine_functions(cl_object v1uiop_utility__function_spec_list)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_map(3, ECL_NIL, VV[211], v1uiop_utility__function_spec_list);
 return value0;
}
static cl_object L4259undefine_functions_va(cl_narg narg, cl_object v2uiop_utility__function_spec_list, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[214]);
 {
  return L4259undefine_functions(v2uiop_utility__function_spec_list);
 }
}
/* local function DEFGENERIC*                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4260defgeneric_(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4uiop_utility__name;
  cl_object v5uiop_utility__formals;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4uiop_utility__name = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5uiop_utility__formals = v6;
  }
  {
   cl_object v6;
   cl_object v7;
   cl_object v8uiop_utility__name;
   cl_object v9;
   cl_object v10uiop_utility__supersede;
   if (ECL_ATOM(v4uiop_utility__name)) {
    goto L18;
   }
   T0 = ecl_car(v4uiop_utility__name);
   if (!((T0)==(ECL_SYM("SETF",753)))){
    goto L16;
   }
   goto L17;
L18:;
L17:;
   v6 = cl_list(3, v4uiop_utility__name, ECL_SYM("SUPERSEDE",1351), ECL_NIL);
   goto L15;
L16:;
   v6 = v4uiop_utility__name;
L15:;
   v7 = v6;
   if (!(v7==ECL_NIL)){
    goto L22;
   }
   si_dm_too_few_arguments(v6);
L22:;
   {
    cl_object v11;
    v11 = ecl_car(v7);
    v7 = ecl_cdr(v7);
    v8uiop_utility__name = v11;
   }
   v9 = si_search_keyword(v7, ECL_SYM("SUPERSEDE",1351));
   if (!((v9)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L29;
   }
   v10uiop_utility__supersede = ECL_T;
   goto L28;
L29:;
   v10uiop_utility__supersede = v9;
L28:;
   si_check_keyword(2, v7, VV[219]);
   value0 = v10uiop_utility__supersede;
   if (value0!=ECL_NIL) {
    goto L35;
   }
   goto L33;
L35:;
   goto L33;
L33:;
   T1 = cl_list(2, ECL_SYM("QUOTE",682), v8uiop_utility__name);
   T2 = cl_list(2, VV[211], T1);
   T0 = ecl_list1(T2);
   if (!(ECL_SYMBOLP(v8uiop_utility__name))){
    goto L38;
   }
   T2 = cl_list(2, ECL_SYM("NOTINLINE",589), v8uiop_utility__name);
   T3 = cl_list(2, ECL_SYM("DECLAIM",274), T2);
   T1 = ecl_list1(T3);
   goto L37;
L38:;
   T1 = ECL_NIL;
L37:;
   T2 = cl_listX(4, ECL_SYM("DEFGENERIC",942), v8uiop_utility__name, v5uiop_utility__formals, v3);
   T3 = ecl_list1(T2);
   T4 = cl_append(3, T0, T1, T3);
   value0 = CONS(ECL_SYM("PROGN",674),T4);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object LC4260defgeneric__va(cl_narg narg, cl_object v11, cl_object v12, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[216]);
 {
  return LC4260defgeneric_(v11, v12);
 }
}
/* local function DEFUN*                                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4261defun_(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4uiop_utility__name;
  cl_object v5uiop_utility__formals;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4uiop_utility__name = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5uiop_utility__formals = v6;
  }
  {
   cl_object v6;
   cl_object v7;
   cl_object v8uiop_utility__name;
   cl_object v9;
   cl_object v10uiop_utility__supersede;
   if (ECL_ATOM(v4uiop_utility__name)) {
    goto L18;
   }
   T0 = ecl_car(v4uiop_utility__name);
   if (!((T0)==(ECL_SYM("SETF",753)))){
    goto L16;
   }
   goto L17;
L18:;
L17:;
   v6 = cl_list(3, v4uiop_utility__name, ECL_SYM("SUPERSEDE",1351), ECL_NIL);
   goto L15;
L16:;
   v6 = v4uiop_utility__name;
L15:;
   v7 = v6;
   if (!(v7==ECL_NIL)){
    goto L22;
   }
   si_dm_too_few_arguments(v6);
L22:;
   {
    cl_object v11;
    v11 = ecl_car(v7);
    v7 = ecl_cdr(v7);
    v8uiop_utility__name = v11;
   }
   v9 = si_search_keyword(v7, ECL_SYM("SUPERSEDE",1351));
   if (!((v9)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L29;
   }
   v10uiop_utility__supersede = ECL_T;
   goto L28;
L29:;
   v10uiop_utility__supersede = v9;
L28:;
   si_check_keyword(2, v7, VV[219]);
   value0 = v10uiop_utility__supersede;
   if (value0!=ECL_NIL) {
    goto L35;
   }
   goto L33;
L35:;
   goto L33;
L33:;
   T1 = cl_list(2, ECL_SYM("QUOTE",682), v8uiop_utility__name);
   T2 = cl_list(2, VV[211], T1);
   T0 = ecl_list1(T2);
   if (!(ECL_SYMBOLP(v8uiop_utility__name))){
    goto L38;
   }
   T2 = cl_list(2, ECL_SYM("NOTINLINE",589), v8uiop_utility__name);
   T3 = cl_list(2, ECL_SYM("DECLAIM",274), T2);
   T1 = ecl_list1(T3);
   goto L37;
L38:;
   T1 = ECL_NIL;
L37:;
   T2 = cl_listX(4, ECL_SYM("DEFUN",291), v8uiop_utility__name, v5uiop_utility__formals, v3);
   T3 = ecl_list1(T2);
   T4 = cl_append(3, T0, T1, T3);
   value0 = CONS(ECL_SYM("PROGN",674),T4);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object LC4261defun__va(cl_narg narg, cl_object v11, cl_object v12, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[221]);
 {
  return LC4261defun_(v11, v12);
 }
}
/* local function WITH-UPGRADABILITY                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4262with_upgradability(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v5;
  }
  if (Null(v4)){
   goto L9;
  }
  si_dm_too_many_arguments(v1);
L9:;
  {
   cl_object v5;
   cl_object v6uiop_utility__form;
   cl_object v7;
   {
    cl_object v8;
    v8 = v3;
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v8;
   }
   v6uiop_utility__form = ECL_NIL;
   v7 = v5;
   {
    cl_object v8;
    cl_object v9;
    v8 = ecl_list1(ECL_NIL);
    v9 = v8;
L19:;
    if (!(ecl_endp(v7))){
     goto L21;
    }
    goto L20;
L21:;
    v6uiop_utility__form = ECL_CONS_CAR(v7);
    {
     cl_object v10;
     v10 = ECL_CONS_CDR(v7);
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v7 = v10;
    }
    {
     cl_object v10;
     v10 = v9;
     if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T1 = v10;
    }
    if (!(ECL_CONSP(v6uiop_utility__form))){
     goto L35;
    }
    {
     cl_object v10;
     cl_object v11car;
     v10 = v6uiop_utility__form;
     if (!(v10==ECL_NIL)){
      goto L39;
     }
     si_dm_too_few_arguments(v6uiop_utility__form);
L39:;
     {
      cl_object v12;
      v12 = ecl_car(v10);
      v10 = ecl_cdr(v10);
      v11car = v12;
     }
     if (!((v11car)==(ECL_SYM("DEFUN",291)))){
      goto L44;
     }
     T2 = CONS(VV[221],v10);
     goto L34;
L44:;
     if (!((v11car)==(ECL_SYM("DEFGENERIC",942)))){
      goto L47;
     }
     T2 = CONS(VV[216],v10);
     goto L34;
L47:;
     T2 = v6uiop_utility__form;
     goto L34;
    }
L35:;
    T2 = v6uiop_utility__form;
L34:;
    v9 = ecl_list1(T2);
    (ECL_CONS_CDR(T1)=v9,T1);
    goto L19;
L20:;
    T0 = ecl_cdr(v8);
    goto L11;
   }
  }
L11:;
  value0 = cl_listX(3, ECL_SYM("EVAL-WHEN",342), VV[192], T0);
  return value0;
 }
}
static cl_object LC4262with_upgradability_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[223]);
 {
  return LC4262with_upgradability(v5, v6);
 }
}
/* local function UIOP-DEBUG                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4263uiop_debug(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  T0 = CONS(VV[229],v3);
  value0 = cl_list(3, ECL_SYM("EVAL-WHEN",342), VV[192], T0);
  return value0;
 }
}
static cl_object LC4263uiop_debug_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[228]);
 {
  return LC4263uiop_debug(v4, v5);
 }
}
/* function definition for LOAD-UIOP-DEBUG-UTILITY                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4265load_uiop_debug_utility(volatile cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object volatile v1package;
  cl_object volatile v2uiop_utility__utility_file;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4265load_uiop_debug_utilitykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1package = keyvars[0];
   v2uiop_utility__utility_file = keyvars[1];
  }
  {
   volatile cl_object v3keyword;
   if (Null(v1package)){
    goto L2;
   }
   T0 = cl_find_package(v1package);
   goto L1;
L2:;
   T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PACKAGE*",45));
L1:;
   ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T0); /*  *PACKAGE*        */
   T0 = cl_package_name(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PACKAGE*",45)));
   T1 = cl_format(3, ECL_NIL, VV[231], T0);
   v3keyword = cl_read_from_string(1, T1);
   {
    cl_object v4;
    cl_object v5;
    cl_object v6;
    v4 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
    v5 = v3keyword;
    v6 = v4;
    if (ecl_memql(v5,v6)!=ECL_NIL) {
     goto L5;
    }
   }
   {
    volatile cl_object v4uiop_utility__utility_file;
    volatile cl_object v5uiop_utility__file;
    value0 = v2uiop_utility__utility_file;
    if (value0!=ECL_NIL) {
     goto L12;
    }
    v4uiop_utility__utility_file = ecl_cmp_symbol_value(cl_env_copy,VV[227]);
    goto L10;
L12:;
    v4uiop_utility__utility_file = value0;
    goto L10;
L10:;
    {
     volatile cl_object env1 = env0;
     env1 = ECL_NIL;
     CLV0 = env1 = CONS(ECL_NIL,env1);
     {
      volatile cl_object env2 = env1;
      CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY     */
      {
       ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
       if (__ecl_frs_push_result!=0) {
       if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
        goto L15;
       }
       ecl_internal_error("GO found an inexistent tag");
       } else {
       {
        cl_object v6;
        v6 = ecl_make_cclosure_va((cl_objectfn)LC4264__lambda1292,env2,Cblock,1);
        T0 = v6;
       }
       T1 = CONS(ECL_SYM("ERROR",339),T0);
       T2 = ecl_list1(T1);
       T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
       ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
       T0 = cl_eval(v4uiop_utility__utility_file);
       v5uiop_utility__file = cl_probe_file(T0);
       ecl_frs_pop_n(cl_env_copy, 1);
       ecl_bds_unwind1(cl_env_copy);
       goto L14;
L15:;
       {
        cl_object v6condition;
        v6condition = ECL_CONS_CAR(CLV0);
        cl_env_copy->nvalues = 2;
        cl_env_copy->values[1] = v6condition;
        cl_env_copy->values[0] = ECL_NIL;
        v5uiop_utility__file = cl_env_copy->values[0];
        ecl_frs_pop_n(cl_env_copy, 1);
        goto L14;
       }
       }
      }
     }
    }
L14:;
    if (Null(v5uiop_utility__file)){
     goto L20;
    }
    value0 = cl_load(1, v5uiop_utility__file);
    ecl_bds_unwind1(cl_env_copy);
    return value0;
L20:;
    value0 = cl_error(2, VV[234], v4uiop_utility__utility_file);
    ecl_bds_unwind1(cl_env_copy);
    return value0;
   }
L5:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   ecl_bds_unwind1(cl_env_copy);
   return value0;
  }
 }
}
/* local function NEST                                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4267nest(cl_object v1, cl_object v2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  {
   cl_object v4;
   v4 = ecl_make_cfun_va((cl_objectfn)LC4266__lambda1301_va,ECL_NIL,Cblock,2);
   T0 = v4;
  }
  value0 = cl_reduce(4, T0, v3, VV[91], ECL_T);
  return value0;
 }
}
static cl_object LC4267nest_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[236]);
 {
  return LC4267nest(v4, v5);
 }
}
/* local function IF-LET                                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4268if_let(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4uiop_utility__bindings;
  cl_object v5;
  cl_object v6uiop_utility__then_form;
  cl_object v7uiop_utility__else_form;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4uiop_utility__bindings = v8;
  }
  v5 = v3;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_utility__then_form = v8;
  }
  if (Null(v5)){
   goto L17;
  }
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7uiop_utility__else_form = v8;
   goto L16;
  }
L17:;
  v7uiop_utility__else_form = ECL_NIL;
L16:;
  if (Null(v5)){
   goto L22;
  }
  si_dm_too_many_arguments(v1);
L22:;
  {
   cl_object v8uiop_utility__binding_list;
   cl_object v9uiop_utility__variables;
   if (!(ECL_CONSP(v4uiop_utility__bindings))){
    goto L25;
   }
   T0 = ecl_car(v4uiop_utility__bindings);
   if (!(ECL_SYMBOLP(T0))){
    goto L25;
   }
   v8uiop_utility__binding_list = ecl_list1(v4uiop_utility__bindings);
   goto L24;
L25:;
   v8uiop_utility__binding_list = v4uiop_utility__bindings;
L24:;
   {
    cl_object v10;
    v10 = (ECL_SYM("CAR",182)->symbol.gfdef);
    {
     cl_object v11;
     cl_object v12;
     cl_object v13;
     {
      cl_object v14;
      v14 = v8uiop_utility__binding_list;
      if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v11 = v14;
     }
     v12 = ECL_NIL;
     v13 = v11;
     {
      cl_object v14;
      cl_object v15;
      v14 = ecl_list1(ECL_NIL);
      v15 = v14;
L37:;
      if (!(ecl_endp(v13))){
       goto L39;
      }
      goto L38;
L39:;
      v12 = ECL_CONS_CAR(v13);
      {
       cl_object v16;
       v16 = ECL_CONS_CDR(v13);
       if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v13 = v16;
      }
      {
       cl_object v16;
       v16 = v15;
       if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v16;
      }
      T1 = ecl_function_dispatch(cl_env_copy,v10)(1, v12);
      v15 = ecl_list1(T1);
      (ECL_CONS_CDR(T0)=v15,T0);
      goto L37;
L38:;
      v9uiop_utility__variables = ecl_cdr(v14);
      goto L28;
     }
    }
   }
L28:;
   T0 = CONS(ECL_SYM("AND",89),v9uiop_utility__variables);
   T1 = cl_list(4, ECL_SYM("IF",950), T0, v6uiop_utility__then_form, v7uiop_utility__else_form);
   value0 = cl_list(3, ECL_SYM("LET",479), v8uiop_utility__binding_list, T1);
   return value0;
  }
 }
}
static cl_object LC4268if_let_va(cl_narg narg, cl_object v10, cl_object v11, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[239]);
 {
  return LC4268if_let(v10, v11);
 }
}
/* local function WHILE-COLLECTING                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4272while_collecting(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v5;
  }
  {
   cl_object v5;
   cl_object v6;
   {
    cl_object v7;
    {
     cl_object v8;
     v8 = ecl_make_cfun_va((cl_objectfn)LC4269__lambda1343_va,ECL_NIL,Cblock,1);
     v7 = v8;
    }
    {
     cl_object v8;
     cl_object v9;
     cl_object v10;
     {
      cl_object v11;
      v11 = v4;
      if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v8 = v11;
     }
     v9 = ECL_NIL;
     v10 = v8;
     {
      cl_object v11;
      cl_object v12;
      v11 = ecl_list1(ECL_NIL);
      v12 = v11;
L18:;
      if (!(ecl_endp(v10))){
       goto L20;
      }
      goto L19;
L20:;
      v9 = ECL_CONS_CAR(v10);
      {
       cl_object v13;
       v13 = ECL_CONS_CDR(v10);
       if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v10 = v13;
      }
      {
       cl_object v13;
       v13 = v12;
       if (ecl_unlikely(ECL_ATOM(v13))) FEtype_error_cons(v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v13;
      }
      T1 = ecl_function_dispatch(cl_env_copy,v7)(1, v9);
      v12 = ecl_list1(T1);
      (ECL_CONS_CDR(T0)=v12,T0);
      goto L18;
L19:;
      v5 = ecl_cdr(v11);
      goto L9;
     }
    }
   }
L9:;
   {
    cl_object v7;
    v7 = cl_constantly(ECL_NIL);
    {
     cl_object v8;
     cl_object v9;
     cl_object v10;
     {
      cl_object v11;
      v11 = v4;
      if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v8 = v11;
     }
     v9 = ECL_NIL;
     v10 = v8;
     {
      cl_object v11;
      cl_object v12;
      v11 = ecl_list1(ECL_NIL);
      v12 = v11;
L45:;
      if (!(ecl_endp(v10))){
       goto L47;
      }
      goto L46;
L47:;
      v9 = ECL_CONS_CAR(v10);
      {
       cl_object v13;
       v13 = ECL_CONS_CDR(v10);
       if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v10 = v13;
      }
      {
       cl_object v13;
       v13 = v12;
       if (ecl_unlikely(ECL_ATOM(v13))) FEtype_error_cons(v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v13;
      }
      T1 = ecl_function_dispatch(cl_env_copy,v7)(1, v9);
      v12 = ecl_list1(T1);
      (ECL_CONS_CDR(T0)=v12,T0);
      goto L45;
L46:;
      v6 = ecl_cdr(v11);
      goto L36;
     }
    }
   }
L36:;
   {
    cl_object v7;
    v7 = (ECL_SYM("LIST",483)->symbol.gfdef);
    {
     cl_object v8;
     cl_object v9;
     cl_object v10;
     {
      cl_object v11;
      v11 = v5;
      if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v8 = v11;
     }
     v9 = ECL_NIL;
     v10 = v8;
     {
      cl_object v11;
      cl_object v12;
      cl_object v13;
      {
       cl_object v14;
       v14 = v6;
       if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v11 = v14;
      }
      v12 = ECL_NIL;
      v13 = v11;
      {
       cl_object v14;
       cl_object v15;
       v14 = ecl_list1(ECL_NIL);
       v15 = v14;
L77:;
       if (!(ecl_endp(v10))){
        goto L79;
       }
       goto L78;
L79:;
       v9 = ECL_CONS_CAR(v10);
       {
        cl_object v16;
        v16 = ECL_CONS_CDR(v10);
        if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v10 = v16;
       }
       if (!(ecl_endp(v13))){
        goto L87;
       }
       goto L78;
L87:;
       v12 = ECL_CONS_CAR(v13);
       {
        cl_object v16;
        v16 = ECL_CONS_CDR(v13);
        if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v13 = v16;
       }
       {
        cl_object v16;
        v16 = v15;
        if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T1 = v16;
       }
       T2 = ecl_function_dispatch(cl_env_copy,v7)(2, v9, v12);
       v15 = ecl_list1(T2);
       (ECL_CONS_CDR(T1)=v15,T1);
       goto L77;
L78:;
       T0 = ecl_cdr(v14);
       goto L63;
      }
     }
    }
   }
L63:;
   {
    cl_object v7;
    {
     cl_object v8;
     v8 = ecl_make_cfun_va((cl_objectfn)LC4270__lambda1372_va,ECL_NIL,Cblock,2);
     v7 = v8;
    }
    {
     cl_object v8;
     cl_object v9;
     cl_object v10;
     {
      cl_object v11;
      v11 = v4;
      if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v8 = v11;
     }
     v9 = ECL_NIL;
     v10 = v8;
     {
      cl_object v11;
      cl_object v12;
      cl_object v13;
      {
       cl_object v14;
       v14 = v5;
       if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v11 = v14;
      }
      v12 = ECL_NIL;
      v13 = v11;
      {
       cl_object v14;
       cl_object v15;
       v14 = ecl_list1(ECL_NIL);
       v15 = v14;
L117:;
       if (!(ecl_endp(v10))){
        goto L119;
       }
       goto L118;
L119:;
       v9 = ECL_CONS_CAR(v10);
       {
        cl_object v16;
        v16 = ECL_CONS_CDR(v10);
        if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v10 = v16;
       }
       if (!(ecl_endp(v13))){
        goto L127;
       }
       goto L118;
L127:;
       v12 = ECL_CONS_CAR(v13);
       {
        cl_object v16;
        v16 = ECL_CONS_CDR(v13);
        if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v13 = v16;
       }
       {
        cl_object v16;
        v16 = v15;
        if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T2 = v16;
       }
       T3 = ecl_function_dispatch(cl_env_copy,v7)(2, v9, v12);
       v15 = ecl_list1(T3);
       (ECL_CONS_CDR(T2)=v15,T2);
       goto L117;
L118:;
       T1 = ecl_cdr(v14);
       goto L103;
      }
     }
    }
   }
L103:;
   {
    cl_object v7;
    {
     cl_object v8;
     v8 = ecl_make_cfun_va((cl_objectfn)LC4271__lambda1383_va,ECL_NIL,Cblock,1);
     v7 = v8;
    }
    {
     cl_object v8;
     cl_object v9;
     cl_object v10;
     {
      cl_object v11;
      v11 = v5;
      if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v8 = v11;
     }
     v9 = ECL_NIL;
     v10 = v8;
     {
      cl_object v11;
      cl_object v12;
      v11 = ecl_list1(ECL_NIL);
      v12 = v11;
L152:;
      if (!(ecl_endp(v10))){
       goto L154;
      }
      goto L153;
L154:;
      v9 = ECL_CONS_CAR(v10);
      {
       cl_object v13;
       v13 = ECL_CONS_CDR(v10);
       if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v10 = v13;
      }
      {
       cl_object v13;
       v13 = v12;
       if (ecl_unlikely(ECL_ATOM(v13))) FEtype_error_cons(v13);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T3 = v13;
      }
      T4 = ecl_function_dispatch(cl_env_copy,v7)(1, v9);
      v12 = ecl_list1(T4);
      (ECL_CONS_CDR(T3)=v12,T3);
      goto L152;
L153:;
      T2 = ecl_cdr(v11);
      goto L143;
     }
    }
   }
L143:;
   T3 = CONS(ECL_SYM("VALUES",899),T2);
   T4 = ecl_list1(T3);
   T5 = ecl_append(v3,T4);
   T6 = cl_listX(3, ECL_SYM("FLET",375), T1, T5);
   value0 = cl_list(3, ECL_SYM("LET",479), T0, T6);
   return value0;
  }
 }
}
static cl_object LC4272while_collecting_va(cl_narg narg, cl_object v7, cl_object v8, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[241]);
 {
  return LC4272while_collecting(v7, v8);
 }
}
/* local function APPENDF                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4274appendf(cl_object v1, cl_object v2si__env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4si___reference;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4si___reference = v5;
  }
  {
   cl_object v5;                                  /*  VARS                    */
   cl_object v6;                                  /*  VALS                    */
   cl_object v7;                                  /*  STORES                  */
   cl_object v8;                                  /*  SETTER                  */
   cl_object v9;                                  /*  GETTER                  */
   value0 = (cl_env_copy->function=(ECL_SYM("GET-SETF-EXPANSION",412)->symbol.gfdef))->cfun.entry(2, v4si___reference, v2si__env) /*  GET-SETF-EXPANSION */;
   {
    v5 = value0;
    v6 = cl_env_copy->values[1];
    v7 = cl_env_copy->values[2];
    v8 = cl_env_copy->values[3];
    v9 = cl_env_copy->values[4];
   }
   {
    cl_object v10si__all_vars;
    {
     cl_object v11;
     v11 = ecl_make_cfun_va((cl_objectfn)LC4273__lambda1393_va,ECL_NIL,Cblock,1);
     T0 = v11;
    }
    T1 = v3;
    v10si__all_vars = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T0, T1) /*  MAPCAR */;
    if (!(ECL_SYMBOLP(v9))){
     goto L12;
    }
    T0 = (ECL_SYM("CAR",182)->symbol.gfdef);
    T1 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T0, v10si__all_vars) /*  MAPCAR */;
    T2 = cl_listX(3, ECL_SYM("APPEND",90), v9, T1);
    T3 = ecl_car(v7);
    T4 = (ECL_SYM("FIRST",373)->symbol.gfdef);
    T5 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T4, v10si__all_vars) /*  MAPCAR */;
    T6 = CONS(VV[251],T5);
    T7 = cl_list(2, ECL_SYM("DECLARE",276), T6);
    T8 = cl_list(4, ECL_SYM("LET*",480), v10si__all_vars, T7, v8);
    value0 = cl_subst(3, T2, T3, T8);
    return value0;
L12:;
    {
     cl_object v11si__d;
     cl_object v12si__v;
     cl_object v13si__let_list;
     v11si__d = v5;
     v12si__v = v6;
     v13si__let_list = ECL_NIL;
     goto L21;
L20:;
     T0 = ecl_cdr(v11si__d);
     T1 = ecl_cdr(v12si__v);
     T2 = ecl_car(v11si__d);
     T3 = ecl_car(v12si__v);
     T4 = cl_list(2, T2, T3);
     v13si__let_list = CONS(T4,v13si__let_list);
     v12si__v = T1;
     v11si__d = T0;
L21:;
     if (v11si__d==ECL_NIL) {
      goto L27;
     }
     goto L20;
L27:;
     T0 = ecl_car(v7);
     T1 = (ECL_SYM("CAR",182)->symbol.gfdef);
     T2 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T1, v10si__all_vars) /*  MAPCAR */;
     T3 = cl_listX(3, ECL_SYM("APPEND",90), v9, T2);
     T4 = cl_list(2, T0, T3);
     T5 = ecl_append(v10si__all_vars,v13si__let_list);
     v13si__let_list = CONS(T4,T5);
     T0 = cl_nreverse(v13si__let_list);
     T1 = (ECL_SYM("FIRST",373)->symbol.gfdef);
     T2 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T1, v10si__all_vars) /*  MAPCAR */;
     T3 = ecl_append(T2,v5);
     T4 = CONS(VV[251],T3);
     T5 = cl_list(2, ECL_SYM("DECLARE",276), T4);
     value0 = cl_list(4, ECL_SYM("LET*",480), T0, T5, v8);
     return value0;
    }
   }
  }
 }
}
static cl_object LC4274appendf_va(cl_narg narg, cl_object v5, cl_object v6si__env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[249]);
 {
  return LC4274appendf(v5, v6si__env);
 }
}
/* function definition for LENGTH=N-P                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4275length_n_p(cl_object v1uiop_utility__x, cl_object v2uiop_utility__n)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = v2uiop_utility__n;
  {
   cl_object v4;
   cl_object v5;
   v4 = ecl_make_int8_t(0);
   v5 = v4;
   if (!(ECL_FIXNUMP(v3)||ECL_BIGNUMP(v3))){
    goto L9;
   }
   v5 = v3;
   if (ecl_greatereq(v5,ecl_make_int8_t(0))) {
    goto L4;
   }
   goto L5;
L9:;
   goto L5;
  }
L5:;
  v2uiop_utility__n = si_do_check_type(v3, VV[254], ECL_NIL, VV[255]);
L4:;
 }
 {
  cl_object v3uiop_utility__l;
  v3uiop_utility__l = ECL_NIL;
  {
   cl_object v4uiop_utility__i;
   {
    cl_object v5;
    v5 = v2uiop_utility__n;
    {
     bool v6;
     v6 = ecl_numberp(v5);
     if (ecl_unlikely(!(v6)))
         FEwrong_type_argument(ECL_SYM("NUMBER",608),v5);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
    v4uiop_utility__i = v5;
   }
   v3uiop_utility__l = v1uiop_utility__x;
L18:;
   if (!(ecl_zerop(v4uiop_utility__i))){
    goto L22;
   }
   value0 = ecl_make_bool(v3uiop_utility__l==ECL_NIL);
   cl_env_copy->nvalues = 1;
   return value0;
L22:;
   if (ECL_CONSP(v3uiop_utility__l)) {
    goto L21;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L21:;
   v3uiop_utility__l = ecl_cdr(v3uiop_utility__l);
   v4uiop_utility__i = ecl_one_minus(v4uiop_utility__i);
   goto L18;
  }
 }
}
static cl_object L4275length_n_p_va(cl_narg narg, cl_object v5uiop_utility__x, cl_object v6uiop_utility__n, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[253]);
 {
  return L4275length_n_p(v5uiop_utility__x, v6uiop_utility__n);
 }
}
/* function definition for ENSURE-LIST                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4276ensure_list(cl_object v1uiop_utility__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(v1uiop_utility__x))){
  goto L2;
 }
 value0 = v1uiop_utility__x;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ecl_list1(v1uiop_utility__x);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4276ensure_list_va(cl_narg narg, cl_object v2uiop_utility__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[257]);
 {
  return L4276ensure_list(v2uiop_utility__x);
 }
}
/* function definition for REMOVE-PLIST-KEY                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4277remove_plist_key(cl_object v1uiop_utility__key, cl_object v2uiop_utility__plist)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4uiop_utility__k;
  cl_object v5uiop_utility__v;
  v3 = v2uiop_utility__plist;
  v4uiop_utility__k = ECL_NIL;
  v5uiop_utility__v = ECL_NIL;
  {
   cl_object v6;
   cl_object v7;
   v6 = ecl_list1(ECL_NIL);
   v7 = v6;
L7:;
   if (!(ECL_ATOM(v3))){
    goto L9;
   }
   goto L8;
L9:;
   {
    cl_object v8;
    v8 = v3;
    v4uiop_utility__k = ecl_car(v8);
    v8 = ecl_cdr(v8);
    v5uiop_utility__v = ecl_car(v8);
   }
   v3 = ecl_cddr(v3);
   if ((v4uiop_utility__k)==(v1uiop_utility__key)) {
    goto L20;
   }
   {
    cl_object v8;
    v8 = cl_list(2, v4uiop_utility__k, v5uiop_utility__v);
    {
     cl_object v9;
     v9 = v7;
     if (ecl_unlikely(ECL_ATOM(v9))) FEtype_error_cons(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T1 = v9;
    }
    (ECL_CONS_CDR(T1)=v8,T1);
    T0 = v8;
   }
   v7 = ecl_cdr(T0);
L20:;
   goto L7;
L8:;
   value0 = ecl_cdr(v6);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4277remove_plist_key_va(cl_narg narg, cl_object v8uiop_utility__key, cl_object v9uiop_utility__plist, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[259]);
 {
  return L4277remove_plist_key(v8uiop_utility__key, v9uiop_utility__plist);
 }
}
/* function definition for REMOVE-PLIST-KEYS                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4278remove_plist_keys(cl_object v1uiop_utility__keys, cl_object v2uiop_utility__plist)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4uiop_utility__k;
  cl_object v5uiop_utility__v;
  v3 = v2uiop_utility__plist;
  v4uiop_utility__k = ECL_NIL;
  v5uiop_utility__v = ECL_NIL;
  {
   cl_object v6;
   cl_object v7;
   v6 = ecl_list1(ECL_NIL);
   v7 = v6;
L7:;
   if (!(ECL_ATOM(v3))){
    goto L9;
   }
   goto L8;
L9:;
   {
    cl_object v8;
    v8 = v3;
    v4uiop_utility__k = ecl_car(v8);
    v8 = ecl_cdr(v8);
    v5uiop_utility__v = ecl_car(v8);
   }
   v3 = ecl_cddr(v3);
   {
    cl_object v8;
    cl_object v9;
    v8 = v4uiop_utility__k;
    v9 = v1uiop_utility__keys;
    if (ecl_memql(v8,v9)!=ECL_NIL) {
     goto L20;
    }
   }
   {
    cl_object v8;
    v8 = cl_list(2, v4uiop_utility__k, v5uiop_utility__v);
    {
     cl_object v9;
     v9 = v7;
     if (ecl_unlikely(ECL_ATOM(v9))) FEtype_error_cons(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T1 = v9;
    }
    (ECL_CONS_CDR(T1)=v8,T1);
    T0 = v8;
   }
   v7 = ecl_cdr(T0);
L20:;
   goto L7;
L8:;
   value0 = ecl_cdr(v6);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4278remove_plist_keys_va(cl_narg narg, cl_object v8uiop_utility__keys, cl_object v9uiop_utility__plist, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[261]);
 {
  return L4278remove_plist_keys(v8uiop_utility__keys, v9uiop_utility__plist);
 }
}
/* function definition for EMPTYP                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4279emptyp(cl_object v1uiop_utility__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_make_bool(v1uiop_utility__x==ECL_NIL);
 if (value0!=ECL_NIL) {
  goto L3;
 }
 if (!(ECL_VECTORP(v1uiop_utility__x))){
  goto L6;
 }
 {
  cl_fixnum v2;
  v2 = ecl_length(v1uiop_utility__x);
  value0 = ecl_make_bool((v2)==0);
  cl_env_copy->nvalues = 1;
  return value0;
 }
L6:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4279emptyp_va(cl_narg narg, cl_object v2uiop_utility__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[263]);
 {
  return L4279emptyp(v2uiop_utility__x);
 }
}
/* function definition for CHARACTER-TYPE-INDEX                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4280character_type_index(cl_object v1uiop_utility__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_CHARACTERP(v1uiop_utility__x))){
  goto L2;
 }
 if (Null(si_base_char_p(v1uiop_utility__x))){
  goto L4;
 }
 value0 = ecl_make_int8_t(0);
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 value0 = ecl_make_int8_t(1);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!(ECL_SYMBOLP(v1uiop_utility__x))){
  goto L6;
 }
 if (Null(cl_subtypep(2, v1uiop_utility__x, ECL_SYM("BASE-CHAR",122)))){
  goto L8;
 }
 value0 = ecl_make_int8_t(0);
 cl_env_copy->nvalues = 1;
 return value0;
L8:;
 value0 = ecl_make_int8_t(1);
 cl_env_copy->nvalues = 1;
 return value0;
L6:;
 value0 = si_etypecase_error(v1uiop_utility__x, VV[270]);
 return value0;
}
static cl_object L4280character_type_index_va(cl_narg narg, cl_object v2uiop_utility__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[269]);
 {
  return L4280character_type_index(v2uiop_utility__x);
 }
}
/* function definition for BASE-STRING-P                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4281base_string_p(cl_object v1string)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_array_element_type(v1string);
 value0 = ecl_make_bool((ECL_SYM("BASE-CHAR",122))==(T0));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4281base_string_p_va(cl_narg narg, cl_object v2string, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[272]);
 {
  return L4281base_string_p(v2string);
 }
}
/* function definition for STRINGS-COMMON-ELEMENT-TYPE                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4283strings_common_element_type(cl_object volatile v1uiop_utility__strings)
{
 cl_object T0, T1, T2;
 cl_object volatile env0 = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object volatile CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v2;
  v2 = ecl_cmp_symbol_value(cl_env_copy,VV[265]);
  T0 = v2;
  {
   volatile cl_object v3;
   {
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env0); /*  NIL           */
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV0));
     if (__ecl_frs_push_result!=0) {
     v3 = cl_env_copy->values[0];
     ecl_frs_pop_n(cl_env_copy, 1);
     } else {
     {
      cl_object v4uiop_utility__s;
      cl_object v5;
      v4uiop_utility__s = ECL_NIL;
      v5 = v1uiop_utility__strings;
L8:;
      if (!(v5==ECL_NIL)){
       goto L10;
      }
      goto L9;
L10:;
      v4uiop_utility__s = ECL_CONS_CAR(v5);
      v5 = ECL_CONS_CDR(v5);
      {
       cl_object v6;
       v6 = (cl_env_copy->function=(VV[263]->symbol.gfdef))->cfun.entry(1, v4uiop_utility__s) /*  EMPTYP */;
       if (Null(v6)){
        goto L18;
       }
       goto L16;
L18:;
       if (!(ECL_CHARACTERP(v4uiop_utility__s))){
        goto L20;
       }
       T2 = (cl_env_copy->function=(VV[269]->symbol.gfdef))->cfun.entry(1, v4uiop_utility__s) /*  CHARACTER-TYPE-INDEX */;
       (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4282consider(1, T2));
       goto L16;
L20:;
       if (!(ECL_STRINGP(v4uiop_utility__s))){
        goto L22;
       }
       {
        cl_object v7uiop_utility__string_type_index;
        T2 = cl_array_element_type(v4uiop_utility__s);
        v7uiop_utility__string_type_index = (cl_env_copy->function=(VV[269]->symbol.gfdef))->cfun.entry(1, T2) /*  CHARACTER-TYPE-INDEX */;
        if (ecl_greatereq(ecl_make_int8_t(0),v7uiop_utility__string_type_index)) {
         goto L16;
        }
        {
         cl_object v8uiop_utility__c;
         cl_fixnum v9;
         cl_fixnum v10;
         v8uiop_utility__c = ECL_NIL;
         v9 = (cl_fixnum)(0);
         v10 = (cl_fixnum)(0);
         {
          cl_object v11uiop_utility__i;
          v11uiop_utility__i = ECL_NIL;
          v10 = (v4uiop_utility__s)->vector.fillp;
L30:;
          if (!((v9)>=(v10))){
          goto L34;
          }
          goto L31;
L34:;
          v8uiop_utility__c = ecl_aref_unsafe(v4uiop_utility__s,v9);
          v9 = (v9)+1;
          v11uiop_utility__i = (cl_env_copy->function=(VV[269]->symbol.gfdef))->cfun.entry(1, v8uiop_utility__c) /*  CHARACTER-TYPE-INDEX */;
          (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4282consider(1, v11uiop_utility__i));
          goto L30;
L31:;
          goto L16;
         }
        }
       }
L22:;
       cl_error(3, VV[276], v4uiop_utility__s, VV[274]);
      }
L16:;
      goto L8;
L9:;
      v3 = ecl_make_int8_t(0);
      ecl_frs_pop_n(cl_env_copy, 1);
      goto L5;
     }
     }
    }
   }
L5:;
   if (ecl_unlikely((ecl_fixnum(v3))>=(v2)->vector.dim))
           FEwrong_index(ECL_NIL,v2,-1,ecl_make_fixnum(ecl_fixnum(v3)),(v2)->vector.dim);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   T1 = v3;
  }
  value0 = ecl_aref_unsafe(T0,ecl_fixnum(T1));
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4283strings_common_element_type_va(cl_narg narg, cl_object v3uiop_utility__strings, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[274]);
 {
  return L4283strings_common_element_type(v3uiop_utility__strings);
 }
}
/* function definition for REDUCE/STRCAT                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4284reduce_strcat(cl_narg narg, cl_object v1uiop_utility__strings, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[280]);
 {
  cl_object v2uiop_utility__key;
  cl_object v3uiop_utility__start;
  cl_object v4uiop_utility__end;
  ecl_va_list args; ecl_va_start(args,v1uiop_utility__strings,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L4284reduce_strcatkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2uiop_utility__key = keyvars[0];
   v3uiop_utility__start = keyvars[1];
   v4uiop_utility__end = keyvars[2];
  }
  if (v3uiop_utility__start!=ECL_NIL) {
   goto L3;
  }
  if (Null(v4uiop_utility__end)){
   goto L1;
  }
  goto L2;
L3:;
L2:;
  v1uiop_utility__strings = cl_subseq(3, v1uiop_utility__strings, v3uiop_utility__start, v4uiop_utility__end);
L1:;
  if (Null(v2uiop_utility__key)){
   goto L6;
  }
  {
   cl_object v5;
   cl_object v6;
   cl_object v7;
   {
    cl_object v8;
    v8 = v1uiop_utility__strings;
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v8;
   }
   v6 = ECL_NIL;
   v7 = v5;
   {
    cl_object v8;
    cl_object v9;
    v8 = ecl_list1(ECL_NIL);
    v9 = v8;
L16:;
    if (!(ecl_endp(v7))){
     goto L18;
    }
    goto L17;
L18:;
    v6 = ECL_CONS_CAR(v7);
    {
     cl_object v10;
     v10 = ECL_CONS_CDR(v7);
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v7 = v10;
    }
    {
     cl_object v10;
     v10 = v9;
     if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T0 = v10;
    }
    T1 = ecl_function_dispatch(cl_env_copy,v2uiop_utility__key)(1, v6);
    v9 = ecl_list1(T1);
    (ECL_CONS_CDR(T0)=v9,T0);
    goto L16;
L17:;
    v1uiop_utility__strings = ecl_cdr(v8);
    goto L8;
   }
  }
L8:;
L6:;
  {
   cl_object v5uiop_utility__output;
   {
    cl_object v6;
    cl_object v7uiop_utility__s;
    cl_object v8;
    {
     cl_object v9;
     v9 = v1uiop_utility__strings;
     if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v6 = v9;
    }
    v7uiop_utility__s = ECL_NIL;
    v8 = v6;
    {
     cl_object v9;
     v9 = ecl_make_int8_t(0);
L42:;
     if (!(ecl_endp(v8))){
      goto L44;
     }
     goto L43;
L44:;
     v7uiop_utility__s = ECL_CONS_CAR(v8);
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v8);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v8 = v10;
     }
     if (!(ECL_CHARACTERP(v7uiop_utility__s))){
      goto L55;
     }
     T1 = ecl_make_int8_t(1);
     goto L54;
L55:;
     T1 = ecl_make_fixnum(ecl_length(v7uiop_utility__s));
L54:;
     v9 = ecl_plus(v9,T1);
     goto L42;
L43:;
     T0 = v9;
     goto L35;
    }
   }
L35:;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[274]))->cfun.entry(1, v1uiop_utility__strings) /*  STRINGS-COMMON-ELEMENT-TYPE */;
   v5uiop_utility__output = cl_make_string(3, T0, ECL_SYM("ELEMENT-TYPE",1255), T1);
   {
    cl_object v6uiop_utility__pos;
    v6uiop_utility__pos = ecl_make_int8_t(0);
    {
     cl_object v7;
     cl_object v8uiop_utility__input;
     cl_object v9;
     {
      cl_object v10;
      v10 = v1uiop_utility__strings;
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v7 = v10;
     }
     v8uiop_utility__input = ECL_NIL;
     v9 = v7;
L65:;
     if (!(ecl_endp(v9))){
      goto L67;
     }
     goto L66;
L67:;
     v8uiop_utility__input = ECL_CONS_CAR(v9);
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v9);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v9 = v10;
     }
     if (v8uiop_utility__input==ECL_NIL) {
      goto L75;
     }
     if (!(ECL_CHARACTERP(v8uiop_utility__input))){
      goto L77;
     }
     si_char_set(v5uiop_utility__output,v6uiop_utility__pos,v8uiop_utility__input);
     v6uiop_utility__pos = ecl_plus(v6uiop_utility__pos,ecl_make_int8_t(1));
     goto L75;
L77:;
     if (!(ECL_STRINGP(v8uiop_utility__input))){
      goto L81;
     }
     cl_replace(4, v5uiop_utility__output, v8uiop_utility__input, ECL_SYM("START1",1348), v6uiop_utility__pos);
     {
      cl_object v10;
      v10 = ecl_make_fixnum(ecl_length(v8uiop_utility__input));
      v6uiop_utility__pos = ecl_plus(v6uiop_utility__pos,v10);
      goto L75;
     }
L81:;
     si_etypecase_error(v8uiop_utility__input, VV[281]);
L75:;
     goto L65;
L66:;
     value0 = v5uiop_utility__output;
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
}
/* function definition for STRCAT                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4285strcat(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_utility__strings;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_utility__strings = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[280]))->cfun.entry(1, v1uiop_utility__strings) /*  REDUCE/STRCAT */;
  return value0;
 }
}
/* function definition for FIRST-CHAR                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4286first_char(cl_object v1uiop_utility__s)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_STRINGP(v1uiop_utility__s))){
  goto L3;
 }
 {
  cl_fixnum v2;
  v2 = ecl_length(v1uiop_utility__s);
  if (!((v2)>0)){
   goto L3;
  }
 }
 value0 = ECL_CODE_CHAR(ecl_char(v1uiop_utility__s,(cl_fixnum)(0)));
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4286first_char_va(cl_narg narg, cl_object v2uiop_utility__s, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[285]);
 {
  return L4286first_char(v2uiop_utility__s);
 }
}
/* function definition for LAST-CHAR                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4287last_char(cl_object v1uiop_utility__s)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_STRINGP(v1uiop_utility__s))){
  goto L3;
 }
 {
  cl_fixnum v2;
  v2 = ecl_length(v1uiop_utility__s);
  if (!((v2)>0)){
   goto L3;
  }
 }
 {
  cl_fixnum v2;
  v2 = ecl_length(v1uiop_utility__s);
  T0 = ecl_make_integer((v2)-1);
  value0 = cl_char(v1uiop_utility__s, T0);
  return value0;
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4287last_char_va(cl_narg narg, cl_object v2uiop_utility__s, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[287]);
 {
  return L4287last_char(v2uiop_utility__s);
 }
}
/* function definition for SPLIT-STRING                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4290split_string(volatile cl_narg narg, cl_object volatile v1string, ...)
{
 cl_object T0, T1;
 cl_object volatile env0 = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[289]);
 {
  cl_object volatile v2max;
  ecl_va_list args; ecl_va_start(args,v1string,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1string,env0);              /*  STRING                  */
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4290split_stringkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2max = keyvars[0];
   if (Null(keyvars[3])) {
    CLV1 = env0 = CONS(VV[290],env0);             /*  SEPARATOR               */
   } else {
    CLV1 = env0 = CONS(keyvars[1],env0);          /*  SEPARATOR               */
   }
  }
  {
   CLV2 = env0 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env0); /*  NIL            */
   {
    ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV2));
    if (__ecl_frs_push_result!=0) {
    ecl_frs_pop_n(cl_env_copy, 1);
    return cl_env_copy->values[0];
    } else {
    {
     cl_object v3;
     cl_object v4uiop_utility__words;
     cl_object env1 = env0;
     v3 = ecl_make_fixnum(ecl_length(ECL_CONS_CAR(CLV0)));
     CLV3 = env1 = CONS(ECL_NIL,env1);            /*  LIST                    */
     v4uiop_utility__words = ecl_make_int8_t(0);
     CLV4 = env1 = CONS(v3,env1);                 /*  END                     */
     if (!(ecl_zerop(ECL_CONS_CAR(CLV4)))){
      goto L3;
     }
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     ecl_frs_pop_n(cl_env_copy, 1);
     return value0;
L3:;
     {
      cl_object v5;
      v5 = ecl_make_cclosure_va((cl_objectfn)LC4288separatorp,env1,Cblock,1);
      {
       cl_object v6uiop_utility__start;
       v6uiop_utility__start = ECL_NIL;
L6:;
       if (Null(v2max)){
        goto L9;
       }
       T0 = ecl_one_minus(v2max);
       if (!(ecl_greatereq(v4uiop_utility__words,T0))){
        goto L9;
       }
       v6uiop_utility__start = (aux_closure.env=env1,cl_env_copy->function=(cl_object)&aux_closure,LC4289done(0));
       goto L8;
L9:;
       v6uiop_utility__start = cl_position_if(6, v5, ECL_CONS_CAR(CLV0), ECL_SYM("END",1256), ECL_CONS_CAR(CLV4), VV[91], ECL_T);
L8:;
       if (!(v6uiop_utility__start==ECL_NIL)){
        goto L13;
       }
       (aux_closure.env=env1,cl_env_copy->function=(cl_object)&aux_closure,LC4289done(0));
L13:;
       T0 = ecl_one_plus(v6uiop_utility__start);
       T1 = cl_subseq(3, ECL_CONS_CAR(CLV0), T0, ECL_CONS_CAR(CLV4));
       ECL_CONS_CAR(CLV3) = CONS(T1,ECL_CONS_CAR(CLV3));
       v4uiop_utility__words = ecl_plus(v4uiop_utility__words,ecl_make_int8_t(1));
       ECL_CONS_CAR(CLV4) = v6uiop_utility__start;
       goto L6;
      }
     }
    }
    }
   }
  }
 }
}
/* function definition for STRING-PREFIX-P                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4291string_prefix_p(cl_object v1uiop_utility__prefix, cl_object v2string)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3uiop_utility__x;
  cl_object v4uiop_utility__y;
  cl_object v5uiop_utility__lx;
  cl_object v6uiop_utility__ly;
  v3uiop_utility__x = cl_string(v1uiop_utility__prefix);
  v4uiop_utility__y = cl_string(v2string);
  v5uiop_utility__lx = ecl_make_fixnum(ecl_length(v3uiop_utility__x));
  v6uiop_utility__ly = ecl_make_fixnum(ecl_length(v4uiop_utility__y));
  if (!((ecl_fixnum(v5uiop_utility__lx))<=(ecl_fixnum(v6uiop_utility__ly)))){
   goto L7;
  }
  value0 = cl_stringE(4, v3uiop_utility__x, v4uiop_utility__y, ECL_SYM("END2",1258), v5uiop_utility__lx);
  return value0;
L7:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4291string_prefix_p_va(cl_narg narg, cl_object v7uiop_utility__prefix, cl_object v8string, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[298]);
 {
  return L4291string_prefix_p(v7uiop_utility__prefix, v8string);
 }
}
/* function definition for STRING-SUFFIX-P                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4292string_suffix_p(cl_object v1string, cl_object v2uiop_utility__suffix)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3uiop_utility__x;
  cl_object v4uiop_utility__y;
  cl_object v5uiop_utility__lx;
  cl_object v6uiop_utility__ly;
  v3uiop_utility__x = cl_string(v1string);
  v4uiop_utility__y = cl_string(v2uiop_utility__suffix);
  v5uiop_utility__lx = ecl_make_fixnum(ecl_length(v3uiop_utility__x));
  v6uiop_utility__ly = ecl_make_fixnum(ecl_length(v4uiop_utility__y));
  if (!((ecl_fixnum(v6uiop_utility__ly))<=(ecl_fixnum(v5uiop_utility__lx)))){
   goto L7;
  }
  T0 = ecl_minus(v5uiop_utility__lx,v6uiop_utility__ly);
  value0 = cl_stringE(4, v3uiop_utility__x, v4uiop_utility__y, ECL_SYM("START1",1348), T0);
  return value0;
L7:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4292string_suffix_p_va(cl_narg narg, cl_object v7string, cl_object v8uiop_utility__suffix, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[300]);
 {
  return L4292string_suffix_p(v7string, v8uiop_utility__suffix);
 }
}
/* function definition for STRING-ENCLOSED-P                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4293string_enclosed_p(cl_object v1uiop_utility__prefix, cl_object v2string, cl_object v3uiop_utility__suffix)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[298]))->cfun.entry(2, v1uiop_utility__prefix, v2string) /*  STRING-PREFIX-P */)){
  goto L3;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[300]))->cfun.entry(2, v2string, v3uiop_utility__suffix) /*  STRING-SUFFIX-P */;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4293string_enclosed_p_va(cl_narg narg, cl_object v4uiop_utility__prefix, cl_object v5string, cl_object v6uiop_utility__suffix, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[302]);
 {
  return L4293string_enclosed_p(v4uiop_utility__prefix, v5string, v6uiop_utility__suffix);
 }
}
/* function definition for STRIPLN                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4295stripln(cl_object volatile v1uiop_utility__x)
{
 cl_object volatile env0 = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1uiop_utility__x,env0);      /*  X                       */
 {
  cl_object v2;
  v2 = ECL_CONS_CAR(CLV0);
  if (ECL_STRINGP(v2)) {
   goto L3;
  }
  ECL_CONS_CAR(CLV0) = si_do_check_type(v2, ECL_SYM("STRING",808), ECL_NIL, VV[245]);
L3:;
 }
 {
  CLV1 = env0 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env0); /*  NIL             */
  {
   ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
   if (__ecl_frs_push_result!=0) {
   ecl_frs_pop_n(cl_env_copy, 1);
   return cl_env_copy->values[0];
   } else {
   if (Null(ECL_CONS_CAR(CLV0))){
    goto L6;
   }
   (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4294c(1, ecl_cmp_symbol_value(cl_env_copy,VV[307])));
   (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4294c(1, ecl_cmp_symbol_value(cl_env_copy,VV[306])));
   (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4294c(1, ecl_cmp_symbol_value(cl_env_copy,VV[304])));
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = ECL_NIL;
   cl_env_copy->values[0] = ECL_CONS_CAR(CLV0);
   ecl_frs_pop_n(cl_env_copy, 1);
   return cl_env_copy->values[0];
L6:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   ecl_frs_pop_n(cl_env_copy, 1);
   return value0;
   }
  }
 }
}
static cl_object L4295stripln_va(cl_narg narg, cl_object v2uiop_utility__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[308]);
 {
  return L4295stripln(v2uiop_utility__x);
 }
}
/* function definition for STANDARD-CASE-SYMBOL-NAME                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4296standard_case_symbol_name(cl_object v1uiop_utility__name_designator)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = v1uiop_utility__name_designator;
  if (ECL_STRINGP(v2)) {
   goto L4;
  }
  if (ECL_SYMBOLP(v2)) {
   goto L4;
  }
  v1uiop_utility__name_designator = si_do_check_type(v2, VV[312], ECL_NIL, VV[313]);
L4:;
 }
 if (!(ECL_SYMBOLP(v1uiop_utility__name_designator))){
  goto L8;
 }
 value0 = cl_string(v1uiop_utility__name_designator);
 return value0;
L8:;
 value0 = cl_string_upcase(1, v1uiop_utility__name_designator);
 return value0;
}
static cl_object L4296standard_case_symbol_name_va(cl_narg narg, cl_object v2uiop_utility__name_designator, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[311]);
 {
  return L4296standard_case_symbol_name(v2uiop_utility__name_designator);
 }
}
/* function definition for FIND-STANDARD-CASE-SYMBOL                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4297find_standard_case_symbol(cl_narg narg, cl_object v1uiop_utility__name_designator, cl_object v2uiop_utility__package_designator, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[315]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[315]);
 {
  cl_object v3error;
  va_list args; va_start(args,v2uiop_utility__package_designator);
  {
   int i = 2;
   if (i >= narg) {
    v3error = ECL_T;
   } else {
    i++;
    v3error = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[311]))->cfun.entry(1, v1uiop_utility__name_designator) /*  STANDARD-CASE-SYMBOL-NAME */;
  if (cl_packagep(v2uiop_utility__package_designator)!=ECL_NIL) {
   goto L5;
  }
  if (!(ECL_SYMBOLP(v2uiop_utility__package_designator))){
   goto L3;
  }
  goto L4;
L5:;
L4:;
  T1 = v2uiop_utility__package_designator;
  goto L2;
L3:;
  if (!(ECL_STRINGP(v2uiop_utility__package_designator))){
   goto L7;
  }
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[311]))->cfun.entry(1, v2uiop_utility__package_designator) /*  STANDARD-CASE-SYMBOL-NAME */;
  goto L2;
L7:;
  T1 = si_etypecase_error(v2uiop_utility__package_designator, VV[316]);
L2:;
  value0 = L4198find_symbol_(3, T0, T1, v3error);
  return value0;
 }
}
/* function definition for STAMP<                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4298stamp_(cl_object v1uiop_utility__x, cl_object v2uiop_utility__y)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(v1uiop_utility__x==ECL_NIL)){
  goto L2;
 }
 if (Null(v2uiop_utility__y)){
  goto L5;
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L5:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (Null(cl_typep(2, v1uiop_utility__x, VV[40]))){
  goto L7;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L7:;
 if (Null(cl_realp(v1uiop_utility__x))){
  goto L9;
 }
 if (!(v2uiop_utility__y==ECL_NIL)){
  goto L11;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L11:;
 if (Null(cl_typep(2, v2uiop_utility__y, VV[40]))){
  goto L13;
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L13:;
 if (Null(cl_realp(v2uiop_utility__y))){
  goto L15;
 }
 value0 = ecl_make_bool(ecl_lower(v1uiop_utility__x,v2uiop_utility__y));
 cl_env_copy->nvalues = 1;
 return value0;
L15:;
 value0 = si_etypecase_error(v2uiop_utility__y, VV[320]);
 return value0;
L9:;
 value0 = si_etypecase_error(v1uiop_utility__x, VV[320]);
 return value0;
}
static cl_object L4298stamp__va(cl_narg narg, cl_object v3uiop_utility__x, cl_object v4uiop_utility__y, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[319]);
 {
  return L4298stamp_(v3uiop_utility__x, v4uiop_utility__y);
 }
}
/* function definition for STAMPS<                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4299stamps_(cl_object v1list)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3uiop_utility__y;
  cl_object v4;
  {
   cl_object v5;
   v5 = v1list;
   if (ecl_unlikely(!ECL_LISTP(v5))) FEtype_error_list(v5);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v2 = v5;
  }
  v3uiop_utility__y = ECL_NIL;
  v4 = v2;
  {
   cl_object v5uiop_utility__x;
   v5uiop_utility__x = ECL_NIL;
   if (!(ecl_endp(v4))){
    goto L10;
   }
   goto L9;
L10:;
   v3uiop_utility__y = ECL_CONS_CAR(v4);
   {
    cl_object v6;
    v6 = ECL_CONS_CDR(v4);
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v6;
   }
   v5uiop_utility__x = ECL_NIL;
L8:;
   if ((cl_env_copy->function=ecl_fdefinition(VV[319]))->cfun.entry(2, v5uiop_utility__x, v3uiop_utility__y) /*  STAMP< */!=ECL_NIL) {
    goto L20;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L20:;
   if (!(ecl_endp(v4))){
    goto L22;
   }
   goto L9;
L22:;
   v3uiop_utility__y = ECL_CONS_CAR(v4);
   {
    cl_object v6;
    v6 = ECL_CONS_CDR(v4);
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v6;
   }
   v5uiop_utility__x = v3uiop_utility__y;
   goto L8;
L9:;
   value0 = ECL_T;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4299stamps__va(cl_narg narg, cl_object v6list, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[322]);
 {
  return L4299stamps_(v6list);
 }
}
/* function definition for STAMP*<                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4300stamp__(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1list;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1list = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[322]))->cfun.entry(1, v1list) /*  STAMPS< */;
  return value0;
 }
}
/* function definition for STAMP<=                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4301stamp__(cl_object v1uiop_utility__x, cl_object v2uiop_utility__y)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[319]))->cfun.entry(2, v2uiop_utility__y, v1uiop_utility__x) /*  STAMP< */;
 value0 = Null(T0)?ECL_T:ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4301stamp___va(cl_narg narg, cl_object v3uiop_utility__x, cl_object v4uiop_utility__y, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[326]);
 {
  return L4301stamp__(v3uiop_utility__x, v4uiop_utility__y);
 }
}
/* function definition for EARLIER-STAMP                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4302earlier_stamp(cl_object v1uiop_utility__x, cl_object v2uiop_utility__y)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[319]))->cfun.entry(2, v1uiop_utility__x, v2uiop_utility__y) /*  STAMP< */)){
  goto L2;
 }
 value0 = v1uiop_utility__x;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = v2uiop_utility__y;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4302earlier_stamp_va(cl_narg narg, cl_object v3uiop_utility__x, cl_object v4uiop_utility__y, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[328]);
 {
  return L4302earlier_stamp(v3uiop_utility__x, v4uiop_utility__y);
 }
}
/* function definition for STAMPS-EARLIEST                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4303stamps_earliest(cl_object v1list)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_reduce(4, VV[328], v1list, VV[331], ECL_T);
 return value0;
}
static cl_object L4303stamps_earliest_va(cl_narg narg, cl_object v2list, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[330]);
 {
  return L4303stamps_earliest(v2list);
 }
}
/* function definition for EARLIEST-STAMP                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4304earliest_stamp(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1list;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1list = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[330]))->cfun.entry(1, v1list) /*  STAMPS-EARLIEST */;
  return value0;
 }
}
/* function definition for LATER-STAMP                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4305later_stamp(cl_object v1uiop_utility__x, cl_object v2uiop_utility__y)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[319]))->cfun.entry(2, v1uiop_utility__x, v2uiop_utility__y) /*  STAMP< */)){
  goto L2;
 }
 value0 = v2uiop_utility__y;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = v1uiop_utility__x;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4305later_stamp_va(cl_narg narg, cl_object v3uiop_utility__x, cl_object v4uiop_utility__y, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[335]);
 {
  return L4305later_stamp(v3uiop_utility__x, v4uiop_utility__y);
 }
}
/* function definition for STAMPS-LATEST                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4306stamps_latest(cl_object v1list)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_reduce(4, VV[335], v1list, VV[331], ECL_NIL);
 return value0;
}
static cl_object L4306stamps_latest_va(cl_narg narg, cl_object v2list, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[337]);
 {
  return L4306stamps_latest(v2list);
 }
}
/* function definition for LATEST-STAMP                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4307latest_stamp(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1list;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1list = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[337]))->cfun.entry(1, v1list) /*  STAMPS-LATEST */;
  return value0;
 }
}
/* local function LATEST-STAMP-F                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4309latest_stamp_f(cl_object v1, cl_object v2si__env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4si___reference;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4si___reference = v5;
  }
  {
   cl_object v5;                                  /*  VARS                    */
   cl_object v6;                                  /*  VALS                    */
   cl_object v7;                                  /*  STORES                  */
   cl_object v8;                                  /*  SETTER                  */
   cl_object v9;                                  /*  GETTER                  */
   value0 = (cl_env_copy->function=(ECL_SYM("GET-SETF-EXPANSION",412)->symbol.gfdef))->cfun.entry(2, v4si___reference, v2si__env) /*  GET-SETF-EXPANSION */;
   {
    v5 = value0;
    v6 = cl_env_copy->values[1];
    v7 = cl_env_copy->values[2];
    v8 = cl_env_copy->values[3];
    v9 = cl_env_copy->values[4];
   }
   {
    cl_object v10si__all_vars;
    {
     cl_object v11;
     v11 = ecl_make_cfun_va((cl_objectfn)LC4308__lambda1648_va,ECL_NIL,Cblock,1);
     T0 = v11;
    }
    T1 = v3;
    v10si__all_vars = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T0, T1) /*  MAPCAR */;
    if (!(ECL_SYMBOLP(v9))){
     goto L12;
    }
    T0 = (ECL_SYM("CAR",182)->symbol.gfdef);
    T1 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T0, v10si__all_vars) /*  MAPCAR */;
    T2 = cl_listX(3, VV[339], v9, T1);
    T3 = ecl_car(v7);
    T4 = (ECL_SYM("FIRST",373)->symbol.gfdef);
    T5 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T4, v10si__all_vars) /*  MAPCAR */;
    T6 = CONS(VV[251],T5);
    T7 = cl_list(2, ECL_SYM("DECLARE",276), T6);
    T8 = cl_list(4, ECL_SYM("LET*",480), v10si__all_vars, T7, v8);
    value0 = cl_subst(3, T2, T3, T8);
    return value0;
L12:;
    {
     cl_object v11si__d;
     cl_object v12si__v;
     cl_object v13si__let_list;
     v11si__d = v5;
     v12si__v = v6;
     v13si__let_list = ECL_NIL;
     goto L21;
L20:;
     T0 = ecl_cdr(v11si__d);
     T1 = ecl_cdr(v12si__v);
     T2 = ecl_car(v11si__d);
     T3 = ecl_car(v12si__v);
     T4 = cl_list(2, T2, T3);
     v13si__let_list = CONS(T4,v13si__let_list);
     v12si__v = T1;
     v11si__d = T0;
L21:;
     if (v11si__d==ECL_NIL) {
      goto L27;
     }
     goto L20;
L27:;
     T0 = ecl_car(v7);
     T1 = (ECL_SYM("CAR",182)->symbol.gfdef);
     T2 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T1, v10si__all_vars) /*  MAPCAR */;
     T3 = cl_listX(3, VV[339], v9, T2);
     T4 = cl_list(2, T0, T3);
     T5 = ecl_append(v10si__all_vars,v13si__let_list);
     v13si__let_list = CONS(T4,T5);
     T0 = cl_nreverse(v13si__let_list);
     T1 = (ECL_SYM("FIRST",373)->symbol.gfdef);
     T2 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T1, v10si__all_vars) /*  MAPCAR */;
     T3 = ecl_append(T2,v5);
     T4 = CONS(VV[251],T3);
     T5 = cl_list(2, ECL_SYM("DECLARE",276), T4);
     value0 = cl_list(4, ECL_SYM("LET*",480), T0, T5, v8);
     return value0;
    }
   }
  }
 }
}
static cl_object LC4309latest_stamp_f_va(cl_narg narg, cl_object v5, cl_object v6si__env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[341]);
 {
  return LC4309latest_stamp_f(v5, v6si__env);
 }
}
/* function definition for ENSURE-FUNCTION                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4312ensure_function(cl_narg narg, cl_object v1uiop_utility__fun, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[344]);
 {
  cl_object v2package;
  ecl_va_list args; ecl_va_start(args,v1uiop_utility__fun,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1uiop_utility__fun,env0);   /*  FUN                     */
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4312ensure_functionkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v2package = VV[36];
   } else {
    v2package = keyvars[0];
   }
  }
  if (Null(cl_functionp(ECL_CONS_CAR(CLV0)))){
   goto L2;
  }
  value0 = ECL_CONS_CAR(CLV0);
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  if (!((ECL_CONS_CAR(CLV0))==(ECL_NIL))){
   goto L10;
  }
  goto L6;
L10:;
  goto L8;
L8:;
  if (!((ECL_CONS_CAR(CLV0))==(ECL_T))){
   goto L13;
  }
  goto L6;
L13:;
  goto L7;
L7:;
  if (cl_keywordp(ECL_CONS_CAR(CLV0))!=ECL_NIL) {
   goto L6;
  }
  if (ECL_CHARACTERP(ECL_CONS_CAR(CLV0))) {
   goto L6;
  }
  if (ecl_numberp(ECL_CONS_CAR(CLV0))) {
   goto L6;
  }
  if (Null(cl_pathnamep(ECL_CONS_CAR(CLV0)))){
   goto L4;
  }
  goto L5;
L6:;
L5:;
  value0 = cl_constantly(ECL_CONS_CAR(CLV0));
  return value0;
L4:;
  if (Null(cl_hash_table_p(ECL_CONS_CAR(CLV0)))){
   goto L18;
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4310__lambda1670,env0,Cblock,1);
   value0 = v3;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L18:;
  if (!(ECL_SYMBOLP(ECL_CONS_CAR(CLV0)))){
   goto L20;
  }
  value0 = cl_fdefinition(ECL_CONS_CAR(CLV0));
  return value0;
L20:;
  if (!(ECL_CONSP(ECL_CONS_CAR(CLV0)))){
   goto L22;
  }
  T0 = ecl_car(ECL_CONS_CAR(CLV0));
  if (!((ECL_SYM("LAMBDA",454))==(T0))){
   goto L24;
  }
  value0 = cl_eval(ECL_CONS_CAR(CLV0));
  return value0;
L24:;
  {
   cl_object v4;
   v4 = ecl_make_cclosure_va((cl_objectfn)LC4311__lambda1672,env0,Cblock,0);
   value0 = v4;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L22:;
  if (!(ECL_STRINGP(ECL_CONS_CAR(CLV0)))){
   goto L26;
  }
  {
   cl_object v5;
   v5 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("+IO-SYNTAX-PROGV-LIST+",1805));
   {
    cl_object v7, v8; cl_index v6;
    v7 = ECL_CONS_CAR(v5);
    v8 = ECL_CONS_CDR(v5);
    v6 = ecl_progv(cl_env_copy, v7, v8);
    T1 = cl_find_package(v2package);
    ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T1); /*  *PACKAGE*       */
    T0 = cl_read_from_string(1, ECL_CONS_CAR(CLV0));
    ecl_bds_unwind(cl_env_copy,v6);
   }
  }
  T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
  value0 = cl_eval(T1);
  return value0;
L26:;
  value0 = si_etypecase_error(ECL_CONS_CAR(CLV0), VV[347]);
  return value0;
 }
}
/* function definition for ACCESS-AT                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4314access_at(cl_object v1uiop_utility__object, cl_object v2uiop_utility__at)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(v2uiop_utility__at))){
  goto L2;
 }
 {
  cl_object v3;
  v3 = v2uiop_utility__at;
  goto L7;
L6:;
  {
   cl_object v4uiop_utility__accessor;
   v4uiop_utility__accessor = ecl_car(v3);
   v1uiop_utility__object = LC4313access(v1uiop_utility__object, v4uiop_utility__accessor);
  }
  v3 = ecl_cdr(v3);
L7:;
  if (Null(v3)){
   goto L15;
  }
  goto L6;
L15:;
  value0 = v1uiop_utility__object;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L2:;
 value0 = LC4313access(v1uiop_utility__object, v2uiop_utility__at);
 return value0;
}
static cl_object L4314access_at_va(cl_narg narg, cl_object v4uiop_utility__object, cl_object v5uiop_utility__at, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[349]);
 {
  return L4314access_at(v4uiop_utility__object, v5uiop_utility__at);
 }
}
/* function definition for ACCESS-AT-COUNT                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4315access_at_count(cl_object v1uiop_utility__at)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_FIXNUMP(v1uiop_utility__at)||ECL_BIGNUMP(v1uiop_utility__at))){
  goto L2;
 }
 value0 = ecl_one_plus(v1uiop_utility__at);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!(ECL_CONSP(v1uiop_utility__at))){
  goto L4;
 }
 T0 = ecl_car(v1uiop_utility__at);
 if (!(ECL_FIXNUMP(T0)||ECL_BIGNUMP(T0))){
  goto L4;
 }
 T0 = ecl_car(v1uiop_utility__at);
 value0 = ecl_one_plus(T0);
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4315access_at_count_va(cl_narg narg, cl_object v2uiop_utility__at, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[353]);
 {
  return L4315access_at_count(v2uiop_utility__at);
 }
}
/* function definition for CALL-FUNCTION                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4316call_function(cl_narg narg, cl_object v1uiop_utility__function_spec, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[355]);
 {
  cl_object v2uiop_utility__arguments;
  ecl_va_list args; ecl_va_start(args,v1uiop_utility__function_spec,narg,1);
  v2uiop_utility__arguments = cl_grab_rest_args(args);
  ecl_va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[344]))->cfun.entry(1, v1uiop_utility__function_spec) /*  ENSURE-FUNCTION */;
  value0 = cl_apply(2, T0, v2uiop_utility__arguments);
  return value0;
 }
}
/* function definition for CALL-FUNCTIONS                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4317call_functions(cl_object v1uiop_utility__function_specs)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_map(3, ECL_NIL, VV[355], v1uiop_utility__function_specs);
 return value0;
}
static cl_object L4317call_functions_va(cl_narg narg, cl_object v2uiop_utility__function_specs, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[357]);
 {
  return L4317call_functions(v2uiop_utility__function_specs);
 }
}
/* function definition for REGISTER-HOOK-FUNCTION                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4318register_hook_function(cl_narg narg, cl_object v1variable, cl_object v2uiop_utility__hook, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[359]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[359]);
 {
  cl_object v3uiop_utility__call_now_p;
  va_list args; va_start(args,v2uiop_utility__hook);
  {
   int i = 2;
   if (i >= narg) {
    v3uiop_utility__call_now_p = ECL_NIL;
   } else {
    i++;
    v3uiop_utility__call_now_p = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v4;
   T0 = cl_symbol_value(v1variable);
   v4 = cl_adjoin(4, v2uiop_utility__hook, T0, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
   cl_set(v1variable, v4);
  }
  if (Null(v3uiop_utility__call_now_p)){
   goto L4;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(1, v2uiop_utility__hook) /*  CALL-FUNCTION */;
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for COERCE-CLASS                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4319coerce_class(cl_narg narg, cl_object v1class, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[361]);
 {
  cl_object v2package;
  cl_object v3uiop_utility__super;
  cl_object v4error;
  ecl_va_list args; ecl_va_start(args,v1class,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L4319coerce_classkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[3])) {
    v2package = VV[36];
   } else {
    v2package = keyvars[0];
   }
   if (Null(keyvars[4])) {
    v3uiop_utility__super = ECL_T;
   } else {
    v3uiop_utility__super = keyvars[1];
   }
   if (Null(keyvars[5])) {
    v4error = ECL_SYM("ERROR",339);
   } else {
    v4error = keyvars[2];
   }
  }
  {
   cl_object v5uiop_utility__normalized;
   cl_object v6uiop_utility__found;
   if (Null(cl_keywordp(v1class))){
    goto L5;
   }
   value0 = L4198find_symbol_(3, v1class, v2package, ECL_NIL);
   if (value0!=ECL_NIL) {
    goto L8;
   }
   v5uiop_utility__normalized = L4198find_symbol_(3, v1class, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PACKAGE*",45)), ECL_NIL);
   goto L4;
L8:;
   v5uiop_utility__normalized = value0;
   goto L4;
L5:;
   if (!(ECL_STRINGP(v1class))){
    goto L10;
   }
   v5uiop_utility__normalized = L4199symbol_call(5, VV[362], VV[363], v1class, ECL_SYM("PACKAGE",1321), v2package);
   goto L4;
L10:;
   v5uiop_utility__normalized = v1class;
L4:;
   if (si_of_class_p(2, v5uiop_utility__normalized, ECL_SYM("STANDARD-CLASS",977))!=ECL_NIL) {
    goto L15;
   }
   if (Null(si_of_class_p(2, v5uiop_utility__normalized, ECL_SYM("BUILT-IN-CLASS",933)))){
    goto L13;
   }
   goto L14;
L15:;
L14:;
   v6uiop_utility__found = v5uiop_utility__normalized;
   goto L12;
L13:;
   if (v5uiop_utility__normalized==ECL_NIL) {
    goto L19;
   }
   if (Null(cl_keywordp(v5uiop_utility__normalized))){
    goto L17;
   }
   goto L18;
L19:;
L18:;
   v6uiop_utility__found = ECL_NIL;
   goto L12;
L17:;
   if (!(ECL_SYMBOLP(v5uiop_utility__normalized))){
    goto L21;
   }
   v6uiop_utility__found = cl_find_class(3, v5uiop_utility__normalized, ECL_NIL, ECL_NIL);
   goto L12;
L21:;
   v6uiop_utility__found = si_etypecase_error(v5uiop_utility__normalized, VV[364]);
L12:;
   if (Null(v6uiop_utility__found)){
    goto L27;
   }
   if ((v3uiop_utility__super)==(ECL_T)) {
    goto L30;
   }
   if (Null(cl_subtypep(2, v6uiop_utility__found, v3uiop_utility__super))){
    goto L27;
   }
   goto L29;
L30:;
L29:;
   value0 = v6uiop_utility__found;
   goto L25;
L27:;
   value0 = ECL_NIL;
   goto L25;
L25:;
   if (value0!=ECL_NIL) {
    goto L24;
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(4, v4error, VV[365], v1class, v3uiop_utility__super) /*  CALL-FUNCTION */;
   return value0;
L24:;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for ENSURE-GETHASH                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4320ensure_gethash(cl_object v1uiop_utility__key, cl_object v2uiop_utility__table, cl_object v3uiop_utility__default)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;                                   /*  VALUE                   */
  cl_object v5;                                   /*  FOUNDP                  */
  value0 = cl_gethash(2, v1uiop_utility__key, v2uiop_utility__table);
  {
   v4 = value0;
   v5 = cl_env_copy->values[1];
  }
  if (Null(v5)){
   goto L4;
  }
  T0 = v4;
  goto L3;
L4:;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(1, v3uiop_utility__default) /*  CALL-FUNCTION */;
  T0 = si_hash_set(v1uiop_utility__key, v2uiop_utility__table, T1);
L3:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
}
static cl_object L4320ensure_gethash_va(cl_narg narg, cl_object v4uiop_utility__key, cl_object v5uiop_utility__table, cl_object v6uiop_utility__default, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[367]);
 {
  return L4320ensure_gethash(v4uiop_utility__key, v5uiop_utility__table, v6uiop_utility__default);
 }
}
/* function definition for LIST-TO-HASH-SET                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4321list_to_hash_set(cl_object v1list)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_utility__h;
  v2uiop_utility__h = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
  {
   cl_object v3;
   v3 = v1list;
   goto L6;
L5:;
   {
    cl_object v4uiop_utility__x;
    v4uiop_utility__x = ecl_car(v3);
    si_hash_set(v4uiop_utility__x, v2uiop_utility__h, ECL_T);
   }
   v3 = ecl_cdr(v3);
L6:;
   if (Null(v3)){
    goto L13;
   }
   goto L5;
L13:;
   value0 = v2uiop_utility__h;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4321list_to_hash_set_va(cl_narg narg, cl_object v4list, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[369]);
 {
  return L4321list_to_hash_set(v4list);
 }
}
/* function definition for UNPARSE-VERSION                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4322unparse_version(cl_object v1uiop_utility__version_list)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(3, ECL_NIL, VV[372], v1uiop_utility__version_list);
 return value0;
}
static cl_object L4322unparse_version_va(cl_narg narg, cl_object v2uiop_utility__version_list, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[371]);
 {
  return L4322unparse_version(v2uiop_utility__version_list);
 }
}
/* function definition for PARSE-VERSION                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4323parse_version(cl_narg narg, cl_object v1uiop_utility__version_string, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[374]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[374]);
 {
  cl_object v2uiop_utility__on_error;
  va_list args; va_start(args,v1uiop_utility__version_string);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_utility__on_error = ECL_NIL;
   } else {
    i++;
    v2uiop_utility__on_error = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (ECL_STRINGP(v1uiop_utility__version_string)) {
   goto L2;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(4, v2uiop_utility__on_error, VV[375], VV[374], v1uiop_utility__version_string) /*  CALL-FUNCTION */;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  {
   cl_object v3uiop_utility__prev;
   v3uiop_utility__prev = ECL_NIL;
   {
    cl_object v4;
    cl_fixnum v5;
    cl_fixnum v6;
    cl_object v7uiop_utility__c;
    cl_fixnum v8;
    cl_fixnum v9;
    {
     cl_object v10;
     v10 = v1uiop_utility__version_string;
     if (ecl_unlikely(!ECL_VECTORP(v10))) FEtype_error_vector(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v4 = v10;
    }
    v5 = (cl_fixnum)(0);
    v6 = (cl_fixnum)(0);
    v7uiop_utility__c = ECL_NIL;
    v8 = v5;
    v9 = v6;
    v9 = ecl_length(v4);
    v3uiop_utility__prev = ECL_NIL;
L16:;
    if (!((v8)>=(v9))){
     goto L22;
    }
    goto L17;
L22:;
    {
     cl_object v10;
     v10 = v4;
     T0 = v10;
     {
      cl_fixnum v11;
      v11 = v8;
      if (ecl_unlikely((v11)>=(v10)->vector.dim))
           FEwrong_index(ECL_NIL,v10,-1,ecl_make_fixnum(v11),(v10)->vector.dim);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T1 = ecl_make_fixnum(v11);
     }
     v7uiop_utility__c = ecl_aref_unsafe(T0,ecl_fixnum(T1));
    }
    {
     cl_object v10;
     v10 = ecl_make_integer((v8)+1);
     {
      bool v11;
      v11 = ECL_FIXNUMP(v10);
      if (ecl_unlikely(!(v11)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
     v8 = ecl_fixnum(v10);
    }
    if (cl_digit_char_p(1, v7uiop_utility__c)!=ECL_NIL) {
     goto L36;
    }
    if (!(((v7uiop_utility__c)==ECL_CODE_CHAR((ecl_character)(46))))){
     goto L40;
    }
    if (Null(v3uiop_utility__prev)){
     goto L40;
    }
    if (!(((v3uiop_utility__prev)==ECL_CODE_CHAR((ecl_character)(46))))){
     goto L36;
    }
    goto L37;
L40:;
    goto L37;
L37:;
    goto L6;
L36:;
    v3uiop_utility__prev = v7uiop_utility__c;
    goto L16;
L17:;
    if (Null(v7uiop_utility__c)){
     goto L48;
    }
    if (cl_digit_char_p(1, v7uiop_utility__c)!=ECL_NIL) {
     goto L5;
    }
    goto L6;
L48:;
    goto L6;
   }
  }
L6:;
  (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(4, v2uiop_utility__on_error, VV[376], VV[374], v1uiop_utility__version_string) /*  CALL-FUNCTION */;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L5:;
  {
   cl_object v3uiop_utility__version_list;
   cl_object v4uiop_utility__normalized_version;
   {
    cl_object v5;
    v5 = (ECL_SYM("PARSE-INTEGER",630)->symbol.gfdef);
    {
     cl_object v6;
     cl_object v7;
     cl_object v8;
     {
      cl_object v9;
      v9 = (cl_env_copy->function=ecl_fdefinition(VV[289]))->cfun.entry(3, v1uiop_utility__version_string, VV[377], VV[378]) /*  SPLIT-STRING */;
      if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v6 = v9;
     }
     v7 = ECL_NIL;
     v8 = v6;
     {
      cl_object v9;
      cl_object v10;
      v9 = ecl_list1(ECL_NIL);
      v10 = v9;
L60:;
      if (!(ecl_endp(v8))){
       goto L62;
      }
      goto L61;
L62:;
      v7 = ECL_CONS_CAR(v8);
      {
       cl_object v11;
       v11 = ECL_CONS_CDR(v8);
       if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v8 = v11;
      }
      {
       cl_object v11;
       v11 = v10;
       if (ecl_unlikely(ECL_ATOM(v11))) FEtype_error_cons(v11);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v11;
      }
      T1 = ecl_function_dispatch(cl_env_copy,v5)(1, v7);
      v10 = ecl_list1(T1);
      (ECL_CONS_CDR(T0)=v10,T0);
      goto L60;
L61:;
      v3uiop_utility__version_list = ecl_cdr(v9);
      goto L51;
     }
    }
   }
L51:;
   v4uiop_utility__normalized_version = (cl_env_copy->function=ecl_fdefinition(VV[371]))->cfun.entry(1, v3uiop_utility__version_list) /*  UNPARSE-VERSION */;
   if (ecl_equal(v1uiop_utility__version_string,v4uiop_utility__normalized_version)) {
    goto L79;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(4, v2uiop_utility__on_error, VV[379], VV[374], v1uiop_utility__version_string) /*  CALL-FUNCTION */;
L79:;
   value0 = v3uiop_utility__version_list;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for LEXICOGRAPHIC<                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4324lexicographic_(cl_object v1uiop_utility__element_, cl_object v2uiop_utility__x, cl_object v3uiop_utility__y)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(v3uiop_utility__y==ECL_NIL)){
  goto L2;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!(v2uiop_utility__x==ECL_NIL)){
  goto L4;
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 T0 = ecl_car(v2uiop_utility__x);
 T1 = ecl_car(v3uiop_utility__y);
 if (Null(ecl_function_dispatch(cl_env_copy,v1uiop_utility__element_)(2, T0, T1))){
  goto L6;
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L6:;
 T0 = ecl_car(v3uiop_utility__y);
 T1 = ecl_car(v2uiop_utility__x);
 if (Null(ecl_function_dispatch(cl_env_copy,v1uiop_utility__element_)(2, T0, T1))){
  goto L8;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L8:;
 T0 = ecl_cdr(v2uiop_utility__x);
 T1 = ecl_cdr(v3uiop_utility__y);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[381]))->cfun.entry(3, v1uiop_utility__element_, T0, T1) /*  LEXICOGRAPHIC< */;
 return value0;
}
static cl_object L4324lexicographic__va(cl_narg narg, cl_object v4uiop_utility__element_, cl_object v5uiop_utility__x, cl_object v6uiop_utility__y, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[381]);
 {
  return L4324lexicographic_(v4uiop_utility__element_, v5uiop_utility__x, v6uiop_utility__y);
 }
}
/* function definition for LEXICOGRAPHIC<=                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4325lexicographic__(cl_object v1uiop_utility__element_, cl_object v2uiop_utility__x, cl_object v3uiop_utility__y)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[381]))->cfun.entry(3, v1uiop_utility__element_, v3uiop_utility__y, v2uiop_utility__x) /*  LEXICOGRAPHIC< */;
 value0 = Null(T0)?ECL_T:ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4325lexicographic___va(cl_narg narg, cl_object v4uiop_utility__element_, cl_object v5uiop_utility__x, cl_object v6uiop_utility__y, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[383]);
 {
  return L4325lexicographic__(v4uiop_utility__element_, v5uiop_utility__x, v6uiop_utility__y);
 }
}
/* function definition for VERSION<                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4326version_(cl_object v1uiop_utility__version1, cl_object v2uiop_utility__version2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[374]))->cfun.entry(2, v1uiop_utility__version1, ECL_NIL) /*  PARSE-VERSION */;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[374]))->cfun.entry(2, v2uiop_utility__version2, ECL_NIL) /*  PARSE-VERSION */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[381]))->cfun.entry(3, ECL_SYM("<",74), v3, v4) /*  LEXICOGRAPHIC< */;
  return value0;
 }
}
static cl_object L4326version__va(cl_narg narg, cl_object v5uiop_utility__version1, cl_object v6uiop_utility__version2, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[385]);
 {
  return L4326version_(v5uiop_utility__version1, v6uiop_utility__version2);
 }
}
/* function definition for VERSION<=                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4327version__(cl_object v1uiop_utility__version1, cl_object v2uiop_utility__version2)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[385]))->cfun.entry(2, v2uiop_utility__version2, v1uiop_utility__version1) /*  VERSION< */;
 value0 = Null(T0)?ECL_T:ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4327version___va(cl_narg narg, cl_object v3uiop_utility__version1, cl_object v4uiop_utility__version2, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[387]);
 {
  return L4327version__(v3uiop_utility__version1, v4uiop_utility__version2);
 }
}
/* function definition for VERSION-COMPATIBLE-P                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4328version_compatible_p(cl_object v1uiop_utility__provided_version, cl_object v2uiop_utility__required_version)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[374]))->cfun.entry(2, v1uiop_utility__provided_version, ECL_NIL) /*  PARSE-VERSION */;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[374]))->cfun.entry(2, v2uiop_utility__required_version, ECL_NIL) /*  PARSE-VERSION */;
  if (Null(v3)){
   goto L5;
  }
  if (Null(v4)){
   goto L5;
  }
  T0 = ecl_car(v3);
  T1 = ecl_car(v4);
  if (!(ecl_number_equalp(T0,T1))){
   goto L5;
  }
  T0 = ecl_cdr(v4);
  T1 = ecl_cdr(v3);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[383]))->cfun.entry(3, ECL_SYM("<",74), T0, T1) /*  LEXICOGRAPHIC<= */;
  return value0;
L5:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4328version_compatible_p_va(cl_narg narg, cl_object v5uiop_utility__provided_version, cl_object v6uiop_utility__required_version, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[389]);
 {
  return L4328version_compatible_p(v5uiop_utility__provided_version, v6uiop_utility__required_version);
 }
}
/* function definition for MATCH-CONDITION-P                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4331match_condition_p(cl_object volatile v1uiop_utility__x, cl_object volatile v2condition)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_SYMBOLP(v1uiop_utility__x))){
  goto L2;
 }
 value0 = cl_typep(2, v2condition, v1uiop_utility__x);
 return value0;
L2:;
 if (Null(cl_typep(2, v1uiop_utility__x, VV[47]))){
  goto L4;
 }
 {
  volatile cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(ECL_NIL,env1);
  {
   volatile cl_object env2 = env1;
   CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY        */
   {
    ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
    if (__ecl_frs_push_result!=0) {
    if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
     goto L6;
    }
    ecl_internal_error("GO found an inexistent tag");
    } else {
    {
     cl_object v3;
     v3 = ecl_make_cclosure_va((cl_objectfn)LC4329__lambda1790,env2,Cblock,1);
     T0 = v3;
    }
    T1 = CONS(ECL_SYM("ERROR",339),T0);
    T2 = ecl_list1(T1);
    T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
    ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
    T0 = ecl_aref1(v1uiop_utility__x,(cl_fixnum)(0));
    T1 = ecl_aref1(v1uiop_utility__x,(cl_fixnum)(1));
    T2 = L4198find_symbol_(3, T0, T1, ECL_NIL);
    value0 = cl_typep(2, v2condition, T2);
    ecl_frs_pop_n(cl_env_copy, 1);
    ecl_bds_unwind1(cl_env_copy);
    return value0;
L6:;
    {
     cl_object v3condition;
     v3condition = ECL_CONS_CAR(CLV0);
     cl_env_copy->nvalues = 2;
     cl_env_copy->values[1] = v3condition;
     cl_env_copy->values[0] = ECL_NIL;
     ecl_frs_pop_n(cl_env_copy, 1);
     return cl_env_copy->values[0];
    }
    }
   }
  }
 }
L4:;
 if (Null(cl_functionp(v1uiop_utility__x))){
  goto L11;
 }
 value0 = ecl_function_dispatch(cl_env_copy,v1uiop_utility__x)(1, v2condition);
 return value0;
L11:;
 if (!(ECL_STRINGP(v1uiop_utility__x))){
  goto L13;
 }
 if (Null(si_of_class_p(2, v2condition, ECL_SYM("SIMPLE-CONDITION",770)))){
  goto L16;
 }
 {
  volatile cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(ECL_NIL,env1);
  {
   volatile cl_object env2 = env1;
   CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY        */
   {
    ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
    if (__ecl_frs_push_result!=0) {
    if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
     goto L18;
    }
    ecl_internal_error("GO found an inexistent tag");
    } else {
    {
     cl_object v3;
     v3 = ecl_make_cclosure_va((cl_objectfn)LC4330__lambda1795,env2,Cblock,1);
     T0 = v3;
    }
    T1 = CONS(ECL_SYM("ERROR",339),T0);
    T2 = ecl_list1(T1);
    T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
    ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
    T0 = (cl_env_copy->function=(ECL_SYM("SIMPLE-CONDITION-FORMAT-CONTROL",771)->symbol.gfdef))->cfun.entry(1, v2condition) /*  SIMPLE-CONDITION-FORMAT-CONTROL */;
    value0 = ecl_make_bool(ecl_equal(T0,v1uiop_utility__x));
    cl_env_copy->nvalues = 1;
    ecl_frs_pop_n(cl_env_copy, 1);
    ecl_bds_unwind1(cl_env_copy);
    return value0;
L18:;
    {
     cl_object v3condition;
     v3condition = ECL_CONS_CAR(CLV0);
     cl_env_copy->nvalues = 2;
     cl_env_copy->values[1] = v3condition;
     cl_env_copy->values[0] = ECL_NIL;
     ecl_frs_pop_n(cl_env_copy, 1);
     return cl_env_copy->values[0];
    }
    }
   }
  }
 }
L16:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L13:;
 value0 = si_etypecase_error(v1uiop_utility__x, VV[398]);
 return value0;
}
static cl_object L4331match_condition_p_va(cl_narg narg, cl_object v3uiop_utility__x, cl_object v4condition, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[393]);
 {
  return L4331match_condition_p(v3uiop_utility__x, v4condition);
 }
}
/* function definition for MATCH-ANY-CONDITION-P                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4332match_any_condition_p(cl_object v1condition, cl_object v2uiop_utility__conditions)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4uiop_utility__x;
  cl_object v5;
  {
   cl_object v6;
   v6 = v2uiop_utility__conditions;
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3 = v6;
  }
  v4uiop_utility__x = ECL_NIL;
  v5 = v3;
  {
   cl_object v6;
   v6 = ECL_NIL;
L8:;
   if (!(ecl_endp(v5))){
    goto L10;
   }
   goto L9;
L10:;
   v4uiop_utility__x = ECL_CONS_CAR(v5);
   {
    cl_object v7;
    v7 = ECL_CONS_CDR(v5);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v7;
   }
   v6 = (cl_env_copy->function=ecl_fdefinition(VV[393]))->cfun.entry(2, v4uiop_utility__x, v1condition) /*  MATCH-CONDITION-P */;
   if (Null(v6)){
    goto L18;
   }
   value0 = v6;
   cl_env_copy->nvalues = 1;
   return value0;
L18:;
   goto L8;
L9:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4332match_any_condition_p_va(cl_narg narg, cl_object v7condition, cl_object v8uiop_utility__conditions, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[400]);
 {
  return L4332match_any_condition_p(v7condition, v8uiop_utility__conditions);
 }
}
/* function definition for CALL-WITH-MUFFLED-CONDITIONS                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4334call_with_muffled_conditions(cl_object v1uiop_utility__thunk, cl_object v2uiop_utility__conditions)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v2uiop_utility__conditions,env0); /*  CONDITIONS          */
 {
  cl_object v3;
  v3 = ecl_make_cclosure_va((cl_objectfn)LC4333__lambda1807,env0,Cblock,1);
  T0 = v3;
 }
 T1 = CONS(ECL_T,T0);
 T2 = ecl_list1(T1);
 T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
 ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
 value0 = ecl_function_dispatch(cl_env_copy,v1uiop_utility__thunk)(0);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L4334call_with_muffled_conditions_va(cl_narg narg, cl_object v3uiop_utility__thunk, cl_object v4uiop_utility__conditions, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[402]);
 {
  return L4334call_with_muffled_conditions(v3uiop_utility__thunk, v4uiop_utility__conditions);
 }
}
/* local function WITH-MUFFLED-CONDITIONS                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4335with_muffled_conditions(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_utility__conditions;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v7;
   v7 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v7;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v7;
   v7 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_utility__conditions = v7;
  }
  if (Null(v5)){
   goto L16;
  }
  si_dm_too_many_arguments(v1);
L16:;
  T0 = cl_listX(3, ECL_SYM("LAMBDA",454), ECL_NIL, v3);
  T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
  value0 = cl_list(3, VV[402], T1, v6uiop_utility__conditions);
  return value0;
 }
}
static cl_object LC4335with_muffled_conditions_va(cl_narg narg, cl_object v7, cl_object v8, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[405]);
 {
  return LC4335with_muffled_conditions(v7, v8);
 }
}
/* local function LAMBDA1822                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4337__lambda1822()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC4336__lambda1824_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4337__lambda1822_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[408]);
 {
  return LC4337__lambda1822();
 }
}
/* function definition for NOT-IMPLEMENTED-ERROR                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4338not_implemented_error(cl_narg narg, cl_object v1uiop_utility__functionality, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[407]);
 {
  cl_object v2uiop_utility__format_control;
  cl_object v3uiop_utility__format_arguments;
  ecl_va_list args; ecl_va_start(args,v1uiop_utility__functionality,narg,1);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_utility__format_control = ECL_NIL;
   } else {
    i++;
    v2uiop_utility__format_control = ecl_va_arg(args);
   }
  }
  v3uiop_utility__format_arguments = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = cl_error(7, VV[407], VV[414], v1uiop_utility__functionality, ECL_SYM("FORMAT-CONTROL",1272), v2uiop_utility__format_control, ECL_SYM("FORMAT-ARGUMENTS",1271), v3uiop_utility__format_arguments);
  return value0;
 }
}
/* local function LAMBDA1827                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4340__lambda1827()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC4339__lambda1829_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4340__lambda1827_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[417]);
 {
  return LC4340__lambda1827();
 }
}
/* function definition for PARAMETER-ERROR                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4341parameter_error(cl_narg narg, cl_object v1uiop_utility__format_control, cl_object v2uiop_utility__functionality, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[416]);
 {
  cl_object v3uiop_utility__format_arguments;
  ecl_va_list args; ecl_va_start(args,v2uiop_utility__functionality,narg,2);
  v3uiop_utility__format_arguments = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = cl_error(7, VV[416], VV[414], v2uiop_utility__functionality, ECL_SYM("FORMAT-CONTROL",1272), v1uiop_utility__format_control, ECL_SYM("FORMAT-ARGUMENTS",1271), v3uiop_utility__format_arguments);
  return value0;
 }
}
/* function definition for FEATUREP                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4342featurep(cl_narg narg, cl_object v1uiop_os__x, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[420]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[420]);
 {
  va_list args; va_start(args,v1uiop_os__x);
  {
   int i = 1;
   if (i >= narg) {
    ecl_bds_push(cl_env_copy,ECL_SYM("*FEATURES*",36)); /*  *FEATURES*        */
   } else {
    i++;
    ecl_bds_bind(cl_env_copy,ECL_SYM("*FEATURES*",36),va_arg(args,cl_object)); /*  *FEATURES* */
   }
  }
  va_end(args);
  if (!(ECL_ATOM(v1uiop_os__x))){
   goto L1;
  }
  {
   cl_object v2;
   cl_object v3;
   cl_object v4;
   v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
   v3 = v1uiop_os__x;
   v4 = v2;
   if (Null(ecl_memql(v3,v4))){
    goto L4;
   }
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L1:;
  T0 = ecl_car(v1uiop_os__x);
  if (!((VV[421])==(T0))){
   goto L9;
  }
  goto L13;
L12:;
  si_assert_failure(1, VV[422]);
L13:;
  T0 = ecl_cddr(v1uiop_os__x);
  if (T0==ECL_NIL) {
   goto L16;
  }
  goto L12;
L16:;
  T0 = ecl_cadr(v1uiop_os__x);
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[420]))->cfun.entry(1, T0) /*  FEATUREP */;
  value0 = Null(T1)?ECL_T:ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L9:;
  T0 = ecl_car(v1uiop_os__x);
  if (!((VV[423])==(T0))){
   goto L18;
  }
  T0 = ecl_fdefinition(VV[420]);
  T1 = ecl_cdr(v1uiop_os__x);
  value0 = cl_some(2, T0, T1);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L18:;
  T0 = ecl_car(v1uiop_os__x);
  if (!((VV[424])==(T0))){
   goto L21;
  }
  T0 = ecl_fdefinition(VV[420]);
  T1 = ecl_cdr(v1uiop_os__x);
  value0 = cl_every(2, T0, T1);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L21:;
  value0 = cl_error(2, VV[425], v1uiop_os__x);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
/* function definition for OS-MACOSX-P                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4343os_macosx_p()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[420]))->cfun.entry(1, VV[428]) /*  FEATUREP */;
 return value0;
}
static cl_object L4343os_macosx_p_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[427]);
 {
  return L4343os_macosx_p();
 }
}
/* function definition for OS-UNIX-P                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4344os_unix_p()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[420]))->cfun.entry(1, VV[431]) /*  FEATUREP */;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[427]))->cfun.entry(0) /*  OS-MACOSX-P */;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4344os_unix_p_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[430]);
 {
  return L4344os_unix_p();
 }
}
/* function definition for OS-WINDOWS-P                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4345os_windows_p()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if ((cl_env_copy->function=ecl_fdefinition(VV[430]))->cfun.entry(0) /*  OS-UNIX-P */!=ECL_NIL) {
  goto L3;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[420]))->cfun.entry(1, VV[434]) /*  FEATUREP */;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4345os_windows_p_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[433]);
 {
  return L4345os_windows_p();
 }
}
/* function definition for OS-GENERA-P                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4346os_genera_p()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[420]))->cfun.entry(1, VV[437]) /*  FEATUREP */;
 return value0;
}
static cl_object L4346os_genera_p_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[436]);
 {
  return L4346os_genera_p();
 }
}
/* function definition for OS-OLDMAC-P                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4347os_oldmac_p()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[420]))->cfun.entry(1, VV[440]) /*  FEATUREP */;
 return value0;
}
static cl_object L4347os_oldmac_p_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[439]);
 {
  return L4347os_oldmac_p();
 }
}
/* function definition for OS-HAIKU-P                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4348os_haiku_p()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[420]))->cfun.entry(1, VV[443]) /*  FEATUREP */;
 return value0;
}
static cl_object L4348os_haiku_p_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[442]);
 {
  return L4348os_haiku_p();
 }
}
/* function definition for DETECT-OS                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4349detect_os()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1uiop_os__o;
  v1uiop_os__o = ECL_NIL;
  {
   cl_object v2uiop_os__feature;
   cl_object v3uiop_os__detect;
   cl_object v4;
   v2uiop_os__feature = ECL_NIL;
   v3uiop_os__detect = ECL_NIL;
   v4 = VV[446];
L6:;
   {
    cl_object v5;
    v5 = ECL_CONS_CAR(v4);
    v2uiop_os__feature = ecl_car(v5);
    v5 = ecl_cdr(v5);
    v3uiop_os__detect = v5;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    if (ecl_unlikely(!ECL_LISTP(v5))) FEtype_error_list(v5);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v5;
   }
   if (Null(v1uiop_os__o)){
    goto L22;
   }
   if (!((v2uiop_os__feature)==(VV[447]))){
    goto L19;
   }
   goto L21;
L22:;
L21:;
   if (Null(ecl_function_dispatch(cl_env_copy,v3uiop_os__detect)(0))){
    goto L19;
   }
   v1uiop_os__o = v2uiop_os__feature;
   T0 = cl_adjoin(2, v2uiop_os__feature, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36)));
   ecl_cmp_setq(cl_env_copy,ECL_SYM("*FEATURES*",36),T0);
L19:;
   if (!(ecl_endp(v4))){
    goto L27;
   }
   goto L7;
L27:;
   goto L6;
L7:;
   value0 = v1uiop_os__o;
   if (value0!=ECL_NIL) {
    goto L32;
   }
   value0 = cl_error(1, VV[448]);
   return value0;
L32:;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4349detect_os_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[445]);
 {
  return L4349detect_os();
 }
}
/* local function OS-COND                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4350os_cond(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  {
   cl_object v4;
   cl_object v5uiop_os__test;
   cl_object v6uiop_os__body;
   cl_object v7;
   {
    cl_object v8;
    v8 = v3;
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v8;
   }
   v5uiop_os__test = ECL_NIL;
   v6uiop_os__body = ECL_NIL;
   v7 = v4;
L9:;
   if (!(ecl_endp(v7))){
    goto L11;
   }
   goto L10;
L11:;
   {
    cl_object v8;
    v8 = ECL_CONS_CAR(v7);
    v5uiop_os__test = ecl_car(v8);
    v8 = ecl_cdr(v8);
    v6uiop_os__body = v8;
   }
   {
    cl_object v8;
    v8 = ECL_CONS_CDR(v7);
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v7 = v8;
   }
   if (Null(cl_eval(v5uiop_os__test))){
    goto L24;
   }
   value0 = CONS(ECL_SYM("PROGN",674),v6uiop_os__body);
   cl_env_copy->nvalues = 1;
   return value0;
L24:;
   goto L9;
L10:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object LC4350os_cond_va(cl_narg narg, cl_object v8, cl_object v9, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[450]);
 {
  return LC4350os_cond(v8, v9);
 }
}
/* function definition for GETENV                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4351getenv(cl_object v1uiop_os__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = si_getenv(v1uiop_os__x);
 return value0;
}
static cl_object L4351getenv_va(cl_narg narg, cl_object v2uiop_os__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[452]);
 {
  return L4351getenv(v2uiop_os__x);
 }
}
/* local function LAMBDA1880                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4352__lambda1880(cl_object v1uiop_os__val, cl_object v2uiop_os__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_list(3, ECL_SYM("SETENV",1164), v2uiop_os__x, v1uiop_os__val);
 return value0;
}
static cl_object LC4352__lambda1880_va(cl_narg narg, cl_object v3uiop_os__val, cl_object v4uiop_os__x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[454]);
 {
  return LC4352__lambda1880(v3uiop_os__val, v4uiop_os__x);
 }
}
/* function definition for GETENVP                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4353getenvp(cl_object v1uiop_os__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_os__g;
  v2uiop_os__g = (cl_env_copy->function=ecl_fdefinition(VV[452]))->cfun.entry(1, v1uiop_os__x) /*  GETENV */;
  if ((cl_env_copy->function=ecl_fdefinition(VV[263]))->cfun.entry(1, v2uiop_os__g) /*  EMPTYP */!=ECL_NIL) {
   goto L4;
  }
  value0 = v2uiop_os__g;
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4353getenvp_va(cl_narg narg, cl_object v3uiop_os__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[455]);
 {
  return L4353getenvp(v3uiop_os__x);
 }
}
/* function definition for FIRST-FEATURE                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4354first_feature(cl_object v1uiop_os__feature_sets)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = v1uiop_os__feature_sets;
  goto L5;
L4:;
  {
   cl_object v3uiop_os__x;
   v3uiop_os__x = ecl_car(v2);
   {
    cl_object v4;                                 /*  SHORT                   */
    cl_object v5;                                 /*  LONG                    */
    cl_object v6;                                 /*  FEATURE-EXPR            */
    if (!(ECL_CONSP(v3uiop_os__x))){
     goto L11;
    }
    T0 = ecl_car(v3uiop_os__x);
    T1 = ecl_cadr(v3uiop_os__x);
    T2 = ecl_cdr(v3uiop_os__x);
    T3 = CONS(VV[423],T2);
    cl_env_copy->nvalues = 3;
    cl_env_copy->values[2] = T3;
    cl_env_copy->values[1] = T1;
    cl_env_copy->values[0] = T0;
    value0 = cl_env_copy->values[0];
    goto L10;
L11:;
    cl_env_copy->nvalues = 3;
    cl_env_copy->values[2] = v3uiop_os__x;
    cl_env_copy->values[1] = v3uiop_os__x;
    cl_env_copy->values[0] = v3uiop_os__x;
    value0 = cl_env_copy->values[0];
L10:;
    {
     v4 = value0;
     v5 = cl_env_copy->values[1];
     v6 = cl_env_copy->values[2];
    }
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[420]))->cfun.entry(1, v6) /*  FEATUREP */)){
     goto L9;
    }
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = v5;
    cl_env_copy->values[0] = v4;
    return cl_env_copy->values[0];
   }
L9:;
  }
  v2 = ecl_cdr(v2);
L5:;
  if (Null(v2)){
   goto L16;
  }
  goto L4;
L16:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4354first_feature_va(cl_narg narg, cl_object v3uiop_os__feature_sets, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[457]);
 {
  return L4354first_feature(v3uiop_os__feature_sets);
 }
}
/* function definition for IMPLEMENTATION-TYPE                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4355implementation_type()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[457]))->cfun.entry(1, VV[460]) /*  FIRST-FEATURE */;
 return value0;
}
static cl_object L4355implementation_type_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[459]);
 {
  return L4355implementation_type();
 }
}
/* function definition for OPERATING-SYSTEM                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4356operating_system()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[457]))->cfun.entry(1, VV[464]) /*  FIRST-FEATURE */;
 return value0;
}
static cl_object L4356operating_system_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[463]);
 {
  return L4356operating_system();
 }
}
/* function definition for ARCHITECTURE                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4357architecture()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[457]))->cfun.entry(1, VV[467]) /*  FIRST-FEATURE */;
 return value0;
}
static cl_object L4357architecture_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[466]);
 {
  return L4357architecture();
 }
}
/* function definition for LISP-VERSION-STRING                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4358lisp_version_string()
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1uiop_os__s;
  v1uiop_os__s = cl_lisp_implementation_version();
  {
   cl_object v2uiop_os__vcs_id;
   v2uiop_os__vcs_id = si_lisp_implementation_vcs_id();
   {
    cl_fixnum v3;
    v3 = ecl_length(v2uiop_os__vcs_id);
    {
     cl_fixnum v4;
     v4 = (v3)<=((cl_fixnum)(8))?v3:(cl_fixnum)(8);
     T0 = cl_subseq(3, v2uiop_os__vcs_id, ecl_make_int8_t(0), ecl_make_fixnum(v4));
    }
   }
  }
  T1 = cl_format(4, ECL_NIL, VV[470], v1uiop_os__s, T0);
  T2 = cl_list(2, T1, v1uiop_os__s);
  value0 = ecl_car(T2);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4358lisp_version_string_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[469]);
 {
  return L4358lisp_version_string();
 }
}
/* function definition for IMPLEMENTATION-IDENTIFIER                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4360implementation_identifier()
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC4359__lambda1892_va,ECL_NIL,Cblock,1);
  T0 = v1;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[459]))->cfun.entry(0) /*  IMPLEMENTATION-TYPE */;
 if (value0!=ECL_NIL) {
  goto L5;
 }
 T1 = cl_lisp_implementation_type();
 goto L3;
L5:;
 T1 = value0;
 goto L3;
L3:;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[469]))->cfun.entry(0) /*  LISP-VERSION-STRING */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[463]))->cfun.entry(0) /*  OPERATING-SYSTEM */;
 if (value0!=ECL_NIL) {
  goto L9;
 }
 T3 = cl_software_type();
 goto L7;
L9:;
 T3 = value0;
 goto L7;
L7:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[466]))->cfun.entry(0) /*  ARCHITECTURE */;
 if (value0!=ECL_NIL) {
  goto L13;
 }
 T4 = cl_machine_type();
 goto L11;
L13:;
 T4 = value0;
 goto L11;
L11:;
 T5 = cl_format(6, ECL_NIL, VV[475], T1, T2, T3, T4);
 value0 = cl_substitute_if(3, ECL_CODE_CHAR(95), T0, T5);
 return value0;
}
static cl_object L4360implementation_identifier_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[472]);
 {
  return L4360implementation_identifier();
 }
}
/* function definition for HOSTNAME                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4361hostname()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_machine_instance();
 return value0;
}
static cl_object L4361hostname_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[477]);
 {
  return L4361hostname();
 }
}
/* function definition for GETCWD                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4362getcwd()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = si_getcwd(0);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4362getcwd_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[479]);
 {
  return L4362getcwd();
 }
}
/* function definition for CHDIR                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4363chdir(cl_object v1uiop_os__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_os__x;
  v2uiop_os__x = cl_pathname(v1uiop_os__x);
  value0 = si_chdir(1, v2uiop_os__x);
  return value0;
 }
}
static cl_object L4363chdir_va(cl_narg narg, cl_object v3uiop_os__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[482]);
 {
  return L4363chdir(v3uiop_os__x);
 }
}
/* function definition for READ-NULL-TERMINATED-STRING                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4364read_null_terminated_string(cl_object volatile v1uiop_os__s)
{
 cl_object T0;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v2uiop_os__out;
  v2uiop_os__out = cl_make_string_output_stream(0);
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    {
     cl_object v3uiop_os__code;
     v3uiop_os__code = ECL_NIL;
L6:;
     v3uiop_os__code = cl_read_byte(1, v1uiop_os__s);
     if (!(ecl_zerop(v3uiop_os__code))){
      goto L10;
     }
     goto L7;
L10:;
     T0 = cl_code_char(v3uiop_os__code);
     cl_write_char(2, T0, v2uiop_os__out);
     goto L6;
L7:;
    }
    cl_env_copy->values[0] = cl_get_output_stream_string(v2uiop_os__out);
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   cl_close(1, v2uiop_os__out);
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
}
static cl_object L4364read_null_terminated_string_va(cl_narg narg, cl_object v3uiop_os__s, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[486]);
 {
  return L4364read_null_terminated_string(v3uiop_os__s);
 }
}
/* function definition for READ-LITTLE-ENDIAN                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4365read_little_endian(cl_narg narg, cl_object v1uiop_os__s, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[488]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[488]);
 {
  cl_object v2uiop_os__bytes;
  va_list args; va_start(args,v1uiop_os__s);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_os__bytes = ecl_make_int8_t(4);
   } else {
    i++;
    v2uiop_os__bytes = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v3;
   cl_object v4;
   cl_object v5uiop_os__i;
   v3 = ecl_make_int8_t(0);
   {
    cl_object v6;
    v6 = v2uiop_os__bytes;
    {
     bool v7;
     v7 = ecl_numberp(v6);
     if (ecl_unlikely(!(v7)))
         FEwrong_type_argument(ECL_SYM("NUMBER",608),v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
    v4 = v6;
   }
   v5uiop_os__i = v3;
   {
    cl_object v6;
    v6 = ecl_make_int8_t(0);
L8:;
    if (!(ecl_greatereq(v5uiop_os__i,v4))){
     goto L10;
    }
    goto L9;
L10:;
    T0 = cl_read_byte(1, v1uiop_os__s);
    T1 = ecl_times(ecl_make_int8_t(8),v5uiop_os__i);
    T2 = cl_ash(T0, T1);
    v6 = ecl_plus(v6,T2);
    v5uiop_os__i = ecl_one_plus(v5uiop_os__i);
    goto L8;
L9:;
    value0 = v6;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for PARSE-FILE-LOCATION-INFO                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4366parse_file_location_info(cl_object v1uiop_os__s)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  cl_object v8;
  cl_object v9;
  v2 = cl_file_position(1, v1uiop_os__s);
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[488]))->cfun.entry(1, v1uiop_os__s) /*  READ-LITTLE-ENDIAN */;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[488]))->cfun.entry(1, v1uiop_os__s) /*  READ-LITTLE-ENDIAN */;
  v5 = (cl_env_copy->function=ecl_fdefinition(VV[488]))->cfun.entry(1, v1uiop_os__s) /*  READ-LITTLE-ENDIAN */;
  v6 = (cl_env_copy->function=ecl_fdefinition(VV[488]))->cfun.entry(1, v1uiop_os__s) /*  READ-LITTLE-ENDIAN */;
  v7 = (cl_env_copy->function=ecl_fdefinition(VV[488]))->cfun.entry(1, v1uiop_os__s) /*  READ-LITTLE-ENDIAN */;
  v8 = (cl_env_copy->function=ecl_fdefinition(VV[488]))->cfun.entry(1, v1uiop_os__s) /*  READ-LITTLE-ENDIAN */;
  v9 = (cl_env_copy->function=ecl_fdefinition(VV[488]))->cfun.entry(1, v1uiop_os__s) /*  READ-LITTLE-ENDIAN */;
  if (ecl_zerop(v5)) {
   goto L10;
  }
  if (Null(cl_logbitp(ecl_make_int8_t(0), v5))){
   goto L13;
  }
  T0 = ecl_plus(v2,v7);
  cl_file_position(2, v1uiop_os__s, T0);
  goto L12;
L13:;
  if (Null(cl_logbitp(ecl_make_int8_t(1), v5))){
   goto L12;
  }
  T0 = ecl_plus(v2,v8);
  T1 = ecl_plus(T0,ecl_make_int8_t(20));
  cl_file_position(2, v1uiop_os__s, T1);
L12:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[486]))->cfun.entry(1, v1uiop_os__s) /*  READ-NULL-TERMINATED-STRING */;
  T1 = ecl_plus(v2,v9);
  cl_file_position(2, v1uiop_os__s, T1);
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[486]))->cfun.entry(1, v1uiop_os__s) /*  READ-NULL-TERMINATED-STRING */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[283]))->cfun.entry(2, T0, T1) /*  STRCAT */;
  return value0;
L10:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4366parse_file_location_info_va(cl_narg narg, cl_object v10uiop_os__s, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[490]);
 {
  return L4366parse_file_location_info(v10uiop_os__s);
 }
}
/* function definition for PARSE-WINDOWS-SHORTCUT                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4368parse_windows_shortcut(cl_object volatile v1pathname)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v2uiop_os__s;
  v2uiop_os__s = cl_open(3, v1pathname, ECL_SYM("ELEMENT-TYPE",1255), VV[493]);
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    {
     struct ecl_stack_frame _ecl_inner_frame_aux;
     volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
     {
      volatile cl_object env1 = env0;
      env1 = ECL_NIL;
      CLV0 = env1 = CONS(ECL_NIL,env1);
      {
       volatile cl_object env2 = env1;
       CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY    */
       {
        ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
        if (__ecl_frs_push_result!=0) {
        if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
         goto L5;
        }
        ecl_internal_error("GO found an inexistent tag");
        } else {
        {
         cl_object v3;
         v3 = ecl_make_cclosure_va((cl_objectfn)LC4367__lambda1947,env2,Cblock,1);
         T0 = v3;
        }
        T1 = CONS(ECL_SYM("END-OF-FILE",331),T0);
        T2 = ecl_list1(T1);
        T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
        ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
        T0 = (cl_env_copy->function=ecl_fdefinition(VV[488]))->cfun.entry(1, v2uiop_os__s) /*  READ-LITTLE-ENDIAN */;
        if (!(ecl_number_equalp(T0,ecl_cmp_symbol_value(cl_env_copy,VV[484])))){
         goto L8;
        }
        {
         cl_object v3uiop_os__header;
         {
          cl_object v4;
          v4 = ecl_make_fixnum(ecl_length(ecl_cmp_symbol_value(cl_env_copy,VV[485])));
          v3uiop_os__header = si_make_pure_array(ECL_T, v4, ECL_NIL, ECL_NIL, ECL_NIL, ecl_make_int8_t(0));
         }
         cl_read_sequence(2, v3uiop_os__header, v2uiop_os__s);
         if (!(ecl_equalp(v3uiop_os__header,ecl_cmp_symbol_value(cl_env_copy,VV[485])))){
          goto L8;
         }
        }
        {
         cl_object v3uiop_os__flags;
         v3uiop_os__flags = (cl_env_copy->function=ecl_fdefinition(VV[488]))->cfun.entry(1, v2uiop_os__s) /*  READ-LITTLE-ENDIAN */;
         cl_file_position(2, v2uiop_os__s, ecl_make_int8_t(76));
         if (Null(cl_logbitp(ecl_make_int8_t(0), v3uiop_os__flags))){
          goto L16;
         }
         {
          cl_object v4length;
          v4length = (cl_env_copy->function=ecl_fdefinition(VV[488]))->cfun.entry(2, v2uiop_os__s, ecl_make_int8_t(2)) /*  READ-LITTLE-ENDIAN */;
          T0 = cl_file_position(1, v2uiop_os__s);
          T1 = ecl_plus(v4length,T0);
          cl_file_position(2, v2uiop_os__s, T1);
         }
L16:;
         if (Null(cl_logbitp(ecl_make_int8_t(1), v3uiop_os__flags))){
          goto L19;
         }
         cl_env_copy->values[0] = (cl_env_copy->function=ecl_fdefinition(VV[490]))->cfun.entry(1, v2uiop_os__s) /*  PARSE-FILE-LOCATION-INFO */;
         ecl_frs_pop_n(cl_env_copy, 1);
         ecl_bds_unwind1(cl_env_copy);
         goto L4;
L19:;
         if (Null(cl_logbitp(ecl_make_int8_t(2), v3uiop_os__flags))){
          goto L21;
         }
         {
          cl_object v4length;
          v4length = (cl_env_copy->function=ecl_fdefinition(VV[488]))->cfun.entry(2, v2uiop_os__s, ecl_make_int8_t(2)) /*  READ-LITTLE-ENDIAN */;
          T0 = cl_file_position(1, v2uiop_os__s);
          T1 = ecl_plus(v4length,T0);
          cl_file_position(2, v2uiop_os__s, T1);
         }
L21:;
         if (Null(cl_logbitp(ecl_make_int8_t(3), v3uiop_os__flags))){
          goto L24;
         }
         {
          cl_object v4length;
          cl_object v5uiop_os__buffer;
          v4length = (cl_env_copy->function=ecl_fdefinition(VV[488]))->cfun.entry(2, v2uiop_os__s, ecl_make_int8_t(2)) /*  READ-LITTLE-ENDIAN */;
          v5uiop_os__buffer = si_make_pure_array(ECL_T, v4length, ECL_NIL, ECL_NIL, ECL_NIL, ecl_make_int8_t(0));
          cl_read_sequence(2, v5uiop_os__buffer, v2uiop_os__s);
          T0 = (ECL_SYM("CODE-CHAR",232)->symbol.gfdef);
          cl_env_copy->values[0] = cl_map(3, ECL_SYM("STRING",808), T0, v5uiop_os__buffer);
          ecl_frs_pop_n(cl_env_copy, 1);
          ecl_bds_unwind1(cl_env_copy);
          goto L4;
         }
L24:;
         cl_env_copy->values[0] = ECL_NIL;
         cl_env_copy->nvalues = 1;
         ecl_frs_pop_n(cl_env_copy, 1);
         ecl_bds_unwind1(cl_env_copy);
         goto L4;
        }
L8:;
        cl_env_copy->values[0] = ECL_NIL;
        cl_env_copy->nvalues = 1;
        ecl_frs_pop_n(cl_env_copy, 1);
        ecl_bds_unwind1(cl_env_copy);
        goto L4;
L5:;
        cl_env_copy->values[0] = ECL_NIL;
        cl_env_copy->nvalues = 1;
        ecl_frs_pop_n(cl_env_copy, 1);
        goto L4;
        }
       }
      }
     }
L4:;
     ecl_stack_frame_push_values(_ecl_inner_frame);
     if (Null(v2uiop_os__s)){
      goto L31;
     }
     cl_close(1, v2uiop_os__s);
L31:;
     ecl_stack_frame_pop_values(_ecl_inner_frame);
     ecl_stack_frame_close(_ecl_inner_frame);
    }
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   if (Null(v2uiop_os__s)){
    goto L33;
   }
   cl_close(3, v2uiop_os__s, ECL_SYM("ABORT",1225), ECL_T);
L33:;
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
}
static cl_object L4368parse_windows_shortcut_va(cl_narg narg, cl_object v3pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[492]);
 {
  return L4368parse_windows_shortcut(v3pathname);
 }
}
/* function definition for NORMALIZE-PATHNAME-DIRECTORY-COMPONENT             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4369normalize_pathname_directory_component(cl_object v1directory)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_STRINGP(v1directory))){
  goto L2;
 }
 value0 = cl_list(2, ECL_SYM("ABSOLUTE",1226), v1directory);
 return value0;
L2:;
 if (v1directory==ECL_NIL) {
  goto L6;
 }
 if (!(ECL_CONSP(v1directory))){
  goto L4;
 }
 {
  cl_object v2;
  v2 = ecl_car(v1directory);
  if (!((v2)==(ECL_SYM("ABSOLUTE",1226)))){
   goto L13;
  }
  goto L10;
L13:;
  goto L11;
L11:;
  if (!((v2)==(ECL_SYM("RELATIVE",1336)))){
   goto L4;
  }
  goto L5;
L10:;
  goto L5;
 }
L6:;
L5:;
 value0 = v1directory;
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 value0 = cl_error(2, VV[500], v1directory);
 return value0;
}
static cl_object L4369normalize_pathname_directory_component_va(cl_narg narg, cl_object v2directory, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[497]);
 {
  return L4369normalize_pathname_directory_component(v2directory);
 }
}
/* function definition for DENORMALIZE-PATHNAME-DIRECTORY-COMPONENT           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4370denormalize_pathname_directory_component(cl_object v1uiop_pathname__directory_component)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = v1uiop_pathname__directory_component;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4370denormalize_pathname_directory_component_va(cl_narg narg, cl_object v2uiop_pathname__directory_component, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[502]);
 {
  return L4370denormalize_pathname_directory_component(v2uiop_pathname__directory_component);
 }
}
/* function definition for MERGE-PATHNAME-DIRECTORY-COMPONENTS                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4371merge_pathname_directory_components(cl_object v1uiop_pathname__specified, cl_object v2uiop_pathname__defaults)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3directory;
  v3directory = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, v1uiop_pathname__specified) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
  {
   cl_object v4;
   v4 = ecl_car(v3directory);
   if (!((v4)==(ECL_NIL))){
    goto L4;
   }
   value0 = v2uiop_pathname__defaults;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!((v4)==(ECL_SYM("ABSOLUTE",1226)))){
    goto L7;
   }
   value0 = v1uiop_pathname__specified;
   cl_env_copy->nvalues = 1;
   return value0;
L7:;
   if (!((v4)==(ECL_SYM("RELATIVE",1336)))){
    goto L9;
   }
   {
    cl_object v5;
    cl_object v6;
    cl_object v7uiop_pathname__reldir;
    v5 = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, v2uiop_pathname__defaults) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
    v6 = ecl_cdr(v3directory);
    v7uiop_pathname__reldir = v6;
    if (!(v5==ECL_NIL)){
     goto L14;
    }
    value0 = v3directory;
    cl_env_copy->nvalues = 1;
    return value0;
L14:;
    T0 = ecl_car(v7uiop_pathname__reldir);
    if ((ECL_SYM("BACK",1230))==(T0)) {
     goto L16;
    }
    value0 = ecl_append(v5,v7uiop_pathname__reldir);
    cl_env_copy->nvalues = 1;
    return value0;
L16:;
    {
     cl_object v8uiop_pathname__defabs;
     v8uiop_pathname__defabs = ecl_car(v5);
     {
      cl_object v9uiop_pathname__defrev;
      T0 = ecl_cdr(v5);
      v9uiop_pathname__defrev = cl_reverse(T0);
L20:;
      T0 = ecl_car(v7uiop_pathname__reldir);
      if (!((ECL_SYM("BACK",1230))==(T0))){
       goto L25;
      }
      if (!((ECL_SYM("ABSOLUTE",1226))==(v8uiop_pathname__defabs))){
       goto L29;
      }
      if (v9uiop_pathname__defrev==ECL_NIL) {
       goto L22;
      }
      goto L27;
L29:;
      goto L27;
L27:;
      T0 = ecl_car(v9uiop_pathname__defrev);
      if (ECL_STRINGP(T0)) {
       goto L22;
      }
      goto L23;
L25:;
      goto L23;
L23:;
      goto L21;
L22:;
      {
       cl_object v10;
       v10 = v7uiop_pathname__reldir;
       {
        cl_object v11;
        v11 = v10;
        {
         bool v12;
         v12 = ECL_LISTP(v11);
         if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[508],v11);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
       }
       if (Null(v10)){
        goto L37;
       }
       {
        cl_object v11;
        v11 = ECL_CONS_CDR(v10);
        v7uiop_pathname__reldir = v11;
        v10 = ECL_CONS_CAR(v10);
       }
L37:;
      }
      {
       cl_object v10;
       v10 = v9uiop_pathname__defrev;
       {
        cl_object v11;
        v11 = v10;
        {
         bool v12;
         v12 = ECL_LISTP(v11);
         if (ecl_unlikely(!(v12)))
         FEwrong_type_argument(VV[508],v11);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
       }
       if (Null(v10)){
        goto L47;
       }
       {
        cl_object v11;
        v11 = ECL_CONS_CDR(v10);
        v9uiop_pathname__defrev = v11;
        v10 = ECL_CONS_CAR(v10);
       }
L47:;
      }
      goto L20;
L21:;
      T0 = cl_reverse(v9uiop_pathname__defrev);
      T1 = ecl_append(T0,v7uiop_pathname__reldir);
      value0 = CONS(v8uiop_pathname__defabs,T1);
      cl_env_copy->nvalues = 1;
      return value0;
     }
    }
   }
L9:;
   value0 = si_ecase_error(v4, VV[509]);
   return value0;
  }
 }
}
static cl_object L4371merge_pathname_directory_components_va(cl_narg narg, cl_object v10uiop_pathname__specified, cl_object v11uiop_pathname__defaults, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[504]);
 {
  return L4371merge_pathname_directory_components(v10uiop_pathname__specified, v11uiop_pathname__defaults);
 }
}
/* function definition for MAKE-PATHNAME*                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4372make_pathname_(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_pathname__keys;
  cl_object v2directory;
  cl_object v3uiop_pathname__host;
  cl_object v4uiop_pathname__device;
  cl_object v5uiop_pathname__name;
  cl_object v6type;
  cl_object v7uiop_pathname__version;
  cl_object v8uiop_pathname__defaults;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[14];
   cl_parse_key(args,7,L4372make_pathname_keys,keyvars,(cl_object*)&v1uiop_pathname__keys,FALSE);
   ecl_va_end(args);
   v2directory = keyvars[0];
   v3uiop_pathname__host = keyvars[1];
   v4uiop_pathname__device = keyvars[2];
   v5uiop_pathname__name = keyvars[3];
   v6type = keyvars[4];
   v7uiop_pathname__version = keyvars[5];
   v8uiop_pathname__defaults = keyvars[6];
  }
  value0 = cl_apply(2, ECL_SYM("MAKE-PATHNAME",533), v1uiop_pathname__keys);
  return value0;
 }
}
/* function definition for MAKE-PATHNAME-COMPONENT-LOGICAL                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4373make_pathname_component_logical(cl_object v1uiop_pathname__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_typep(2, v1uiop_pathname__x, VV[515]))){
  goto L2;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = v1uiop_pathname__x;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4373make_pathname_component_logical_va(cl_narg narg, cl_object v2uiop_pathname__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[514]);
 {
  return L4373make_pathname_component_logical(v2uiop_pathname__x);
 }
}
/* function definition for MAKE-PATHNAME-LOGICAL                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4374make_pathname_logical(cl_object v1pathname, cl_object v2uiop_pathname__host)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_pathname_directory(1, v1pathname);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[514]))->cfun.entry(1, T0) /*  MAKE-PATHNAME-COMPONENT-LOGICAL */;
 T2 = cl_pathname_name(1, v1pathname);
 T3 = (cl_env_copy->function=ecl_fdefinition(VV[514]))->cfun.entry(1, T2) /*  MAKE-PATHNAME-COMPONENT-LOGICAL */;
 T4 = cl_pathname_type(1, v1pathname);
 T5 = (cl_env_copy->function=ecl_fdefinition(VV[514]))->cfun.entry(1, T4) /*  MAKE-PATHNAME-COMPONENT-LOGICAL */;
 T6 = cl_pathname_version(v1pathname);
 T7 = (cl_env_copy->function=ecl_fdefinition(VV[514]))->cfun.entry(1, T6) /*  MAKE-PATHNAME-COMPONENT-LOGICAL */;
 value0 = cl_make_pathname(10, ECL_SYM("HOST",1276), v2uiop_pathname__host, ECL_SYM("DIRECTORY",1250), T1, ECL_SYM("NAME",1309), T3, ECL_SYM("TYPE",1356), T5, ECL_SYM("VERSION",1364), T7);
 return value0;
}
static cl_object L4374make_pathname_logical_va(cl_narg narg, cl_object v3pathname, cl_object v4uiop_pathname__host, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[517]);
 {
  return L4374make_pathname_logical(v3pathname, v4uiop_pathname__host);
 }
}
/* function definition for MERGE-PATHNAMES*                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4376merge_pathnames_(cl_narg narg, cl_object v1uiop_pathname__specified, ...)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[519]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[519]);
 {
  cl_object v2uiop_pathname__defaults;
  va_list args; va_start(args,v1uiop_pathname__specified);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_pathname__defaults = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34));
   } else {
    i++;
    v2uiop_pathname__defaults = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (!(v1uiop_pathname__specified==ECL_NIL)){
   goto L2;
  }
  value0 = v2uiop_pathname__defaults;
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  if (!(v2uiop_pathname__defaults==ECL_NIL)){
   goto L4;
  }
  value0 = v1uiop_pathname__specified;
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  {
   cl_object v3uiop_pathname__specified;
   cl_object v4uiop_pathname__defaults;
   cl_object v5directory;
   cl_object v6uiop_pathname__name;
   cl_object v7type;
   cl_object v8uiop_pathname__version;
   v3uiop_pathname__specified = cl_pathname(v1uiop_pathname__specified);
   v4uiop_pathname__defaults = cl_pathname(v2uiop_pathname__defaults);
   T0 = cl_pathname_directory(1, v3uiop_pathname__specified);
   v5directory = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, T0) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
   value0 = cl_pathname_name(1, v3uiop_pathname__specified);
   if (value0!=ECL_NIL) {
    goto L11;
   }
   v6uiop_pathname__name = cl_pathname_name(1, v4uiop_pathname__defaults);
   goto L9;
L11:;
   v6uiop_pathname__name = value0;
   goto L9;
L9:;
   value0 = cl_pathname_type(1, v3uiop_pathname__specified);
   if (value0!=ECL_NIL) {
    goto L15;
   }
   v7type = cl_pathname_type(1, v4uiop_pathname__defaults);
   goto L13;
L15:;
   v7type = value0;
   goto L13;
L13:;
   value0 = cl_pathname_version(v3uiop_pathname__specified);
   if (value0!=ECL_NIL) {
    goto L19;
   }
   v8uiop_pathname__version = cl_pathname_version(v4uiop_pathname__defaults);
   goto L17;
L19:;
   v8uiop_pathname__version = value0;
   goto L17;
L17:;
   {
    cl_object v9;                                 /*  HOST                    */
    cl_object v10;                                /*  DEVICE                  */
    cl_object v11;                                /*  DIRECTORY               */
    cl_object v12;                                /*  UNSPECIFIC-HANDLER      */
    {
     cl_object v13;
     v13 = ecl_car(v5directory);
     if (!((v13)==(ECL_SYM("ABSOLUTE",1226)))){
      goto L23;
     }
     T0 = cl_pathname_host(1, v3uiop_pathname__specified);
     T1 = cl_pathname_device(1, v3uiop_pathname__specified);
     T2 = LC4375unspecific_handler(v3uiop_pathname__specified);
     cl_env_copy->nvalues = 4;
     cl_env_copy->values[3] = T2;
     cl_env_copy->values[2] = v5directory;
     cl_env_copy->values[1] = T1;
     cl_env_copy->values[0] = T0;
     value0 = cl_env_copy->values[0];
     goto L21;
L23:;
     if (!((v13)==(ECL_NIL))){
      goto L32;
     }
     goto L29;
L32:;
     goto L30;
L30:;
     if (!((v13)==(ECL_SYM("RELATIVE",1336)))){
      goto L27;
     }
     goto L28;
L29:;
L28:;
     T0 = cl_pathname_host(1, v4uiop_pathname__defaults);
     T1 = cl_pathname_device(1, v4uiop_pathname__defaults);
     T2 = cl_pathname_directory(1, v4uiop_pathname__defaults);
     T3 = (cl_env_copy->function=ecl_fdefinition(VV[504]))->cfun.entry(2, v5directory, T2) /*  MERGE-PATHNAME-DIRECTORY-COMPONENTS */;
     T4 = LC4375unspecific_handler(v4uiop_pathname__defaults);
     cl_env_copy->nvalues = 4;
     cl_env_copy->values[3] = T4;
     cl_env_copy->values[2] = T3;
     cl_env_copy->values[1] = T1;
     cl_env_copy->values[0] = T0;
     value0 = cl_env_copy->values[0];
     goto L21;
L27:;
     value0 = si_ecase_error(v13, VV[523]);
    }
L21:;
    {
     const int v13 = cl_env_copy->nvalues;
     v9 = value0;
     cl_object v14;
     v14 = (v13<=1)? ECL_NIL : cl_env_copy->values[1];
     v10 = v14;
     v14 = (v13<=2)? ECL_NIL : cl_env_copy->values[2];
     v11 = v14;
     v14 = (v13<=3)? ECL_NIL : cl_env_copy->values[3];
     v12 = v14;
    }
    T0 = ecl_function_dispatch(cl_env_copy,v12)(1, v6uiop_pathname__name);
    T1 = ecl_function_dispatch(cl_env_copy,v12)(1, v7type);
    T2 = ecl_function_dispatch(cl_env_copy,v12)(1, v8uiop_pathname__version);
    value0 = cl_make_pathname(12, ECL_SYM("HOST",1276), v9, ECL_SYM("DEVICE",1248), v10, ECL_SYM("DIRECTORY",1250), v11, ECL_SYM("NAME",1309), T0, ECL_SYM("TYPE",1356), T1, ECL_SYM("VERSION",1364), T2);
    return value0;
   }
  }
 }
}
/* function definition for LOGICAL-PATHNAME-P                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4377logical_pathname_p(cl_object v1uiop_pathname__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = si_logical_pathname_p(v1uiop_pathname__x);
 return value0;
}
static cl_object L4377logical_pathname_p_va(cl_narg narg, cl_object v2uiop_pathname__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[525]);
 {
  return L4377logical_pathname_p(v2uiop_pathname__x);
 }
}
/* function definition for PHYSICAL-PATHNAME-P                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4378physical_pathname_p(cl_object v1uiop_pathname__x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_pathnamep(v1uiop_pathname__x))){
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[525]))->cfun.entry(1, v1uiop_pathname__x) /*  LOGICAL-PATHNAME-P */;
 value0 = Null(T0)?ECL_T:ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4378physical_pathname_p_va(cl_narg narg, cl_object v2uiop_pathname__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[527]);
 {
  return L4378physical_pathname_p(v2uiop_pathname__x);
 }
}
/* function definition for PHYSICALIZE-PATHNAME                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4379physicalize_pathname(cl_object v1uiop_pathname__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_pathname__p;
  if (Null(v1uiop_pathname__x)){
   goto L3;
  }
  v2uiop_pathname__p = cl_pathname(v1uiop_pathname__x);
  goto L2;
L3:;
  v2uiop_pathname__p = ECL_NIL;
L2:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[525]))->cfun.entry(1, v2uiop_pathname__p) /*  LOGICAL-PATHNAME-P */)){
   goto L5;
  }
  value0 = cl_translate_logical_pathname(1, v2uiop_pathname__p);
  return value0;
L5:;
  value0 = v2uiop_pathname__p;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4379physicalize_pathname_va(cl_narg narg, cl_object v3uiop_pathname__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[529]);
 {
  return L4379physicalize_pathname(v3uiop_pathname__x);
 }
}
/* function definition for NIL-PATHNAME                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4380nil_pathname(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[531]);
 {
  cl_object v1uiop_pathname__defaults;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1uiop_pathname__defaults = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34));
   } else {
    i++;
    v1uiop_pathname__defaults = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = cl_make_pathname(14, ECL_SYM("DIRECTORY",1250), ECL_NIL, ECL_SYM("NAME",1309), ECL_NIL, ECL_SYM("TYPE",1356), ECL_NIL, ECL_SYM("VERSION",1364), ECL_NIL, ECL_SYM("DEVICE",1248), ECL_NIL, ECL_SYM("HOST",1276), ECL_NIL, ECL_SYM("DEFAULTS",1247), v1uiop_pathname__defaults);
  return value0;
 }
}
/* local function WITH-PATHNAME-DEFAULTS                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4381with_pathname_defaults(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_pathname__defaults;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v7;
   v7 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v7;
  }
  v5 = v4;
  if (Null(v5)){
   goto L11;
  }
  {
   cl_object v7;
   v7 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_pathname__defaults = v7;
   goto L10;
  }
L11:;
  v6uiop_pathname__defaults = ECL_NIL;
L10:;
  if (Null(v5)){
   goto L16;
  }
  si_dm_too_many_arguments(v1);
L16:;
  value0 = v6uiop_pathname__defaults;
  if (value0!=ECL_NIL) {
   goto L20;
  }
  T0 = VV[533];
  goto L18;
L20:;
  T0 = value0;
  goto L18;
L18:;
  T1 = cl_list(2, ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34), T0);
  T2 = ecl_list1(T1);
  value0 = cl_listX(3, ECL_SYM("LET",479), T2, v3);
  return value0;
 }
}
static cl_object LC4381with_pathname_defaults_va(cl_narg narg, cl_object v7, cl_object v8, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[534]);
 {
  return LC4381with_pathname_defaults(v7, v8);
 }
}
/* function definition for PATHNAME-EQUAL                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4383pathname_equal(cl_object v1uiop_pathname__p1, cl_object v2uiop_pathname__p2)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_STRINGP(v1uiop_pathname__p1))){
  goto L2;
 }
 v1uiop_pathname__p1 = cl_pathname(v1uiop_pathname__p1);
L2:;
 if (!(ECL_STRINGP(v2uiop_pathname__p2))){
  goto L5;
 }
 v2uiop_pathname__p2 = cl_pathname(v2uiop_pathname__p2);
L5:;
 if (!(v1uiop_pathname__p1==ECL_NIL)){
  goto L12;
 }
 value0 = ecl_make_bool(v2uiop_pathname__p2==ECL_NIL);
 goto L10;
L12:;
 value0 = ECL_NIL;
 goto L10;
L10:;
 if (value0!=ECL_NIL) {
  goto L9;
 }
 if (Null(cl_pathnamep(v1uiop_pathname__p1))){
  goto L15;
 }
 if (Null(cl_pathnamep(v2uiop_pathname__p2))){
  goto L15;
 }
 T1 = cl_pathname_host(1, v1uiop_pathname__p1);
 T0 = LC4382normalize_component(T1);
 T2 = cl_pathname_host(1, v2uiop_pathname__p2);
 T1 = LC4382normalize_component(T2);
 if (!(ecl_equal(T0,T1))){
  goto L19;
 }
 T1 = cl_pathname_device(1, v1uiop_pathname__p1);
 T0 = LC4382normalize_component(T1);
 T2 = cl_pathname_device(1, v2uiop_pathname__p2);
 T1 = LC4382normalize_component(T2);
 if (!(ecl_equal(T0,T1))){
  goto L19;
 }
 T1 = cl_pathname_directory(1, v1uiop_pathname__p1);
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, T1) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
 T0 = LC4382normalize_component(T2);
 T2 = cl_pathname_directory(1, v2uiop_pathname__p2);
 T3 = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, T2) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
 T1 = LC4382normalize_component(T3);
 if (!(ecl_equal(T0,T1))){
  goto L19;
 }
 T1 = cl_pathname_name(1, v1uiop_pathname__p1);
 T0 = LC4382normalize_component(T1);
 T2 = cl_pathname_name(1, v2uiop_pathname__p2);
 T1 = LC4382normalize_component(T2);
 if (!(ecl_equal(T0,T1))){
  goto L19;
 }
 T1 = cl_pathname_type(1, v1uiop_pathname__p1);
 T0 = LC4382normalize_component(T1);
 T2 = cl_pathname_type(1, v2uiop_pathname__p2);
 T1 = LC4382normalize_component(T2);
 if (!(ecl_equal(T0,T1))){
  goto L19;
 }
 T1 = cl_pathname_version(v1uiop_pathname__p1);
 T0 = LC4382normalize_component(T1);
 T2 = cl_pathname_version(v2uiop_pathname__p2);
 T1 = LC4382normalize_component(T2);
 value0 = ecl_make_bool(ecl_equal(T0,T1));
 cl_env_copy->nvalues = 1;
 return value0;
L19:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L15:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L9:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4383pathname_equal_va(cl_narg narg, cl_object v3uiop_pathname__p1, cl_object v4uiop_pathname__p2, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[536]);
 {
  return L4383pathname_equal(v3uiop_pathname__p1, v4uiop_pathname__p2);
 }
}
/* function definition for ABSOLUTE-PATHNAME-P                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4384absolute_pathname_p(cl_object v1uiop_pathname__pathspec)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1uiop_pathname__pathspec)){
  goto L3;
 }
 if (v1uiop_pathname__pathspec==ECL_NIL) {
  goto L6;
 }
 if (cl_pathnamep(v1uiop_pathname__pathspec)!=ECL_NIL) {
  goto L6;
 }
 if (!(ECL_STRINGP(v1uiop_pathname__pathspec))){
  goto L3;
 }
 goto L5;
L6:;
L5:;
 {
  cl_object v2pathname;
  v2pathname = cl_pathname(v1uiop_pathname__pathspec);
  T0 = cl_pathname_directory(1, v2pathname);
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, T0) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
  T2 = ecl_car(T1);
  if (!((ECL_SYM("ABSOLUTE",1226))==(T2))){
   goto L11;
  }
  value0 = v2pathname;
  cl_env_copy->nvalues = 1;
  return value0;
L11:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4384absolute_pathname_p_va(cl_narg narg, cl_object v3uiop_pathname__pathspec, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[544]);
 {
  return L4384absolute_pathname_p(v3uiop_pathname__pathspec);
 }
}
/* function definition for RELATIVE-PATHNAME-P                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4385relative_pathname_p(cl_object v1uiop_pathname__pathspec)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1uiop_pathname__pathspec)){
  goto L3;
 }
 if (v1uiop_pathname__pathspec==ECL_NIL) {
  goto L6;
 }
 if (cl_pathnamep(v1uiop_pathname__pathspec)!=ECL_NIL) {
  goto L6;
 }
 if (!(ECL_STRINGP(v1uiop_pathname__pathspec))){
  goto L3;
 }
 goto L5;
L6:;
L5:;
 {
  cl_object v2pathname;
  cl_object v3directory;
  v2pathname = cl_pathname(v1uiop_pathname__pathspec);
  T0 = cl_pathname_directory(1, v2pathname);
  v3directory = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, T0) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
  if (v3directory==ECL_NIL) {
   goto L13;
  }
  T0 = ecl_car(v3directory);
  if (!((ECL_SYM("RELATIVE",1336))==(T0))){
   goto L11;
  }
  goto L12;
L13:;
L12:;
  value0 = v2pathname;
  cl_env_copy->nvalues = 1;
  return value0;
L11:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4385relative_pathname_p_va(cl_narg narg, cl_object v4uiop_pathname__pathspec, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[546]);
 {
  return L4385relative_pathname_p(v4uiop_pathname__pathspec);
 }
}
/* function definition for HIDDEN-PATHNAME-P                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4386hidden_pathname_p(cl_object v1pathname)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1pathname)){
  goto L3;
 }
 T0 = cl_pathname_name(1, v1pathname);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[285]))->cfun.entry(1, T0) /*  FIRST-CHAR */;
 value0 = ecl_make_bool(ecl_equal(T1,ECL_CODE_CHAR(46)));
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4386hidden_pathname_p_va(cl_narg narg, cl_object v2pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[548]);
 {
  return L4386hidden_pathname_p(v2pathname);
 }
}
/* function definition for FILE-PATHNAME-P                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4387file_pathname_p(cl_object v1pathname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1pathname)){
  goto L2;
 }
 {
  cl_object v2pathname;
  v2pathname = cl_pathname(v1pathname);
  {
   cl_object v3;
   v3 = cl_pathname_name(1, v2pathname);
   if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v3, ECL_NIL))){
    goto L14;
   }
   goto L11;
L14:;
   goto L12;
L12:;
   if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v3, ECL_SYM("UNSPECIFIC",1357)))){
    goto L18;
   }
   goto L11;
L18:;
   goto L16;
L16:;
   if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v3, VV[96]))){
    goto L8;
   }
   goto L9;
L11:;
  }
L9:;
  {
   cl_object v3;
   v3 = cl_pathname_type(1, v2pathname);
   if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v3, ECL_NIL))){
    goto L24;
   }
   goto L5;
L24:;
   goto L22;
L22:;
   if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v3, ECL_SYM("UNSPECIFIC",1357)))){
    goto L28;
   }
   goto L5;
L28:;
   goto L26;
L26:;
   if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v3, VV[96]))){
    goto L31;
   }
   goto L5;
L31:;
   goto L6;
  }
L8:;
  goto L6;
L6:;
  value0 = v2pathname;
  cl_env_copy->nvalues = 1;
  return value0;
L5:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4387file_pathname_p_va(cl_narg narg, cl_object v3pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[550]);
 {
  return L4387file_pathname_p(v3pathname);
 }
}
/* function definition for PATHNAME-DIRECTORY-PATHNAME                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4388pathname_directory_pathname(cl_object v1pathname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1pathname)){
  goto L2;
 }
 value0 = cl_make_pathname(8, ECL_SYM("NAME",1309), ECL_NIL, ECL_SYM("TYPE",1356), ECL_NIL, ECL_SYM("VERSION",1364), ECL_NIL, ECL_SYM("DEFAULTS",1247), v1pathname);
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4388pathname_directory_pathname_va(cl_narg narg, cl_object v2pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[555]);
 {
  return L4388pathname_directory_pathname(v2pathname);
 }
}
/* function definition for PATHNAME-PARENT-DIRECTORY-PATHNAME                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4389pathname_parent_directory_pathname(cl_object v1pathname)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1pathname)){
  goto L2;
 }
 T0 = cl_pathname_directory(1, v1pathname);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[504]))->cfun.entry(2, VV[558], T0) /*  MERGE-PATHNAME-DIRECTORY-COMPONENTS */;
 value0 = cl_make_pathname(10, ECL_SYM("NAME",1309), ECL_NIL, ECL_SYM("TYPE",1356), ECL_NIL, ECL_SYM("VERSION",1364), ECL_NIL, ECL_SYM("DIRECTORY",1250), T1, ECL_SYM("DEFAULTS",1247), v1pathname);
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4389pathname_parent_directory_pathname_va(cl_narg narg, cl_object v2pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[557]);
 {
  return L4389pathname_parent_directory_pathname(v2pathname);
 }
}
/* function definition for DIRECTORY-PATHNAME-P                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4391directory_pathname_p(cl_object v1pathname)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1pathname)){
  goto L2;
 }
 {
  cl_object v2pathname;
  v2pathname = cl_pathname(v1pathname);
  if (cl_wild_pathname_p(1, v2pathname)!=ECL_NIL) {
   goto L6;
  }
  T0 = cl_pathname_name(1, v2pathname);
  if (Null(LC4390check_one(T0))){
   goto L6;
  }
  T0 = cl_pathname_type(1, v2pathname);
  if (Null(LC4390check_one(T0))){
   goto L6;
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4391directory_pathname_p_va(cl_narg narg, cl_object v3pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[560]);
 {
  return L4391directory_pathname_p(v3pathname);
 }
}
/* function definition for ENSURE-DIRECTORY-PATHNAME                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4393ensure_directory_pathname(volatile cl_narg narg, cl_object volatile v1uiop_pathname__pathspec, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[565]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[565]);
 {
  cl_object volatile v2uiop_pathname__on_error;
  va_list args; va_start(args,v1uiop_pathname__pathspec);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_pathname__on_error = ECL_SYM("ERROR",339);
   } else {
    i++;
    v2uiop_pathname__on_error = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (!(ECL_STRINGP(v1uiop_pathname__pathspec))){
   goto L2;
  }
  T0 = cl_pathname(v1uiop_pathname__pathspec);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[565]))->cfun.entry(1, T0) /*  ENSURE-DIRECTORY-PATHNAME */;
  return value0;
L2:;
  if (cl_pathnamep(v1uiop_pathname__pathspec)!=ECL_NIL) {
   goto L4;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(3, v2uiop_pathname__on_error, VV[566], v1uiop_pathname__pathspec) /*  CALL-FUNCTION */;
  return value0;
L4:;
  if (Null(cl_wild_pathname_p(1, v1uiop_pathname__pathspec))){
   goto L6;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(3, v2uiop_pathname__on_error, VV[567], v1uiop_pathname__pathspec) /*  CALL-FUNCTION */;
  return value0;
L6:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, v1uiop_pathname__pathspec) /*  DIRECTORY-PATHNAME-P */)){
   goto L8;
  }
  value0 = v1uiop_pathname__pathspec;
  cl_env_copy->nvalues = 1;
  return value0;
L8:;
  {
   volatile cl_object env1 = env0;
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(ECL_NIL,env1);
   CLV1 = env1 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env1); /*  TAGBODY        */
   {
    ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
    if (__ecl_frs_push_result!=0) {
    if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
     goto L10;
    }
    ecl_internal_error("GO found an inexistent tag");
    } else {
    {
     cl_object v3;
     v3 = ecl_make_cclosure_va((cl_objectfn)LC4392__lambda2143,env1,Cblock,1);
     T0 = v3;
    }
    T1 = CONS(ECL_SYM("ERROR",339),T0);
    T2 = ecl_list1(T1);
    T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
    ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
    T1 = cl_pathname_directory(1, v1uiop_pathname__pathspec);
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, T1) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
    if (value0!=ECL_NIL) {
     goto L15;
    }
    T0 = ecl_list1(ECL_SYM("RELATIVE",1336));
    goto L13;
L15:;
    T0 = value0;
    goto L13;
L13:;
    T1 = cl_file_namestring(v1uiop_pathname__pathspec);
    T2 = ecl_list1(T1);
    T3 = ecl_append(T0,T2);
    value0 = cl_make_pathname(10, ECL_SYM("DIRECTORY",1250), T3, ECL_SYM("NAME",1309), ECL_NIL, ECL_SYM("TYPE",1356), ECL_NIL, ECL_SYM("VERSION",1364), ECL_NIL, ECL_SYM("DEFAULTS",1247), v1uiop_pathname__pathspec);
    ecl_frs_pop_n(cl_env_copy, 1);
    ecl_bds_unwind1(cl_env_copy);
    return value0;
L10:;
    {
     cl_object v3uiop_pathname__c;
     v3uiop_pathname__c = ECL_CONS_CAR(CLV0);
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(4, v2uiop_pathname__on_error, VV[570], v1uiop_pathname__pathspec, v3uiop_pathname__c) /*  CALL-FUNCTION */;
     ecl_frs_pop_n(cl_env_copy, 1);
     return value0;
    }
    }
   }
  }
 }
}
/* function definition for SPLIT-UNIX-NAMESTRING-DIRECTORY-COMPONENTS         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4395split_unix_namestring_directory_components(cl_narg narg, cl_object v1unix_namestring, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[572]);
 {
  cl_object v2uiop_pathname__ensure_directory;
  cl_object v3uiop_pathname__dot_dot;
  ecl_va_list args; ecl_va_start(args,v1unix_namestring,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4395split_unix_namestring_directory_componentskeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2uiop_pathname__ensure_directory = keyvars[0];
   v3uiop_pathname__dot_dot = keyvars[1];
  }
  {
   cl_object v4;
   v4 = v1unix_namestring;
   if (ECL_STRINGP(v4)) {
    goto L3;
   }
   v1unix_namestring = si_do_check_type(v4, ECL_SYM("STRING",808), ECL_NIL, VV[573]);
L3:;
  }
  {
   cl_object v4;
   v4 = v3uiop_pathname__dot_dot;
   if (!((v4)==(ECL_NIL))){
    goto L12;
   }
   goto L8;
L12:;
   goto L10;
L10:;
   if (!((v4)==(ECL_SYM("BACK",1230)))){
    goto L16;
   }
   goto L8;
L16:;
   goto L14;
L14:;
   if (!((v4)==(ECL_SYM("UP",1359)))){
    goto L19;
   }
   goto L8;
L19:;
   goto L9;
L9:;
   v3uiop_pathname__dot_dot = si_do_check_type(v4, VV[577], ECL_NIL, VV[578]);
L8:;
  }
  {
   cl_object v4;
   v4 = si_make_seq_iterator(2, v1unix_namestring, ecl_make_int8_t(0));
L26:;
   if (v4!=ECL_NIL) {
    goto L28;
   }
   goto L24;
L28:;
   {
    cl_object v5;
    v5 = si_seq_iterator_ref(v1unix_namestring, v4);
    if (!((ECL_CODE_CHAR((ecl_character)(47))==(v5)))){
     goto L30;
    }
    if (v5!=ECL_NIL) {
     goto L22;
    }
    goto L24;
   }
L30:;
   v4 = si_seq_iterator_next(v1unix_namestring, v4);
   goto L26;
  }
L24:;
  if (v2uiop_pathname__ensure_directory!=ECL_NIL) {
   goto L22;
  }
  {
   cl_fixnum v4;
   v4 = ecl_length(v1unix_namestring);
   if (!((v4)>0)){
    goto L22;
   }
  }
  cl_env_copy->nvalues = 4;
  cl_env_copy->values[3] = ECL_T;
  cl_env_copy->values[2] = v1unix_namestring;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_SYM("RELATIVE",1336);
  return cl_env_copy->values[0];
L22:;
  {
   cl_object v4uiop_pathname__components;
   cl_object v5uiop_pathname__last_comp;
   v4uiop_pathname__components = (cl_env_copy->function=ecl_fdefinition(VV[289]))->cfun.entry(3, v1unix_namestring, VV[377], VV[579]) /*  SPLIT-STRING */;
   T0 = ecl_last(v4uiop_pathname__components,1);
   v5uiop_pathname__last_comp = ecl_car(T0);
   {
    cl_object v6;                                 /*  RELATIVE                */
    cl_object v7;                                 /*  COMPONENTS              */
    T0 = ecl_car(v4uiop_pathname__components);
    if (!(ecl_equal(T0,VV[96]))){
     goto L39;
    }
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[285]))->cfun.entry(1, v1unix_namestring) /*  FIRST-CHAR */;
    if (!(ecl_equal(T0,ECL_CODE_CHAR(47)))){
     goto L41;
    }
    T0 = ecl_cdr(v4uiop_pathname__components);
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = T0;
    cl_env_copy->values[0] = ECL_SYM("ABSOLUTE",1226);
    value0 = cl_env_copy->values[0];
    goto L38;
L41:;
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = ECL_NIL;
    cl_env_copy->values[0] = ECL_SYM("RELATIVE",1336);
    value0 = cl_env_copy->values[0];
    goto L38;
L39:;
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = v4uiop_pathname__components;
    cl_env_copy->values[0] = ECL_SYM("RELATIVE",1336);
    value0 = cl_env_copy->values[0];
L38:;
    {
     v6 = value0;
     v7 = cl_env_copy->values[1];
    }
    {
     cl_object v8;
     v8 = ecl_make_cfun_va((cl_objectfn)LC4394__lambda2194_va,ECL_NIL,Cblock,1);
     T0 = v8;
    }
    v7 = cl_remove_if(2, T0, v7);
    value0 = v3uiop_pathname__dot_dot;
    if (value0!=ECL_NIL) {
     goto L50;
    }
    T0 = ECL_SYM("BACK",1230);
    goto L48;
L50:;
    T0 = value0;
    goto L48;
L48:;
    T1 = (ECL_SYM("EQUAL",337)->symbol.gfdef);
    v7 = cl_substitute(5, T0, VV[583], v7, ECL_SYM("TEST",1353), T1);
    if (!(ecl_equal(v5uiop_pathname__last_comp,VV[96]))){
     goto L53;
    }
    cl_env_copy->nvalues = 4;
    cl_env_copy->values[3] = ECL_NIL;
    cl_env_copy->values[2] = ECL_NIL;
    cl_env_copy->values[1] = v7;
    cl_env_copy->values[0] = v6;
    return cl_env_copy->values[0];
L53:;
    if (Null(v2uiop_pathname__ensure_directory)){
     goto L55;
    }
    cl_env_copy->nvalues = 4;
    cl_env_copy->values[3] = ECL_NIL;
    cl_env_copy->values[2] = ECL_NIL;
    cl_env_copy->values[1] = v7;
    cl_env_copy->values[0] = v6;
    return cl_env_copy->values[0];
L55:;
    T0 = ecl_butlast(v7,1);
    cl_env_copy->nvalues = 4;
    cl_env_copy->values[3] = ECL_NIL;
    cl_env_copy->values[2] = v5uiop_pathname__last_comp;
    cl_env_copy->values[1] = T0;
    cl_env_copy->values[0] = v6;
    return cl_env_copy->values[0];
   }
  }
 }
}
/* function definition for SPLIT-NAME-TYPE                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4396split_name_type(cl_object v1uiop_pathname__filename)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = v1uiop_pathname__filename;
  if (ECL_STRINGP(v2)) {
   goto L4;
  }
  v1uiop_pathname__filename = si_do_check_type(v2, ECL_SYM("STRING",808), ECL_NIL, VV[586]);
L4:;
 }
 goto L9;
L8:;
 si_assert_failure(1, VV[587]);
L9:;
 {
  cl_fixnum v2;
  v2 = ecl_length(v1uiop_pathname__filename);
  if ((v2)>0) {
   goto L12;
  }
 }
 goto L8;
L12:;
 {
  cl_object v2;
  cl_object v3;
  cl_object v4uiop_pathname__name;
  cl_object v5type;
  v2 = (cl_env_copy->function=ecl_fdefinition(VV[289]))->cfun.entry(5, v1uiop_pathname__filename, VV[588], ecl_make_int8_t(2), VV[377], VV[378]) /*  SPLIT-STRING */;
  v3 = v2;
  if (!(v3==ECL_NIL)){
   goto L17;
  }
  si_dm_too_few_arguments(v2);
L17:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4uiop_pathname__name = v6;
  }
  if (Null(v3)){
   goto L23;
  }
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5type = v6;
   goto L22;
  }
L23:;
  v5type = ecl_cmp_symbol_value(cl_env_copy,VV[511]);
L22:;
  if (Null(v3)){
   goto L28;
  }
  si_dm_too_many_arguments(v2);
L28:;
  if (!(ecl_equal(v4uiop_pathname__name,VV[96]))){
   goto L30;
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = ecl_cmp_symbol_value(cl_env_copy,VV[511]);
  cl_env_copy->values[0] = v1uiop_pathname__filename;
  return cl_env_copy->values[0];
L30:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = v5type;
  cl_env_copy->values[0] = v4uiop_pathname__name;
  return cl_env_copy->values[0];
 }
}
static cl_object L4396split_name_type_va(cl_narg narg, cl_object v6uiop_pathname__filename, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[585]);
 {
  return L4396split_name_type(v6uiop_pathname__filename);
 }
}
/* function definition for PARSE-UNIX-NAMESTRING                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4397parse_unix_namestring(cl_narg narg, cl_object v1uiop_pathname__name, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[590]);
 {
  cl_object v2uiop_pathname__keys;
  cl_object v3type;
  cl_object v4uiop_pathname__defaults;
  cl_object v5uiop_pathname__dot_dot;
  cl_object v6uiop_pathname__ensure_directory;
  ecl_va_list args; ecl_va_start(args,v1uiop_pathname__name,narg,1);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L4397parse_unix_namestringkeys,keyvars,(cl_object*)&v2uiop_pathname__keys,TRUE);
   ecl_va_end(args);
   v3type = keyvars[0];
   v4uiop_pathname__defaults = keyvars[1];
   v5uiop_pathname__dot_dot = keyvars[2];
   v6uiop_pathname__ensure_directory = keyvars[3];
  }
  {
   cl_object v7;
   v7 = v3type;
   if (v7==ECL_NIL) {
    goto L3;
   }
   if (ECL_STRINGP(v7)) {
    goto L3;
   }
   if (cl_typep(2, v7, VV[591])!=ECL_NIL) {
    goto L3;
   }
   v3type = si_do_check_type(v7, VV[592], ECL_NIL, ECL_SYM("TYPE",872));
L3:;
  }
  if (Null(v6uiop_pathname__ensure_directory)){
   goto L8;
  }
  v3type = ECL_SYM("DIRECTORY",1250);
L8:;
  {
   cl_object v7;
   v7 = v1uiop_pathname__name;
   if (v7==ECL_NIL) {
    goto L15;
   }
   if (Null(cl_pathnamep(v7))){
    goto L13;
   }
   goto L14;
L15:;
L14:;
   value0 = v1uiop_pathname__name;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   if (!(ECL_SYMBOLP(v7))){
    goto L17;
   }
   v1uiop_pathname__name = cl_string_downcase(1, v1uiop_pathname__name);
   goto L11;
L17:;
   if (ECL_STRINGP(v7)) {
    goto L11;
   }
   si_etypecase_error(v7, VV[593]);
  }
L11:;
  {
   cl_object v7;                                  /*  RELATIVE                */
   cl_object v8;                                  /*  PATH                    */
   cl_object v9;                                  /*  FILENAME                */
   cl_object v10;                                 /*  FILE-ONLY               */
   {
    bool v11;
    v11 = (v3type)==(ECL_SYM("DIRECTORY",1250));
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[572]))->cfun.entry(5, v1uiop_pathname__name, VV[594], v5uiop_pathname__dot_dot, VV[595], ecl_make_bool(v11)) /*  SPLIT-UNIX-NAMESTRING-DIRECTORY-COMPONENTS */;
   }
   {
    const int v11 = cl_env_copy->nvalues;
    v7 = value0;
    cl_object v12;
    v12 = (v11<=1)? ECL_NIL : cl_env_copy->values[1];
    v8 = v12;
    v12 = (v11<=2)? ECL_NIL : cl_env_copy->values[2];
    v9 = v12;
    v12 = (v11<=3)? ECL_NIL : cl_env_copy->values[3];
    v10 = v12;
   }
   {
    cl_object v11;                                /*  NAME                    */
    cl_object v12;                                /*  TYPE                    */
    if ((v3type)==(ECL_SYM("DIRECTORY",1250))) {
     goto L25;
    }
    if (!(v9==ECL_NIL)){
     goto L23;
    }
    goto L24;
L25:;
L24:;
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = ECL_NIL;
    cl_env_copy->values[0] = ECL_NIL;
    value0 = cl_env_copy->values[0];
    goto L22;
L23:;
    if (Null(v3type)){
     goto L27;
    }
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = v3type;
    cl_env_copy->values[0] = v9;
    value0 = cl_env_copy->values[0];
    goto L22;
L27:;
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[585]))->cfun.entry(1, v9) /*  SPLIT-NAME-TYPE */;
L22:;
    {
     const int v13 = cl_env_copy->nvalues;
     v11 = value0;
     cl_object v14;
     v14 = (v13<=1)? ECL_NIL : cl_env_copy->values[1];
     v12 = v14;
    }
    if (v10!=ECL_NIL) {
     goto L30;
    }
    T0 = CONS(v7,v8);
    goto L29;
L30:;
    T0 = ECL_NIL;
L29:;
    value0 = v4uiop_pathname__defaults;
    if (value0!=ECL_NIL) {
     goto L34;
    }
    T1 = ecl_cmp_symbol_value(cl_env_copy,VV[533]);
    goto L32;
L34:;
    T1 = value0;
    goto L32;
L32:;
    T2 = cl_make_pathname(8, ECL_SYM("DIRECTORY",1250), T0, ECL_SYM("NAME",1309), v11, ECL_SYM("TYPE",1356), v12, ECL_SYM("DEFAULTS",1247), T1);
    T3 = (cl_env_copy->function=ecl_fdefinition(VV[261]))->cfun.entry(2, VV[597], v2uiop_pathname__keys) /*  REMOVE-PLIST-KEYS */;
    value0 = cl_apply(3, VV[596], T2, T3);
    return value0;
   }
  }
 }
}
/* function definition for UNIX-NAMESTRING                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4399unix_namestring(cl_object volatile v1pathname)
{
 cl_object T0;
 volatile cl_object lex0[1];
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 lex0[0] = v1pathname;                            /*  PATHNAME                */
L1:;
 if (lex0[0]==ECL_NIL) {
  goto L4;
 }
 if (!(ECL_STRINGP(lex0[0]))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = lex0[0];
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (Null(cl_pathnamep(lex0[0]))){
  goto L6;
 }
 {
  volatile cl_object v2uiop_pathname__s;
  v2uiop_pathname__s = cl_make_string_output_stream(0);
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    {
     cl_object v3uiop_pathname__dir;
     cl_object v4uiop_pathname__name;
     cl_object v5uiop_pathname__name;
     cl_object v6type;
     cl_object v7type;
     T0 = cl_pathname_directory(1, lex0[0]);
     v3uiop_pathname__dir = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, T0) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
     v4uiop_pathname__name = cl_pathname_name(1, lex0[0]);
     if ((v4uiop_pathname__name)==(ECL_SYM("UNSPECIFIC",1357))) {
      goto L15;
     }
     v5uiop_pathname__name = v4uiop_pathname__name;
     goto L13;
L15:;
     v5uiop_pathname__name = ECL_NIL;
     goto L13;
L13:;
     v6type = cl_pathname_type(1, lex0[0]);
     if ((v6type)==(ECL_SYM("UNSPECIFIC",1357))) {
      goto L20;
     }
     v7type = v6type;
     goto L18;
L20:;
     v7type = ECL_NIL;
     goto L18;
L18:;
     {
      cl_object v8;
      if (!((v3uiop_pathname__dir)==(ECL_NIL))){
       goto L28;
      }
      value0 = VV[562];
      goto L26;
L28:;
      value0 = ECL_NIL;
      goto L26;
L26:;
      if (value0!=ECL_NIL) {
       goto L25;
      }
      if (!((v3uiop_pathname__dir)==(ECL_SYM("UNSPECIFIC",1357)))){
       goto L31;
      }
      v8 = VV[563];
      goto L23;
L31:;
      v8 = ECL_NIL;
      goto L23;
L25:;
      v8 = value0;
      goto L23;
L23:;
      if (Null(v8)){
       goto L33;
      }
      goto L22;
L33:;
      if (!((v3uiop_pathname__dir)==(VV[499]))){
       goto L35;
      }
      ecl_princ(VV[601],v2uiop_pathname__s);
      goto L22;
L35:;
      if (!(ECL_CONSP(v3uiop_pathname__dir))){
       goto L37;
      }
      {
       cl_object v9;
       cl_object v10uiop_pathname__relabs;
       v9 = v3uiop_pathname__dir;
       if (!(v9==ECL_NIL)){
        goto L41;
       }
       si_dm_too_few_arguments(v3uiop_pathname__dir);
L41:;
       {
        cl_object v11;
        v11 = ecl_car(v9);
        v9 = ecl_cdr(v9);
        v10uiop_pathname__relabs = v11;
       }
       if (!((v10uiop_pathname__relabs)==(ECL_SYM("RELATIVE",1336)))){
        goto L54;
       }
       value0 = VV[602];
       goto L52;
L54:;
       value0 = ECL_NIL;
       goto L52;
L52:;
       if (value0!=ECL_NIL) {
        goto L51;
       }
       if (!((v10uiop_pathname__relabs)==(ECL_SYM("ABSOLUTE",1226)))){
        goto L57;
       }
       value0 = VV[521];
       goto L49;
L57:;
       value0 = ECL_NIL;
       goto L49;
L51:;
       goto L49;
L49:;
       if (value0!=ECL_NIL) {
        goto L48;
       }
       LC4398err(lex0);
       goto L46;
L48:;
       goto L46;
L46:;
       if (!((v10uiop_pathname__relabs)==(ECL_SYM("ABSOLUTE",1226)))){
        goto L59;
       }
       ecl_princ_char((ecl_character)(47),v2uiop_pathname__s);
L59:;
       {
        cl_object v11;
        cl_object v12uiop_pathname__x;
        cl_object v13;
        {
         cl_object v14;
         v14 = v9;
         if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         v11 = v14;
        }
        v12uiop_pathname__x = ECL_NIL;
        v13 = v11;
L66:;
        if (!(ecl_endp(v13))){
         goto L68;
        }
        goto L67;
L68:;
        v12uiop_pathname__x = ECL_CONS_CAR(v13);
        {
         cl_object v14;
         v14 = ECL_CONS_CDR(v13);
         if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         v13 = v14;
        }
        if (!((v12uiop_pathname__x)==(ECL_SYM("BACK",1230)))){
         goto L82;
        }
        goto L79;
L82:;
        goto L80;
L80:;
        if (!((v12uiop_pathname__x)==(ECL_SYM("UP",1359)))){
         goto L77;
        }
        goto L78;
L79:;
L78:;
        ecl_princ(VV[603],v2uiop_pathname__s);
        goto L76;
L77:;
        if (!(ecl_equal(v12uiop_pathname__x,VV[96]))){
         goto L85;
        }
        LC4398err(lex0);
        goto L76;
L85:;
        if (!(ECL_STRINGP(v12uiop_pathname__x))){
         goto L87;
        }
        cl_format(3, v2uiop_pathname__s, VV[604], v12uiop_pathname__x);
        goto L76;
L87:;
        LC4398err(lex0);
L76:;
        goto L66;
L67:;
        goto L22;
       }
      }
L37:;
      LC4398err(lex0);
     }
L22:;
     if (Null(v5uiop_pathname__name)){
      goto L90;
     }
     if (!(ECL_STRINGP(v5uiop_pathname__name))){
      goto L95;
     }
     if (v7type==ECL_NIL) {
      goto L92;
     }
     if (ECL_STRINGP(v7type)) {
      goto L92;
     }
     goto L93;
L95:;
     goto L93;
L93:;
     LC4398err(lex0);
L92:;
     cl_format(4, v2uiop_pathname__s, VV[605], v5uiop_pathname__name, v7type);
     goto L10;
L90:;
     value0 = ecl_make_bool(v7type==ECL_NIL);
     if (value0!=ECL_NIL) {
      goto L99;
     }
     LC4398err(lex0);
     goto L10;
L99:;
     goto L10;
    }
L10:;
    cl_env_copy->values[0] = cl_get_output_stream_string(v2uiop_pathname__s);
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   cl_close(1, v2uiop_pathname__s);
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
L6:;
 value0 = si_etypecase_error(lex0[0], VV[606]);
 return value0;
}
static cl_object L4399unix_namestring_va(cl_narg narg, cl_object v3pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[573]);
 {
  return L4399unix_namestring(v3pathname);
 }
}
/* function definition for SUBPATHNAME                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4400subpathname(cl_narg narg, cl_object v1pathname, cl_object v2uiop_pathname__subpath, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[608]);
 {
  cl_object v3type;
  ecl_va_list args; ecl_va_start(args,v2uiop_pathname__subpath,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4400subpathnamekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v3type = keyvars[0];
  }
  if (Null(cl_pathnamep(v2uiop_pathname__subpath))){
   goto L5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v2uiop_pathname__subpath) /*  ABSOLUTE-PATHNAME-P */;
  goto L3;
L5:;
  value0 = ECL_NIL;
  goto L3;
L3:;
  if (value0!=ECL_NIL) {
   goto L2;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(5, v2uiop_pathname__subpath, ECL_SYM("TYPE",1356), v3type, VV[609], ECL_T) /*  PARSE-UNIX-NAMESTRING */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[555]))->cfun.entry(1, v1pathname) /*  PATHNAME-DIRECTORY-PATHNAME */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, T0, T1) /*  MERGE-PATHNAMES* */;
  return value0;
L2:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for SUBPATHNAME*                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4401subpathname_(cl_narg narg, cl_object v1pathname, cl_object v2uiop_pathname__subpath, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[611]);
 {
  cl_object v3type;
  ecl_va_list args; ecl_va_start(args,v2uiop_pathname__subpath,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4401subpathname_keys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v3type = keyvars[0];
  }
  if (Null(v1pathname)){
   goto L2;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[565]))->cfun.entry(1, v1pathname) /*  ENSURE-DIRECTORY-PATHNAME */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(4, T0, v2uiop_pathname__subpath, ECL_SYM("TYPE",1356), v3type) /*  SUBPATHNAME */;
  return value0;
L2:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for PATHNAME-ROOT                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4402pathname_root(cl_object v1pathname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_make_pathname(10, ECL_SYM("DIRECTORY",1250), VV[521], ECL_SYM("NAME",1309), ECL_NIL, ECL_SYM("TYPE",1356), ECL_NIL, ECL_SYM("VERSION",1364), ECL_NIL, ECL_SYM("DEFAULTS",1247), v1pathname);
 return value0;
}
static cl_object L4402pathname_root_va(cl_narg narg, cl_object v2pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[613]);
 {
  return L4402pathname_root(v2pathname);
 }
}
/* function definition for PATHNAME-HOST-PATHNAME                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4403pathname_host_pathname(cl_object v1pathname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_make_pathname(12, ECL_SYM("DIRECTORY",1250), ECL_NIL, ECL_SYM("NAME",1309), ECL_NIL, ECL_SYM("TYPE",1356), ECL_NIL, ECL_SYM("VERSION",1364), ECL_NIL, ECL_SYM("DEVICE",1248), ECL_NIL, ECL_SYM("DEFAULTS",1247), v1pathname);
 return value0;
}
static cl_object L4403pathname_host_pathname_va(cl_narg narg, cl_object v2pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[615]);
 {
  return L4403pathname_host_pathname(v2pathname);
 }
}
/* function definition for ENSURE-ABSOLUTE-PATHNAME                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4404ensure_absolute_pathname(cl_narg narg, cl_object v1uiop_pathname__path, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[617]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[617]);
 {
  cl_object v2uiop_pathname__defaults;
  cl_object v3uiop_pathname__on_error;
  va_list args; va_start(args,v1uiop_pathname__path);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_pathname__defaults = ECL_NIL;
   } else {
    i++;
    v2uiop_pathname__defaults = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v3uiop_pathname__on_error = ECL_SYM("ERROR",339);
   } else {
    i++;
    v3uiop_pathname__on_error = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v4;
   v4 = (cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v1uiop_pathname__path) /*  ABSOLUTE-PATHNAME-P */;
   if (Null(v4)){
    goto L4;
   }
   value0 = v4;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(ECL_STRINGP(v1uiop_pathname__path))){
    goto L6;
   }
   T0 = cl_pathname(v1uiop_pathname__path);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[617]))->cfun.entry(3, T0, v2uiop_pathname__defaults, v3uiop_pathname__on_error) /*  ENSURE-ABSOLUTE-PATHNAME */;
   return value0;
L6:;
   if (cl_pathnamep(v1uiop_pathname__path)!=ECL_NIL) {
    goto L8;
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(3, v3uiop_pathname__on_error, VV[618], v1uiop_pathname__path) /*  CALL-FUNCTION */;
   return value0;
L8:;
   {
    cl_object v5;
    {
     cl_object v6uiop_pathname__default_pathname;
     if (Null(cl_pathnamep(v2uiop_pathname__defaults))){
      goto L12;
     }
     v6uiop_pathname__default_pathname = v2uiop_pathname__defaults;
     goto L11;
L12:;
     v6uiop_pathname__default_pathname = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(1, v2uiop_pathname__defaults) /*  CALL-FUNCTION */;
L11:;
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v6uiop_pathname__default_pathname) /*  ABSOLUTE-PATHNAME-P */)){
      goto L17;
     }
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, v1uiop_pathname__path, v6uiop_pathname__default_pathname) /*  MERGE-PATHNAMES* */;
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, T0) /*  ABSOLUTE-PATHNAME-P */;
     goto L16;
L17:;
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(3, v3uiop_pathname__on_error, VV[619], v6uiop_pathname__default_pathname) /*  CALL-FUNCTION */;
L16:;
     if (value0!=ECL_NIL) {
      goto L15;
     }
     v5 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(4, v3uiop_pathname__on_error, VV[620], v1uiop_pathname__path, v6uiop_pathname__default_pathname) /*  CALL-FUNCTION */;
     goto L10;
L15:;
     v5 = value0;
     goto L10;
    }
L10:;
    if (Null(v5)){
     goto L19;
    }
    value0 = v5;
    cl_env_copy->nvalues = 1;
    return value0;
L19:;
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(4, v3uiop_pathname__on_error, VV[621], v1uiop_pathname__path, v2uiop_pathname__defaults) /*  CALL-FUNCTION */;
    return value0;
   }
  }
 }
}
/* function definition for SUBPATHP                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4405subpathp(cl_object v1uiop_pathname__maybe_subpath, cl_object v2uiop_pathname__base_pathname)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_pathnamep(v1uiop_pathname__maybe_subpath))){
  goto L3;
 }
 if (Null(cl_pathnamep(v2uiop_pathname__base_pathname))){
  goto L3;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v1uiop_pathname__maybe_subpath) /*  ABSOLUTE-PATHNAME-P */)){
  goto L3;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v2uiop_pathname__base_pathname) /*  ABSOLUTE-PATHNAME-P */)){
  goto L3;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, v2uiop_pathname__base_pathname) /*  DIRECTORY-PATHNAME-P */)){
  goto L3;
 }
 if (cl_wild_pathname_p(1, v2uiop_pathname__base_pathname)!=ECL_NIL) {
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[613]))->cfun.entry(1, v1uiop_pathname__maybe_subpath) /*  PATHNAME-ROOT */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[613]))->cfun.entry(1, v2uiop_pathname__base_pathname) /*  PATHNAME-ROOT */;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[536]))->cfun.entry(2, T0, T1) /*  PATHNAME-EQUAL */)){
  goto L3;
 }
 ecl_bds_bind(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34),ecl_cmp_symbol_value(cl_env_copy,VV[533])); /*  *DEFAULT-PATHNAME-DEFAULTS* */
 {
  cl_object v3uiop_pathname__enough;
  v3uiop_pathname__enough = cl_enough_namestring(2, v1uiop_pathname__maybe_subpath, v2uiop_pathname__base_pathname);
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[546]))->cfun.entry(1, v3uiop_pathname__enough) /*  RELATIVE-PATHNAME-P */)){
   goto L13;
  }
  value0 = cl_pathname(v3uiop_pathname__enough);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L13:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4405subpathp_va(cl_narg narg, cl_object v4uiop_pathname__maybe_subpath, cl_object v5uiop_pathname__base_pathname, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[623]);
 {
  return L4405subpathp(v4uiop_pathname__maybe_subpath, v5uiop_pathname__base_pathname);
 }
}
/* function definition for ENOUGH-PATHNAME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4406enough_pathname(cl_object v1uiop_pathname__maybe_subpath, cl_object v2uiop_pathname__base_pathname)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  if (Null(v1uiop_pathname__maybe_subpath)){
   goto L3;
  }
  v3 = cl_pathname(v1uiop_pathname__maybe_subpath);
  goto L2;
L3:;
  v3 = ECL_NIL;
L2:;
  if (Null(v2uiop_pathname__base_pathname)){
   goto L6;
  }
  T0 = cl_pathname(v2uiop_pathname__base_pathname);
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[617]))->cfun.entry(1, T0) /*  ENSURE-ABSOLUTE-PATHNAME */;
  goto L5;
L6:;
  v4 = ECL_NIL;
L5:;
  if (Null(v4)){
   goto L12;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[623]))->cfun.entry(2, v3, v4) /*  SUBPATHP */;
  goto L10;
L12:;
  value0 = ECL_NIL;
  goto L10;
L10:;
  if (value0!=ECL_NIL) {
   goto L9;
  }
  value0 = v3;
  cl_env_copy->nvalues = 1;
  return value0;
L9:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4406enough_pathname_va(cl_narg narg, cl_object v5uiop_pathname__maybe_subpath, cl_object v6uiop_pathname__base_pathname, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[625]);
 {
  return L4406enough_pathname(v5uiop_pathname__maybe_subpath, v6uiop_pathname__base_pathname);
 }
}
/* function definition for CALL-WITH-ENOUGH-PATHNAME                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4407call_with_enough_pathname(cl_object v1uiop_pathname__maybe_subpath, cl_object v2uiop_pathname__defaults_pathname, cl_object v3uiop_pathname__thunk)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  cl_object v5;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[625]))->cfun.entry(2, v1uiop_pathname__maybe_subpath, v2uiop_pathname__defaults_pathname) /*  ENOUGH-PATHNAME */;
  value0 = v2uiop_pathname__defaults_pathname;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  v5 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34));
  goto L3;
L5:;
  v5 = value0;
  goto L3;
L3:;
  ecl_bds_bind(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34),v5); /*  *DEFAULT-PATHNAME-DEFAULTS* */
  value0 = ecl_function_dispatch(cl_env_copy,v3uiop_pathname__thunk)(1, v4);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L4407call_with_enough_pathname_va(cl_narg narg, cl_object v6uiop_pathname__maybe_subpath, cl_object v7uiop_pathname__defaults_pathname, cl_object v8uiop_pathname__thunk, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[627]);
 {
  return L4407call_with_enough_pathname(v6uiop_pathname__maybe_subpath, v7uiop_pathname__defaults_pathname, v8uiop_pathname__thunk);
 }
}
/* local function WITH-ENOUGH-PATHNAME                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4408with_enough_pathname(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_pathname__pathname_var;
  cl_object v7;
  cl_object v8pathname;
  cl_object v9;
  cl_object v10uiop_pathname__defaults;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v11;
   v11 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v11;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v11;
   v11 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_pathname__pathname_var = v11;
  }
  v7 = si_search_keyword(v5, ECL_SYM("PATHNAME",1322));
  if (!((v7)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L18;
  }
  v8pathname = v6uiop_pathname__pathname_var;
  goto L17;
L18:;
  v8pathname = v7;
L17:;
  v9 = si_search_keyword(v5, ECL_SYM("DEFAULTS",1247));
  if (!((v9)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L22;
  }
  v10uiop_pathname__defaults = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34));
  goto L21;
L22:;
  v10uiop_pathname__defaults = v9;
L21:;
  si_check_keyword(2, v5, VV[630]);
  T0 = ecl_list1(v6uiop_pathname__pathname_var);
  T1 = cl_listX(3, ECL_SYM("LAMBDA",454), T0, v3);
  T2 = cl_list(2, ECL_SYM("FUNCTION",398), T1);
  value0 = cl_list(4, VV[627], v8pathname, v10uiop_pathname__defaults, T2);
  return value0;
 }
}
static cl_object LC4408with_enough_pathname_va(cl_narg narg, cl_object v11, cl_object v12, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[629]);
 {
  return LC4408with_enough_pathname(v11, v12);
 }
}
/* function definition for WILDEN                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4409wilden(cl_object v1uiop_pathname__path)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, ecl_cmp_symbol_value(cl_env_copy,VV[639]), v1uiop_pathname__path) /*  MERGE-PATHNAMES* */;
 return value0;
}
static cl_object L4409wilden_va(cl_narg narg, cl_object v2uiop_pathname__path, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[640]);
 {
  return L4409wilden(v2uiop_pathname__path);
 }
}
/* function definition for RELATIVIZE-DIRECTORY-COMPONENT                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4410relativize_directory_component(cl_object v1uiop_pathname__directory_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2directory;
  v2directory = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, v1uiop_pathname__directory_component) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
  if (!(ECL_STRINGP(v2directory))){
   goto L3;
  }
  value0 = cl_list(2, ECL_SYM("RELATIVE",1336), v2directory);
  return value0;
L3:;
  T0 = ecl_car(v2directory);
  if (!((T0)==(ECL_SYM("ABSOLUTE",1226)))){
   goto L5;
  }
  T0 = ecl_cdr(v2directory);
  value0 = CONS(ECL_SYM("RELATIVE",1336),T0);
  cl_env_copy->nvalues = 1;
  return value0;
L5:;
  value0 = v2directory;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4410relativize_directory_component_va(cl_narg narg, cl_object v3uiop_pathname__directory_component, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[642]);
 {
  return L4410relativize_directory_component(v3uiop_pathname__directory_component);
 }
}
/* function definition for RELATIVIZE-PATHNAME-DIRECTORY                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4411relativize_pathname_directory(cl_object v1uiop_pathname__pathspec)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_pathname__p;
  v2uiop_pathname__p = cl_pathname(v1uiop_pathname__pathspec);
  T0 = cl_pathname_directory(1, v2uiop_pathname__p);
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[642]))->cfun.entry(1, T0) /*  RELATIVIZE-DIRECTORY-COMPONENT */;
  value0 = cl_make_pathname(4, ECL_SYM("DIRECTORY",1250), T1, ECL_SYM("DEFAULTS",1247), v2uiop_pathname__p);
  return value0;
 }
}
static cl_object L4411relativize_pathname_directory_va(cl_narg narg, cl_object v3uiop_pathname__pathspec, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[644]);
 {
  return L4411relativize_pathname_directory(v3uiop_pathname__pathspec);
 }
}
/* function definition for DIRECTORY-SEPARATOR-FOR-HOST                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4412directory_separator_for_host(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[646]);
 {
  cl_object v1pathname;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1pathname = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34));
   } else {
    i++;
    v1pathname = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v2uiop_pathname__foo;
   v2uiop_pathname__foo = cl_make_pathname(4, ECL_SYM("DIRECTORY",1250), VV[647], ECL_SYM("DEFAULTS",1247), v1pathname);
   T0 = cl_namestring(v2uiop_pathname__foo);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[287]))->cfun.entry(1, T0) /*  LAST-CHAR */;
   return value0;
  }
 }
}
/* function definition for DIRECTORIZE-PATHNAME-HOST-DEVICE                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4414directorize_pathname_host_device(cl_object v1pathname)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[527]))->cfun.entry(1, v1pathname) /*  PHYSICAL-PATHNAME-P */)){
  goto L2;
 }
 value0 = v1pathname;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 {
  cl_object v2uiop_pathname__root;
  cl_object v3uiop_pathname__wild_root;
  cl_object v4uiop_pathname__absolute_pathname;
  cl_object v5uiop_pathname__root_namestring;
  cl_object v6uiop_pathname__root_string;
  cl_object env1 = env0;
  v2uiop_pathname__root = (cl_env_copy->function=ecl_fdefinition(VV[613]))->cfun.entry(1, v1pathname) /*  PATHNAME-ROOT */;
  v3uiop_pathname__wild_root = (cl_env_copy->function=ecl_fdefinition(VV[640]))->cfun.entry(1, v2uiop_pathname__root) /*  WILDEN */;
  v4uiop_pathname__absolute_pathname = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, v1pathname, v2uiop_pathname__root) /*  MERGE-PATHNAMES* */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[646]))->cfun.entry(1, v2uiop_pathname__root) /*  DIRECTORY-SEPARATOR-FOR-HOST */;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(T0,env1);                    /*  SEPARATOR               */
  v5uiop_pathname__root_namestring = cl_namestring(v2uiop_pathname__root);
  {
   cl_object v7;
   v7 = ecl_make_cclosure_va((cl_objectfn)LC4413__lambda2327,env1,Cblock,1);
   T0 = v7;
  }
  v6uiop_pathname__root_string = cl_substitute_if(3, ECL_CODE_CHAR(47), T0, v5uiop_pathname__root_namestring);
  {
   cl_object v7;                                  /*  PATH                    */
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[572]))->cfun.entry(3, v6uiop_pathname__root_string, VV[595], ECL_T) /*  SPLIT-UNIX-NAMESTRING-DIRECTORY-COMPONENTS */;
   {
    const int v8 = cl_env_copy->nvalues;
    cl_object v9;
    v9 = (v8<=1)? ECL_NIL : cl_env_copy->values[1];
    v7 = v9;
   }
   {
    cl_object v8uiop_pathname__new_base;
    T0 = CONS(ECL_SYM("ABSOLUTE",1226),v7);
    v8uiop_pathname__new_base = cl_make_pathname(4, ECL_SYM("DEFAULTS",1247), v2uiop_pathname__root, ECL_SYM("DIRECTORY",1250), T0);
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[640]))->cfun.entry(1, v8uiop_pathname__new_base) /*  WILDEN */;
    value0 = cl_translate_pathname(3, v4uiop_pathname__absolute_pathname, v3uiop_pathname__wild_root, T0);
    return value0;
   }
  }
 }
}
static cl_object L4414directorize_pathname_host_device_va(cl_narg narg, cl_object v7pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[649]);
 {
  return L4414directorize_pathname_host_device(v7pathname);
 }
}
/* function definition for TRANSLATE-PATHNAME*                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4415translate_pathname_(cl_narg narg, cl_object v1uiop_pathname__path, cl_object v2uiop_pathname__absolute_source, cl_object v3uiop_pathname__destination, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[652]);
 if (ecl_unlikely(narg>5)) FEwrong_num_arguments(VV[652]);
 {
  cl_object v4uiop_pathname__root;
  cl_object v5uiop_pathname__source;
  va_list args; va_start(args,v3uiop_pathname__destination);
  {
   int i = 3;
   if (i >= narg) {
    v4uiop_pathname__root = ECL_NIL;
   } else {
    i++;
    v4uiop_pathname__root = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v5uiop_pathname__source = ECL_NIL;
   } else {
    i++;
    v5uiop_pathname__source = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(cl_functionp(v3uiop_pathname__destination))){
   goto L3;
  }
  value0 = ecl_function_dispatch(cl_env_copy,v3uiop_pathname__destination)(2, v1uiop_pathname__path, v2uiop_pathname__absolute_source);
  return value0;
L3:;
  if (!((v3uiop_pathname__destination)==(ECL_T))){
   goto L5;
  }
  value0 = v1uiop_pathname__path;
  cl_env_copy->nvalues = 1;
  return value0;
L5:;
  if (cl_pathnamep(v3uiop_pathname__destination)!=ECL_NIL) {
   goto L7;
  }
  value0 = cl_error(1, VV[653]);
  return value0;
L7:;
  if ((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v3uiop_pathname__destination) /*  ABSOLUTE-PATHNAME-P */!=ECL_NIL) {
   goto L9;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, v3uiop_pathname__destination, v4uiop_pathname__root) /*  MERGE-PATHNAMES* */;
  value0 = cl_translate_pathname(3, v1uiop_pathname__path, v2uiop_pathname__absolute_source, T0);
  return value0;
L9:;
  if (Null(v4uiop_pathname__root)){
   goto L11;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[649]))->cfun.entry(1, v1uiop_pathname__path) /*  DIRECTORIZE-PATHNAME-HOST-DEVICE */;
  value0 = cl_translate_pathname(3, T0, v2uiop_pathname__absolute_source, v3uiop_pathname__destination);
  return value0;
L11:;
  value0 = cl_translate_pathname(3, v1uiop_pathname__path, v2uiop_pathname__absolute_source, v3uiop_pathname__destination);
  return value0;
 }
}
/* function definition for NATIVE-NAMESTRING                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4416native_namestring(cl_object v1uiop_filesystem__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1uiop_filesystem__x)){
  goto L2;
 }
 {
  cl_object v2uiop_filesystem__p;
  v2uiop_filesystem__p = cl_pathname(v1uiop_filesystem__x);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[573]))->cfun.entry(1, v2uiop_filesystem__p) /*  UNIX-NAMESTRING */;
  return value0;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4416native_namestring_va(cl_narg narg, cl_object v3uiop_filesystem__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[656]);
 {
  return L4416native_namestring(v3uiop_filesystem__x);
 }
}
/* function definition for PARSE-NATIVE-NAMESTRING                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4417parse_native_namestring(cl_narg narg, cl_object v1string, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[658]);
 {
  cl_object v2uiop_filesystem__constraints;
  cl_object v3uiop_filesystem__ensure_directory;
  ecl_va_list args; ecl_va_start(args,v1string,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4417parse_native_namestringkeys,keyvars,(cl_object*)&v2uiop_filesystem__constraints,TRUE);
   ecl_va_end(args);
   v3uiop_filesystem__ensure_directory = keyvars[0];
  }
  {
   cl_object v4;
   v4 = v1string;
   if (ECL_STRINGP(v4)) {
    goto L3;
   }
   if (v4==ECL_NIL) {
    goto L3;
   }
   v1string = si_do_check_type(v4, VV[659], ECL_NIL, ECL_SYM("STRING",808));
L3:;
  }
  {
   cl_object v4pathname;
   cl_object v5pathname;
   if (Null(v1string)){
    goto L8;
   }
   ecl_bds_bind(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34),ecl_cmp_symbol_value(cl_env_copy,VV[533])); /*  *DEFAULT-PATHNAME-DEFAULTS* */
   v4pathname = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(3, v1string, VV[595], v3uiop_filesystem__ensure_directory) /*  PARSE-UNIX-NAMESTRING */;
   ecl_bds_unwind1(cl_env_copy);
   goto L7;
L8:;
   v4pathname = ECL_NIL;
L7:;
   if (Null(v3uiop_filesystem__ensure_directory)){
    goto L11;
   }
   if (Null(v4pathname)){
    goto L14;
   }
   v5pathname = (cl_env_copy->function=ecl_fdefinition(VV[565]))->cfun.entry(1, v4pathname) /*  ENSURE-DIRECTORY-PATHNAME */;
   goto L10;
L14:;
   v5pathname = ECL_NIL;
   goto L10;
L11:;
   v5pathname = v4pathname;
L10:;
   value0 = cl_apply(3, VV[596], v5pathname, v2uiop_filesystem__constraints);
   return value0;
  }
 }
}
/* function definition for TRUENAME*                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4419truename_(cl_object volatile v1uiop_filesystem__p)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1uiop_filesystem__p)){
  goto L2;
 }
 if (!(ECL_STRINGP(v1uiop_filesystem__p))){
  goto L4;
 }
 ecl_bds_bind(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34),ecl_cmp_symbol_value(cl_env_copy,VV[533])); /*  *DEFAULT-PATHNAME-DEFAULTS* */
 v1uiop_filesystem__p = cl_parse_namestring(1, v1uiop_filesystem__p);
 ecl_bds_unwind1(cl_env_copy);
L4:;
 {
  volatile cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(ECL_NIL,env1);
  {
   volatile cl_object env2 = env1;
   CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY        */
   {
    ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
    if (__ecl_frs_push_result!=0) {
    if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
     goto L8;
    }
    ecl_internal_error("GO found an inexistent tag");
    } else {
    {
     cl_object v2;
     v2 = ecl_make_cclosure_va((cl_objectfn)LC4418__lambda2352,env2,Cblock,1);
     T0 = v2;
    }
    T1 = CONS(ECL_SYM("ERROR",339),T0);
    T2 = ecl_list1(T1);
    T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
    ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
    value0 = cl_truename(v1uiop_filesystem__p);
    ecl_frs_pop_n(cl_env_copy, 1);
    ecl_bds_unwind1(cl_env_copy);
    goto L7;
L8:;
    {
     cl_object v2condition;
     v2condition = ECL_CONS_CAR(CLV0);
     cl_env_copy->nvalues = 2;
     cl_env_copy->values[1] = v2condition;
     cl_env_copy->values[0] = ECL_NIL;
     value0 = cl_env_copy->values[0];
     ecl_frs_pop_n(cl_env_copy, 1);
     goto L7;
    }
    }
   }
  }
 }
L7:;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4419truename__va(cl_narg narg, cl_object v2uiop_filesystem__p, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[661]);
 {
  return L4419truename_(v2uiop_filesystem__p);
 }
}
/* function definition for SAFE-FILE-WRITE-DATE                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4421safe_file_write_date(cl_object volatile v1pathname)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1pathname)){
  goto L3;
 }
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env0); /*  TAGBODY          */
 {
  ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV0));
  if (__ecl_frs_push_result!=0) {
  if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
   goto L5;
  }
  ecl_internal_error("GO found an inexistent tag");
  } else {
  {
   cl_object v2;
   v2 = ecl_make_cclosure_va((cl_objectfn)LC4420__lambda2364,env0,Cblock,1);
   T0 = v2;
  }
  T1 = CONS(ECL_SYM("FILE-ERROR",355),T0);
  T2 = ecl_list1(T1);
  T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
  ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[529]))->cfun.entry(1, v1pathname) /*  PHYSICALIZE-PATHNAME */;
  value0 = cl_file_write_date(T0);
  ecl_frs_pop_n(cl_env_copy, 1);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L5:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_frs_pop_n(cl_env_copy, 1);
  return value0;
  }
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4421safe_file_write_date_va(cl_narg narg, cl_object v2pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[665]);
 {
  return L4421safe_file_write_date(v2pathname);
 }
}
/* function definition for PROBE-FILE*                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4423probe_file_(volatile cl_narg narg, cl_object volatile v1uiop_filesystem__p, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[669]);
 {
  cl_object volatile v2truename;
  ecl_va_list args; ecl_va_start(args,v1uiop_filesystem__p,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4423probe_file_keys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2truename = keyvars[0];
  }
  {
   volatile cl_object env1 = env0;
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(ECL_NIL,env1);
   {
    volatile cl_object env2 = env1;
    CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY       */
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
     if (__ecl_frs_push_result!=0) {
     if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
      goto L2;
     }
     ecl_internal_error("GO found an inexistent tag");
     } else {
     {
      cl_object v3;
      v3 = ecl_make_cclosure_va((cl_objectfn)LC4422__lambda2378,env2,Cblock,1);
      T0 = v3;
     }
     T1 = CONS(ECL_SYM("ERROR",339),T0);
     T2 = ecl_list1(T1);
     T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
     ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
     v1uiop_filesystem__p = ecl_function_dispatch(cl_env_copy,VV[596])(13, v1uiop_filesystem__p, VV[672], VV[673], VV[674], ECL_T, VV[675], ECL_T, ECL_SYM("DEFAULTS",1247), VV[676], VV[677], ECL_T, VV[678], ECL_NIL);
     if (Null(v1uiop_filesystem__p)){
      goto L7;
     }
     if (Null(v2truename)){
      goto L9;
     }
     value0 = cl_probe_file(v1uiop_filesystem__p);
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     goto L1;
L9:;
     if (Null(cl_file_write_date(v1uiop_filesystem__p))){
      goto L12;
     }
     value0 = v1uiop_filesystem__p;
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     goto L1;
L12:;
     value0 = ECL_NIL;
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     goto L1;
L7:;
     value0 = ECL_NIL;
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     goto L1;
L2:;
     {
      cl_object v3condition;
      v3condition = ECL_CONS_CAR(CLV0);
      cl_env_copy->nvalues = 2;
      cl_env_copy->values[1] = v3condition;
      cl_env_copy->values[0] = ECL_NIL;
      value0 = cl_env_copy->values[0];
      ecl_frs_pop_n(cl_env_copy, 1);
      goto L1;
     }
     }
    }
   }
  }
L1:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for DIRECTORY-EXISTS-P                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4424directory_exists_p(cl_object v1uiop_filesystem__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_filesystem__p;
  v2uiop_filesystem__p = (cl_env_copy->function=ecl_fdefinition(VV[669]))->cfun.entry(3, v1uiop_filesystem__x, VV[681], ECL_T) /*  PROBE-FILE* */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, v2uiop_filesystem__p) /*  DIRECTORY-PATHNAME-P */)){
   goto L4;
  }
  value0 = v2uiop_filesystem__p;
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4424directory_exists_p_va(cl_narg narg, cl_object v3uiop_filesystem__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[680]);
 {
  return L4424directory_exists_p(v3uiop_filesystem__x);
 }
}
/* function definition for FILE-EXISTS-P                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4425file_exists_p(cl_object v1uiop_filesystem__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_filesystem__p;
  v2uiop_filesystem__p = (cl_env_copy->function=ecl_fdefinition(VV[669]))->cfun.entry(3, v1uiop_filesystem__x, VV[681], ECL_T) /*  PROBE-FILE* */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[550]))->cfun.entry(1, v2uiop_filesystem__p) /*  FILE-PATHNAME-P */)){
   goto L4;
  }
  value0 = v2uiop_filesystem__p;
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4425file_exists_p_va(cl_narg narg, cl_object v3uiop_filesystem__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[683]);
 {
  return L4425file_exists_p(v3uiop_filesystem__x);
 }
}
/* function definition for DIRECTORY*                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4426directory_(cl_narg narg, cl_object v1uiop_filesystem__pathname_spec, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[685]);
 {
  cl_object v2uiop_filesystem__keys;
  ecl_va_list args; ecl_va_start(args,v1uiop_filesystem__pathname_spec,narg,1);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v2uiop_filesystem__keys,TRUE);
  ecl_va_end(args);
  T0 = ecl_append(v2uiop_filesystem__keys,ECL_NIL);
  value0 = cl_apply(3, ECL_SYM("DIRECTORY",305), v1uiop_filesystem__pathname_spec, T0);
  return value0;
 }
}
/* function definition for FILTER-LOGICAL-DIRECTORY-RESULTS                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4428filter_logical_directory_results(cl_object volatile v1directory, cl_object volatile v2uiop_filesystem__entries, cl_object volatile v3uiop_filesystem__merger)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[525]))->cfun.entry(1, v1directory) /*  LOGICAL-PATHNAME-P */)){
  goto L2;
 }
 {
  volatile cl_object v4;
  volatile cl_object v5uiop_filesystem__f;
  volatile cl_object v6;
  {
   cl_object v7;
   v7 = v2uiop_filesystem__entries;
   if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v4 = v7;
  }
  v5uiop_filesystem__f = ECL_NIL;
  v6 = v4;
  {
   volatile cl_object v7uiop_filesystem__p;
   v7uiop_filesystem__p = ECL_NIL;
   {
    volatile cl_object v8;
    volatile cl_object v9;
    v8 = ecl_list1(ECL_NIL);
    v9 = v8;
L13:;
    if (!(ecl_endp(v6))){
     goto L15;
    }
    goto L14;
L15:;
    v5uiop_filesystem__f = ECL_CONS_CAR(v6);
    {
     cl_object v10;
     v10 = ECL_CONS_CDR(v6);
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v6 = v10;
    }
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[525]))->cfun.entry(1, v5uiop_filesystem__f) /*  LOGICAL-PATHNAME-P */)){
     goto L29;
    }
    value0 = v5uiop_filesystem__f;
    goto L27;
L29:;
    value0 = ECL_NIL;
    goto L27;
L27:;
    if (value0!=ECL_NIL) {
     goto L26;
    }
    {
     volatile cl_object v10uiop_filesystem__u;
     {
      volatile cl_object env1 = env0;
      env1 = ECL_NIL;
      CLV0 = env1 = CONS(ECL_NIL,env1);
      {
       volatile cl_object env2 = env1;
       CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY    */
       {
        ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
        if (__ecl_frs_push_result!=0) {
        if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
         goto L32;
        }
        ecl_internal_error("GO found an inexistent tag");
        } else {
        {
         cl_object v11;
         v11 = ecl_make_cclosure_va((cl_objectfn)LC4427__lambda2405,env2,Cblock,1);
         T1 = v11;
        }
        T2 = CONS(ECL_SYM("ERROR",339),T1);
        T3 = ecl_list1(T2);
        T4 = CONS(T3,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
        ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T4); /*  *HANDLER-CLUSTERS* */
        v10uiop_filesystem__u = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, v3uiop_filesystem__merger, v5uiop_filesystem__f) /*  CALL-FUNCTION */;
        ecl_frs_pop_n(cl_env_copy, 1);
        ecl_bds_unwind1(cl_env_copy);
        goto L31;
L32:;
        {
         cl_object v11condition;
         v11condition = ECL_CONS_CAR(CLV0);
         cl_env_copy->nvalues = 2;
         cl_env_copy->values[1] = v11condition;
         cl_env_copy->values[0] = ECL_NIL;
         v10uiop_filesystem__u = cl_env_copy->values[0];
         ecl_frs_pop_n(cl_env_copy, 1);
         goto L31;
        }
        }
       }
      }
     }
L31:;
     if (Null(v10uiop_filesystem__u)){
      goto L38;
     }
     T1 = (cl_env_copy->function=ecl_fdefinition(VV[661]))->cfun.entry(1, v10uiop_filesystem__u) /*  TRUENAME* */;
     T2 = (cl_env_copy->function=ecl_fdefinition(VV[661]))->cfun.entry(1, v5uiop_filesystem__f) /*  TRUENAME* */;
     if (!(ecl_equal(T1,T2))){
      goto L38;
     }
     v7uiop_filesystem__p = v10uiop_filesystem__u;
     goto L24;
L38:;
     v7uiop_filesystem__p = ECL_NIL;
     goto L24;
    }
L26:;
    v7uiop_filesystem__p = value0;
    goto L24;
L24:;
    if (Null(v7uiop_filesystem__p)){
     goto L41;
    }
    {
     cl_object v10;
     v10 = v9;
     if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T1 = v10;
    }
    v9 = ecl_list1(v7uiop_filesystem__p);
    (ECL_CONS_CDR(T1)=v9,T1);
L41:;
    goto L13;
L14:;
    T0 = ecl_cdr(v8);
    goto L4;
   }
  }
 }
L4:;
 value0 = cl_remove_duplicates(3, T0, ECL_SYM("TEST",1353), VV[536]);
 return value0;
L2:;
 value0 = v2uiop_filesystem__entries;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4428filter_logical_directory_results_va(cl_narg narg, cl_object v4directory, cl_object v5uiop_filesystem__entries, cl_object v6uiop_filesystem__merger, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[687]);
 {
  return L4428filter_logical_directory_results(v4directory, v5uiop_filesystem__entries, v6uiop_filesystem__merger);
 }
}
/* function definition for DIRECTORY-FILES                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4431directory_files(volatile cl_narg narg, cl_object volatile v1directory, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[691]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[691]);
 {
  cl_object volatile v2uiop_filesystem__pattern;
  va_list args; va_start(args,v1directory);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_filesystem__pattern = ecl_cmp_symbol_value(cl_env_copy,VV[636]);
   } else {
    i++;
    v2uiop_filesystem__pattern = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   volatile cl_object env1 = env0;
   T0 = cl_pathname(v1directory);
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(T0,env1);                   /*  DIR                     */
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[525]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  LOGICAL-PATHNAME-P */)){
    goto L2;
   }
   if (Null(cl_wild_pathname_p(1, ECL_CONS_CAR(CLV0)))){
    goto L4;
   }
   cl_error(2, VV[692], v1directory);
L4:;
   {
    cl_object v3;
    v3 = cl_pathname_directory(1, v2uiop_filesystem__pattern);
    if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v3, ECL_NIL))){
     goto L11;
    }
    goto L6;
L11:;
    goto L9;
L9:;
    if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v3, VV[499]))){
     goto L14;
    }
    goto L6;
L14:;
    goto L7;
   }
L7:;
   cl_error(3, VV[694], v2uiop_filesystem__pattern, v1directory);
L6:;
   T0 = cl_pathname_host(1, ECL_CONS_CAR(CLV0));
   v2uiop_filesystem__pattern = (cl_env_copy->function=ecl_fdefinition(VV[517]))->cfun.entry(2, v2uiop_filesystem__pattern, T0) /*  MAKE-PATHNAME-LOGICAL */;
L2:;
   {
    volatile cl_object v3uiop_filesystem__pat;
    volatile cl_object v4uiop_filesystem__entries;
    v3uiop_filesystem__pat = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, v2uiop_filesystem__pattern, ECL_CONS_CAR(CLV0)) /*  MERGE-PATHNAMES* */;
    {
     volatile cl_object env2 = env1;
     CLV1 = env2 = CONS(ECL_NIL,env2);
     {
      volatile cl_object env3 = env2;
      CLV2 = env3 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env3); /*  TAGBODY     */
      {
       ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV2));
       if (__ecl_frs_push_result!=0) {
       if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
        goto L19;
       }
       ecl_internal_error("GO found an inexistent tag");
       } else {
       {
        cl_object v5;
        v5 = ecl_make_cclosure_va((cl_objectfn)LC4429__lambda2430,env3,Cblock,1);
        T0 = v5;
       }
       T1 = CONS(ECL_SYM("ERROR",339),T0);
       T2 = ecl_list1(T1);
       T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
       ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
       v4uiop_filesystem__entries = (cl_env_copy->function=ecl_fdefinition(VV[685]))->cfun.entry(1, v3uiop_filesystem__pat) /*  DIRECTORY* */;
       ecl_frs_pop_n(cl_env_copy, 1);
       ecl_bds_unwind1(cl_env_copy);
       goto L18;
L19:;
       {
        cl_object v5condition;
        v5condition = ECL_CONS_CAR(CLV1);
        cl_env_copy->nvalues = 2;
        cl_env_copy->values[1] = v5condition;
        cl_env_copy->values[0] = ECL_NIL;
        v4uiop_filesystem__entries = cl_env_copy->values[0];
        ecl_frs_pop_n(cl_env_copy, 1);
        goto L18;
       }
       }
      }
     }
    }
L18:;
    {
     cl_object volatile v5;
     v5 = ecl_make_cclosure_va((cl_objectfn)LC4430__lambda2432,env1,Cblock,1);
     T0 = v5;
    }
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[687]))->cfun.entry(3, v1directory, v4uiop_filesystem__entries, T0) /*  FILTER-LOGICAL-DIRECTORY-RESULTS */;
    value0 = cl_remove_if(2, VV[560], T1);
    return value0;
   }
  }
 }
}
/* function definition for SUBDIRECTORIES                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4434subdirectories(cl_object volatile v1directory)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v2uiop_filesystem__wild;
  volatile cl_object v3uiop_filesystem__dirs;
  volatile cl_object env1 = env0;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[565]))->cfun.entry(1, v1directory) /*  ENSURE-DIRECTORY-PATHNAME */;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(T0,env1);                    /*  DIRECTORY               */
  v2uiop_filesystem__wild = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, ecl_cmp_symbol_value(cl_env_copy,VV[637]), ECL_CONS_CAR(CLV0)) /*  MERGE-PATHNAMES* */;
  {
   volatile cl_object env2 = env1;
   CLV1 = env2 = CONS(ECL_NIL,env2);
   {
    volatile cl_object env3 = env2;
    CLV2 = env3 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env3); /*  TAGBODY       */
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV2));
     if (__ecl_frs_push_result!=0) {
     if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
      goto L4;
     }
     ecl_internal_error("GO found an inexistent tag");
     } else {
     {
      cl_object v4;
      v4 = ecl_make_cclosure_va((cl_objectfn)LC4432__lambda2444,env3,Cblock,1);
      T0 = v4;
     }
     T1 = CONS(ECL_SYM("ERROR",339),T0);
     T2 = ecl_list1(T1);
     T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
     ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
     v3uiop_filesystem__dirs = (cl_env_copy->function=ecl_fdefinition(VV[685]))->cfun.entry(1, v2uiop_filesystem__wild) /*  DIRECTORY* */;
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     goto L3;
L4:;
     {
      cl_object v4condition;
      v4condition = ECL_CONS_CAR(CLV1);
      cl_env_copy->nvalues = 2;
      cl_env_copy->values[1] = v4condition;
      cl_env_copy->values[0] = ECL_NIL;
      v3uiop_filesystem__dirs = cl_env_copy->values[0];
      ecl_frs_pop_n(cl_env_copy, 1);
      goto L3;
     }
     }
    }
   }
  }
L3:;
  {
   cl_object env2 = env1;
   T2 = cl_pathname_directory(1, ECL_CONS_CAR(CLV0));
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, T2) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
   if (value0!=ECL_NIL) {
    goto L12;
   }
   T1 = VV[521];
   goto L10;
L12:;
   T1 = value0;
   goto L10;
L10:;
   CLV1 = env2 = CONS(T1,env2);                   /*  PREFIX                  */
   {
    cl_object v4;
    v4 = ecl_make_cclosure_va((cl_objectfn)LC4433__lambda2446,env2,Cblock,1);
    T0 = v4;
   }
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[687]))->cfun.entry(3, ECL_CONS_CAR(CLV0), v3uiop_filesystem__dirs, T0) /*  FILTER-LOGICAL-DIRECTORY-RESULTS */;
  return value0;
 }
}
static cl_object L4434subdirectories_va(cl_narg narg, cl_object v4directory, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[699]);
 {
  return L4434subdirectories(v4directory);
 }
}
/* function definition for COLLECT-SUB*DIRECTORIES                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4435collect_sub_directories(cl_object v1directory, cl_object v2uiop_filesystem__collectp, cl_object v3uiop_filesystem__recursep, cl_object v4uiop_filesystem__collector)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, v2uiop_filesystem__collectp, v1directory) /*  CALL-FUNCTION */)){
  goto L2;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, v4uiop_filesystem__collector, v1directory) /*  CALL-FUNCTION */;
 {
  cl_object v5;
  v5 = (cl_env_copy->function=ecl_fdefinition(VV[699]))->cfun.entry(1, v1directory) /*  SUBDIRECTORIES */;
  goto L8;
L7:;
  {
   cl_object v6uiop_filesystem__subdir;
   v6uiop_filesystem__subdir = ecl_car(v5);
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, v3uiop_filesystem__recursep, v6uiop_filesystem__subdir) /*  CALL-FUNCTION */)){
    goto L12;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[704]))->cfun.entry(4, v6uiop_filesystem__subdir, v2uiop_filesystem__collectp, v3uiop_filesystem__recursep, v4uiop_filesystem__collector) /*  COLLECT-SUB*DIRECTORIES */;
L12:;
  }
  v5 = ecl_cdr(v5);
L8:;
  if (Null(v5)){
   goto L16;
  }
  goto L7;
L16:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4435collect_sub_directories_va(cl_narg narg, cl_object v6directory, cl_object v7uiop_filesystem__collectp, cl_object v8uiop_filesystem__recursep, cl_object v9uiop_filesystem__collector, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[704]);
 {
  return L4435collect_sub_directories(v6directory, v7uiop_filesystem__collectp, v8uiop_filesystem__recursep, v9uiop_filesystem__collector);
 }
}
/* function definition for TRUENAMIZE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4438truenamize(cl_object volatile v1pathname)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (v1pathname==ECL_NIL) {
  goto L4;
 }
 if (Null(si_logical_pathname_p(v1pathname))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = v1pathname;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 {
  volatile cl_object v2uiop_filesystem__p;
  v2uiop_filesystem__p = v1pathname;
  if ((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v2uiop_filesystem__p) /*  ABSOLUTE-PATHNAME-P */!=ECL_NIL) {
   goto L7;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[617]))->cfun.entry(3, v2uiop_filesystem__p, VV[676], ECL_NIL) /*  ENSURE-ABSOLUTE-PATHNAME */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, T0) /*  ABSOLUTE-PATHNAME-P */;
  if (value0!=ECL_NIL) {
   goto L11;
  }
  value0 = v2uiop_filesystem__p;
  cl_env_copy->nvalues = 1;
  return value0;
L11:;
  v2uiop_filesystem__p = value0;
  goto L9;
L9:;
L7:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[525]))->cfun.entry(1, v2uiop_filesystem__p) /*  LOGICAL-PATHNAME-P */)){
   goto L13;
  }
  value0 = v2uiop_filesystem__p;
  cl_env_copy->nvalues = 1;
  return value0;
L13:;
  {
   cl_object v3uiop_filesystem__found;
   v3uiop_filesystem__found = (cl_env_copy->function=ecl_fdefinition(VV[669]))->cfun.entry(3, v2uiop_filesystem__p, VV[681], ECL_T) /*  PROBE-FILE* */;
   if (Null(v3uiop_filesystem__found)){
    goto L15;
   }
   value0 = v3uiop_filesystem__found;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L15:;
  {
   volatile cl_object v3directory;
   volatile cl_object v4uiop_filesystem__up_components;
   volatile cl_object v5uiop_filesystem__down_components;
   T0 = cl_pathname_directory(1, v2uiop_filesystem__p);
   v3directory = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, T0) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
   T0 = ecl_cdr(v3directory);
   v4uiop_filesystem__up_components = cl_reverse(T0);
   v5uiop_filesystem__down_components = ECL_NIL;
   goto L23;
L22:;
   si_assert_failure(1, VV[707]);
L23:;
   T0 = ecl_car(v3directory);
   if ((ECL_SYM("ABSOLUTE",1226))==(T0)) {
    goto L26;
   }
   goto L22;
L26:;
L28:;
   if (v4uiop_filesystem__up_components!=ECL_NIL) {
    goto L30;
   }
   goto L29;
L30:;
   {
    volatile cl_object v6uiop_filesystem__parent;
    {
     volatile cl_object env1 = env0;
     env1 = ECL_NIL;
     CLV0 = env1 = CONS(ECL_NIL,env1);
     {
      volatile cl_object env2 = env1;
      CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY     */
      {
       ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
       if (__ecl_frs_push_result!=0) {
       if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
        goto L35;
       }
       ecl_internal_error("GO found an inexistent tag");
       } else {
       {
        cl_object v7;
        v7 = ecl_make_cclosure_va((cl_objectfn)LC4436__lambda2478,env2,Cblock,1);
        T0 = v7;
       }
       T1 = CONS(ECL_SYM("ERROR",339),T0);
       T2 = ecl_list1(T1);
       T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
       ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
       T0 = cl_reverse(v4uiop_filesystem__up_components);
       T1 = CONS(ECL_SYM("ABSOLUTE",1226),T0);
       T2 = cl_make_pathname(10, ECL_SYM("DIRECTORY",1250), T1, ECL_SYM("NAME",1309), ECL_NIL, ECL_SYM("TYPE",1356), ECL_NIL, ECL_SYM("VERSION",1364), ECL_NIL, ECL_SYM("DEFAULTS",1247), v2uiop_filesystem__p);
       v6uiop_filesystem__parent = (cl_env_copy->function=ecl_fdefinition(VV[669]))->cfun.entry(1, T2) /*  PROBE-FILE* */;
       ecl_frs_pop_n(cl_env_copy, 1);
       ecl_bds_unwind1(cl_env_copy);
       goto L34;
L35:;
       {
        cl_object v7condition;
        v7condition = ECL_CONS_CAR(CLV0);
        cl_env_copy->nvalues = 2;
        cl_env_copy->values[1] = v7condition;
        cl_env_copy->values[0] = ECL_NIL;
        v6uiop_filesystem__parent = cl_env_copy->values[0];
        ecl_frs_pop_n(cl_env_copy, 1);
        goto L34;
       }
       }
      }
     }
    }
L34:;
    if (Null(v6uiop_filesystem__parent)){
     goto L33;
    }
    {
     volatile cl_object v7uiop_filesystem__simplified;
     {
      volatile cl_object env1 = env0;
      env1 = ECL_NIL;
      CLV0 = env1 = CONS(ECL_NIL,env1);
      {
       volatile cl_object env2 = env1;
       CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY    */
       {
        ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
        if (__ecl_frs_push_result!=0) {
        if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
         goto L42;
        }
        ecl_internal_error("GO found an inexistent tag");
        } else {
        {
         cl_object v8;
         v8 = ecl_make_cclosure_va((cl_objectfn)LC4437__lambda2483,env2,Cblock,1);
         T0 = v8;
        }
        T1 = CONS(ECL_SYM("ERROR",339),T0);
        T2 = ecl_list1(T1);
        T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
        ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
        T0 = CONS(ECL_SYM("RELATIVE",1336),v5uiop_filesystem__down_components);
        T1 = cl_make_pathname(4, ECL_SYM("DIRECTORY",1250), T0, ECL_SYM("DEFAULTS",1247), v2uiop_filesystem__p);
        T2 = (cl_env_copy->function=ecl_fdefinition(VV[565]))->cfun.entry(1, v6uiop_filesystem__parent) /*  ENSURE-DIRECTORY-PATHNAME */;
        v7uiop_filesystem__simplified = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, T1, T2) /*  MERGE-PATHNAMES* */;
        ecl_frs_pop_n(cl_env_copy, 1);
        ecl_bds_unwind1(cl_env_copy);
        goto L41;
L42:;
        {
         cl_object v8condition;
         v8condition = ECL_CONS_CAR(CLV0);
         cl_env_copy->nvalues = 2;
         cl_env_copy->values[1] = v8condition;
         cl_env_copy->values[0] = ECL_NIL;
         v7uiop_filesystem__simplified = cl_env_copy->values[0];
         ecl_frs_pop_n(cl_env_copy, 1);
         goto L41;
        }
        }
       }
      }
     }
L41:;
     if (Null(v7uiop_filesystem__simplified)){
      goto L33;
     }
     value0 = v7uiop_filesystem__simplified;
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
L33:;
   {
    cl_object v6;
    v6 = v4uiop_filesystem__up_components;
    {
     cl_object v7;
     v7 = v6;
     {
      bool v8;
      v8 = ECL_LISTP(v7);
      if (ecl_unlikely(!(v8)))
         FEwrong_type_argument(VV[508],v7);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v6)){
     goto L54;
    }
    {
     cl_object v7;
     v7 = ECL_CONS_CDR(v6);
     v4uiop_filesystem__up_components = v7;
     v6 = ECL_CONS_CAR(v6);
    }
L54:;
    T0 = v6;
   }
   v5uiop_filesystem__down_components = CONS(T0,v5uiop_filesystem__down_components);
   goto L28;
L29:;
   value0 = v2uiop_filesystem__p;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4438truenamize_va(cl_narg narg, cl_object v6pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[706]);
 {
  return L4438truenamize(v6pathname);
 }
}
/* function definition for RESOLVE-SYMLINKS                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4439resolve_symlinks(cl_object v1uiop_filesystem__path)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[706]))->cfun.entry(1, v1uiop_filesystem__path) /*  TRUENAMIZE */;
 return value0;
}
static cl_object L4439resolve_symlinks_va(cl_narg narg, cl_object v2uiop_filesystem__path, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[713]);
 {
  return L4439resolve_symlinks(v2uiop_filesystem__path);
 }
}
/* function definition for RESOLVE-SYMLINKS*                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4440resolve_symlinks_(cl_object v1uiop_filesystem__path)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[715]))){
  goto L2;
 }
 if (Null(v1uiop_filesystem__path)){
  goto L5;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[713]))->cfun.entry(1, v1uiop_filesystem__path) /*  RESOLVE-SYMLINKS */;
 return value0;
L5:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = v1uiop_filesystem__path;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4440resolve_symlinks__va(cl_narg narg, cl_object v2uiop_filesystem__path, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[716]);
 {
  return L4440resolve_symlinks_(v2uiop_filesystem__path);
 }
}
/* function definition for ENSURE-PATHNAME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4442ensure_pathname(cl_narg narg, cl_object v1pathname, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[596]);
 {
  cl_object v2uiop_filesystem__defaults;
  cl_object v3type;
  cl_object v4uiop_filesystem__dot_dot;
  cl_object v5namestring;
  cl_object v6uiop_filesystem__empty_is_nil;
  cl_object v7uiop_filesystem__want_pathname;
  cl_object v8uiop_filesystem__want_logical;
  cl_object v9uiop_filesystem__want_physical;
  cl_object v10uiop_filesystem__ensure_physical;
  cl_object v11uiop_filesystem__want_relative;
  cl_object v12uiop_filesystem__want_absolute;
  cl_object v13uiop_filesystem__ensure_absolute;
  cl_object v14uiop_filesystem__ensure_subpath;
  cl_object v15uiop_filesystem__want_non_wild;
  cl_object v16uiop_filesystem__want_wild;
  cl_object v17wilden;
  cl_object v18uiop_filesystem__want_file;
  cl_object v19uiop_filesystem__want_directory;
  cl_object v20uiop_filesystem__ensure_directory;
  cl_object v21uiop_filesystem__want_existing;
  cl_object v22ensure_directories_exist;
  cl_object v23truename;
  cl_object v24resolve_symlinks;
  cl_object v25truenamize;
  ecl_va_list args; ecl_va_start(args,v1pathname,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1pathname,env0);            /*  PATHNAME                */
  {
   cl_object keyvars[50];
   cl_parse_key(args,25,L4442ensure_pathnamekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   CLV1 = env0 = CONS(keyvars[0],env0);           /*  ON-ERROR                */
   v2uiop_filesystem__defaults = keyvars[1];
   v3type = keyvars[2];
   v4uiop_filesystem__dot_dot = keyvars[3];
   v5namestring = keyvars[4];
   v6uiop_filesystem__empty_is_nil = keyvars[5];
   v7uiop_filesystem__want_pathname = keyvars[6];
   v8uiop_filesystem__want_logical = keyvars[7];
   v9uiop_filesystem__want_physical = keyvars[8];
   v10uiop_filesystem__ensure_physical = keyvars[9];
   v11uiop_filesystem__want_relative = keyvars[10];
   v12uiop_filesystem__want_absolute = keyvars[11];
   v13uiop_filesystem__ensure_absolute = keyvars[12];
   v14uiop_filesystem__ensure_subpath = keyvars[13];
   v15uiop_filesystem__want_non_wild = keyvars[14];
   v16uiop_filesystem__want_wild = keyvars[15];
   v17wilden = keyvars[16];
   v18uiop_filesystem__want_file = keyvars[17];
   v19uiop_filesystem__want_directory = keyvars[18];
   v20uiop_filesystem__ensure_directory = keyvars[19];
   v21uiop_filesystem__want_existing = keyvars[20];
   v22ensure_directories_exist = keyvars[21];
   v23truename = keyvars[22];
   v24resolve_symlinks = keyvars[23];
   v25truenamize = keyvars[24];
  }
  {
   cl_object v26uiop_filesystem__p;
   v26uiop_filesystem__p = ECL_CONS_CAR(CLV0);
   {
    cl_object v27;
    v27 = ecl_make_cclosure_va((cl_objectfn)LC4441report_error,env0,Cblock,2);
    {
     cl_object v28;
     v28 = v26uiop_filesystem__p;
     if (v28==ECL_NIL) {
      goto L2;
     }
     if (cl_pathnamep(v28)!=ECL_NIL) {
      goto L2;
     }
     if (!(ECL_STRINGP(v28))){
      goto L6;
     }
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[263]))->cfun.entry(1, v26uiop_filesystem__p) /*  EMPTYP */)){
      goto L8;
     }
     if (Null(v6uiop_filesystem__empty_is_nil)){
      goto L8;
     }
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     return value0;
L8:;
     if (!((v5namestring)==(ECL_SYM("UNIX",1814)))){
      goto L17;
     }
     goto L14;
L17:;
     goto L15;
L15:;
     if (!((v5namestring)==(ECL_NIL))){
      goto L12;
     }
     goto L13;
L14:;
L13:;
     v26uiop_filesystem__p = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(11, v26uiop_filesystem__p, ECL_SYM("DEFAULTS",1247), v2uiop_filesystem__defaults, ECL_SYM("TYPE",1356), v3type, VV[594], v4uiop_filesystem__dot_dot, VV[595], v20uiop_filesystem__ensure_directory, VV[609], v11uiop_filesystem__want_relative) /*  PARSE-UNIX-NAMESTRING */;
     goto L11;
L12:;
     if (!((v5namestring)==(VV[722]))){
      goto L20;
     }
     v26uiop_filesystem__p = (cl_env_copy->function=ecl_fdefinition(VV[658]))->cfun.entry(1, v26uiop_filesystem__p) /*  PARSE-NATIVE-NAMESTRING */;
     goto L11;
L20:;
     if (!((v5namestring)==(VV[673]))){
      goto L23;
     }
     v26uiop_filesystem__p = cl_parse_namestring(1, v26uiop_filesystem__p);
     goto L11;
L23:;
     v26uiop_filesystem__p = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, v5namestring, v26uiop_filesystem__p) /*  CALL-FUNCTION */;
L11:;
     goto L2;
L6:;
     si_etypecase_error(v28, VV[724]);
    }
L2:;
    if (cl_pathnamep(v26uiop_filesystem__p)!=ECL_NIL) {
     goto L26;
    }
    if (!(v26uiop_filesystem__p==ECL_NIL)){
     goto L28;
    }
    if (Null(v7uiop_filesystem__want_pathname)){
     goto L30;
    }
    if (cl_pathnamep(v26uiop_filesystem__p)!=ECL_NIL) {
     goto L30;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(2, VV[727], VV[728]));
L30:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L28:;
    si_etypecase_error(v26uiop_filesystem__p, VV[729]);
L26:;
    if (Null(v8uiop_filesystem__want_logical)){
     goto L33;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[525]))->cfun.entry(1, v26uiop_filesystem__p) /*  LOGICAL-PATHNAME-P */!=ECL_NIL) {
     goto L33;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(2, VV[730], VV[731]));
L33:;
    if (Null(v9uiop_filesystem__want_physical)){
     goto L36;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[527]))->cfun.entry(1, v26uiop_filesystem__p) /*  PHYSICAL-PATHNAME-P */!=ECL_NIL) {
     goto L36;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(2, VV[732], VV[733]));
L36:;
    if (Null(v10uiop_filesystem__ensure_physical)){
     goto L39;
    }
    v26uiop_filesystem__p = (cl_env_copy->function=ecl_fdefinition(VV[529]))->cfun.entry(1, v26uiop_filesystem__p) /*  PHYSICALIZE-PATHNAME */;
L39:;
    if (Null(v10uiop_filesystem__ensure_physical)){
     goto L42;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[527]))->cfun.entry(1, v26uiop_filesystem__p) /*  PHYSICAL-PATHNAME-P */!=ECL_NIL) {
     goto L42;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(2, VV[674], VV[735]));
L42:;
    if (Null(v11uiop_filesystem__want_relative)){
     goto L45;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[546]))->cfun.entry(1, v26uiop_filesystem__p) /*  RELATIVE-PATHNAME-P */!=ECL_NIL) {
     goto L45;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(2, VV[609], VV[736]));
L45:;
    if (Null(v12uiop_filesystem__want_absolute)){
     goto L48;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v26uiop_filesystem__p) /*  ABSOLUTE-PATHNAME-P */!=ECL_NIL) {
     goto L48;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(2, VV[737], VV[738]));
L48:;
    if (Null(v13uiop_filesystem__ensure_absolute)){
     goto L51;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v26uiop_filesystem__p) /*  ABSOLUTE-PATHNAME-P */!=ECL_NIL) {
     goto L51;
    }
    T0 = cl_list(3, v27, VV[675], VV[739]);
    v26uiop_filesystem__p = (cl_env_copy->function=ecl_fdefinition(VV[617]))->cfun.entry(3, v26uiop_filesystem__p, v2uiop_filesystem__defaults, T0) /*  ENSURE-ABSOLUTE-PATHNAME */;
L51:;
    if (Null(v13uiop_filesystem__ensure_absolute)){
     goto L55;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v26uiop_filesystem__p) /*  ABSOLUTE-PATHNAME-P */!=ECL_NIL) {
     goto L55;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(3, VV[675], VV[740], v2uiop_filesystem__defaults));
L55:;
    if (Null(v14uiop_filesystem__ensure_subpath)){
     goto L58;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v2uiop_filesystem__defaults) /*  ABSOLUTE-PATHNAME-P */!=ECL_NIL) {
     goto L58;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(3, VV[741], VV[742], v2uiop_filesystem__defaults));
L58:;
    if (Null(v14uiop_filesystem__ensure_subpath)){
     goto L61;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[623]))->cfun.entry(2, v26uiop_filesystem__p, v2uiop_filesystem__defaults) /*  SUBPATHP */!=ECL_NIL) {
     goto L61;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(3, VV[741], VV[743], v2uiop_filesystem__defaults));
L61:;
    if (Null(v18uiop_filesystem__want_file)){
     goto L64;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[550]))->cfun.entry(1, v26uiop_filesystem__p) /*  FILE-PATHNAME-P */!=ECL_NIL) {
     goto L64;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(2, VV[744], VV[745]));
L64:;
    if (Null(v19uiop_filesystem__want_directory)){
     goto L67;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, v26uiop_filesystem__p) /*  DIRECTORY-PATHNAME-P */!=ECL_NIL) {
     goto L67;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(2, VV[746], VV[747]));
L67:;
    if (Null(v20uiop_filesystem__ensure_directory)){
     goto L70;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, v26uiop_filesystem__p) /*  DIRECTORY-PATHNAME-P */!=ECL_NIL) {
     goto L70;
    }
    v26uiop_filesystem__p = (cl_env_copy->function=ecl_fdefinition(VV[565]))->cfun.entry(1, v26uiop_filesystem__p) /*  ENSURE-DIRECTORY-PATHNAME */;
L70:;
    if (Null(v15uiop_filesystem__want_non_wild)){
     goto L74;
    }
    if (Null(cl_wild_pathname_p(1, v26uiop_filesystem__p))){
     goto L74;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(2, VV[677], VV[748]));
L74:;
    if (Null(v16uiop_filesystem__want_wild)){
     goto L77;
    }
    if (cl_wild_pathname_p(1, v26uiop_filesystem__p)!=ECL_NIL) {
     goto L77;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(2, VV[749], VV[750]));
L77:;
    if (Null(v17wilden)){
     goto L80;
    }
    if (cl_wild_pathname_p(1, v26uiop_filesystem__p)!=ECL_NIL) {
     goto L80;
    }
    v26uiop_filesystem__p = (cl_env_copy->function=ecl_fdefinition(VV[640]))->cfun.entry(1, v26uiop_filesystem__p) /*  WILDEN */;
L80:;
    if (Null(v21uiop_filesystem__want_existing)){
     goto L84;
    }
    {
     cl_object v28uiop_filesystem__existing;
     v28uiop_filesystem__existing = (cl_env_copy->function=ecl_fdefinition(VV[669]))->cfun.entry(3, v26uiop_filesystem__p, VV[681], v23truename) /*  PROBE-FILE* */;
     if (Null(v28uiop_filesystem__existing)){
      goto L87;
     }
     if (Null(v23truename)){
      goto L84;
     }
     value0 = v28uiop_filesystem__existing;
     cl_env_copy->nvalues = 1;
     return value0;
L87:;
     (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(2, VV[751], VV[752]));
    }
L84:;
    if (Null(v22ensure_directories_exist)){
     goto L90;
    }
    cl_ensure_directories_exist(1, v26uiop_filesystem__p);
L90:;
    if (Null(v23truename)){
     goto L92;
    }
    {
     cl_object v28truename;
     v28truename = (cl_env_copy->function=ecl_fdefinition(VV[661]))->cfun.entry(1, v26uiop_filesystem__p) /*  TRUENAME* */;
     if (Null(v28truename)){
      goto L95;
     }
     value0 = v28truename;
     cl_env_copy->nvalues = 1;
     return value0;
L95:;
     (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4441report_error(2, VV[681], VV[753]));
    }
L92:;
    if (Null(v24resolve_symlinks)){
     goto L97;
    }
    v26uiop_filesystem__p = (cl_env_copy->function=ecl_fdefinition(VV[713]))->cfun.entry(1, v26uiop_filesystem__p) /*  RESOLVE-SYMLINKS */;
L97:;
    if (Null(v25truenamize)){
     goto L100;
    }
    v26uiop_filesystem__p = (cl_env_copy->function=ecl_fdefinition(VV[706]))->cfun.entry(1, v26uiop_filesystem__p) /*  TRUENAMIZE */;
L100:;
    value0 = v26uiop_filesystem__p;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for GET-PATHNAME-DEFAULTS                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4443get_pathname_defaults(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[676]);
 {
  cl_object v1uiop_filesystem__defaults;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1uiop_filesystem__defaults = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34));
   } else {
    i++;
    v1uiop_filesystem__defaults = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v1uiop_filesystem__defaults) /*  ABSOLUTE-PATHNAME-P */;
  if (value0!=ECL_NIL) {
   goto L3;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[479]))->cfun.entry(0) /*  GETCWD */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, v1uiop_filesystem__defaults, T0) /*  MERGE-PATHNAMES* */;
  return value0;
L3:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for CALL-WITH-CURRENT-DIRECTORY                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4444call_with_current_directory(cl_object volatile v1uiop_filesystem__dir, cl_object volatile v2uiop_filesystem__thunk)
{
 cl_object T0, T1;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1uiop_filesystem__dir)){
  goto L2;
 }
 {
  volatile cl_object v3uiop_filesystem__dir;
  volatile cl_object v4uiop_filesystem__cwd;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[555]))->cfun.entry(1, v1uiop_filesystem__dir) /*  PATHNAME-DIRECTORY-PATHNAME */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[676]))->cfun.entry(1, T0) /*  GET-PATHNAME-DEFAULTS */;
  v3uiop_filesystem__dir = (cl_env_copy->function=ecl_fdefinition(VV[716]))->cfun.entry(1, T1) /*  RESOLVE-SYMLINKS* */;
  v4uiop_filesystem__cwd = (cl_env_copy->function=ecl_fdefinition(VV[479]))->cfun.entry(0) /*  GETCWD */;
  ecl_bds_bind(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34),v3uiop_filesystem__dir); /*  *DEFAULT-PATHNAME-DEFAULTS* */
  (cl_env_copy->function=ecl_fdefinition(VV[482]))->cfun.entry(1, v3uiop_filesystem__dir) /*  CHDIR */;
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    cl_env_copy->values[0] = ecl_function_dispatch(cl_env_copy,v2uiop_filesystem__thunk)(0);
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   (cl_env_copy->function=ecl_fdefinition(VV[482]))->cfun.entry(1, v4uiop_filesystem__cwd) /*  CHDIR */;
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   ecl_bds_unwind1(cl_env_copy);
   return cl_env_copy->values[0];
  }
 }
L2:;
 value0 = ecl_function_dispatch(cl_env_copy,v2uiop_filesystem__thunk)(0);
 return value0;
}
static cl_object L4444call_with_current_directory_va(cl_narg narg, cl_object v5uiop_filesystem__dir, cl_object v6uiop_filesystem__thunk, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[756]);
 {
  return L4444call_with_current_directory(v5uiop_filesystem__dir, v6uiop_filesystem__thunk);
 }
}
/* local function WITH-CURRENT-DIRECTORY                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4445with_current_directory(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_filesystem__dir;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v7;
   v7 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v7;
  }
  v5 = v4;
  if (Null(v5)){
   goto L11;
  }
  {
   cl_object v7;
   v7 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_filesystem__dir = v7;
   goto L10;
  }
L11:;
  v6uiop_filesystem__dir = ECL_NIL;
L10:;
  if (Null(v5)){
   goto L16;
  }
  si_dm_too_many_arguments(v1);
L16:;
  T0 = cl_listX(3, ECL_SYM("LAMBDA",454), ECL_NIL, v3);
  T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
  value0 = cl_list(3, VV[756], v6uiop_filesystem__dir, T1);
  return value0;
 }
}
static cl_object LC4445with_current_directory_va(cl_narg narg, cl_object v7, cl_object v8, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[758]);
 {
  return LC4445with_current_directory(v7, v8);
 }
}
/* function definition for INTER-DIRECTORY-SEPARATOR                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4446inter_directory_separator()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_CODE_CHAR(58);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4446inter_directory_separator_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[760]);
 {
  return L4446inter_directory_separator();
 }
}
/* function definition for SPLIT-NATIVE-PATHNAMES-STRING                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4447split_native_pathnames_string(cl_narg narg, cl_object v1string, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[762]);
 {
  cl_object v2uiop_filesystem__constraints;
  ecl_va_list args; ecl_va_start(args,v1string,narg,1);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v2uiop_filesystem__constraints,TRUE);
  ecl_va_end(args);
  {
   cl_object v3;
   cl_object v4namestring;
   cl_object v5;
   {
    cl_object v6;
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[760]))->cfun.entry(0) /*  INTER-DIRECTORY-SEPARATOR */;
    T1 = cl_string(T0);
    v6 = (cl_env_copy->function=ecl_fdefinition(VV[289]))->cfun.entry(3, v1string, VV[377], T1) /*  SPLIT-STRING */;
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v6;
   }
   v4namestring = ECL_NIL;
   v5 = v3;
   {
    cl_object v6;
    cl_object v7;
    v6 = ecl_list1(ECL_NIL);
    v7 = v6;
L8:;
    if (!(ecl_endp(v5))){
     goto L10;
    }
    goto L9;
L10:;
    v4namestring = ECL_CONS_CAR(v5);
    {
     cl_object v8;
     v8 = ECL_CONS_CDR(v5);
     if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v8;
    }
    {
     cl_object v8;
     v8 = v7;
     if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T0 = v8;
    }
    if ((cl_env_copy->function=ecl_fdefinition(VV[263]))->cfun.entry(1, v4namestring) /*  EMPTYP */!=ECL_NIL) {
     goto L24;
    }
    T1 = cl_apply(3, VV[658], v4namestring, v2uiop_filesystem__constraints);
    goto L23;
L24:;
    T1 = ECL_NIL;
L23:;
    v7 = ecl_list1(T1);
    (ECL_CONS_CDR(T0)=v7,T0);
    goto L8;
L9:;
    value0 = ecl_cdr(v6);
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for GETENV-PATHNAME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4448getenv_pathname(cl_narg narg, cl_object v1uiop_filesystem__x, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[764]);
 {
  cl_object v2uiop_filesystem__constraints;
  cl_object v3uiop_filesystem__ensure_directory;
  cl_object v4uiop_filesystem__want_directory;
  cl_object v5uiop_filesystem__on_error;
  ecl_va_list args; ecl_va_start(args,v1uiop_filesystem__x,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L4448getenv_pathnamekeys,keyvars,(cl_object*)&v2uiop_filesystem__constraints,TRUE);
   ecl_va_end(args);
   v3uiop_filesystem__ensure_directory = keyvars[0];
   v4uiop_filesystem__want_directory = keyvars[1];
   v5uiop_filesystem__on_error = keyvars[2];
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[455]))->cfun.entry(1, v1uiop_filesystem__x) /*  GETENVP */;
  value0 = v3uiop_filesystem__ensure_directory;
  if (value0!=ECL_NIL) {
   goto L3;
  }
  T1 = v4uiop_filesystem__want_directory;
  goto L1;
L3:;
  T1 = value0;
  goto L1;
L1:;
  value0 = v5uiop_filesystem__on_error;
  if (value0!=ECL_NIL) {
   goto L7;
  }
  T2 = cl_list(4, ECL_SYM("ERROR",339), VV[765], VV[764], v1uiop_filesystem__x);
  goto L5;
L7:;
  T2 = value0;
  goto L5;
L5:;
  value0 = cl_apply(7, VV[658], T0, VV[595], T1, VV[678], T2, v2uiop_filesystem__constraints);
  return value0;
 }
}
/* function definition for GETENV-PATHNAMES                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4449getenv_pathnames(cl_narg narg, cl_object v1uiop_filesystem__x, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[767]);
 {
  cl_object v2uiop_filesystem__constraints;
  cl_object v3uiop_filesystem__on_error;
  ecl_va_list args; ecl_va_start(args,v1uiop_filesystem__x,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4449getenv_pathnameskeys,keyvars,(cl_object*)&v2uiop_filesystem__constraints,TRUE);
   ecl_va_end(args);
   v3uiop_filesystem__on_error = keyvars[0];
  }
  if (cl_getf(3, v2uiop_filesystem__constraints, VV[768], ECL_T)!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[769]);
L1:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[455]))->cfun.entry(1, v1uiop_filesystem__x) /*  GETENVP */;
  value0 = v3uiop_filesystem__on_error;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = cl_list(4, ECL_SYM("ERROR",339), VV[765], VV[767], v1uiop_filesystem__x);
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  value0 = cl_apply(7, VV[762], T0, VV[678], T1, VV[768], ECL_T, v2uiop_filesystem__constraints);
  return value0;
 }
}
/* function definition for GETENV-ABSOLUTE-DIRECTORY                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4450getenv_absolute_directory(cl_object v1uiop_filesystem__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[764]))->cfun.entry(5, v1uiop_filesystem__x, VV[737], ECL_T, VV[595], ECL_T) /*  GETENV-PATHNAME */;
 return value0;
}
static cl_object L4450getenv_absolute_directory_va(cl_narg narg, cl_object v2uiop_filesystem__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[771]);
 {
  return L4450getenv_absolute_directory(v2uiop_filesystem__x);
 }
}
/* function definition for GETENV-ABSOLUTE-DIRECTORIES                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4451getenv_absolute_directories(cl_object v1uiop_filesystem__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[767]))->cfun.entry(5, v1uiop_filesystem__x, VV[737], ECL_T, VV[595], ECL_T) /*  GETENV-PATHNAMES */;
 return value0;
}
static cl_object L4451getenv_absolute_directories_va(cl_narg narg, cl_object v2uiop_filesystem__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[773]);
 {
  return L4451getenv_absolute_directories(v2uiop_filesystem__x);
 }
}
/* function definition for LISP-IMPLEMENTATION-DIRECTORY                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4452lisp_implementation_directory(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1truename;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4452lisp_implementation_directorykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1truename = keyvars[0];
  }
  if (Null(v1truename)){
   goto L1;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[661]))->cfun.entry(1, VV[776]) /*  TRUENAME* */;
  return value0;
L1:;
  value0 = VV[776];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for LISP-IMPLEMENTATION-PATHNAME-P                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4453lisp_implementation_pathname_p(cl_object v1pathname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1pathname)){
  goto L5;
 }
 {
  cl_object v2uiop_filesystem__impdir;
  v2uiop_filesystem__impdir = (cl_env_copy->function=ecl_fdefinition(VV[775]))->cfun.entry(0) /*  LISP-IMPLEMENTATION-DIRECTORY */;
  if (Null(v2uiop_filesystem__impdir)){
   goto L8;
  }
  if ((cl_env_copy->function=ecl_fdefinition(VV[623]))->cfun.entry(2, v1pathname, v2uiop_filesystem__impdir) /*  SUBPATHP */!=ECL_NIL) {
   goto L10;
  }
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[715]))){
   goto L12;
  }
  {
   cl_object v3truename;
   v3truename = (cl_env_copy->function=ecl_fdefinition(VV[661]))->cfun.entry(1, v1pathname) /*  TRUENAME* */;
   if (Null(v3truename)){
    goto L15;
   }
   {
    cl_object v4uiop_filesystem__trueimpdir;
    v4uiop_filesystem__trueimpdir = (cl_env_copy->function=ecl_fdefinition(VV[661]))->cfun.entry(1, v2uiop_filesystem__impdir) /*  TRUENAME* */;
    if (Null(v4uiop_filesystem__trueimpdir)){
     goto L18;
    }
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[623]))->cfun.entry(2, v3truename, v4uiop_filesystem__trueimpdir) /*  SUBPATHP */)){
     goto L3;
    }
    goto L4;
L18:;
    goto L3;
   }
L15:;
   goto L3;
  }
L12:;
  goto L3;
L10:;
  goto L4;
L8:;
  goto L3;
 }
L5:;
 goto L3;
L4:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4453lisp_implementation_pathname_p_va(cl_narg narg, cl_object v2pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[778]);
 {
  return L4453lisp_implementation_pathname_p(v2pathname);
 }
}
/* function definition for ENSURE-ALL-DIRECTORIES-EXIST                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4454ensure_all_directories_exist(cl_object v1uiop_filesystem__pathnames)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = v1uiop_filesystem__pathnames;
  goto L5;
L4:;
  {
   cl_object v3pathname;
   v3pathname = ecl_car(v2);
   if (Null(v3pathname)){
    goto L9;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[529]))->cfun.entry(1, v3pathname) /*  PHYSICALIZE-PATHNAME */;
   cl_ensure_directories_exist(1, T0);
L9:;
  }
  v2 = ecl_cdr(v2);
L5:;
  if (Null(v2)){
   goto L13;
  }
  goto L4;
L13:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4454ensure_all_directories_exist_va(cl_narg narg, cl_object v3uiop_filesystem__pathnames, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[780]);
 {
  return L4454ensure_all_directories_exist(v3uiop_filesystem__pathnames);
 }
}
/* function definition for DELETE-FILE-IF-EXISTS                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4456delete_file_if_exists(cl_object volatile v1uiop_filesystem__x)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1uiop_filesystem__x)){
  goto L2;
 }
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env0); /*  TAGBODY          */
 {
  ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV0));
  if (__ecl_frs_push_result!=0) {
  if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
   goto L4;
  }
  ecl_internal_error("GO found an inexistent tag");
  } else {
  {
   cl_object v2;
   v2 = ecl_make_cclosure_va((cl_objectfn)LC4455__lambda2608,env0,Cblock,1);
   T0 = v2;
  }
  T1 = CONS(ECL_SYM("FILE-ERROR",355),T0);
  T2 = ecl_list1(T1);
  T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
  ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
  value0 = cl_delete_file(v1uiop_filesystem__x);
  ecl_frs_pop_n(cl_env_copy, 1);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  ecl_frs_pop_n(cl_env_copy, 1);
  return value0;
  }
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4456delete_file_if_exists_va(cl_narg narg, cl_object v2uiop_filesystem__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[782]);
 {
  return L4456delete_file_if_exists(v2uiop_filesystem__x);
 }
}
/* function definition for RENAME-FILE-OVERWRITING-TARGET                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4457rename_file_overwriting_target(cl_object v1uiop_filesystem__source, cl_object v2uiop_filesystem__target)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[596]))->cfun.entry(7, v1uiop_filesystem__source, VV[672], VV[673], VV[674], ECL_T, VV[744], ECL_T) /*  ENSURE-PATHNAME */;
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[596]))->cfun.entry(7, v2uiop_filesystem__target, VV[672], VV[673], VV[674], ECL_T, VV[744], ECL_T) /*  ENSURE-PATHNAME */;
  value0 = cl_rename_file(4, v3, v4, ECL_SYM("IF-EXISTS",1279), ECL_T);
  return value0;
 }
}
static cl_object L4457rename_file_overwriting_target_va(cl_narg narg, cl_object v5uiop_filesystem__source, cl_object v6uiop_filesystem__target, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[786]);
 {
  return L4457rename_file_overwriting_target(v5uiop_filesystem__source, v6uiop_filesystem__target);
 }
}
/* function definition for DELETE-EMPTY-DIRECTORY                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4458delete_empty_directory(cl_object v1uiop_filesystem__directory_pathname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = si_rmdir(v1uiop_filesystem__directory_pathname);
 return value0;
}
static cl_object L4458delete_empty_directory_va(cl_narg narg, cl_object v2uiop_filesystem__directory_pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[788]);
 {
  return L4458delete_empty_directory(v2uiop_filesystem__directory_pathname);
 }
}
/* function definition for DELETE-DIRECTORY-TREE                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4460delete_directory_tree(cl_narg narg, cl_object v1uiop_filesystem__directory_pathname, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[790]);
 {
  cl_object v2uiop_filesystem__validate;
  cl_object v3uiop_filesystem__validatep;
  cl_object v4uiop_filesystem__if_does_not_exist;
  ecl_va_list args; ecl_va_start(args,v1uiop_filesystem__directory_pathname,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4460delete_directory_treekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2uiop_filesystem__validate = keyvars[0];
   v3uiop_filesystem__validatep = keyvars[2];
   if (Null(keyvars[3])) {
    v4uiop_filesystem__if_does_not_exist = ECL_SYM("ERROR",1260);
   } else {
    v4uiop_filesystem__if_does_not_exist = keyvars[1];
   }
  }
  {
   cl_object v5;
   v5 = v4uiop_filesystem__if_does_not_exist;
   if (!((v5)==(ECL_SYM("ERROR",1260)))){
    goto L8;
   }
   goto L4;
L8:;
   goto L6;
L6:;
   if (!((v5)==(ECL_SYM("IGNORE",1282)))){
    goto L11;
   }
   goto L4;
L11:;
   goto L5;
L5:;
   v4uiop_filesystem__if_does_not_exist = si_do_check_type(v5, VV[793], ECL_NIL, VV[794]);
L4:;
  }
  if (Null(cl_pathnamep(v1uiop_filesystem__directory_pathname))){
   goto L17;
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, v1uiop_filesystem__directory_pathname) /*  DIRECTORY-PATHNAME-P */)){
   goto L17;
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[527]))->cfun.entry(1, v1uiop_filesystem__directory_pathname) /*  PHYSICAL-PATHNAME-P */)){
   goto L17;
  }
  if (Null(cl_wild_pathname_p(1, v1uiop_filesystem__directory_pathname))){
   goto L14;
  }
  goto L15;
L17:;
  goto L15;
L15:;
  value0 = cl_error(3, VV[795], VV[790], v1uiop_filesystem__directory_pathname);
  return value0;
L14:;
  if (v3uiop_filesystem__validatep!=ECL_NIL) {
   goto L21;
  }
  value0 = cl_error(3, VV[796], VV[790], v1uiop_filesystem__directory_pathname);
  return value0;
L21:;
  if ((cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, v2uiop_filesystem__validate, v1uiop_filesystem__directory_pathname) /*  CALL-FUNCTION */!=ECL_NIL) {
   goto L23;
  }
  value0 = cl_error(4, VV[797], VV[790], v1uiop_filesystem__directory_pathname, v2uiop_filesystem__validate);
  return value0;
L23:;
  if ((cl_env_copy->function=ecl_fdefinition(VV[680]))->cfun.entry(1, v1uiop_filesystem__directory_pathname) /*  DIRECTORY-EXISTS-P */!=ECL_NIL) {
   goto L25;
  }
  if (!((v4uiop_filesystem__if_does_not_exist)==(ECL_SYM("ERROR",1260)))){
   goto L27;
  }
  value0 = cl_error(3, VV[798], VV[790], v1uiop_filesystem__directory_pathname);
  return value0;
L27:;
  if (!((v4uiop_filesystem__if_does_not_exist)==(ECL_SYM("IGNORE",1282)))){
   goto L29;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L29:;
  value0 = si_ecase_error(v4uiop_filesystem__if_does_not_exist, VV[791]);
  return value0;
L25:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[430]))->cfun.entry(0) /*  OS-UNIX-P */)){
   goto L31;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[656]))->cfun.entry(1, v1uiop_filesystem__directory_pathname) /*  NATIVE-NAMESTRING */;
  T1 = cl_list(3, VV[800], VV[801], T0);
  value0 = L4199symbol_call(3, VV[362], VV[799], T1);
  return value0;
L31:;
  {
   cl_object v5uiop_filesystem__sub_directories;
   {
    cl_object env1 = env0;
    env1 = ECL_NIL;
    CLV0 = env1 = CONS(ECL_NIL,env1);
    {
     cl_object v6;
     v6 = ecl_make_cclosure_va((cl_objectfn)LC4459c,env1,Cblock,1);
     (cl_env_copy->function=ecl_fdefinition(VV[704]))->cfun.entry(4, v1uiop_filesystem__directory_pathname, ECL_T, ECL_T, v6) /*  COLLECT-SUB*DIRECTORIES */;
     v5uiop_filesystem__sub_directories = cl_reverse(ECL_CONS_CAR(CLV0));
    }
   }
   {
    cl_object v6;
    v6 = cl_nreverse(v5uiop_filesystem__sub_directories);
    goto L38;
L37:;
    {
     cl_object v7uiop_filesystem__d;
     v7uiop_filesystem__d = ecl_car(v6);
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[691]))->cfun.entry(1, v7uiop_filesystem__d) /*  DIRECTORY-FILES */;
     cl_map(3, ECL_NIL, ECL_SYM("DELETE-FILE",295), T0);
     (cl_env_copy->function=ecl_fdefinition(VV[788]))->cfun.entry(1, v7uiop_filesystem__d) /*  DELETE-EMPTY-DIRECTORY */;
    }
    v6 = ecl_cdr(v6);
L38:;
    if (Null(v6)){
     goto L46;
    }
    goto L37;
L46:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for SETUP-STDIN                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4461setup_stdin()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("+PROCESS-STANDARD-INPUT+",1920));
 ecl_cmp_setq(cl_env_copy,VV[805],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[805]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4461setup_stdin_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[806]);
 {
  return L4461setup_stdin();
 }
}
/* function definition for SETUP-STDOUT                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4462setup_stdout()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("+PROCESS-STANDARD-OUTPUT+",1921));
 ecl_cmp_setq(cl_env_copy,VV[808],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[808]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4462setup_stdout_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[809]);
 {
  return L4462setup_stdout();
 }
}
/* function definition for SETUP-STDERR                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4463setup_stderr()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("+PROCESS-ERROR-OUTPUT+",1922));
 ecl_cmp_setq(cl_env_copy,VV[811],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[811]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4463setup_stderr_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[812]);
 {
  return L4463setup_stderr();
 }
}
/* function definition for ALWAYS-DEFAULT-ENCODING                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4464always_default_encoding(cl_object v1pathname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[814]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4464always_default_encoding_va(cl_narg narg, cl_object v2pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[816]);
 {
  return L4464always_default_encoding(v2pathname);
 }
}
/* function definition for DETECT-ENCODING                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4465detect_encoding(cl_object v1pathname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1pathname)){
  goto L2;
 }
 if ((cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, v1pathname) /*  DIRECTORY-PATHNAME-P */!=ECL_NIL) {
  goto L2;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[669]))->cfun.entry(1, v1pathname) /*  PROBE-FILE* */)){
  goto L2;
 }
 value0 = ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[818]))(1, v1pathname);
 return value0;
L2:;
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[814]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4465detect_encoding_va(cl_narg narg, cl_object v2pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[819]);
 {
  return L4465detect_encoding(v2pathname);
 }
}
/* function definition for DEFAULT-ENCODING-EXTERNAL-FORMAT                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4466default_encoding_external_format(cl_object v1uiop_stream__encoding)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v1uiop_stream__encoding)==(ECL_SYM("DEFAULT",1246)))){
  goto L2;
 }
 value0 = ECL_SYM("DEFAULT",1246);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!((v1uiop_stream__encoding)==(ECL_SYM("UTF-8",1759)))){
  goto L4;
 }
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[815]);
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 cl_cerror(3, VV[822], VV[823], v1uiop_stream__encoding);
 value0 = ECL_SYM("DEFAULT",1246);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4466default_encoding_external_format_va(cl_narg narg, cl_object v2uiop_stream__encoding, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[821]);
 {
  return L4466default_encoding_external_format(v2uiop_stream__encoding);
 }
}
/* function definition for ENCODING-EXTERNAL-FORMAT                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4467encoding_external_format(cl_object v1uiop_stream__encoding)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = v1uiop_stream__encoding;
 if (value0!=ECL_NIL) {
  goto L4;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,VV[814]);
 goto L2;
L4:;
 T0 = value0;
 goto L2;
L2:;
 value0 = ecl_function_dispatch(cl_env_copy,ecl_cmp_symbol_value(cl_env_copy,VV[825]))(1, T0);
 return value0;
}
static cl_object L4467encoding_external_format_va(cl_narg narg, cl_object v2uiop_stream__encoding, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[826]);
 {
  return L4467encoding_external_format(v2uiop_stream__encoding);
 }
}
/* local function WITH-SAFE-IO-SYNTAX                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4468with_safe_io_syntax(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6package;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v7;
   v7 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v7;
  }
  v5 = si_search_keyword(v4, ECL_SYM("PACKAGE",1321));
  if (!((v5)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L11;
  }
  v6package = VV[36];
  goto L10;
L11:;
  v6package = v5;
L10:;
  si_check_keyword(2, v4, VV[830]);
  T0 = cl_list(2, ECL_SYM("FIND-PACKAGE",369), v6package);
  T1 = cl_list(2, ECL_SYM("*PACKAGE*",45), T0);
  T2 = ecl_list1(T1);
  T3 = cl_listX(3, ECL_SYM("LET",479), T2, v3);
  T4 = cl_list(3, ECL_SYM("LAMBDA",454), ECL_NIL, T3);
  T5 = cl_list(2, ECL_SYM("FUNCTION",398), T4);
  value0 = cl_list(2, VV[831], T5);
  return value0;
 }
}
static cl_object LC4468with_safe_io_syntax_va(cl_narg narg, cl_object v7, cl_object v8, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[829]);
 {
  return LC4468with_safe_io_syntax(v7, v8);
 }
}
/* function definition for CALL-WITH-SAFE-IO-SYNTAX                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4469call_with_safe_io_syntax(cl_narg narg, cl_object v1uiop_stream__thunk, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[831]);
 {
  cl_object v2package;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__thunk,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4469call_with_safe_io_syntaxkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v2package = VV[36];
   } else {
    v2package = keyvars[0];
   }
  }
  {
   cl_object v3;
   v3 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("+IO-SYNTAX-PROGV-LIST+",1805));
   {
    cl_object v5, v6; cl_index v4;
    v5 = ECL_CONS_CAR(v3);
    v6 = ECL_CONS_CDR(v3);
    v4 = ecl_progv(cl_env_copy, v5, v6);
    {
     cl_object v7;
     v7 = cl_find_package(v2package);
     ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),v7); /*  *PACKAGE*      */
     ecl_bds_bind(cl_env_copy,ECL_SYM("*READ-DEFAULT-FLOAT-FORMAT*",64),ECL_SYM("DOUBLE-FLOAT",317)); /*  *READ-DEFAULT-FLOAT-FORMAT* */
     ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59),ECL_NIL); /*  *PRINT-READABLY* */
     ecl_bds_bind(cl_env_copy,ECL_SYM("*READ-EVAL*",65),ECL_NIL); /*  *READ-EVAL* */
     value0 = ecl_function_dispatch(cl_env_copy,v1uiop_stream__thunk)(0);
     ecl_bds_unwind(cl_env_copy,v4);
     return value0;
    }
   }
  }
 }
}
/* function definition for SAFE-READ-FROM-STRING                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4471safe_read_from_string(cl_narg narg, cl_object v1string, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[834]);
 {
  ecl_va_list args; ecl_va_start(args,v1string,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1string,env0);              /*  STRING                  */
  {
   cl_object keyvars[12];
   cl_parse_key(args,6,L4471safe_read_from_stringkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[6])) {
    CLV1 = env0 = CONS(VV[36],env0);              /*  PACKAGE                 */
   } else {
    CLV1 = env0 = CONS(keyvars[0],env0);          /*  PACKAGE                 */
   }
   if (Null(keyvars[7])) {
    CLV2 = env0 = CONS(ECL_T,env0);               /*  EOF-ERROR-P             */
   } else {
    CLV2 = env0 = CONS(keyvars[1],env0);          /*  EOF-ERROR-P             */
   }
   CLV3 = env0 = CONS(keyvars[2],env0);           /*  EOF-VALUE               */
   if (Null(keyvars[9])) {
    CLV4 = env0 = CONS(ecl_make_int8_t(0),env0);  /*  START                   */
   } else {
    CLV4 = env0 = CONS(keyvars[3],env0);          /*  START                   */
   }
   CLV5 = env0 = CONS(keyvars[4],env0);           /*  END                     */
   CLV6 = env0 = CONS(keyvars[5],env0);           /*  PRESERVE-WHITESPACE     */
  }
  {
   cl_object v2;
   v2 = ecl_make_cclosure_va((cl_objectfn)LC4470__lambda2684,env0,Cblock,0);
   T0 = v2;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[831]))->cfun.entry(1, T0) /*  CALL-WITH-SAFE-IO-SYNTAX */;
  return value0;
 }
}
/* function definition for CALL-WITH-OUTPUT-FILE                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4472call_with_output_file(volatile cl_narg narg, cl_object volatile v1pathname, cl_object volatile v2uiop_stream__thunk, ...)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[838]);
 {
  cl_object volatile v3uiop_stream__element_type;
  cl_object volatile v4uiop_stream__external_format;
  cl_object volatile v5uiop_stream__if_exists;
  cl_object volatile v6uiop_stream__if_does_not_exist;
  ecl_va_list args; ecl_va_start(args,v2uiop_stream__thunk,narg,2);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L4472call_with_output_filekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[4])) {
    v3uiop_stream__element_type = ecl_cmp_symbol_value(cl_env_copy,VV[804]);
   } else {
    v3uiop_stream__element_type = keyvars[0];
   }
   if (Null(keyvars[5])) {
    v4uiop_stream__external_format = ecl_cmp_symbol_value(cl_env_copy,VV[815]);
   } else {
    v4uiop_stream__external_format = keyvars[1];
   }
   if (Null(keyvars[6])) {
    v5uiop_stream__if_exists = ECL_SYM("ERROR",1260);
   } else {
    v5uiop_stream__if_exists = keyvars[2];
   }
   if (Null(keyvars[7])) {
    v6uiop_stream__if_does_not_exist = ECL_SYM("CREATE",1244);
   } else {
    v6uiop_stream__if_does_not_exist = keyvars[3];
   }
  }
  {
   volatile cl_object v7uiop_stream__s;
   v7uiop_stream__s = cl_open(11, v1pathname, ECL_SYM("DIRECTION",1249), ECL_SYM("OUTPUT",1319), ECL_SYM("ELEMENT-TYPE",1255), v3uiop_stream__element_type, ECL_SYM("EXTERNAL-FORMAT",1267), v4uiop_stream__external_format, ECL_SYM("IF-EXISTS",1279), v5uiop_stream__if_exists, ECL_SYM("IF-DOES-NOT-EXIST",1277), v6uiop_stream__if_does_not_exist);
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    volatile bool unwinding = FALSE;
    ecl_frame_ptr next_fr;
    {
     ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
     if (__ecl_frs_push_result!=0) {
       unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
     } else {
     {
      struct ecl_stack_frame _ecl_inner_frame_aux;
      volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
      cl_env_copy->values[0] = ecl_function_dispatch(cl_env_copy,v2uiop_stream__thunk)(1, v7uiop_stream__s);
      ecl_stack_frame_push_values(_ecl_inner_frame);
      if (Null(v7uiop_stream__s)){
       goto L8;
      }
      cl_close(1, v7uiop_stream__s);
L8:;
      ecl_stack_frame_pop_values(_ecl_inner_frame);
      ecl_stack_frame_close(_ecl_inner_frame);
     }
     }
    }
    ecl_frs_pop(cl_env_copy);
    ecl_stack_frame_push_values(_ecl_inner_frame);
    if (Null(v7uiop_stream__s)){
     goto L10;
    }
    cl_close(3, v7uiop_stream__s, ECL_SYM("ABORT",1225), ECL_T);
L10:;
    ecl_stack_frame_pop_values(_ecl_inner_frame);
    if (unwinding) ecl_unwind(cl_env_copy,next_fr);
    ecl_stack_frame_close(_ecl_inner_frame);
    return cl_env_copy->values[0];
   }
  }
 }
}
/* local function WITH-OUTPUT-FILE                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4473with_output_file(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_stream__var;
  cl_object v7pathname;
  cl_object v8;
  cl_object v9uiop_stream__element_type;
  cl_object v10;
  cl_object v11uiop_stream__external_format;
  cl_object v12;
  cl_object v13uiop_stream__if_exists;
  cl_object v14;
  cl_object v15uiop_stream__if_does_not_exist;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v16;
   v16 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v16;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v16;
   v16 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_stream__var = v16;
  }
  if (!(v5==ECL_NIL)){
   goto L17;
  }
  si_dm_too_few_arguments(v1);
L17:;
  {
   cl_object v16;
   v16 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7pathname = v16;
  }
  v8 = si_search_keyword(v5, ECL_SYM("ELEMENT-TYPE",1255));
  if (!((v8)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L24;
  }
  v9uiop_stream__element_type = ECL_NIL;
  goto L23;
L24:;
  v9uiop_stream__element_type = v8;
L23:;
  v10 = si_search_keyword(v5, ECL_SYM("EXTERNAL-FORMAT",1267));
  if (!((v10)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L28;
  }
  v11uiop_stream__external_format = ECL_NIL;
  goto L27;
L28:;
  v11uiop_stream__external_format = v10;
L27:;
  v12 = si_search_keyword(v5, ECL_SYM("IF-EXISTS",1279));
  if (!((v12)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L32;
  }
  v13uiop_stream__if_exists = ECL_NIL;
  goto L31;
L32:;
  v13uiop_stream__if_exists = v12;
L31:;
  v14 = si_search_keyword(v5, ECL_SYM("IF-DOES-NOT-EXIST",1277));
  if (!((v14)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L36;
  }
  v15uiop_stream__if_does_not_exist = ECL_NIL;
  goto L35;
L36:;
  v15uiop_stream__if_does_not_exist = v14;
L35:;
  si_check_keyword(2, v5, VV[841]);
  T0 = ecl_list1(v6uiop_stream__var);
  T1 = cl_listX(3, ECL_SYM("LAMBDA",454), T0, v3);
  T2 = cl_list(2, ECL_SYM("FUNCTION",398), T1);
  value0 = cl_listX(4, VV[838], v7pathname, T2, v5);
  return value0;
 }
}
static cl_object LC4473with_output_file_va(cl_narg narg, cl_object v16, cl_object v17, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[840]);
 {
  return LC4473with_output_file(v16, v17);
 }
}
/* function definition for CALL-WITH-OUTPUT                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4474call_with_output(volatile cl_narg narg, cl_object volatile v1uiop_stream__output, cl_object volatile v2function, ...)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[843]);
 {
  cl_object volatile v3uiop_stream__keys;
  ecl_va_list args; ecl_va_start(args,v2function,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4474call_with_outputkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v3uiop_stream__keys = keyvars[0];
  }
  if (!(v1uiop_stream__output==ECL_NIL)){
   goto L1;
  }
  {
   volatile cl_object v4stream;
   v4stream = cl_make_string_output_stream(0);
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    volatile bool unwinding = FALSE;
    ecl_frame_ptr next_fr;
    {
     ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
     if (__ecl_frs_push_result!=0) {
       unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
     } else {
     ecl_function_dispatch(cl_env_copy,v2function)(1, v4stream);
     cl_env_copy->values[0] = cl_get_output_stream_string(v4stream);
     }
    }
    ecl_frs_pop(cl_env_copy);
    ecl_stack_frame_push_values(_ecl_inner_frame);
    cl_close(1, v4stream);
    ecl_stack_frame_pop_values(_ecl_inner_frame);
    if (unwinding) ecl_unwind(cl_env_copy,next_fr);
    ecl_stack_frame_close(_ecl_inner_frame);
    return cl_env_copy->values[0];
   }
  }
L1:;
  if (Null(cl_typep(2, v1uiop_stream__output, VV[40]))){
   goto L7;
  }
  value0 = ecl_function_dispatch(cl_env_copy,v2function)(1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69)));
  return value0;
L7:;
  if (Null(cl_streamp(v1uiop_stream__output))){
   goto L9;
  }
  value0 = ecl_function_dispatch(cl_env_copy,v2function)(1, v1uiop_stream__output);
  return value0;
L9:;
  if (!(ECL_STRINGP(v1uiop_stream__output))){
   goto L11;
  }
  goto L15;
L14:;
  si_assert_failure(1, VV[844]);
L15:;
  cl_fill_pointer(v1uiop_stream__output);
  {
   volatile cl_object v5;
   v5 = si_make_string_output_stream_from_string(v1uiop_stream__output);
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    volatile bool unwinding = FALSE;
    ecl_frame_ptr next_fr;
    {
     ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
     if (__ecl_frs_push_result!=0) {
       unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
     } else {
     cl_env_copy->values[0] = ecl_function_dispatch(cl_env_copy,v2function)(1, v5);
     }
    }
    ecl_frs_pop(cl_env_copy);
    ecl_stack_frame_push_values(_ecl_inner_frame);
    cl_close(1, v5);
    ecl_stack_frame_pop_values(_ecl_inner_frame);
    if (unwinding) ecl_unwind(cl_env_copy,next_fr);
    ecl_stack_frame_close(_ecl_inner_frame);
    return cl_env_copy->values[0];
   }
  }
L11:;
  if (Null(cl_pathnamep(v1uiop_stream__output))){
   goto L24;
  }
  value0 = cl_apply(4, VV[838], v1uiop_stream__output, v2function, v3uiop_stream__keys);
  return value0;
L24:;
  value0 = si_etypecase_error(v1uiop_stream__output, VV[845]);
  return value0;
 }
}
/* local function WITH-OUTPUT                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4475with_output(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_stream__output_var;
  cl_object v7uiop_stream__value;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v8;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_stream__output_var = v8;
  }
  if (Null(v5)){
   goto L17;
  }
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7uiop_stream__value = v8;
   goto L16;
  }
L17:;
  v7uiop_stream__value = v6uiop_stream__output_var;
L16:;
  if (Null(v5)){
   goto L22;
  }
  si_dm_too_many_arguments(v1);
L22:;
  T0 = ecl_list1(v6uiop_stream__output_var);
  T1 = cl_listX(3, ECL_SYM("LAMBDA",454), T0, v3);
  T2 = cl_list(2, ECL_SYM("FUNCTION",398), T1);
  value0 = cl_list(3, VV[843], v7uiop_stream__value, T2);
  return value0;
 }
}
static cl_object LC4475with_output_va(cl_narg narg, cl_object v8, cl_object v9, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[847]);
 {
  return LC4475with_output(v8, v9);
 }
}
/* function definition for OUTPUT-STRING                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4477output_string(cl_narg narg, cl_object v1string, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[849]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[849]);
 {
  cl_object v2uiop_stream__output;
  va_list args; va_start(args,v1string);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1string,env0);              /*  STRING                  */
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_stream__output = ECL_NIL;
   } else {
    i++;
    v2uiop_stream__output = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(v2uiop_stream__output)){
   goto L2;
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4476__lambda2735,env0,Cblock,1);
   T0 = v3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[843]))->cfun.entry(2, v2uiop_stream__output, T0) /*  CALL-WITH-OUTPUT */;
  return value0;
L2:;
  value0 = ECL_CONS_CAR(CLV0);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for CALL-WITH-INPUT-FILE                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4478call_with_input_file(volatile cl_narg narg, cl_object volatile v1pathname, cl_object volatile v2uiop_stream__thunk, ...)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[852]);
 {
  cl_object volatile v3uiop_stream__element_type;
  cl_object volatile v4uiop_stream__external_format;
  cl_object volatile v5uiop_stream__if_does_not_exist;
  ecl_va_list args; ecl_va_start(args,v2uiop_stream__thunk,narg,2);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L4478call_with_input_filekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[3])) {
    v3uiop_stream__element_type = ecl_cmp_symbol_value(cl_env_copy,VV[804]);
   } else {
    v3uiop_stream__element_type = keyvars[0];
   }
   if (Null(keyvars[4])) {
    v4uiop_stream__external_format = ecl_cmp_symbol_value(cl_env_copy,VV[815]);
   } else {
    v4uiop_stream__external_format = keyvars[1];
   }
   if (Null(keyvars[5])) {
    v5uiop_stream__if_does_not_exist = ECL_SYM("ERROR",1260);
   } else {
    v5uiop_stream__if_does_not_exist = keyvars[2];
   }
  }
  {
   volatile cl_object v6uiop_stream__s;
   v6uiop_stream__s = cl_open(9, v1pathname, ECL_SYM("DIRECTION",1249), ECL_SYM("INPUT",1289), ECL_SYM("ELEMENT-TYPE",1255), v3uiop_stream__element_type, ECL_SYM("EXTERNAL-FORMAT",1267), v4uiop_stream__external_format, ECL_SYM("IF-DOES-NOT-EXIST",1277), v5uiop_stream__if_does_not_exist);
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    volatile bool unwinding = FALSE;
    ecl_frame_ptr next_fr;
    {
     ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
     if (__ecl_frs_push_result!=0) {
       unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
     } else {
     {
      struct ecl_stack_frame _ecl_inner_frame_aux;
      volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
      cl_env_copy->values[0] = ecl_function_dispatch(cl_env_copy,v2uiop_stream__thunk)(1, v6uiop_stream__s);
      ecl_stack_frame_push_values(_ecl_inner_frame);
      if (Null(v6uiop_stream__s)){
       goto L7;
      }
      cl_close(1, v6uiop_stream__s);
L7:;
      ecl_stack_frame_pop_values(_ecl_inner_frame);
      ecl_stack_frame_close(_ecl_inner_frame);
     }
     }
    }
    ecl_frs_pop(cl_env_copy);
    ecl_stack_frame_push_values(_ecl_inner_frame);
    if (Null(v6uiop_stream__s)){
     goto L9;
    }
    cl_close(3, v6uiop_stream__s, ECL_SYM("ABORT",1225), ECL_T);
L9:;
    ecl_stack_frame_pop_values(_ecl_inner_frame);
    if (unwinding) ecl_unwind(cl_env_copy,next_fr);
    ecl_stack_frame_close(_ecl_inner_frame);
    return cl_env_copy->values[0];
   }
  }
 }
}
/* local function WITH-INPUT-FILE                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4479with_input_file(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_stream__var;
  cl_object v7pathname;
  cl_object v8;
  cl_object v9uiop_stream__element_type;
  cl_object v10;
  cl_object v11uiop_stream__external_format;
  cl_object v12;
  cl_object v13uiop_stream__if_does_not_exist;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v14;
   v14 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v14;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v14;
   v14 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_stream__var = v14;
  }
  if (!(v5==ECL_NIL)){
   goto L17;
  }
  si_dm_too_few_arguments(v1);
L17:;
  {
   cl_object v14;
   v14 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7pathname = v14;
  }
  v8 = si_search_keyword(v5, ECL_SYM("ELEMENT-TYPE",1255));
  if (!((v8)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L24;
  }
  v9uiop_stream__element_type = ECL_NIL;
  goto L23;
L24:;
  v9uiop_stream__element_type = v8;
L23:;
  v10 = si_search_keyword(v5, ECL_SYM("EXTERNAL-FORMAT",1267));
  if (!((v10)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L28;
  }
  v11uiop_stream__external_format = ECL_NIL;
  goto L27;
L28:;
  v11uiop_stream__external_format = v10;
L27:;
  v12 = si_search_keyword(v5, ECL_SYM("IF-DOES-NOT-EXIST",1277));
  if (!((v12)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L32;
  }
  v13uiop_stream__if_does_not_exist = ECL_NIL;
  goto L31;
L32:;
  v13uiop_stream__if_does_not_exist = v12;
L31:;
  si_check_keyword(2, v5, VV[855]);
  T0 = ecl_list1(v6uiop_stream__var);
  T1 = cl_listX(3, ECL_SYM("LAMBDA",454), T0, v3);
  T2 = cl_list(2, ECL_SYM("FUNCTION",398), T1);
  value0 = cl_listX(4, VV[852], v7pathname, T2, v5);
  return value0;
 }
}
static cl_object LC4479with_input_file_va(cl_narg narg, cl_object v14, cl_object v15, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[854]);
 {
  return LC4479with_input_file(v14, v15);
 }
}
/* function definition for CALL-WITH-INPUT                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4480call_with_input(volatile cl_narg narg, cl_object volatile v1uiop_stream__input, cl_object volatile v2function, ...)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[857]);
 {
  cl_object volatile v3uiop_stream__keys;
  ecl_va_list args; ecl_va_start(args,v2function,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4480call_with_inputkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v3uiop_stream__keys = keyvars[0];
  }
  if (!(v1uiop_stream__input==ECL_NIL)){
   goto L1;
  }
  value0 = ecl_function_dispatch(cl_env_copy,v2function)(1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-INPUT*",68)));
  return value0;
L1:;
  if (Null(cl_typep(2, v1uiop_stream__input, VV[40]))){
   goto L3;
  }
  value0 = ecl_function_dispatch(cl_env_copy,v2function)(1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*TERMINAL-IO*",70)));
  return value0;
L3:;
  if (Null(cl_streamp(v1uiop_stream__input))){
   goto L5;
  }
  value0 = ecl_function_dispatch(cl_env_copy,v2function)(1, v1uiop_stream__input);
  return value0;
L5:;
  if (!(ECL_STRINGP(v1uiop_stream__input))){
   goto L7;
  }
  {
   volatile cl_object v4stream;
   v4stream = cl_make_string_input_stream(3, v1uiop_stream__input, ecl_make_int8_t(0), ECL_NIL);
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    volatile bool unwinding = FALSE;
    ecl_frame_ptr next_fr;
    {
     ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
     if (__ecl_frs_push_result!=0) {
       unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
     } else {
     cl_env_copy->values[0] = ecl_function_dispatch(cl_env_copy,v2function)(1, v4stream);
     }
    }
    ecl_frs_pop(cl_env_copy);
    ecl_stack_frame_push_values(_ecl_inner_frame);
    cl_close(1, v4stream);
    ecl_stack_frame_pop_values(_ecl_inner_frame);
    if (unwinding) ecl_unwind(cl_env_copy,next_fr);
    ecl_stack_frame_close(_ecl_inner_frame);
    return cl_env_copy->values[0];
   }
  }
L7:;
  if (Null(cl_pathnamep(v1uiop_stream__input))){
   goto L12;
  }
  value0 = cl_apply(4, VV[852], v1uiop_stream__input, v2function, v3uiop_stream__keys);
  return value0;
L12:;
  value0 = si_etypecase_error(v1uiop_stream__input, VV[845]);
  return value0;
 }
}
/* local function WITH-INPUT                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4481with_input(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_stream__input_var;
  cl_object v7uiop_stream__value;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v8;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_stream__input_var = v8;
  }
  if (Null(v5)){
   goto L17;
  }
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7uiop_stream__value = v8;
   goto L16;
  }
L17:;
  v7uiop_stream__value = v6uiop_stream__input_var;
L16:;
  if (Null(v5)){
   goto L22;
  }
  si_dm_too_many_arguments(v1);
L22:;
  T0 = ecl_list1(v6uiop_stream__input_var);
  T1 = cl_listX(3, ECL_SYM("LAMBDA",454), T0, v3);
  T2 = cl_list(2, ECL_SYM("FUNCTION",398), T1);
  value0 = cl_list(3, VV[857], v7uiop_stream__value, T2);
  return value0;
 }
}
static cl_object LC4481with_input_va(cl_narg narg, cl_object v8, cl_object v9, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[859]);
 {
  return LC4481with_input(v8, v9);
 }
}
/* function definition for INPUT-STRING                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4483input_string(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[861]);
 {
  cl_object v1uiop_stream__input;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1uiop_stream__input = ECL_NIL;
   } else {
    i++;
    v1uiop_stream__input = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (!(ECL_STRINGP(v1uiop_stream__input))){
   goto L2;
  }
  value0 = v1uiop_stream__input;
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  {
   cl_object v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4482__lambda2777_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[857]))->cfun.entry(2, v1uiop_stream__input, T0) /*  CALL-WITH-INPUT */;
  return value0;
 }
}
/* function definition for NULL-DEVICE-PATHNAME                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4484null_device_pathname()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = VV[866];
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4484null_device_pathname_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[865]);
 {
  return L4484null_device_pathname();
 }
}
/* function definition for CALL-WITH-NULL-INPUT                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4485call_with_null_input(cl_narg narg, cl_object v1uiop_stream__fun, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[868]);
 {
  cl_object v2uiop_stream__keys;
  cl_object v3uiop_stream__element_type;
  cl_object v4uiop_stream__external_format;
  cl_object v5uiop_stream__if_does_not_exist;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__fun,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L4485call_with_null_inputkeys,keyvars,(cl_object*)&v2uiop_stream__keys,FALSE);
   ecl_va_end(args);
   v3uiop_stream__element_type = keyvars[0];
   v4uiop_stream__external_format = keyvars[1];
   v5uiop_stream__if_does_not_exist = keyvars[2];
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[865]))->cfun.entry(0) /*  NULL-DEVICE-PATHNAME */;
  value0 = cl_apply(4, VV[852], T0, v1uiop_stream__fun, v2uiop_stream__keys);
  return value0;
 }
}
/* local function WITH-NULL-INPUT                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4486with_null_input(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_stream__var;
  cl_object v7;
  cl_object v8uiop_stream__element_type;
  cl_object v9;
  cl_object v10uiop_stream__external_format;
  cl_object v11;
  cl_object v12uiop_stream__if_does_not_exist;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v13;
   v13 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v13;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v13;
   v13 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_stream__var = v13;
  }
  v7 = si_search_keyword(v5, ECL_SYM("ELEMENT-TYPE",1255));
  if (!((v7)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L18;
  }
  v8uiop_stream__element_type = ECL_NIL;
  goto L17;
L18:;
  v8uiop_stream__element_type = v7;
L17:;
  v9 = si_search_keyword(v5, ECL_SYM("EXTERNAL-FORMAT",1267));
  if (!((v9)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L22;
  }
  v10uiop_stream__external_format = ECL_NIL;
  goto L21;
L22:;
  v10uiop_stream__external_format = v9;
L21:;
  v11 = si_search_keyword(v5, ECL_SYM("IF-DOES-NOT-EXIST",1277));
  if (!((v11)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L26;
  }
  v12uiop_stream__if_does_not_exist = ECL_NIL;
  goto L25;
L26:;
  v12uiop_stream__if_does_not_exist = v11;
L25:;
  si_check_keyword(2, v5, VV[855]);
  T0 = ecl_list1(v6uiop_stream__var);
  T1 = cl_listX(3, ECL_SYM("LAMBDA",454), T0, v3);
  T2 = cl_list(2, ECL_SYM("FUNCTION",398), T1);
  value0 = cl_listX(3, VV[868], T2, v5);
  return value0;
 }
}
static cl_object LC4486with_null_input_va(cl_narg narg, cl_object v13, cl_object v14, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[870]);
 {
  return LC4486with_null_input(v13, v14);
 }
}
/* function definition for CALL-WITH-NULL-OUTPUT                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4487call_with_null_output(cl_narg narg, cl_object v1uiop_stream__fun, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[872]);
 {
  cl_object v2uiop_stream__element_type;
  cl_object v3uiop_stream__external_format;
  cl_object v4uiop_stream__if_exists;
  cl_object v5uiop_stream__if_does_not_exist;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__fun,narg,1);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L4487call_with_null_outputkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[4])) {
    v2uiop_stream__element_type = ecl_cmp_symbol_value(cl_env_copy,VV[804]);
   } else {
    v2uiop_stream__element_type = keyvars[0];
   }
   if (Null(keyvars[5])) {
    v3uiop_stream__external_format = ecl_cmp_symbol_value(cl_env_copy,VV[815]);
   } else {
    v3uiop_stream__external_format = keyvars[1];
   }
   if (Null(keyvars[6])) {
    v4uiop_stream__if_exists = ECL_SYM("OVERWRITE",1320);
   } else {
    v4uiop_stream__if_exists = keyvars[2];
   }
   if (Null(keyvars[7])) {
    v5uiop_stream__if_does_not_exist = ECL_SYM("ERROR",1260);
   } else {
    v5uiop_stream__if_does_not_exist = keyvars[3];
   }
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[865]))->cfun.entry(0) /*  NULL-DEVICE-PATHNAME */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[838]))->cfun.entry(10, T0, v1uiop_stream__fun, ECL_SYM("ELEMENT-TYPE",1255), v2uiop_stream__element_type, ECL_SYM("EXTERNAL-FORMAT",1267), v3uiop_stream__external_format, ECL_SYM("IF-EXISTS",1279), v4uiop_stream__if_exists, ECL_SYM("IF-DOES-NOT-EXIST",1277), v5uiop_stream__if_does_not_exist) /*  CALL-WITH-OUTPUT-FILE */;
  return value0;
 }
}
/* local function WITH-NULL-OUTPUT                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4488with_null_output(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_stream__var;
  cl_object v7;
  cl_object v8uiop_stream__element_type;
  cl_object v9;
  cl_object v10uiop_stream__external_format;
  cl_object v11;
  cl_object v12uiop_stream__if_does_not_exist;
  cl_object v13;
  cl_object v14uiop_stream__if_exists;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v15;
   v15 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v15;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v15;
   v15 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_stream__var = v15;
  }
  v7 = si_search_keyword(v5, ECL_SYM("ELEMENT-TYPE",1255));
  if (!((v7)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L18;
  }
  v8uiop_stream__element_type = ECL_NIL;
  goto L17;
L18:;
  v8uiop_stream__element_type = v7;
L17:;
  v9 = si_search_keyword(v5, ECL_SYM("EXTERNAL-FORMAT",1267));
  if (!((v9)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L22;
  }
  v10uiop_stream__external_format = ECL_NIL;
  goto L21;
L22:;
  v10uiop_stream__external_format = v9;
L21:;
  v11 = si_search_keyword(v5, ECL_SYM("IF-DOES-NOT-EXIST",1277));
  if (!((v11)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L26;
  }
  v12uiop_stream__if_does_not_exist = ECL_NIL;
  goto L25;
L26:;
  v12uiop_stream__if_does_not_exist = v11;
L25:;
  v13 = si_search_keyword(v5, ECL_SYM("IF-EXISTS",1279));
  if (!((v13)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L30;
  }
  v14uiop_stream__if_exists = ECL_NIL;
  goto L29;
L30:;
  v14uiop_stream__if_exists = v13;
L29:;
  si_check_keyword(2, v5, VV[875]);
  T0 = ecl_list1(v6uiop_stream__var);
  T1 = cl_listX(3, ECL_SYM("LAMBDA",454), T0, v3);
  T2 = cl_list(2, ECL_SYM("FUNCTION",398), T1);
  value0 = cl_listX(3, VV[872], T2, v5);
  return value0;
 }
}
static cl_object LC4488with_null_output_va(cl_narg narg, cl_object v15, cl_object v16, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[874]);
 {
  return LC4488with_null_output(v15, v16);
 }
}
/* function definition for FINISH-OUTPUTS                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4490finish_outputs(volatile cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object volatile v1uiop_stream__streams;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_stream__streams = cl_grab_rest_args(args);
  ecl_va_end(args);
  {
   volatile cl_object v2;
   T0 = cl_list(8, ecl_cmp_symbol_value(cl_env_copy,VV[808]), ecl_cmp_symbol_value(cl_env_copy,VV[811]), ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*ERROR-OUTPUT*",35)), ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69)), ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*TRACE-OUTPUT*",71)), ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*DEBUG-IO*",32)), ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*TERMINAL-IO*",70)), ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*QUERY-IO*",61)));
   v2 = ecl_append(v1uiop_stream__streams,T0);
   goto L5;
L4:;
   {
    volatile cl_object v3uiop_stream__s;
    v3uiop_stream__s = ecl_car(v2);
    {
     volatile cl_object env1 = env0;
     env1 = ECL_NIL;
     CLV0 = env1 = CONS(ECL_NIL,env1);
     {
      volatile cl_object env2 = env1;
      CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY     */
      {
       ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
       if (__ecl_frs_push_result!=0) {
       if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
        goto L10;
       }
       ecl_internal_error("GO found an inexistent tag");
       } else {
       {
        cl_object v4;
        v4 = ecl_make_cclosure_va((cl_objectfn)LC4489__lambda2841,env2,Cblock,1);
        T0 = v4;
       }
       T1 = CONS(ECL_SYM("ERROR",339),T0);
       T2 = ecl_list1(T1);
       T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
       ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
       cl_finish_output(1, v3uiop_stream__s);
       ecl_frs_pop_n(cl_env_copy, 1);
       ecl_bds_unwind1(cl_env_copy);
       goto L9;
L10:;
       {
        cl_object v4condition;
        v4condition = ECL_CONS_CAR(CLV0);
        ecl_frs_pop_n(cl_env_copy, 1);
        goto L9;
       }
       }
      }
     }
    }
L9:;
   }
   v2 = ecl_cdr(v2);
L5:;
   if (Null(v2)){
    goto L19;
   }
   goto L4;
L19:;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
}
/* function definition for FORMAT!                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4491format_(cl_narg narg, cl_object v1stream, cl_object v2format, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[881]);
 {
  cl_object v3uiop_stream__args;
  ecl_va_list args; ecl_va_start(args,v2format,narg,2);
  v3uiop_stream__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  (cl_env_copy->function=ecl_fdefinition(VV[877]))->cfun.entry(1, v1stream) /*  FINISH-OUTPUTS */;
  cl_apply(4, ECL_SYM("FORMAT",389), v1stream, v2format, v3uiop_stream__args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[877]))->cfun.entry(1, v1stream) /*  FINISH-OUTPUTS */;
  return value0;
 }
}
/* function definition for SAFE-FORMAT!                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4494safe_format_(volatile cl_narg narg, cl_object volatile v1stream, cl_object volatile v2format, ...)
{
 cl_object T0;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[883]);
 {
  cl_object volatile v3uiop_stream__args;
  ecl_va_list args; ecl_va_start(args,v2format,narg,2);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1stream,env0);              /*  STREAM                  */
  CLV1 = env0 = CONS(v2format,env0);              /*  FORMAT                  */
  v3uiop_stream__args = cl_grab_rest_args(args);
  CLV2 = env0 = CONS(v3uiop_stream__args,env0);   /*  ARGS                    */
  ecl_va_end(args);
  {
   cl_object volatile v4;
   v4 = ecl_make_cclosure_va((cl_objectfn)LC4493__lambda2851,env0,Cblock,0);
   T0 = v4;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[831]))->cfun.entry(1, T0) /*  CALL-WITH-SAFE-IO-SYNTAX */;
  return value0;
 }
}
/* function definition for COPY-STREAM-TO-STREAM                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4495copy_stream_to_stream(volatile cl_narg narg, cl_object volatile v1uiop_stream__input, cl_object volatile v2uiop_stream__output, ...)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[888]);
 {
  cl_object volatile v3uiop_stream__element_type;
  cl_object volatile v4uiop_stream__buffer_size;
  cl_object volatile v5uiop_stream__linewise;
  cl_object volatile v6uiop_stream__prefix;
  ecl_va_list args; ecl_va_start(args,v2uiop_stream__output,narg,2);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L4495copy_stream_to_streamkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v3uiop_stream__element_type = keyvars[0];
   v4uiop_stream__buffer_size = keyvars[1];
   v5uiop_stream__linewise = keyvars[2];
   v6uiop_stream__prefix = keyvars[3];
  }
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    if (Null(v5uiop_stream__linewise)){
     goto L2;
    }
    {
     cl_object v7uiop_stream__line;
     cl_object v8uiop_stream__eof;
     v7uiop_stream__line = ECL_NIL;
     v8uiop_stream__eof = ECL_NIL;
L6:;
     {
      cl_object v9;
      {
       struct ecl_stack_frame _ecl_inner_frame_aux;
       cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
       cl_env_copy->values[0] = cl_read_line(3, v1uiop_stream__input, ECL_NIL, ECL_NIL);
       ecl_stack_frame_push_values(_ecl_inner_frame);
       v9 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
       ecl_stack_frame_close(_ecl_inner_frame);
      }
      v7uiop_stream__line = ecl_car(v9);
      v9 = ecl_cdr(v9);
      v8uiop_stream__eof = ecl_car(v9);
     }
     if (v7uiop_stream__line!=ECL_NIL) {
      goto L16;
     }
     goto L7;
L16:;
     if (Null(v6uiop_stream__prefix)){
      goto L19;
     }
     ecl_princ(v6uiop_stream__prefix,v2uiop_stream__output);
L19:;
     ecl_princ(v7uiop_stream__line,v2uiop_stream__output);
     if (v8uiop_stream__eof!=ECL_NIL) {
      goto L22;
     }
     (ecl_terpri(v2uiop_stream__output));
L22:;
     cl_finish_output(1, v2uiop_stream__output);
     if (Null(v8uiop_stream__eof)){
      goto L18;
     }
     cl_env_copy->values[0] = ECL_NIL;
     cl_env_copy->nvalues = 1;
     goto L1;
L18:;
     goto L6;
L7:;
     cl_env_copy->values[0] = ECL_NIL;
     cl_env_copy->nvalues = 1;
     goto L1;
    }
L2:;
    {
     cl_object v9uiop_stream__buffer_size;
     value0 = v4uiop_stream__buffer_size;
     if (value0!=ECL_NIL) {
      goto L29;
     }
     v9uiop_stream__buffer_size = ecl_make_fixnum(8192);
     goto L27;
L29:;
     v9uiop_stream__buffer_size = value0;
     goto L27;
L27:;
     {
      cl_object v10uiop_stream__buffer;
      {
       cl_object v11;
       cl_object v12;
       v11 = ecl_list1(v9uiop_stream__buffer_size);
       value0 = v3uiop_stream__element_type;
       if (value0!=ECL_NIL) {
        goto L35;
       }
       v12 = ECL_SYM("CHARACTER",224);
       goto L33;
L35:;
       v12 = value0;
       goto L33;
L33:;
       v10uiop_stream__buffer = si_make_pure_array(v12, v11, ECL_NIL, ECL_NIL, ECL_NIL, ecl_make_int8_t(0));
      }
      {
       cl_object v11uiop_stream__end;
       v11uiop_stream__end = ECL_NIL;
L38:;
       v11uiop_stream__end = cl_read_sequence(2, v10uiop_stream__buffer, v1uiop_stream__input);
       if (!(ecl_zerop(v11uiop_stream__end))){
        goto L42;
       }
       goto L39;
L42:;
       cl_write_sequence(4, v10uiop_stream__buffer, v2uiop_stream__output, ECL_SYM("END",1256), v11uiop_stream__end);
       if (!(ecl_lower(v11uiop_stream__end,v9uiop_stream__buffer_size))){
        goto L44;
       }
       cl_env_copy->values[0] = ECL_NIL;
       cl_env_copy->nvalues = 1;
       goto L1;
L44:;
       goto L38;
L39:;
       cl_env_copy->values[0] = ECL_NIL;
       cl_env_copy->nvalues = 1;
      }
     }
    }
L1:;
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   cl_close(1, v1uiop_stream__input);
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
}
/* function definition for CONCATENATE-FILES                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4496concatenate_files(cl_object volatile v1uiop_stream__inputs, cl_object volatile v2uiop_stream__output)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v3uiop_stream__o;
  v3uiop_stream__o = cl_open(7, v2uiop_stream__output, ECL_SYM("ELEMENT-TYPE",1255), VV[493], ECL_SYM("DIRECTION",1249), ECL_SYM("OUTPUT",1319), ECL_SYM("IF-EXISTS",1279), ECL_SYM("RENAME-AND-DELETE",1338));
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    {
     struct ecl_stack_frame _ecl_inner_frame_aux;
     volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
     {
      volatile cl_object v4;
      v4 = v1uiop_stream__inputs;
      goto L8;
L7:;
      {
       volatile cl_object v5uiop_stream__input;
       v5uiop_stream__input = ecl_car(v4);
       {
        volatile cl_object v6uiop_stream__i;
        v6uiop_stream__i = cl_open(7, v5uiop_stream__input, ECL_SYM("ELEMENT-TYPE",1255), VV[493], ECL_SYM("DIRECTION",1249), ECL_SYM("INPUT",1289), ECL_SYM("IF-DOES-NOT-EXIST",1277), ECL_SYM("ERROR",1260));
        {
         struct ecl_stack_frame _ecl_inner_frame_aux;
         volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
         volatile bool unwinding = FALSE;
         ecl_frame_ptr next_fr;
         {
          ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
          if (__ecl_frs_push_result!=0) {
            unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
          } else {
          {
          struct ecl_stack_frame _ecl_inner_frame_aux;
          volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
          cl_env_copy->values[0] = (cl_env_copy->function=ecl_fdefinition(VV[888]))->cfun.entry(4, v6uiop_stream__i, v3uiop_stream__o, ECL_SYM("ELEMENT-TYPE",1255), VV[493]) /*  COPY-STREAM-TO-STREAM */;
          ecl_stack_frame_push_values(_ecl_inner_frame);
          if (Null(v6uiop_stream__i)){
          goto L16;
          }
          cl_close(1, v6uiop_stream__i);
L16:;
          ecl_stack_frame_pop_values(_ecl_inner_frame);
          ecl_stack_frame_close(_ecl_inner_frame);
          }
          }
         }
         ecl_frs_pop(cl_env_copy);
         ecl_stack_frame_push_values(_ecl_inner_frame);
         if (Null(v6uiop_stream__i)){
          goto L18;
         }
         cl_close(3, v6uiop_stream__i, ECL_SYM("ABORT",1225), ECL_T);
L18:;
         ecl_stack_frame_pop_values(_ecl_inner_frame);
         if (unwinding) ecl_unwind(cl_env_copy,next_fr);
         ecl_stack_frame_close(_ecl_inner_frame);
        }
       }
      }
      v4 = ecl_cdr(v4);
L8:;
      if (Null(v4)){
       goto L22;
      }
      goto L7;
L22:;
      cl_env_copy->values[0] = ECL_NIL;
      cl_env_copy->nvalues = 1;
     }
     ecl_stack_frame_push_values(_ecl_inner_frame);
     if (Null(v3uiop_stream__o)){
      goto L24;
     }
     cl_close(1, v3uiop_stream__o);
L24:;
     ecl_stack_frame_pop_values(_ecl_inner_frame);
     ecl_stack_frame_close(_ecl_inner_frame);
    }
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   if (Null(v3uiop_stream__o)){
    goto L26;
   }
   cl_close(3, v3uiop_stream__o, ECL_SYM("ABORT",1225), ECL_T);
L26:;
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
}
static cl_object L4496concatenate_files_va(cl_narg narg, cl_object v4uiop_stream__inputs, cl_object v5uiop_stream__output, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[890]);
 {
  return L4496concatenate_files(v4uiop_stream__inputs, v5uiop_stream__output);
 }
}
/* function definition for COPY-FILE                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4497copy_file(cl_object v1uiop_stream__input, cl_object v2uiop_stream__output)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = si_copy_file(v1uiop_stream__input, v2uiop_stream__output);
 return value0;
}
static cl_object L4497copy_file_va(cl_narg narg, cl_object v3uiop_stream__input, cl_object v4uiop_stream__output, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[892]);
 {
  return L4497copy_file(v3uiop_stream__input, v4uiop_stream__output);
 }
}
/* function definition for SLURP-STREAM-STRING                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4498slurp_stream_string(volatile cl_narg narg, cl_object volatile v1uiop_stream__input, ...)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[863]);
 {
  cl_object volatile v2uiop_stream__element_type;
  cl_object volatile v3uiop_stream__stripped;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__input,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4498slurp_stream_stringkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[2])) {
    v2uiop_stream__element_type = ECL_SYM("CHARACTER",224);
   } else {
    v2uiop_stream__element_type = keyvars[0];
   }
   v3uiop_stream__stripped = keyvars[1];
  }
  {
   volatile cl_object v4string;
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    volatile bool unwinding = FALSE;
    ecl_frame_ptr next_fr;
    {
     ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
     if (__ecl_frs_push_result!=0) {
       unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
     } else {
     {
      volatile cl_object v5uiop_stream__output;
      v5uiop_stream__output = cl_make_string_output_stream(0);
      {
       struct ecl_stack_frame _ecl_inner_frame_aux;
       volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
       volatile bool unwinding = FALSE;
       ecl_frame_ptr next_fr;
       {
        ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
        if (__ecl_frs_push_result!=0) {
          unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
        } else {
        (cl_env_copy->function=ecl_fdefinition(VV[888]))->cfun.entry(4, v1uiop_stream__input, v5uiop_stream__output, ECL_SYM("ELEMENT-TYPE",1255), v2uiop_stream__element_type) /*  COPY-STREAM-TO-STREAM */;
        cl_env_copy->values[0] = cl_get_output_stream_string(v5uiop_stream__output);
        }
       }
       ecl_frs_pop(cl_env_copy);
       ecl_stack_frame_push_values(_ecl_inner_frame);
       cl_close(1, v5uiop_stream__output);
       ecl_stack_frame_pop_values(_ecl_inner_frame);
       if (unwinding) ecl_unwind(cl_env_copy,next_fr);
       ecl_stack_frame_close(_ecl_inner_frame);
      }
     }
     }
    }
    ecl_frs_pop(cl_env_copy);
    ecl_stack_frame_push_values(_ecl_inner_frame);
    cl_close(1, v1uiop_stream__input);
    ecl_stack_frame_pop_values(_ecl_inner_frame);
    if (unwinding) ecl_unwind(cl_env_copy,next_fr);
    v4string = cl_env_copy->values[0];
    ecl_stack_frame_close(_ecl_inner_frame);
   }
   if (Null(v3uiop_stream__stripped)){
    goto L9;
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[308]))->cfun.entry(1, v4string) /*  STRIPLN */;
   return value0;
L9:;
   value0 = v4string;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for SLURP-STREAM-LINES                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4499slurp_stream_lines(volatile cl_narg narg, cl_object volatile v1uiop_stream__input, ...)
{
 cl_object T0, T1;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[895]);
 {
  cl_object volatile v2count;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__input,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4499slurp_stream_lineskeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2count = keyvars[0];
  }
  {
   cl_object v3;
   v3 = v2count;
   if (v3==ECL_NIL) {
    goto L3;
   }
   if (ECL_FIXNUMP(v3)||ECL_BIGNUMP(v3)) {
    goto L3;
   }
   v2count = si_do_check_type(v3, VV[896], ECL_NIL, ECL_SYM("COUNT",268));
L3:;
  }
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    {
     cl_object v3uiop_stream__n;
     v3uiop_stream__n = ecl_make_int8_t(0);
     {
      cl_object v4uiop_stream__l;
      v4uiop_stream__l = ECL_NIL;
      {
       cl_object v5;
       cl_object v6;
       v5 = ecl_list1(ECL_NIL);
       v6 = v5;
L12:;
       if (Null(v2count)){
        goto L19;
       }
       if (!(ecl_lower(v3uiop_stream__n,v2count))){
        goto L17;
       }
       goto L18;
L19:;
L18:;
       v4uiop_stream__l = cl_read_line(3, v1uiop_stream__input, ECL_NIL, ECL_NIL);
       goto L15;
L17:;
       v4uiop_stream__l = ECL_NIL;
       goto L15;
L15:;
       if (v4uiop_stream__l!=ECL_NIL) {
        goto L21;
       }
       goto L13;
L21:;
       {
        cl_object v7;
        v7 = v6;
        if (ecl_unlikely(ECL_ATOM(v7))) FEtype_error_cons(v7);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T0 = v7;
       }
       T1 = (cl_env_copy->function=ecl_fdefinition(VV[308]))->cfun.entry(1, v4uiop_stream__l) /*  STRIPLN */;
       v6 = ecl_list1(T1);
       (ECL_CONS_CDR(T0)=v6,T0);
       v3uiop_stream__n = ecl_one_plus(v3uiop_stream__n);
       goto L12;
L13:;
       cl_env_copy->values[0] = ecl_cdr(v5);
       cl_env_copy->nvalues = 1;
       goto L7;
      }
     }
    }
L7:;
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   cl_close(1, v1uiop_stream__input);
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
}
/* function definition for SLURP-STREAM-LINE                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4500slurp_stream_line(cl_narg narg, cl_object v1uiop_stream__input, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[898]);
 {
  cl_object v2uiop_stream__at;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__input,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4500slurp_stream_linekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v2uiop_stream__at = ecl_make_int8_t(0);
   } else {
    v2uiop_stream__at = keyvars[0];
   }
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[353]))->cfun.entry(1, v2uiop_stream__at) /*  ACCESS-AT-COUNT */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[895]))->cfun.entry(3, v1uiop_stream__input, ECL_SYM("COUNT",1499), T0) /*  SLURP-STREAM-LINES */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[349]))->cfun.entry(2, T1, v2uiop_stream__at) /*  ACCESS-AT */;
  return value0;
 }
}
/* function definition for SLURP-STREAM-FORMS                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4501slurp_stream_forms(cl_narg narg, cl_object v1uiop_stream__input, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[900]);
 {
  cl_object v2count;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__input,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4501slurp_stream_formskeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2count = keyvars[0];
  }
  {
   cl_object v3;
   v3 = v2count;
   if (v3==ECL_NIL) {
    goto L3;
   }
   if (ECL_FIXNUMP(v3)||ECL_BIGNUMP(v3)) {
    goto L3;
   }
   v2count = si_do_check_type(v3, VV[896], ECL_NIL, ECL_SYM("COUNT",268));
L3:;
  }
  {
   cl_object v3uiop_stream__n;
   v3uiop_stream__n = ecl_make_int8_t(0);
   {
    cl_object v4uiop_stream__form;
    v4uiop_stream__form = ECL_NIL;
    {
     cl_object v5;
     cl_object v6;
     v5 = ecl_list1(ECL_NIL);
     v6 = v5;
L11:;
     if (Null(v2count)){
      goto L15;
     }
     if (!(ecl_greatereq(v3uiop_stream__n,v2count))){
      goto L15;
     }
     v4uiop_stream__form = VV[901];
     goto L14;
L15:;
     v4uiop_stream__form = cl_read_preserving_whitespace(3, v1uiop_stream__input, ECL_NIL, VV[901]);
L14:;
     if (!((v4uiop_stream__form)==(VV[901]))){
      goto L18;
     }
     goto L12;
L18:;
     {
      cl_object v7;
      v7 = v6;
      if (ecl_unlikely(ECL_ATOM(v7))) FEtype_error_cons(v7);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v7;
     }
     v6 = ecl_list1(v4uiop_stream__form);
     (ECL_CONS_CDR(T0)=v6,T0);
     v3uiop_stream__n = ecl_one_plus(v3uiop_stream__n);
     goto L11;
L12:;
     value0 = ecl_cdr(v5);
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
}
/* function definition for SLURP-STREAM-FORM                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4502slurp_stream_form(cl_narg narg, cl_object v1uiop_stream__input, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[903]);
 {
  cl_object v2uiop_stream__at;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__input,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4502slurp_stream_formkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v2uiop_stream__at = ecl_make_int8_t(0);
   } else {
    v2uiop_stream__at = keyvars[0];
   }
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[353]))->cfun.entry(1, v2uiop_stream__at) /*  ACCESS-AT-COUNT */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[900]))->cfun.entry(3, v1uiop_stream__input, ECL_SYM("COUNT",1499), T0) /*  SLURP-STREAM-FORMS */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[349]))->cfun.entry(2, T1, v2uiop_stream__at) /*  ACCESS-AT */;
  return value0;
 }
}
/* function definition for READ-FILE-STRING                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4503read_file_string(cl_narg narg, cl_object v1uiop_stream__file, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[905]);
 {
  cl_object v2uiop_stream__keys;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__file,narg,1);
  v2uiop_stream__keys = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = cl_apply(4, VV[852], v1uiop_stream__file, VV[863], v2uiop_stream__keys);
  return value0;
 }
}
/* function definition for READ-FILE-LINES                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4504read_file_lines(cl_narg narg, cl_object v1uiop_stream__file, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[907]);
 {
  cl_object v2uiop_stream__keys;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__file,narg,1);
  v2uiop_stream__keys = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = cl_apply(4, VV[852], v1uiop_stream__file, VV[895], v2uiop_stream__keys);
  return value0;
 }
}
/* function definition for READ-FILE-LINE                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4506read_file_line(cl_narg narg, cl_object v1uiop_stream__file, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[909]);
 {
  cl_object v2uiop_stream__keys;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__file,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4506read_file_linekeys,keyvars,(cl_object*)&v2uiop_stream__keys,TRUE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(ecl_make_int8_t(0),env0);  /*  AT                      */
   } else {
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(keyvars[0],env0);          /*  AT                      */
   }
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4505__lambda2916,env0,Cblock,1);
   T0 = v3;
  }
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[259]))->cfun.entry(2, VV[911], v2uiop_stream__keys) /*  REMOVE-PLIST-KEY */;
  value0 = cl_apply(4, VV[852], v1uiop_stream__file, T0, T1);
  return value0;
 }
}
/* function definition for READ-FILE-FORMS                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4508read_file_forms(cl_narg narg, cl_object v1uiop_stream__file, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[913]);
 {
  cl_object v2uiop_stream__keys;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__file,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4508read_file_formskeys,keyvars,(cl_object*)&v2uiop_stream__keys,TRUE);
   ecl_va_end(args);
   env0 = ECL_NIL;
   CLV0 = env0 = CONS(keyvars[0],env0);           /*  COUNT                   */
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4507__lambda2919,env0,Cblock,1);
   T0 = v3;
  }
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[259]))->cfun.entry(2, ECL_SYM("COUNT",1499), v2uiop_stream__keys) /*  REMOVE-PLIST-KEY */;
  value0 = cl_apply(4, VV[852], v1uiop_stream__file, T0, T1);
  return value0;
 }
}
/* function definition for READ-FILE-FORM                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4510read_file_form(cl_narg narg, cl_object v1uiop_stream__file, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[916]);
 {
  cl_object v2uiop_stream__keys;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__file,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4510read_file_formkeys,keyvars,(cl_object*)&v2uiop_stream__keys,TRUE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(ecl_make_int8_t(0),env0);  /*  AT                      */
   } else {
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(keyvars[0],env0);          /*  AT                      */
   }
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4509__lambda2922,env0,Cblock,1);
   T0 = v3;
  }
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[259]))->cfun.entry(2, VV[911], v2uiop_stream__keys) /*  REMOVE-PLIST-KEY */;
  value0 = cl_apply(4, VV[852], v1uiop_stream__file, T0, T1);
  return value0;
 }
}
/* function definition for SAFE-READ-FILE-LINE                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4512safe_read_file_line(cl_narg narg, cl_object v1pathname, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[919]);
 {
  cl_object v2uiop_stream__keys;
  ecl_va_list args; ecl_va_start(args,v1pathname,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1pathname,env0);            /*  PATHNAME                */
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4512safe_read_file_linekeys,keyvars,(cl_object*)&v2uiop_stream__keys,TRUE);
   CLV1 = env0 = CONS(v2uiop_stream__keys,env0);  /*  KEYS                    */
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    CLV2 = env0 = CONS(VV[36],env0);              /*  PACKAGE                 */
   } else {
    CLV2 = env0 = CONS(keyvars[0],env0);          /*  PACKAGE                 */
   }
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4511__lambda2925,env0,Cblock,0);
   T0 = v3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[831]))->cfun.entry(1, T0) /*  CALL-WITH-SAFE-IO-SYNTAX */;
  return value0;
 }
}
/* function definition for SAFE-READ-FILE-FORM                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4514safe_read_file_form(cl_narg narg, cl_object v1pathname, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[922]);
 {
  cl_object v2uiop_stream__keys;
  ecl_va_list args; ecl_va_start(args,v1pathname,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1pathname,env0);            /*  PATHNAME                */
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4514safe_read_file_formkeys,keyvars,(cl_object*)&v2uiop_stream__keys,TRUE);
   CLV1 = env0 = CONS(v2uiop_stream__keys,env0);  /*  KEYS                    */
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    CLV2 = env0 = CONS(VV[36],env0);              /*  PACKAGE                 */
   } else {
    CLV2 = env0 = CONS(keyvars[0],env0);          /*  PACKAGE                 */
   }
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4513__lambda2928,env0,Cblock,0);
   T0 = v3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[831]))->cfun.entry(1, T0) /*  CALL-WITH-SAFE-IO-SYNTAX */;
  return value0;
 }
}
/* function definition for EVAL-INPUT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4516eval_input(cl_object v1uiop_stream__input)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = ecl_make_cfun_va((cl_objectfn)LC4515__lambda2933_va,ECL_NIL,Cblock,1);
  T0 = v2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[857]))->cfun.entry(2, v1uiop_stream__input, T0) /*  CALL-WITH-INPUT */;
 return value0;
}
static cl_object L4516eval_input_va(cl_narg narg, cl_object v2uiop_stream__input, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[925]);
 {
  return L4516eval_input(v2uiop_stream__input);
 }
}
/* function definition for EVAL-THUNK                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4517eval_thunk(cl_object v1uiop_stream__thunk)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v1uiop_stream__thunk)==(ECL_NIL))){
  goto L8;
 }
 goto L4;
L8:;
 goto L6;
L6:;
 if (!((v1uiop_stream__thunk)==(ECL_T))){
  goto L11;
 }
 goto L4;
L11:;
 goto L5;
L5:;
 if (cl_keywordp(v1uiop_stream__thunk)!=ECL_NIL) {
  goto L4;
 }
 if (ecl_numberp(v1uiop_stream__thunk)) {
  goto L4;
 }
 if (ECL_CHARACTERP(v1uiop_stream__thunk)) {
  goto L4;
 }
 if (Null(cl_pathnamep(v1uiop_stream__thunk))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = v1uiop_stream__thunk;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (ECL_CONSP(v1uiop_stream__thunk)) {
  goto L18;
 }
 if (!(ECL_SYMBOLP(v1uiop_stream__thunk))){
  goto L16;
 }
 goto L17;
L18:;
L17:;
 value0 = cl_eval(v1uiop_stream__thunk);
 return value0;
L16:;
 if (Null(cl_functionp(v1uiop_stream__thunk))){
  goto L20;
 }
 value0 = ecl_function_dispatch(cl_env_copy,v1uiop_stream__thunk)(0);
 return value0;
L20:;
 if (!(ECL_STRINGP(v1uiop_stream__thunk))){
  goto L22;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[925]))->cfun.entry(1, v1uiop_stream__thunk) /*  EVAL-INPUT */;
 return value0;
L22:;
 value0 = si_etypecase_error(v1uiop_stream__thunk, VV[930]);
 return value0;
}
static cl_object L4517eval_thunk_va(cl_narg narg, cl_object v2uiop_stream__thunk, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[929]);
 {
  return L4517eval_thunk(v2uiop_stream__thunk);
 }
}
/* function definition for STANDARD-EVAL-THUNK                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4519standard_eval_thunk(cl_narg narg, cl_object v1uiop_stream__thunk, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[932]);
 {
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__thunk,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1uiop_stream__thunk,env0);  /*  THUNK                   */
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4519standard_eval_thunkkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    CLV1 = env0 = CONS(VV[36],env0);              /*  PACKAGE                 */
   } else {
    CLV1 = env0 = CONS(keyvars[0],env0);          /*  PACKAGE                 */
   }
  }
  if (Null(ECL_CONS_CAR(CLV0))){
   goto L1;
  }
  {
   cl_object v2;
   v2 = ecl_make_cclosure_va((cl_objectfn)LC4518__lambda2953,env0,Cblock,0);
   T0 = v2;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[831]))->cfun.entry(1, T0) /*  CALL-WITH-SAFE-IO-SYNTAX */;
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for PRINTLN                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4520println(cl_narg narg, cl_object v1uiop_stream__x, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[935]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[935]);
 {
  cl_object v2stream;
  va_list args; va_start(args,v1uiop_stream__x);
  {
   int i = 1;
   if (i >= narg) {
    v2stream = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69));
   } else {
    i++;
    v2stream = va_arg(args,cl_object);
   }
  }
  va_end(args);
  ecl_princ(v1uiop_stream__x,v2stream);
  (ecl_terpri(v2stream));
  cl_finish_output(1, v2stream);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
}
/* function definition for WRITELN                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4521writeln(cl_narg narg, cl_object v1uiop_stream__x, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[937]);
 {
  cl_object v2uiop_stream__keys;
  cl_object v3stream;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__x,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4521writelnkeys,keyvars,(cl_object*)&v2uiop_stream__keys,TRUE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v3stream = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69));
   } else {
    v3stream = keyvars[0];
   }
  }
  cl_apply(3, ECL_SYM("WRITE",921), v1uiop_stream__x, v2uiop_stream__keys);
  (ecl_terpri(v3stream));
  cl_finish_output(1, v3stream);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
}
/* function definition for DEFAULT-TEMPORARY-DIRECTORY                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4522default_temporary_directory()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[764]))->cfun.entry(3, VV[940], VV[595], ECL_T) /*  GETENV-PATHNAME */;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[658]))->cfun.entry(1, VV[941]) /*  PARSE-NATIVE-NAMESTRING */;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4522default_temporary_directory_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[939]);
 {
  return L4522default_temporary_directory();
 }
}
/* function definition for TEMPORARY-DIRECTORY                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4523temporary_directory()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[943]);
 if (value0!=ECL_NIL) {
  goto L3;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[939]))->cfun.entry(0) /*  DEFAULT-TEMPORARY-DIRECTORY */;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4523temporary_directory_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[944]);
 {
  return L4523temporary_directory();
 }
}
/* function definition for SETUP-TEMPORARY-DIRECTORY                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4524setup_temporary_directory()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[939]))->cfun.entry(0) /*  DEFAULT-TEMPORARY-DIRECTORY */;
 ecl_cmp_setq(cl_env_copy,VV[943],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[943]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4524setup_temporary_directory_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[946]);
 {
  return L4524setup_temporary_directory();
 }
}
/* function definition for CALL-WITH-TEMPORARY-FILE                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4526call_with_temporary_file(volatile cl_narg narg, cl_object volatile v1uiop_stream__thunk, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[948]);
 {
  cl_object volatile v2uiop_stream__want_stream_p;
  cl_object volatile v3uiop_stream__want_pathname_p;
  cl_object volatile v4uiop_stream__direction;
  cl_object volatile v5uiop_stream__keep;
  cl_object volatile v6uiop_stream__after;
  cl_object volatile v7directory;
  cl_object volatile v8type;
  cl_object volatile v9typep;
  cl_object volatile v10uiop_stream__prefix;
  cl_object volatile v11uiop_stream__suffix;
  cl_object volatile v12uiop_stream__element_type;
  cl_object volatile v13uiop_stream__external_format;
  ecl_va_list args; ecl_va_start(args,v1uiop_stream__thunk,narg,1);
  {
   cl_object keyvars[22];
   cl_parse_key(args,11,L4526call_with_temporary_filekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[11])) {
    v2uiop_stream__want_stream_p = ECL_T;
   } else {
    v2uiop_stream__want_stream_p = keyvars[0];
   }
   if (Null(keyvars[12])) {
    v3uiop_stream__want_pathname_p = ECL_T;
   } else {
    v3uiop_stream__want_pathname_p = keyvars[1];
   }
   if (Null(keyvars[13])) {
    v4uiop_stream__direction = ECL_SYM("IO",1295);
   } else {
    v4uiop_stream__direction = keyvars[2];
   }
   v5uiop_stream__keep = keyvars[3];
   v6uiop_stream__after = keyvars[4];
   v7directory = keyvars[5];
   if (Null(keyvars[17])) {
    v8type = VV[949];
   } else {
    v8type = keyvars[6];
   }
   v9typep = keyvars[17];
   v10uiop_stream__prefix = keyvars[7];
   if (Null(keyvars[19])) {
    if (Null(v9typep)){
     goto L6;
    }
    v11uiop_stream__suffix = VV[950];
    goto L5;
L6:;
    v11uiop_stream__suffix = ECL_NIL;
L5:;
   } else {
    v11uiop_stream__suffix = keyvars[8];
   }
   if (Null(keyvars[20])) {
    v12uiop_stream__element_type = ecl_cmp_symbol_value(cl_env_copy,VV[804]);
   } else {
    v12uiop_stream__element_type = keyvars[9];
   }
   if (Null(keyvars[21])) {
    v13uiop_stream__external_format = ecl_cmp_symbol_value(cl_env_copy,VV[815]);
   } else {
    v13uiop_stream__external_format = keyvars[10];
   }
  }
  {
   cl_object v14;
   v14 = v4uiop_stream__direction;
   if (!((v14)==(ECL_SYM("OUTPUT",1319)))){
    goto L16;
   }
   goto L12;
L16:;
   goto L14;
L14:;
   if (!((v14)==(ECL_SYM("IO",1295)))){
    goto L19;
   }
   goto L12;
L19:;
   goto L13;
L13:;
   v4uiop_stream__direction = si_do_check_type(v14, VV[953], ECL_NIL, VV[954]);
L12:;
  }
  goto L24;
L23:;
  si_assert_failure(1, VV[955]);
L24:;
  if (v2uiop_stream__want_stream_p!=ECL_NIL) {
   goto L27;
  }
  if (v3uiop_stream__want_pathname_p!=ECL_NIL) {
   goto L27;
  }
  goto L23;
L27:;
  {
   cl_object v14;
   v14 = ECL_NEW_FRAME_ID(cl_env_copy);
   {
    ecl_frs_push(cl_env_copy,v14);
    if (__ecl_frs_push_result!=0) {
    ecl_frs_pop_n(cl_env_copy, 1);
    return cl_env_copy->values[0];
    } else {
    {
     volatile cl_object v15uiop_stream__prefix_pn;
     value0 = v10uiop_stream__prefix;
     if (value0!=ECL_NIL) {
      goto L33;
     }
     T0 = VV[949];
     goto L31;
L33:;
     T0 = value0;
     goto L31;
L31:;
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[596]))->cfun.entry(7, v7directory, VV[672], VV[722], VV[595], ECL_T, VV[674], ECL_T) /*  ENSURE-PATHNAME */;
     if (value0!=ECL_NIL) {
      goto L37;
     }
     T1 = ecl_fdefinition(VV[944]);
     goto L35;
L37:;
     T1 = value0;
     goto L35;
L35:;
     v15uiop_stream__prefix_pn = (cl_env_copy->function=ecl_fdefinition(VV[617]))->cfun.entry(2, T0, T1) /*  ENSURE-ABSOLUTE-PATHNAME */;
     {
      volatile cl_object v16uiop_stream__prefix_nns;
      v16uiop_stream__prefix_nns = (cl_env_copy->function=ecl_fdefinition(VV[656]))->cfun.entry(1, v15uiop_stream__prefix_pn) /*  NATIVE-NAMESTRING */;
      {
       volatile cl_object v17uiop_stream__results;
       cl_ensure_directories_exist(1, v15uiop_stream__prefix_pn);
       v17uiop_stream__results = ECL_NIL;
       {
        volatile cl_object v18uiop_stream__counter;
        {
         cl_object v19;
         T0 = ecl_expt(ecl_make_int8_t(36),ecl_make_int8_t(8));
         v19 = cl_random(1, T0);
         {
          bool v20;
          v20 = ecl_numberp(v19);
          if (ecl_unlikely(!(v20)))
         FEwrong_type_argument(ECL_SYM("NUMBER",608),v19);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
         }
         v18uiop_stream__counter = v19;
        }
        {
         volatile cl_object v19pathname;
         v19pathname = ECL_NIL;
         {
          volatile cl_object v20uiop_stream__okp;
          v20uiop_stream__okp = ECL_NIL;
L47:;
          if ((v8type)==(ECL_SYM("UNSPECIFIC",1357))) {
          goto L51;
          }
          T0 = v8type;
          goto L50;
L51:;
          T0 = ECL_NIL;
L50:;
          T1 = cl_format(6, ECL_NIL, VV[956], v16uiop_stream__prefix_nns, v18uiop_stream__counter, v11uiop_stream__suffix, T0);
          v19pathname = (cl_env_copy->function=ecl_fdefinition(VV[658]))->cfun.entry(1, T1) /*  PARSE-NATIVE-NAMESTRING */;
          v20uiop_stream__okp = ECL_NIL;
          {
          struct ecl_stack_frame _ecl_inner_frame_aux;
          volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
          volatile bool unwinding = FALSE;
          ecl_frame_ptr next_fr;
          {
          ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
          if (__ecl_frs_push_result!=0) {
            unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
          } else {
          cl_ensure_directories_exist(1, v19pathname);
          {
          volatile cl_object v21stream;
          v21stream = cl_open(11, v19pathname, ECL_SYM("DIRECTION",1249), v4uiop_stream__direction, ECL_SYM("ELEMENT-TYPE",1255), v12uiop_stream__element_type, ECL_SYM("EXTERNAL-FORMAT",1267), v13uiop_stream__external_format, ECL_SYM("IF-EXISTS",1279), ECL_NIL, ECL_SYM("IF-DOES-NOT-EXIST",1277), ECL_SYM("CREATE",1244));
          {
          struct ecl_stack_frame _ecl_inner_frame_aux;
          volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
          volatile bool unwinding = FALSE;
          ecl_frame_ptr next_fr;
          {
          ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
          if (__ecl_frs_push_result!=0) {
            unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
          } else {
          {
          struct ecl_stack_frame _ecl_inner_frame_aux;
          volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
          if (Null(v21stream)){
          goto L62;
          }
          v20uiop_stream__okp = v19pathname;
          if (Null(v2uiop_stream__want_stream_p)){
          goto L66;
          }
          {
          struct ecl_stack_frame _ecl_inner_frame_aux;
          volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
          if (Null(v3uiop_stream__want_pathname_p)){
          goto L70;
          }
          cl_env_copy->values[0] = ecl_function_dispatch(cl_env_copy,v1uiop_stream__thunk)(2, v21stream, v19pathname);
          goto L69;
L70:;
          cl_env_copy->values[0] = ecl_function_dispatch(cl_env_copy,v1uiop_stream__thunk)(1, v21stream);
L69:;
          ecl_stack_frame_push_values(_ecl_inner_frame);
          v17uiop_stream__results = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
          ecl_stack_frame_close(_ecl_inner_frame);
          }
          cl_env_copy->values[0] = v17uiop_stream__results;
          cl_env_copy->nvalues = 1;
          goto L61;
L66:;
          cl_env_copy->values[0] = ECL_NIL;
          cl_env_copy->nvalues = 1;
          goto L61;
L62:;
          cl_env_copy->values[0] = ECL_NIL;
          cl_env_copy->nvalues = 1;
L61:;
          ecl_stack_frame_push_values(_ecl_inner_frame);
          if (Null(v21stream)){
          goto L72;
          }
          cl_close(1, v21stream);
L72:;
          ecl_stack_frame_pop_values(_ecl_inner_frame);
          ecl_stack_frame_close(_ecl_inner_frame);
          }
          }
          }
          ecl_frs_pop(cl_env_copy);
          ecl_stack_frame_push_values(_ecl_inner_frame);
          if (Null(v21stream)){
          goto L74;
          }
          cl_close(3, v21stream, ECL_SYM("ABORT",1225), ECL_T);
L74:;
          ecl_stack_frame_pop_values(_ecl_inner_frame);
          if (unwinding) ecl_unwind(cl_env_copy,next_fr);
          ecl_stack_frame_close(_ecl_inner_frame);
          }
          }
          if (v20uiop_stream__okp!=ECL_NIL) {
          goto L76;
          }
          cl_env_copy->values[0] = ECL_NIL;
          cl_env_copy->nvalues = 1;
          goto L56;
L76:;
          if (Null(v6uiop_stream__after)){
          goto L78;
          }
          cl_env_copy->values[0] = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, v6uiop_stream__after, v20uiop_stream__okp) /*  CALL-FUNCTION */;
          cl_return_from(v14,ECL_NIL);
L78:;
          if (Null(v3uiop_stream__want_pathname_p)){
          goto L81;
          }
          if (v2uiop_stream__want_stream_p!=ECL_NIL) {
          goto L81;
          }
          cl_env_copy->values[0] = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, v1uiop_stream__thunk, v20uiop_stream__okp) /*  CALL-FUNCTION */;
          cl_return_from(v14,ECL_NIL);
L81:;
          cl_env_copy->values[0] = cl_apply(2, ECL_SYM("VALUES",899), v17uiop_stream__results);
          cl_return_from(v14,ECL_NIL);
L56:;
          }
          }
          ecl_frs_pop(cl_env_copy);
          ecl_stack_frame_push_values(_ecl_inner_frame);
          if (Null(v20uiop_stream__okp)){
          goto L86;
          }
          if ((cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(1, v5uiop_stream__keep) /*  CALL-FUNCTION */!=ECL_NIL) {
          goto L86;
          }
          {
          volatile cl_object env1 = env0;
          env1 = ECL_NIL;
          CLV0 = env1 = CONS(ECL_NIL,env1);
          {
          volatile cl_object env2 = env1;
          CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY */
          {
          ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
          if (__ecl_frs_push_result!=0) {
          if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
          goto L89;
          }
          ecl_internal_error("GO found an inexistent tag");
          } else {
          {
          cl_object v21;
          v21 = ecl_make_cclosure_va((cl_objectfn)LC4525__lambda2997,env2,Cblock,1);
          T0 = v21;
          }
          T1 = CONS(ECL_SYM("ERROR",339),T0);
          T2 = ecl_list1(T1);
          T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
          ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
          (cl_env_copy->function=ecl_fdefinition(VV[782]))->cfun.entry(1, v20uiop_stream__okp) /*  DELETE-FILE-IF-EXISTS */;
          ecl_frs_pop_n(cl_env_copy, 1);
          ecl_bds_unwind1(cl_env_copy);
          goto L86;
L89:;
          {
          cl_object v21condition;
          v21condition = ECL_CONS_CAR(CLV0);
          ecl_frs_pop_n(cl_env_copy, 1);
          goto L86;
          }
          }
          }
          }
          }
L86:;
          ecl_stack_frame_pop_values(_ecl_inner_frame);
          if (unwinding) ecl_unwind(cl_env_copy,next_fr);
          ecl_stack_frame_close(_ecl_inner_frame);
          }
          v18uiop_stream__counter = ecl_one_plus(v18uiop_stream__counter);
          goto L47;
         }
        }
       }
      }
     }
    }
    }
   }
  }
 }
}
/* local function WITH-TEMPORARY-FILE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4527with_temporary_file(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6stream;
  cl_object v7streamp;
  cl_object v8;
  cl_object v9pathname;
  cl_object v10pathnamep;
  cl_object v11;
  cl_object v12directory;
  cl_object v13;
  cl_object v14uiop_stream__prefix;
  cl_object v15;
  cl_object v16uiop_stream__suffix;
  cl_object v17;
  cl_object v18type;
  cl_object v19;
  cl_object v20uiop_stream__keep;
  cl_object v21;
  cl_object v22uiop_stream__direction;
  cl_object v23;
  cl_object v24uiop_stream__element_type;
  cl_object v25;
  cl_object v26uiop_stream__external_format;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v27;
   v27 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v27;
  }
  v5 = si_search_keyword(v4, ECL_SYM("STREAM",1350));
  if (!((v5)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L11;
  }
  v6stream = cl_gensym(1, VV[960]);
  goto L10;
L11:;
  v6stream = v5;
L10:;
  {
   bool v27;
   v27 = (v5)==(ECL_SYM("MISSING-KEYWORD",2044));
   v7streamp = (v27)?ECL_NIL:ECL_T;
  }
  v8 = si_search_keyword(v4, ECL_SYM("PATHNAME",1322));
  if (!((v8)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L16;
  }
  v9pathname = cl_gensym(1, VV[961]);
  goto L15;
L16:;
  v9pathname = v8;
L15:;
  {
   bool v27;
   v27 = (v8)==(ECL_SYM("MISSING-KEYWORD",2044));
   v10pathnamep = (v27)?ECL_NIL:ECL_T;
  }
  v11 = si_search_keyword(v4, ECL_SYM("DIRECTORY",1250));
  if (!((v11)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L21;
  }
  v12directory = ECL_NIL;
  goto L20;
L21:;
  v12directory = v11;
L20:;
  v13 = si_search_keyword(v4, VV[100]);
  if (!((v13)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L25;
  }
  v14uiop_stream__prefix = ECL_NIL;
  goto L24;
L25:;
  v14uiop_stream__prefix = v13;
L24:;
  v15 = si_search_keyword(v4, VV[962]);
  if (!((v15)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L29;
  }
  v16uiop_stream__suffix = ECL_NIL;
  goto L28;
L29:;
  v16uiop_stream__suffix = v15;
L28:;
  v17 = si_search_keyword(v4, ECL_SYM("TYPE",1356));
  if (!((v17)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L33;
  }
  v18type = ECL_NIL;
  goto L32;
L33:;
  v18type = v17;
L32:;
  v19 = si_search_keyword(v4, VV[963]);
  if (!((v19)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L37;
  }
  v20uiop_stream__keep = ECL_NIL;
  goto L36;
L37:;
  v20uiop_stream__keep = v19;
L36:;
  v21 = si_search_keyword(v4, ECL_SYM("DIRECTION",1249));
  if (!((v21)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L41;
  }
  v22uiop_stream__direction = ECL_NIL;
  goto L40;
L41:;
  v22uiop_stream__direction = v21;
L40:;
  v23 = si_search_keyword(v4, ECL_SYM("ELEMENT-TYPE",1255));
  if (!((v23)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L45;
  }
  v24uiop_stream__element_type = ECL_NIL;
  goto L44;
L45:;
  v24uiop_stream__element_type = v23;
L44:;
  v25 = si_search_keyword(v4, ECL_SYM("EXTERNAL-FORMAT",1267));
  if (!((v25)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L49;
  }
  v26uiop_stream__external_format = ECL_NIL;
  goto L48;
L49:;
  v26uiop_stream__external_format = v25;
L48:;
  si_check_keyword(2, v4, VV[965]);
  {
   cl_object v27;
   v27 = v6stream;
   if (ECL_SYMBOLP(v27)) {
    goto L54;
   }
   v6stream = si_do_check_type(v27, ECL_SYM("SYMBOL",843), ECL_NIL, ECL_SYM("STREAM",802));
L54:;
  }
  {
   cl_object v27;
   v27 = v9pathname;
   if (ECL_SYMBOLP(v27)) {
    goto L59;
   }
   v9pathname = si_do_check_type(v27, ECL_SYM("SYMBOL",843), ECL_NIL, ECL_SYM("PATHNAME",632));
L59:;
  }
  goto L64;
L63:;
  si_assert_failure(1, VV[966]);
L64:;
  if (v7streamp!=ECL_NIL) {
   goto L67;
  }
  if (v10pathnamep!=ECL_NIL) {
   goto L67;
  }
  goto L63;
L67:;
  {
   cl_object v27uiop_stream__afterp;
   cl_object v28uiop_stream__before;
   cl_object v29uiop_stream__after;
   cl_object v30uiop_stream__beforef;
   cl_object v31uiop_stream__afterf;
   v27uiop_stream__afterp = cl_position(2, VV[967], v3);
   if (Null(v27uiop_stream__afterp)){
    goto L72;
   }
   v28uiop_stream__before = cl_subseq(3, v3, ecl_make_int8_t(0), v27uiop_stream__afterp);
   goto L71;
L72:;
   v28uiop_stream__before = v3;
L71:;
   if (Null(v27uiop_stream__afterp)){
    goto L75;
   }
   T0 = ecl_one_plus(v27uiop_stream__afterp);
   v29uiop_stream__after = cl_subseq(2, v3, T0);
   goto L74;
L75:;
   v29uiop_stream__after = ECL_NIL;
L74:;
   v30uiop_stream__beforef = cl_gensym(1, VV[968]);
   v31uiop_stream__afterf = cl_gensym(1, VV[969]);
   if (Null(v28uiop_stream__before)){
    goto L80;
   }
   if (Null(v7streamp)){
    goto L83;
   }
   T1 = ecl_list1(v6stream);
   goto L82;
L83:;
   T1 = ECL_NIL;
L82:;
   if (Null(v10pathnamep)){
    goto L86;
   }
   T2 = ecl_list1(v9pathname);
   goto L85;
L86:;
   T2 = ECL_NIL;
L85:;
   T3 = ecl_append(T1,T2);
   if (Null(v29uiop_stream__after)){
    goto L89;
   }
   T5 = cl_list(2, ECL_SYM("IGNORABLE",429), v9pathname);
   T6 = cl_list(2, ECL_SYM("DECLARE",276), T5);
   T4 = ecl_list1(T6);
   goto L88;
L89:;
   T4 = ECL_NIL;
L88:;
   T5 = ecl_append(T4,v28uiop_stream__before);
   T6 = cl_listX(3, v30uiop_stream__beforef, T3, T5);
   T0 = ecl_list1(T6);
   goto L79;
L80:;
   T0 = ECL_NIL;
L79:;
   if (Null(v29uiop_stream__after)){
    goto L92;
   }
   goto L96;
L95:;
   si_assert_failure(1, ECL_SYM("PATHNAMEP",640));
L96:;
   if (v10pathnamep!=ECL_NIL) {
    goto L99;
   }
   goto L95;
L99:;
   T2 = ecl_list1(v9pathname);
   T3 = cl_listX(3, v31uiop_stream__afterf, T2, v29uiop_stream__after);
   T1 = ecl_list1(T3);
   goto L91;
L92:;
   T1 = ECL_NIL;
L91:;
   T2 = ecl_append(T0,T1);
   if (Null(v28uiop_stream__before)){
    goto L102;
   }
   T4 = cl_list(2, ECL_SYM("FUNCTION",398), v30uiop_stream__beforef);
   T3 = ecl_list1(T4);
   goto L101;
L102:;
   T3 = ECL_NIL;
L101:;
   if (Null(v29uiop_stream__after)){
    goto L105;
   }
   T5 = cl_list(2, ECL_SYM("FUNCTION",398), v31uiop_stream__afterf);
   T4 = ecl_list1(T5);
   goto L104;
L105:;
   T4 = ECL_NIL;
L104:;
   T5 = ecl_append(T3,T4);
   T6 = CONS(ECL_SYM("DYNAMIC-EXTENT",322),T5);
   T7 = cl_list(2, ECL_SYM("DECLARE",276), T6);
   if (Null(v28uiop_stream__before)){
    goto L108;
   }
   T8 = cl_list(2, ECL_SYM("FUNCTION",398), v30uiop_stream__beforef);
   goto L107;
L108:;
   T8 = ECL_NIL;
L107:;
   if (Null(v22uiop_stream__direction)){
    goto L111;
   }
   T9 = cl_list(2, ECL_SYM("DIRECTION",1249), v22uiop_stream__direction);
   goto L110;
L111:;
   T9 = ECL_NIL;
L110:;
   if (Null(v12directory)){
    goto L114;
   }
   T10 = cl_list(2, ECL_SYM("DIRECTORY",1250), v12directory);
   goto L113;
L114:;
   T10 = ECL_NIL;
L113:;
   if (Null(v14uiop_stream__prefix)){
    goto L117;
   }
   T11 = cl_list(2, VV[100], v14uiop_stream__prefix);
   goto L116;
L117:;
   T11 = ECL_NIL;
L116:;
   if (Null(v16uiop_stream__suffix)){
    goto L120;
   }
   T12 = cl_list(2, VV[962], v16uiop_stream__suffix);
   goto L119;
L120:;
   T12 = ECL_NIL;
L119:;
   if (Null(v18type)){
    goto L123;
   }
   T13 = cl_list(2, ECL_SYM("TYPE",1356), v18type);
   goto L122;
L123:;
   T13 = ECL_NIL;
L122:;
   if (Null(v20uiop_stream__keep)){
    goto L126;
   }
   T14 = cl_list(2, VV[963], v20uiop_stream__keep);
   goto L125;
L126:;
   T14 = ECL_NIL;
L125:;
   if (Null(v29uiop_stream__after)){
    goto L129;
   }
   T16 = cl_list(2, ECL_SYM("FUNCTION",398), v31uiop_stream__afterf);
   T15 = cl_list(2, VV[972], T16);
   goto L128;
L129:;
   T15 = ECL_NIL;
L128:;
   if (Null(v24uiop_stream__element_type)){
    goto L132;
   }
   T16 = cl_list(2, ECL_SYM("ELEMENT-TYPE",1255), v24uiop_stream__element_type);
   goto L131;
L132:;
   T16 = ECL_NIL;
L131:;
   if (Null(v26uiop_stream__external_format)){
    goto L135;
   }
   T17 = cl_list(2, ECL_SYM("EXTERNAL-FORMAT",1267), v26uiop_stream__external_format);
   goto L134;
L135:;
   T17 = ECL_NIL;
L134:;
   T18 = cl_append(9, T9, T10, T11, T12, T13, T14, T15, T16, T17);
   T19 = cl_listX(7, VV[948], T8, VV[970], v7streamp, VV[971], v10pathnamep, T18);
   value0 = cl_list(4, ECL_SYM("FLET",375), T2, T7, T19);
   return value0;
  }
 }
}
static cl_object LC4527with_temporary_file_va(cl_narg narg, cl_object v32, cl_object v33, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[964]);
 {
  return LC4527with_temporary_file(v32, v33);
 }
}
/* function definition for GET-TEMPORARY-FILE                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4529get_temporary_file(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1directory;
  cl_object v2uiop_stream__prefix;
  cl_object v3uiop_stream__suffix;
  cl_object v4type;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L4529get_temporary_filekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1directory = keyvars[0];
   v2uiop_stream__prefix = keyvars[1];
   v3uiop_stream__suffix = keyvars[2];
   v4type = keyvars[3];
  }
  {
   cl_object v5;
   v5 = ecl_make_cfun_va((cl_objectfn)LC4528__before3063_va,ECL_NIL,Cblock,1);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[948]))->cfun.entry(15, v5, VV[970], ECL_NIL, VV[971], ECL_T, ECL_SYM("DIRECTORY",1250), v1directory, VV[100], v2uiop_stream__prefix, VV[962], v3uiop_stream__suffix, ECL_SYM("TYPE",1356), v4type, VV[963], ECL_T) /*  CALL-WITH-TEMPORARY-FILE */;
   return value0;
  }
 }
}
/* function definition for ADD-PATHNAME-SUFFIX                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4530add_pathname_suffix(cl_narg narg, cl_object v1pathname, cl_object v2uiop_stream__suffix, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[977]);
 {
  cl_object v3uiop_stream__keys;
  ecl_va_list args; ecl_va_start(args,v2uiop_stream__suffix,narg,2);
  v3uiop_stream__keys = cl_grab_rest_args(args);
  ecl_va_end(args);
  T0 = cl_pathname_name(1, v1pathname);
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[283]))->cfun.entry(2, T0, v2uiop_stream__suffix) /*  STRCAT */;
  value0 = cl_apply(6, ECL_SYM("MAKE-PATHNAME",533), ECL_SYM("NAME",1309), T1, ECL_SYM("DEFAULTS",1247), v1pathname, v3uiop_stream__keys);
  return value0;
 }
}
/* function definition for TMPIZE-PATHNAME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4531tmpize_pathname(cl_object v1uiop_stream__x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_stream__px;
  cl_object v3uiop_stream__prefix;
  cl_object v4directory;
  v2uiop_stream__px = (cl_env_copy->function=ecl_fdefinition(VV[596]))->cfun.entry(3, v1uiop_stream__x, VV[674], ECL_T) /*  ENSURE-PATHNAME */;
  {
   cl_object v5uiop_stream__n;
   v5uiop_stream__n = cl_pathname_name(1, v2uiop_stream__px);
   if (Null(v5uiop_stream__n)){
    goto L5;
   }
   v3uiop_stream__prefix = (cl_env_copy->function=ecl_fdefinition(VV[283]))->cfun.entry(2, v5uiop_stream__n, VV[950]) /*  STRCAT */;
   goto L3;
L5:;
   v3uiop_stream__prefix = VV[949];
  }
L3:;
  v4directory = (cl_env_copy->function=ecl_fdefinition(VV[555]))->cfun.entry(1, v2uiop_stream__px) /*  PATHNAME-DIRECTORY-PATHNAME */;
  T0 = cl_pathname_type(1, v2uiop_stream__px);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[974]))->cfun.entry(6, ECL_SYM("DIRECTORY",1250), v4directory, VV[100], v3uiop_stream__prefix, ECL_SYM("TYPE",1356), T0) /*  GET-TEMPORARY-FILE */;
  return value0;
 }
}
static cl_object L4531tmpize_pathname_va(cl_narg narg, cl_object v5uiop_stream__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[979]);
 {
  return L4531tmpize_pathname(v5uiop_stream__x);
 }
}
/* function definition for CALL-WITH-STAGING-PATHNAME                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4532call_with_staging_pathname(cl_object volatile v1pathname, cl_object volatile v2uiop_stream__fun)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v3pathname;
  volatile cl_object v4uiop_stream__staging;
  v3pathname = cl_pathname(v1pathname);
  v4uiop_stream__staging = (cl_env_copy->function=ecl_fdefinition(VV[979]))->cfun.entry(1, v3pathname) /*  TMPIZE-PATHNAME */;
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    {
     struct ecl_stack_frame _ecl_inner_frame_aux;
     volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
     cl_env_copy->values[0] = ecl_function_dispatch(cl_env_copy,v2uiop_stream__fun)(1, v4uiop_stream__staging);
     ecl_stack_frame_push_values(_ecl_inner_frame);
     (cl_env_copy->function=ecl_fdefinition(VV[786]))->cfun.entry(2, v4uiop_stream__staging, v3pathname) /*  RENAME-FILE-OVERWRITING-TARGET */;
     ecl_stack_frame_pop_values(_ecl_inner_frame);
     ecl_stack_frame_close(_ecl_inner_frame);
    }
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   (cl_env_copy->function=ecl_fdefinition(VV[782]))->cfun.entry(1, v4uiop_stream__staging) /*  DELETE-FILE-IF-EXISTS */;
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
}
static cl_object L4532call_with_staging_pathname_va(cl_narg narg, cl_object v5pathname, cl_object v6uiop_stream__fun, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[981]);
 {
  return L4532call_with_staging_pathname(v5pathname, v6uiop_stream__fun);
 }
}
/* local function WITH-STAGING-PATHNAME                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4533with_staging_pathname(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_stream__pathname_var;
  cl_object v7uiop_stream__pathname_value;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v8;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_stream__pathname_var = v8;
  }
  if (Null(v5)){
   goto L17;
  }
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7uiop_stream__pathname_value = v8;
   goto L16;
  }
L17:;
  v7uiop_stream__pathname_value = v6uiop_stream__pathname_var;
L16:;
  if (Null(v5)){
   goto L22;
  }
  si_dm_too_many_arguments(v1);
L22:;
  T0 = ecl_list1(v6uiop_stream__pathname_var);
  T1 = cl_listX(3, ECL_SYM("LAMBDA",454), T0, v3);
  T2 = cl_list(2, ECL_SYM("FUNCTION",398), T1);
  value0 = cl_list(3, VV[981], v7uiop_stream__pathname_value, T2);
  return value0;
 }
}
static cl_object LC4533with_staging_pathname_va(cl_narg narg, cl_object v8, cl_object v9, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[983]);
 {
  return LC4533with_staging_pathname(v8, v9);
 }
}
/* function definition for FILE-STREAM-P                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4534file_stream_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = si_of_class_p(2, v1stream, ECL_SYM("FILE-STREAM",360));
 return value0;
}
static cl_object L4534file_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[985]);
 {
  return L4534file_stream_p(v2stream);
 }
}
/* function definition for FILE-OR-SYNONYM-STREAM-P                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4535file_or_synonym_stream_p(cl_object v1stream)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[985]))->cfun.entry(1, v1stream) /*  FILE-STREAM-P */;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 if (Null(si_of_class_p(2, v1stream, ECL_SYM("SYNONYM-STREAM",851)))){
  goto L6;
 }
 T0 = cl_synonym_stream_symbol(v1stream);
 T1 = cl_symbol_value(T0);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[987]))->cfun.entry(1, T1) /*  FILE-OR-SYNONYM-STREAM-P */;
 return value0;
L6:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4535file_or_synonym_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[987]);
 {
  return L4535file_or_synonym_stream_p(v2stream);
 }
}
/* local function LAMBDA3088                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4536__lambda3088(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = VV[1000];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4536__lambda3088_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[999]);
 {
  return LC4536__lambda3088(v4, v5);
 }
}
/* function definition for QUIT                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4537quit(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1001]);
 {
  cl_object v1uiop_image__code;
  cl_object v2finish_output;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1uiop_image__code = ecl_make_int8_t(0);
   } else {
    i++;
    v1uiop_image__code = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v2finish_output = ECL_T;
   } else {
    i++;
    v2finish_output = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(v2finish_output)){
   goto L3;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[877]))->cfun.entry(0) /*  FINISH-OUTPUTS */;
L3:;
  value0 = si_quit(1, v1uiop_image__code);
  return value0;
 }
}
/* function definition for DIE                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4540die(volatile cl_narg narg, cl_object volatile v1uiop_image__code, cl_object volatile v2format, ...)
{
 cl_object T0;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1003]);
 {
  cl_object volatile v3uiop_image__arguments;
  ecl_va_list args; ecl_va_start(args,v2format,narg,2);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v2format,env0);              /*  FORMAT                  */
  v3uiop_image__arguments = cl_grab_rest_args(args);
  CLV1 = env0 = CONS(v3uiop_image__arguments,env0); /*  ARGUMENTS             */
  ecl_va_end(args);
  {
   cl_object volatile v4;
   v4 = ecl_make_cclosure_va((cl_objectfn)LC4539__lambda3098,env0,Cblock,0);
   T0 = v4;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[831]))->cfun.entry(1, T0) /*  CALL-WITH-SAFE-IO-SYNTAX */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1001]))->cfun.entry(1, v1uiop_image__code) /*  QUIT */;
  return value0;
 }
}
/* function definition for RAW-PRINT-BACKTRACE                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4541raw_print_backtrace(cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1stream;
  cl_object v2count;
  cl_object v3condition;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L4541raw_print_backtracekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[3])) {
    v1stream = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*DEBUG-IO*",32));
   } else {
    v1stream = keyvars[0];
   }
   v2count = keyvars[1];
   v3condition = keyvars[2];
  }
  {
   cl_object v4uiop_image__top;
   cl_object v5uiop_image__repeats;
   cl_object v6uiop_image__backtrace;
   v4uiop_image__top = si_ihs_top();
   if (Null(v2count)){
    goto L4;
   }
   v5uiop_image__repeats = ((ecl_float_nan_p(v2count) || ecl_lowereq(v4uiop_image__top,v2count))?v4uiop_image__top:v2count);
   goto L3;
L4:;
   v5uiop_image__repeats = v4uiop_image__top;
L3:;
   {
    cl_object v7;
    cl_object v8;
    cl_object v9uiop_image__ihs;
    v7 = ecl_make_int8_t(0);
    v8 = v4uiop_image__top;
    v9uiop_image__ihs = v7;
    {
     cl_object v10;
     cl_object v11;
     v10 = ecl_list1(ECL_NIL);
     v11 = v10;
L12:;
     if (!(ecl_greatereq(v9uiop_image__ihs,v8))){
      goto L14;
     }
     goto L13;
L14:;
     {
      cl_object v12;
      v12 = v11;
      if (ecl_unlikely(ECL_ATOM(v12))) FEtype_error_cons(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v12;
     }
     T1 = si_ihs_fun(v9uiop_image__ihs);
     T2 = si_ihs_env(v9uiop_image__ihs);
     T3 = cl_list(2, T1, T2);
     v11 = ecl_list1(T3);
     (ECL_CONS_CDR(T0)=v11,T0);
     v9uiop_image__ihs = ecl_one_plus(v9uiop_image__ihs);
     goto L12;
L13:;
     v6uiop_image__backtrace = ecl_cdr(v10);
     goto L6;
    }
   }
L6:;
   {
    cl_object v7;
    cl_object v8;
    cl_object v9uiop_image__i;
    v7 = ecl_make_int8_t(0);
    v8 = v5uiop_image__repeats;
    v9uiop_image__i = v7;
    {
     cl_object v10;
     cl_object v11uiop_image__frame;
     cl_object v12;
     {
      cl_object v13;
      v13 = cl_nreverse(v6uiop_image__backtrace);
      if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v10 = v13;
     }
     v11uiop_image__frame = ECL_NIL;
     v12 = v10;
L33:;
     if (!(ecl_greatereq(v9uiop_image__i,v8))){
      goto L35;
     }
     goto L34;
L35:;
     if (!(ecl_endp(v12))){
      goto L37;
     }
     goto L34;
L37:;
     v11uiop_image__frame = ECL_CONS_CAR(v12);
     {
      cl_object v13;
      v13 = ECL_CONS_CDR(v12);
      if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v12 = v13;
     }
     (cl_env_copy->function=ecl_fdefinition(VV[883]))->cfun.entry(4, v1stream, VV[1010], v9uiop_image__i, v11uiop_image__frame) /*  SAFE-FORMAT! */;
     v9uiop_image__i = ecl_one_plus(v9uiop_image__i);
     goto L33;
L34:;
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
}
/* function definition for PRINT-BACKTRACE                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4544print_backtrace(volatile cl_narg narg, ...)
{
 cl_object T0;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object volatile v1uiop_image__keys;
  cl_object volatile v2stream;
  cl_object volatile v3count;
  cl_object volatile v4condition;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L4544print_backtracekeys,keyvars,(cl_object*)&v1uiop_image__keys,FALSE);
   env0 = ECL_NIL;
   CLV0 = env0 = CONS(v1uiop_image__keys,env0);   /*  KEYS                    */
   ecl_va_end(args);
   v2stream = keyvars[0];
   v3count = keyvars[1];
   v4condition = keyvars[2];
  }
  {
   cl_object volatile v5;
   v5 = ecl_make_cclosure_va((cl_objectfn)LC4543__lambda3134,env0,Cblock,0);
   T0 = v5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[831]))->cfun.entry(1, T0) /*  CALL-WITH-SAFE-IO-SYNTAX */;
  return value0;
 }
}
/* function definition for PRINT-CONDITION-BACKTRACE                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4545print_condition_backtrace(cl_narg narg, cl_object v1condition, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1017]);
 {
  cl_object v2stream;
  cl_object v3count;
  ecl_va_list args; ecl_va_start(args,v1condition,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4545print_condition_backtracekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[2])) {
    v2stream = ecl_cmp_symbol_value(cl_env_copy,VV[811]);
   } else {
    v2stream = keyvars[0];
   }
   v3count = keyvars[1];
  }
  (cl_env_copy->function=ecl_fdefinition(VV[1012]))->cfun.entry(6, ECL_SYM("STREAM",1350), v2stream, ECL_SYM("COUNT",1499), v3count, VV[1018], v1condition) /*  PRINT-BACKTRACE */;
  if (Null(v1condition)){
   goto L3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[883]))->cfun.entry(3, v2stream, VV[1019], v1condition) /*  SAFE-FORMAT! */;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for FATAL-CONDITION-P                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4546fatal_condition_p(cl_object v1condition)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = si_of_class_p(2, v1condition, ECL_SYM("SERIOUS-CONDITION",745));
 return value0;
}
static cl_object L4546fatal_condition_p_va(cl_narg narg, cl_object v2condition, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1021]);
 {
  return L4546fatal_condition_p(v2condition);
 }
}
/* function definition for HANDLE-FATAL-CONDITION                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4547handle_fatal_condition(cl_object v1condition)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[989]))){
  goto L2;
 }
 value0 = (cl_env_copy->function=(ECL_SYM("INVOKE-DEBUGGER",447)->symbol.gfdef))->cfun.entry(1, v1condition) /*  INVOKE-DEBUGGER */;
 return value0;
L2:;
 (cl_env_copy->function=ecl_fdefinition(VV[883]))->cfun.entry(3, ecl_cmp_symbol_value(cl_env_copy,VV[811]), VV[1024], v1condition) /*  SAFE-FORMAT! */;
 (cl_env_copy->function=ecl_fdefinition(VV[1017]))->cfun.entry(3, v1condition, ECL_SYM("STREAM",1350), ecl_cmp_symbol_value(cl_env_copy,VV[811])) /*  PRINT-CONDITION-BACKTRACE */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1003]))->cfun.entry(3, ecl_make_int8_t(99), VV[1025], v1condition) /*  DIE */;
 return value0;
}
static cl_object L4547handle_fatal_condition_va(cl_narg narg, cl_object v2condition, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1023]);
 {
  return L4547handle_fatal_condition(v2condition);
 }
}
/* function definition for CALL-WITH-FATAL-CONDITION-HANDLER                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4548call_with_fatal_condition_handler(cl_object v1uiop_image__thunk)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_fdefinition(VV[1023]);
 T1 = CONS(VV[998],T0);
 T2 = ecl_list1(T1);
 T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
 ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
 value0 = ecl_function_dispatch(cl_env_copy,v1uiop_image__thunk)(0);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L4548call_with_fatal_condition_handler_va(cl_narg narg, cl_object v2uiop_image__thunk, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1027]);
 {
  return L4548call_with_fatal_condition_handler(v2uiop_image__thunk);
 }
}
/* local function WITH-FATAL-CONDITION-HANDLER                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4549with_fatal_condition_handler(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v5;
  }
  if (Null(v4)){
   goto L9;
  }
  si_dm_too_many_arguments(v1);
L9:;
  T0 = cl_listX(3, ECL_SYM("LAMBDA",454), ECL_NIL, v3);
  T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
  value0 = cl_list(2, VV[1027], T1);
  return value0;
 }
}
static cl_object LC4549with_fatal_condition_handler_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1029]);
 {
  return LC4549with_fatal_condition_handler(v5, v6);
 }
}
/* function definition for SHELL-BOOLEAN-EXIT                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4550shell_boolean_exit(cl_object v1uiop_image__x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1uiop_image__x)){
  goto L3;
 }
 T0 = ecl_make_int8_t(0);
 goto L2;
L3:;
 T0 = ecl_make_int8_t(1);
L2:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1001]))->cfun.entry(1, T0) /*  QUIT */;
 return value0;
}
static cl_object L4550shell_boolean_exit_va(cl_narg narg, cl_object v2uiop_image__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1031]);
 {
  return L4550shell_boolean_exit(v2uiop_image__x);
 }
}
/* function definition for REGISTER-IMAGE-RESTORE-HOOK                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4551register_image_restore_hook(cl_narg narg, cl_object v1uiop_image__hook, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1033]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1033]);
 {
  cl_object v2uiop_image__call_now_p;
  va_list args; va_start(args,v1uiop_image__hook);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_image__call_now_p = ECL_T;
   } else {
    i++;
    v2uiop_image__call_now_p = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[359]))->cfun.entry(3, VV[992], v1uiop_image__hook, v2uiop_image__call_now_p) /*  REGISTER-HOOK-FUNCTION */;
  return value0;
 }
}
/* function definition for REGISTER-IMAGE-DUMP-HOOK                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4552register_image_dump_hook(cl_narg narg, cl_object v1uiop_image__hook, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1035]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1035]);
 {
  cl_object v2uiop_image__call_now_p;
  va_list args; va_start(args,v1uiop_image__hook);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_image__call_now_p = ECL_NIL;
   } else {
    i++;
    v2uiop_image__call_now_p = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[359]))->cfun.entry(3, VV[997], v1uiop_image__hook, v2uiop_image__call_now_p) /*  REGISTER-HOOK-FUNCTION */;
  return value0;
 }
}
/* function definition for CALL-IMAGE-RESTORE-HOOK                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4553call_image_restore_hook()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_reverse(ecl_cmp_symbol_value(cl_env_copy,VV[992]));
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[357]))->cfun.entry(1, T0) /*  CALL-FUNCTIONS */;
 return value0;
}
static cl_object L4553call_image_restore_hook_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1037]);
 {
  return L4553call_image_restore_hook();
 }
}
/* function definition for CALL-IMAGE-DUMP-HOOK                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4554call_image_dump_hook()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[357]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[997])) /*  CALL-FUNCTIONS */;
 return value0;
}
static cl_object L4554call_image_dump_hook_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1039]);
 {
  return L4554call_image_dump_hook();
 }
}
/* function definition for RAW-COMMAND-LINE-ARGUMENTS                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4555raw_command_line_arguments()
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2;
  cl_object v3uiop_image__i;
  v1 = ecl_make_int8_t(0);
  v2 = si_argc();
  v3uiop_image__i = v1;
  {
   cl_object v4;
   cl_object v5;
   v4 = ecl_list1(ECL_NIL);
   v5 = v4;
L7:;
   if (!(ecl_greatereq(v3uiop_image__i,v2))){
    goto L9;
   }
   goto L8;
L9:;
   {
    cl_object v6;
    v6 = v5;
    if (ecl_unlikely(ECL_ATOM(v6))) FEtype_error_cons(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T0 = v6;
   }
   T1 = si_argv(v3uiop_image__i);
   v5 = ecl_list1(T1);
   (ECL_CONS_CDR(T0)=v5,T0);
   v3uiop_image__i = ecl_one_plus(v3uiop_image__i);
   goto L7;
L8:;
   value0 = ecl_cdr(v4);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4555raw_command_line_arguments_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1041]);
 {
  return L4555raw_command_line_arguments();
 }
}
/* function definition for COMMAND-LINE-ARGUMENTS                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4556command_line_arguments(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[1043]);
 {
  cl_object v1uiop_image__arguments;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1uiop_image__arguments = (cl_env_copy->function=ecl_fdefinition(VV[1041]))->cfun.entry(0) /*  RAW-COMMAND-LINE-ARGUMENTS */;
   } else {
    i++;
    v1uiop_image__arguments = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if ((ecl_cmp_symbol_value(cl_env_copy,VV[991]))==(VV[1044])) {
   goto L2;
  }
  {
   cl_object v2;
   v2 = v1uiop_image__arguments;
   goto L8;
L7:;
   {
    cl_object v3;
    cl_object v4;
    {
     cl_object v5;
     v5 = v2;
     if (ecl_unlikely(ECL_ATOM(v5))) FEtype_error_cons(v5);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v3 = v5;
    }
    v4 = ECL_CONS_CAR(v3);
    if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("STRING-EQUAL",811))(2, VV[1045], v4))){
     goto L10;
    }
    v1uiop_image__arguments = v3;
    goto L4;
   }
L10:;
   v2 = ECL_CONS_CDR(v2);
L8:;
   if (v2==ECL_NIL) {
    goto L18;
   }
   goto L7;
L18:;
   v1uiop_image__arguments = ECL_NIL;
  }
L4:;
L2:;
  value0 = ecl_cdr(v1uiop_image__arguments);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for ARGV0                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4557argv0()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((ecl_cmp_symbol_value(cl_env_copy,VV[991]))==(VV[1044]))){
  goto L2;
 }
 value0 = si_argv(ecl_make_int8_t(0));
 return value0;
L2:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[455]))->cfun.entry(1, VV[1049]) /*  GETENVP */;
 return value0;
}
static cl_object L4557argv0_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1048]);
 {
  return L4557argv0();
 }
}
/* function definition for SETUP-COMMAND-LINE-ARGUMENTS                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4558setup_command_line_arguments()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1043]))->cfun.entry(0) /*  COMMAND-LINE-ARGUMENTS */;
 ecl_cmp_setq(cl_env_copy,VV[990],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[990]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4558setup_command_line_arguments_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1051]);
 {
  return L4558setup_command_line_arguments();
 }
}
/* function definition for RESTORE-IMAGE                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4560restore_image(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_image__if_already_restored;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[10];
   cl_parse_key(args,5,L4560restore_imagekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[5])) {
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(ecl_cmp_symbol_value(cl_env_copy,VV[989]),env0); /*  LISP-INTERACTION */
   } else {
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(keyvars[0],env0);          /*  LISP-INTERACTION        */
   }
   if (Null(keyvars[6])) {
    CLV1 = env0 = CONS(ecl_cmp_symbol_value(cl_env_copy,VV[992]),env0); /*  RESTORE-HOOK */
   } else {
    CLV1 = env0 = CONS(keyvars[1],env0);          /*  RESTORE-HOOK            */
   }
   if (Null(keyvars[7])) {
    CLV2 = env0 = CONS(ecl_cmp_symbol_value(cl_env_copy,VV[994]),env0); /*  PRELUDE */
   } else {
    CLV2 = env0 = CONS(keyvars[2],env0);          /*  PRELUDE                 */
   }
   if (Null(keyvars[8])) {
    CLV3 = env0 = CONS(ecl_cmp_symbol_value(cl_env_copy,VV[995]),env0); /*  ENTRY-POINT */
   } else {
    CLV3 = env0 = CONS(keyvars[3],env0);          /*  ENTRY-POINT             */
   }
   if (Null(keyvars[9])) {
    v1uiop_image__if_already_restored = VV[1054];
   } else {
    v1uiop_image__if_already_restored = keyvars[4];
   }
  }
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[993]))){
   goto L2;
  }
  if (Null(v1uiop_image__if_already_restored)){
   goto L4;
  }
  {
   bool v2;
   v2 = (ecl_cmp_symbol_value(cl_env_copy,VV[993]))==(ECL_T);
   (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(3, v1uiop_image__if_already_restored, VV[1055], ecl_make_bool(v2)) /*  CALL-FUNCTION */;
   goto L2;
  }
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  {
   cl_object v2;
   v2 = ecl_make_cclosure_va((cl_objectfn)LC4559__lambda3212,env0,Cblock,0);
   T0 = v2;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1027]))->cfun.entry(1, T0) /*  CALL-WITH-FATAL-CONDITION-HANDLER */;
  return value0;
 }
}
/* function definition for DUMP-IMAGE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4561dump_image(cl_narg narg, cl_object v1uiop_image__filename, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1059]);
 {
  cl_object v2uiop_image__output_name;
  cl_object v3uiop_image__executable;
  cl_object v4uiop_image__postlude;
  cl_object v5uiop_image__dump_hook;
  ecl_va_list args; ecl_va_start(args,v1uiop_image__filename,narg,1);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L4561dump_imagekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2uiop_image__output_name = keyvars[0];
   v3uiop_image__executable = keyvars[1];
   if (Null(keyvars[6])) {
    v4uiop_image__postlude = ecl_cmp_symbol_value(cl_env_copy,VV[996]);
   } else {
    v4uiop_image__postlude = keyvars[2];
   }
   if (Null(keyvars[7])) {
    v5uiop_image__dump_hook = ecl_cmp_symbol_value(cl_env_copy,VV[997]);
   } else {
    v5uiop_image__dump_hook = keyvars[3];
   }
  }
  if (Null(v3uiop_image__executable)){
   goto L5;
  }
  T0 = VV[1044];
  ecl_cmp_setq(cl_env_copy,VV[991],T0);
  goto L4;
L5:;
  T0 = ECL_T;
  ecl_cmp_setq(cl_env_copy,VV[991],T0);
L4:;
  T0 = VV[1060];
  ecl_cmp_setq(cl_env_copy,VV[993],T0);
  T0 = v4uiop_image__postlude;
  ecl_cmp_setq(cl_env_copy,VV[996],T0);
  (cl_env_copy->function=ecl_fdefinition(VV[932]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[996])) /*  STANDARD-EVAL-THUNK */;
  T0 = v5uiop_image__dump_hook;
  ecl_cmp_setq(cl_env_copy,VV[997],T0);
  (cl_env_copy->function=ecl_fdefinition(VV[1039]))->cfun.entry(0) /*  CALL-IMAGE-DUMP-HOOK */;
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[993],T0);
  if (Null(v3uiop_image__executable)){
   goto L17;
  }
  cl_error(1, VV[1061]);
L17:;
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   cl_env_copy->values[0] = (cl_env_copy->function=ecl_fdefinition(VV[459]))->cfun.entry(0) /*  IMPLEMENTATION-TYPE */;
   ecl_stack_frame_push_values(_ecl_inner_frame);
   T0 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
   ecl_stack_frame_close(_ecl_inner_frame);
  }
  T1 = ecl_cadr(T0);
  value0 = cl_error(4, VV[1062], VV[1059], v1uiop_image__filename, T1);
  return value0;
 }
}
/* function definition for CREATE-IMAGE                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4562create_image(cl_narg narg, cl_object v1uiop_image__destination, cl_object v2uiop_image__lisp_object_files, ...)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1064]);
 {
  cl_object v3uiop_image__kind;
  cl_object v4uiop_image__output_name;
  cl_object v5uiop_image__prologue_code;
  cl_object v6uiop_image__epilogue_code;
  cl_object v7uiop_image__extra_object_files;
  cl_object v8uiop_image__prelude;
  cl_object v9uiop_image__preludep;
  cl_object v10uiop_image__postlude;
  cl_object v11uiop_image__postludep;
  cl_object v12uiop_image__entry_point;
  cl_object v13uiop_image__entry_point_p;
  cl_object v14uiop_image__build_args;
  cl_object v15uiop_image__no_uiop;
  ecl_va_list args; ecl_va_start(args,v2uiop_image__lisp_object_files,narg,2);
  {
   cl_object keyvars[20];
   cl_parse_key(args,10,L4562create_imagekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v3uiop_image__kind = keyvars[0];
   v4uiop_image__output_name = keyvars[1];
   v5uiop_image__prologue_code = keyvars[2];
   v6uiop_image__epilogue_code = keyvars[3];
   v7uiop_image__extra_object_files = keyvars[4];
   v8uiop_image__prelude = keyvars[5];
   v9uiop_image__preludep = keyvars[15];
   v10uiop_image__postlude = keyvars[6];
   v11uiop_image__postludep = keyvars[16];
   v12uiop_image__entry_point = keyvars[7];
   v13uiop_image__entry_point_p = keyvars[17];
   v14uiop_image__build_args = keyvars[8];
   v15uiop_image__no_uiop = keyvars[9];
  }
  {
   cl_object v16uiop_image__epilogue_code;
   if (Null(v15uiop_image__no_uiop)){
    goto L2;
   }
   v16uiop_image__epilogue_code = v6uiop_image__epilogue_code;
   goto L1;
L2:;
   {
    cl_object v17uiop_image__forms;
    if (Null(v6uiop_image__epilogue_code)){
     goto L6;
    }
    T0 = ecl_list1(v6uiop_image__epilogue_code);
    goto L5;
L6:;
    T0 = ECL_NIL;
L5:;
    if (Null(v11uiop_image__postludep)){
     goto L9;
    }
    T2 = cl_list(2, ECL_SYM("QUOTE",682), v10uiop_image__postlude);
    T3 = cl_list(3, ECL_SYM("SETF",753), VV[996], T2);
    T1 = ecl_list1(T3);
    goto L8;
L9:;
    T1 = ECL_NIL;
L8:;
    if (Null(v9uiop_image__preludep)){
     goto L12;
    }
    T3 = cl_list(2, ECL_SYM("QUOTE",682), v8uiop_image__prelude);
    T4 = cl_list(3, ECL_SYM("SETF",753), VV[994], T3);
    T2 = ecl_list1(T4);
    goto L11;
L12:;
    T2 = ECL_NIL;
L11:;
    if (Null(v13uiop_image__entry_point_p)){
     goto L15;
    }
    T4 = cl_list(2, ECL_SYM("QUOTE",682), v12uiop_image__entry_point);
    T5 = cl_list(3, ECL_SYM("SETF",753), VV[995], T4);
    T3 = ecl_list1(T5);
    goto L14;
L15:;
    T3 = ECL_NIL;
L14:;
    {
     cl_object v18;
     v18 = v3uiop_image__kind;
     if (!((v18)==(VV[1066]))){
      goto L19;
     }
     v3uiop_image__kind = VV[1067];
     T4 = VV[1068];
     goto L17;
L19:;
     if (!((v18)==(VV[1067]))){
      goto L24;
     }
     T4 = VV[1070];
     goto L17;
L24:;
     T4 = ECL_NIL;
    }
L17:;
    v17uiop_image__forms = cl_append(5, T0, T1, T2, T3, T4);
    if (Null(v17uiop_image__forms)){
     goto L27;
    }
    v16uiop_image__epilogue_code = CONS(ECL_SYM("PROGN",674),v17uiop_image__forms);
    goto L1;
L27:;
    v16uiop_image__epilogue_code = ECL_NIL;
   }
L1:;
   if (!((v3uiop_image__kind)==(VV[1066]))){
    goto L29;
   }
   v3uiop_image__kind = VV[1067];
L29:;
   {
    cl_object v17;
    v17 = v3uiop_image__kind;
    {
     cl_object v18;
     cl_object v19;
     v18 = v17;
     v19 = VV[1071];
     if (ecl_memql(v18,v19)!=ECL_NIL) {
      goto L34;
     }
    }
    v3uiop_image__kind = si_do_check_type(v17, VV[1072], ECL_NIL, VV[1073]);
L34:;
   }
   T0 = cl_pathname(v1uiop_image__destination);
   T1 = ecl_append(v2uiop_image__lisp_object_files,v7uiop_image__extra_object_files);
   T2 = cl_getf(2, v14uiop_image__build_args, VV[1076]);
   if (Null(v5uiop_image__prologue_code)){
    goto L40;
   }
   T3 = cl_list(2, VV[1077], v5uiop_image__prologue_code);
   goto L39;
L40:;
   T3 = ECL_NIL;
L39:;
   if (Null(v16uiop_image__epilogue_code)){
    goto L43;
   }
   T4 = cl_list(2, VV[1078], v16uiop_image__epilogue_code);
   goto L42;
L43:;
   T4 = ECL_NIL;
L42:;
   T5 = cl_append(3, T3, T4, v14uiop_image__build_args);
   value0 = cl_apply(8, VV[1074], v3uiop_image__kind, T0, VV[1075], T1, VV[1076], T2, T5);
   return value0;
  }
 }
}
/* function definition for REQUIRES-ESCAPING-P                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4565requires_escaping_p(cl_narg narg, cl_object v1uiop_run_program__token, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1080]);
 {
  ecl_va_list args; ecl_va_start(args,v1uiop_run_program__token,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4565requires_escaping_pkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   env0 = ECL_NIL;
   CLV0 = env0 = CONS(keyvars[0],env0);           /*  GOOD-CHARS              */
   CLV1 = env0 = CONS(keyvars[1],env0);           /*  BAD-CHARS               */
  }
  if (Null(ECL_CONS_CAR(CLV0))){
   goto L2;
  }
  if (Null(ECL_CONS_CAR(CLV1))){
   goto L2;
  }
  T0 = cl_error(1, VV[1081]);
  goto L1;
L2:;
  if (Null(cl_functionp(ECL_CONS_CAR(CLV0)))){
   goto L5;
  }
  T0 = cl_complement(ECL_CONS_CAR(CLV0));
  goto L1;
L5:;
  if (Null(cl_functionp(ECL_CONS_CAR(CLV1)))){
   goto L7;
  }
  T0 = ECL_CONS_CAR(CLV1);
  goto L1;
L7:;
  if (Null(ECL_CONS_CAR(CLV0))){
   goto L9;
  }
  if (ECL_CONSP(ECL_CONS_CAR(CLV0))) {
   goto L12;
  }
  if (ECL_CONS_CAR(CLV0)==ECL_NIL) {
   goto L12;
  }
  if (!(ECL_VECTORP(ECL_CONS_CAR(CLV0)))){
   goto L9;
  }
  goto L10;
L12:;
L10:;
  {
   cl_object v2;
   v2 = ecl_make_cclosure_va((cl_objectfn)LC4563__lambda3281,env0,Cblock,1);
   T0 = v2;
   goto L1;
  }
L9:;
  if (Null(ECL_CONS_CAR(CLV1))){
   goto L15;
  }
  if (ECL_CONSP(ECL_CONS_CAR(CLV1))) {
   goto L18;
  }
  if (ECL_CONS_CAR(CLV1)==ECL_NIL) {
   goto L18;
  }
  if (!(ECL_VECTORP(ECL_CONS_CAR(CLV1)))){
   goto L15;
  }
  goto L16;
L18:;
L16:;
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4564__lambda3305,env0,Cblock,1);
   T0 = v3;
   goto L1;
  }
L15:;
  T0 = cl_error(1, VV[1084]);
L1:;
  value0 = cl_some(2, T0, v1uiop_run_program__token);
  return value0;
 }
}
/* function definition for ESCAPE-TOKEN                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4567escape_token(cl_narg narg, cl_object v1uiop_run_program__token, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1086]);
 {
  cl_object v2stream;
  cl_object v3uiop_run_program__good_chars;
  cl_object v4uiop_run_program__bad_chars;
  ecl_va_list args; ecl_va_start(args,v1uiop_run_program__token,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1uiop_run_program__token,env0); /*  TOKEN               */
  {
   cl_object keyvars[10];
   cl_parse_key(args,5,L4567escape_tokenkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2stream = keyvars[0];
   CLV1 = env0 = CONS(keyvars[1],env0);           /*  QUOTE                   */
   v3uiop_run_program__good_chars = keyvars[2];
   v4uiop_run_program__bad_chars = keyvars[3];
   CLV2 = env0 = CONS(keyvars[4],env0);           /*  ESCAPER                 */
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[1080]))->cfun.entry(5, ECL_CONS_CAR(CLV0), VV[1087], v3uiop_run_program__good_chars, VV[1088], v4uiop_run_program__bad_chars) /*  REQUIRES-ESCAPING-P */)){
   goto L1;
  }
  {
   cl_object v5;
   v5 = ecl_make_cclosure_va((cl_objectfn)LC4566__lambda3329,env0,Cblock,1);
   T0 = v5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[843]))->cfun.entry(2, v2stream, T0) /*  CALL-WITH-OUTPUT */;
  return value0;
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[849]))->cfun.entry(2, ECL_CONS_CAR(CLV0), v2stream) /*  OUTPUT-STRING */;
  return value0;
 }
}
/* function definition for ESCAPE-WINDOWS-TOKEN-WITHIN-DOUBLE-QUOTES          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4571escape_windows_token_within_double_quotes(cl_narg narg, cl_object v1uiop_run_program__x, ...)
{
 cl_object T0, T1;
 volatile cl_object lex0[1];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1092]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1092]);
 {
  va_list args; va_start(args,v1uiop_run_program__x);
  {
   int i = 1;
   if (i >= narg) {
    lex0[0] = ECL_NIL;                            /*  S                       */
   } else {
    i++;
    lex0[0] = va_arg(args,cl_object);             /*  S                       */
   }
  }
  va_end(args);
  {
   cl_object v2uiop_run_program__l;
   v2uiop_run_program__l = ecl_make_fixnum(ecl_length(v1uiop_run_program__x));
   {
    cl_object v3uiop_run_program__i;
    v3uiop_run_program__i = ecl_make_int8_t(0);
    {
     cl_object v4uiop_run_program__i_1;
     v4uiop_run_program__i_1 = ECL_NIL;
     LC4568issue(lex0, ECL_CODE_CHAR(34));
L4:;
     v4uiop_run_program__i_1 = ecl_one_plus(v3uiop_run_program__i);
     if (ecl_lower(v3uiop_run_program__i,v2uiop_run_program__l)) {
      goto L9;
     }
     goto L5;
L9:;
     {
      cl_object v5;
      v5 = cl_char(v1uiop_run_program__x, v3uiop_run_program__i);
      if (!((ECL_CHAR_CODE(v5))==((ecl_character)(34)))){
       goto L13;
      }
      LC4569issue_backslash(lex0, ecl_make_int8_t(1));
      LC4568issue(lex0, ECL_CODE_CHAR(34));
      v3uiop_run_program__i = v4uiop_run_program__i_1;
      goto L11;
L13:;
      if (!((ECL_CHAR_CODE(v5))==((ecl_character)(92)))){
       goto L19;
      }
      {
       cl_object v6uiop_run_program__j;
       cl_object v7uiop_run_program__n;
       if (!(ecl_lower(v4uiop_run_program__i_1,v2uiop_run_program__l))){
        goto L24;
       }
       {
        cl_object v8;
        v8 = ecl_make_cfun_va((cl_objectfn)LC4570__lambda3399_va,ECL_NIL,Cblock,1);
        T0 = v8;
       }
       v6uiop_run_program__j = cl_position_if_not(4, T0, v1uiop_run_program__x, ECL_SYM("START",1347), v4uiop_run_program__i_1);
       goto L22;
L24:;
       v6uiop_run_program__j = ECL_NIL;
       goto L22;
L22:;
       value0 = v6uiop_run_program__j;
       if (value0!=ECL_NIL) {
        goto L30;
       }
       T0 = v2uiop_run_program__l;
       goto L28;
L30:;
       T0 = value0;
       goto L28;
L28:;
       v7uiop_run_program__n = ecl_minus(T0,v3uiop_run_program__i);
       if (!(v6uiop_run_program__j==ECL_NIL)){
        goto L32;
       }
       T0 = ecl_times(ecl_make_int8_t(2),v7uiop_run_program__n);
       LC4569issue_backslash(lex0, T0);
       v3uiop_run_program__i = v2uiop_run_program__l;
       goto L11;
L32:;
       if (!(ecl_lower(v6uiop_run_program__j,v2uiop_run_program__l))){
        goto L36;
       }
       T0 = cl_char(v1uiop_run_program__x, v6uiop_run_program__j);
       if (!((ECL_CHAR_CODE(T0))==((ecl_character)(34)))){
        goto L36;
       }
       T0 = ecl_times(ecl_make_int8_t(2),v7uiop_run_program__n);
       T1 = ecl_one_plus(T0);
       LC4569issue_backslash(lex0, T1);
       LC4568issue(lex0, ECL_CODE_CHAR(34));
       v3uiop_run_program__i = ecl_one_plus(v6uiop_run_program__j);
       goto L11;
L36:;
       LC4569issue_backslash(lex0, v7uiop_run_program__n);
       v3uiop_run_program__i = v6uiop_run_program__j;
       goto L11;
      }
L19:;
      T0 = cl_char(v1uiop_run_program__x, v3uiop_run_program__i);
      LC4568issue(lex0, T0);
      v3uiop_run_program__i = v4uiop_run_program__i_1;
     }
L11:;
     goto L4;
L5:;
     LC4568issue(lex0, ECL_CODE_CHAR(34));
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
}
/* function definition for EASY-WINDOWS-CHARACTER-P                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4572easy_windows_character_p(cl_object v1uiop_run_program__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_alphanumericp(v1uiop_run_program__x);
 if (value0!=ECL_NIL) {
  goto L3;
 }
 {
  cl_object v2;
  v2 = si_make_seq_iterator(2, VV[1100], ecl_make_int8_t(0));
L6:;
  if (v2!=ECL_NIL) {
   goto L8;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L8:;
  {
   cl_object v3;
   v3 = si_seq_iterator_ref(VV[1100], v2);
   if (!(ecl_eql(v1uiop_run_program__x,v3))){
    goto L10;
   }
   value0 = v3;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L10:;
  v2 = si_seq_iterator_next(VV[1100], v2);
  goto L6;
 }
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4572easy_windows_character_p_va(cl_narg narg, cl_object v3uiop_run_program__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1099]);
 {
  return L4572easy_windows_character_p(v3uiop_run_program__x);
 }
}
/* function definition for ESCAPE-WINDOWS-TOKEN                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4573escape_windows_token(cl_narg narg, cl_object v1uiop_run_program__token, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1102]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1102]);
 {
  cl_object v2uiop_run_program__s;
  va_list args; va_start(args,v1uiop_run_program__token);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_run_program__s = ECL_NIL;
   } else {
    i++;
    v2uiop_run_program__s = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = ecl_fdefinition(VV[1099]);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1086]))->cfun.entry(9, v1uiop_run_program__token, ECL_SYM("STREAM",1350), v2uiop_run_program__s, VV[1087], T0, VV[1090], ECL_NIL, VV[1103], VV[1092]) /*  ESCAPE-TOKEN */;
  return value0;
 }
}
/* function definition for ESCAPE-SH-TOKEN-WITHIN-DOUBLE-QUOTES               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4574escape_sh_token_within_double_quotes(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2uiop_run_program__s, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1105]);
 {
  cl_object v3quote;
  ecl_va_list args; ecl_va_start(args,v2uiop_run_program__s,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4574escape_sh_token_within_double_quoteskeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v3quote = ECL_T;
   } else {
    v3quote = keyvars[0];
   }
  }
  if (Null(v3quote)){
   goto L2;
  }
  ecl_princ_char((ecl_character)(34),v2uiop_run_program__s);
L2:;
  {
   cl_object v4;
   cl_fixnum v5;
   cl_fixnum v6;
   cl_object v7uiop_run_program__c;
   cl_fixnum v8;
   cl_fixnum v9;
   {
    cl_object v10;
    v10 = v1uiop_run_program__x;
    if (ecl_unlikely(!ECL_VECTORP(v10))) FEtype_error_vector(v10);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v10;
   }
   v5 = (cl_fixnum)(0);
   v6 = (cl_fixnum)(0);
   v7uiop_run_program__c = ECL_NIL;
   v8 = v5;
   v9 = v6;
   v9 = ecl_length(v4);
L13:;
   if (!((v8)>=(v9))){
    goto L17;
   }
   goto L14;
L17:;
   {
    cl_object v10;
    v10 = v4;
    T0 = v10;
    {
     cl_fixnum v11;
     v11 = v8;
     if (ecl_unlikely((v11)>=(v10)->vector.dim))
           FEwrong_index(ECL_NIL,v10,-1,ecl_make_fixnum(v11),(v10)->vector.dim);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T1 = ecl_make_fixnum(v11);
    }
    v7uiop_run_program__c = ecl_aref_unsafe(T0,ecl_fixnum(T1));
   }
   {
    cl_object v10;
    v10 = ecl_make_integer((v8)+1);
    {
     bool v11;
     v11 = ECL_FIXNUMP(v10);
     if (ecl_unlikely(!(v11)))
         FEwrong_type_argument(ECL_SYM("FIXNUM",374),v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
    v8 = ecl_fixnum(v10);
   }
   {
    cl_object v10;
    v10 = si_make_seq_iterator(2, VV[1106], ecl_make_int8_t(0));
L35:;
    if (v10!=ECL_NIL) {
     goto L37;
    }
    goto L32;
L37:;
    {
     cl_object v11;
     v11 = si_seq_iterator_ref(VV[1106], v10);
     if (!(ecl_eql(v7uiop_run_program__c,v11))){
      goto L39;
     }
     if (Null(v11)){
      goto L32;
     }
     goto L33;
    }
L39:;
    v10 = si_seq_iterator_next(VV[1106], v10);
    goto L35;
   }
L33:;
   ecl_princ_char((ecl_character)(92),v2uiop_run_program__s);
L32:;
   ecl_princ(v7uiop_run_program__c,v2uiop_run_program__s);
   goto L13;
L14:;
  }
  if (Null(v3quote)){
   goto L45;
  }
  value0 = ECL_CODE_CHAR(ecl_princ_char((ecl_character)(34),v2uiop_run_program__s));
  cl_env_copy->nvalues = 1;
  return value0;
L45:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for EASY-SH-CHARACTER-P                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4575easy_sh_character_p(cl_object v1uiop_run_program__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_alphanumericp(v1uiop_run_program__x);
 if (value0!=ECL_NIL) {
  goto L3;
 }
 {
  cl_object v2;
  v2 = si_make_seq_iterator(2, VV[1109], ecl_make_int8_t(0));
L6:;
  if (v2!=ECL_NIL) {
   goto L8;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L8:;
  {
   cl_object v3;
   v3 = si_seq_iterator_ref(VV[1109], v2);
   if (!(ecl_eql(v1uiop_run_program__x,v3))){
    goto L10;
   }
   value0 = v3;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L10:;
  v2 = si_seq_iterator_next(VV[1109], v2);
  goto L6;
 }
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4575easy_sh_character_p_va(cl_narg narg, cl_object v3uiop_run_program__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1108]);
 {
  return L4575easy_sh_character_p(v3uiop_run_program__x);
 }
}
/* function definition for ESCAPE-SH-TOKEN                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4576escape_sh_token(cl_narg narg, cl_object v1uiop_run_program__token, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1111]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1111]);
 {
  cl_object v2uiop_run_program__s;
  va_list args; va_start(args,v1uiop_run_program__token);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_run_program__s = ECL_NIL;
   } else {
    i++;
    v2uiop_run_program__s = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = ecl_fdefinition(VV[1108]);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1086]))->cfun.entry(9, v1uiop_run_program__token, ECL_SYM("STREAM",1350), v2uiop_run_program__s, VV[1090], ECL_CODE_CHAR(34), VV[1087], T0, VV[1103], VV[1105]) /*  ESCAPE-TOKEN */;
  return value0;
 }
}
/* function definition for ESCAPE-SHELL-TOKEN                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4577escape_shell_token(cl_narg narg, cl_object v1uiop_run_program__token, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1113]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1113]);
 {
  cl_object v2uiop_run_program__s;
  va_list args; va_start(args,v1uiop_run_program__token);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_run_program__s = ECL_NIL;
   } else {
    i++;
    v2uiop_run_program__s = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1111]))->cfun.entry(2, v1uiop_run_program__token, v2uiop_run_program__s) /*  ESCAPE-SH-TOKEN */;
  return value0;
 }
}
/* function definition for ESCAPE-COMMAND                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4579escape_command(cl_narg narg, cl_object v1uiop_run_program__command, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1115]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[1115]);
 {
  cl_object v2uiop_run_program__s;
  va_list args; va_start(args,v1uiop_run_program__command);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1uiop_run_program__command,env0); /*  COMMAND           */
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_run_program__s = ECL_NIL;
   } else {
    i++;
    v2uiop_run_program__s = va_arg(args,cl_object);
   }
   if (i >= narg) {
    CLV1 = env0 = CONS(VV[1113],env0);            /*  ESCAPER                 */
   } else {
    i++;
    CLV1 = env0 = CONS(va_arg(args,cl_object),env0); /*  ESCAPER              */
   }
  }
  va_end(args);
  if (!(ECL_STRINGP(ECL_CONS_CAR(CLV0)))){
   goto L2;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[849]))->cfun.entry(2, ECL_CONS_CAR(CLV0), v2uiop_run_program__s) /*  OUTPUT-STRING */;
  return value0;
L2:;
  if (!(ECL_LISTP(ECL_CONS_CAR(CLV0)))){
   goto L4;
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4578__lambda3493,env0,Cblock,1);
   T0 = v3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[843]))->cfun.entry(2, v2uiop_run_program__s, T0) /*  CALL-WITH-OUTPUT */;
  return value0;
L4:;
  value0 = si_etypecase_error(ECL_CONS_CAR(CLV0), VV[1117]);
  return value0;
 }
}
/* function definition for ESCAPE-WINDOWS-COMMAND                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4580escape_windows_command(cl_narg narg, cl_object v1uiop_run_program__command, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1119]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1119]);
 {
  cl_object v2uiop_run_program__s;
  va_list args; va_start(args,v1uiop_run_program__command);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_run_program__s = ECL_NIL;
   } else {
    i++;
    v2uiop_run_program__s = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1115]))->cfun.entry(3, v1uiop_run_program__command, v2uiop_run_program__s, VV[1102]) /*  ESCAPE-COMMAND */;
  return value0;
 }
}
/* function definition for ESCAPE-SH-COMMAND                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4581escape_sh_command(cl_narg narg, cl_object v1uiop_run_program__command, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1121]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1121]);
 {
  cl_object v2uiop_run_program__s;
  va_list args; va_start(args,v1uiop_run_program__command);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_run_program__s = ECL_NIL;
   } else {
    i++;
    v2uiop_run_program__s = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1115]))->cfun.entry(3, v1uiop_run_program__command, v2uiop_run_program__s, VV[1111]) /*  ESCAPE-COMMAND */;
  return value0;
 }
}
/* function definition for ESCAPE-SHELL-COMMAND                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4582escape_shell_command(cl_narg narg, cl_object v1uiop_run_program__command, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1123]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1123]);
 {
  cl_object v2stream;
  va_list args; va_start(args,v1uiop_run_program__command);
  {
   int i = 1;
   if (i >= narg) {
    v2stream = ECL_NIL;
   } else {
    i++;
    v2stream = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1115]))->cfun.entry(3, v1uiop_run_program__command, v2stream, VV[1113]) /*  ESCAPE-COMMAND */;
  return value0;
 }
}
/* function definition for CALL-STREAM-PROCESSOR                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4583call_stream_processor(cl_object v1uiop_run_program__fun, cl_object v2uiop_run_program__processor, cl_object v3stream)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_CONSP(v2uiop_run_program__processor))){
  goto L2;
 }
 T0 = ecl_car(v2uiop_run_program__processor);
 T1 = ecl_cdr(v2uiop_run_program__processor);
 value0 = cl_apply(4, v1uiop_run_program__fun, T0, v3stream, T1);
 return value0;
L2:;
 value0 = ecl_function_dispatch(cl_env_copy,v1uiop_run_program__fun)(2, v2uiop_run_program__processor, v3stream);
 return value0;
}
static cl_object L4583call_stream_processor_va(cl_narg narg, cl_object v4uiop_run_program__fun, cl_object v5uiop_run_program__processor, cl_object v6stream, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[1125]);
 {
  return L4583call_stream_processor(v4uiop_run_program__fun, v5uiop_run_program__processor, v6stream);
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4584slurp_input_stream(cl_narg narg, cl_object v1function, cl_object v2uiop_run_program__input_stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  ecl_va_list args; ecl_va_start(args,v2uiop_run_program__input_stream,narg,2);
  cl_parse_key(args,0,NULL,NULL,NULL,TRUE);
  ecl_va_end(args);
  value0 = ecl_function_dispatch(cl_env_copy,v1function)(1, v2uiop_run_program__input_stream);
  return value0;
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4585slurp_input_stream(cl_narg narg, cl_object v1list, cl_object v2uiop_run_program__input_stream, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  ecl_va_list args; ecl_va_start(args,v2uiop_run_program__input_stream,narg,2);
  cl_parse_key(args,0,NULL,NULL,NULL,TRUE);
  ecl_va_end(args);
  T0 = ecl_car(v1list);
  T1 = ecl_cdr(v1list);
  value0 = cl_apply(3, T0, v2uiop_run_program__input_stream, T1);
  return value0;
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4586slurp_input_stream(cl_narg narg, cl_object v1uiop_run_program__output_stream, cl_object v2uiop_run_program__input_stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  cl_object v3uiop_run_program__linewise;
  cl_object v4uiop_run_program__prefix;
  cl_object v5uiop_run_program__element_type;
  cl_object v6uiop_run_program__buffer_size;
  ecl_va_list args; ecl_va_start(args,v2uiop_run_program__input_stream,narg,2);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,LC4586slurp_input_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3uiop_run_program__linewise = keyvars[0];
   v4uiop_run_program__prefix = keyvars[1];
   if (Null(keyvars[6])) {
    v5uiop_run_program__element_type = ECL_SYM("CHARACTER",224);
   } else {
    v5uiop_run_program__element_type = keyvars[2];
   }
   v6uiop_run_program__buffer_size = keyvars[3];
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[888]))->cfun.entry(10, v2uiop_run_program__input_stream, v1uiop_run_program__output_stream, VV[1130], v3uiop_run_program__linewise, VV[100], v4uiop_run_program__prefix, ECL_SYM("ELEMENT-TYPE",1255), v5uiop_run_program__element_type, VV[1131], v6uiop_run_program__buffer_size) /*  COPY-STREAM-TO-STREAM */;
  return value0;
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4587slurp_input_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  cl_object v3uiop_run_program__stripped;
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4587slurp_input_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3uiop_run_program__stripped = keyvars[0];
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[863]))->cfun.entry(3, v2stream, VV[1132], v3uiop_run_program__stripped) /*  SLURP-STREAM-STRING */;
  return value0;
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4588slurp_input_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  cl_object v3uiop_run_program__stripped;
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4588slurp_input_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3uiop_run_program__stripped = keyvars[0];
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[863]))->cfun.entry(3, v2stream, VV[1132], v3uiop_run_program__stripped) /*  SLURP-STREAM-STRING */;
  return value0;
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4589slurp_input_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  cl_object v3count;
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4589slurp_input_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3count = keyvars[0];
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[895]))->cfun.entry(3, v2stream, ECL_SYM("COUNT",1499), v3count) /*  SLURP-STREAM-LINES */;
  return value0;
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4590slurp_input_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  cl_object v3uiop_run_program__at;
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4590slurp_input_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v3uiop_run_program__at = ecl_make_int8_t(0);
   } else {
    v3uiop_run_program__at = keyvars[0];
   }
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[898]))->cfun.entry(3, v2stream, VV[911], v3uiop_run_program__at) /*  SLURP-STREAM-LINE */;
  return value0;
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4591slurp_input_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  cl_object v3count;
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4591slurp_input_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3count = keyvars[0];
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[900]))->cfun.entry(3, v2stream, ECL_SYM("COUNT",1499), v3count) /*  SLURP-STREAM-FORMS */;
  return value0;
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4592slurp_input_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  cl_object v3uiop_run_program__at;
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4592slurp_input_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v3uiop_run_program__at = ecl_make_int8_t(0);
   } else {
    v3uiop_run_program__at = keyvars[0];
   }
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[903]))->cfun.entry(3, v2stream, VV[911], v3uiop_run_program__at) /*  SLURP-STREAM-FORM */;
  return value0;
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4593slurp_input_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  cl_object v3uiop_run_program__keys;
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3uiop_run_program__keys,TRUE);
  ecl_va_end(args);
  value0 = cl_apply(4, VV[1127], ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69)), v2stream, v3uiop_run_program__keys);
  return value0;
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4594slurp_input_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  cl_parse_key(args,0,NULL,NULL,NULL,TRUE);
  ecl_va_end(args);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4596slurp_input_stream(cl_narg narg, cl_object v1pathname, cl_object v2uiop_run_program__input, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  cl_object v3uiop_run_program__external_format;
  cl_object v4uiop_run_program__if_exists;
  cl_object v5uiop_run_program__if_does_not_exist;
  ecl_va_list args; ecl_va_start(args,v2uiop_run_program__input,narg,2);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v2uiop_run_program__input,env0); /*  INPUT               */
  {
   cl_object keyvars[12];
   cl_parse_key(args,6,LC4596slurp_input_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   if (Null(keyvars[6])) {
    CLV1 = env0 = CONS(ecl_cmp_symbol_value(cl_env_copy,VV[804]),env0); /*  ELEMENT-TYPE */
   } else {
    CLV1 = env0 = CONS(keyvars[0],env0);          /*  ELEMENT-TYPE            */
   }
   if (Null(keyvars[7])) {
    v3uiop_run_program__external_format = ecl_cmp_symbol_value(cl_env_copy,VV[815]);
   } else {
    v3uiop_run_program__external_format = keyvars[1];
   }
   if (Null(keyvars[8])) {
    v4uiop_run_program__if_exists = ECL_SYM("RENAME-AND-DELETE",1338);
   } else {
    v4uiop_run_program__if_exists = keyvars[2];
   }
   if (Null(keyvars[9])) {
    v5uiop_run_program__if_does_not_exist = ECL_SYM("CREATE",1244);
   } else {
    v5uiop_run_program__if_does_not_exist = keyvars[3];
   }
   CLV2 = env0 = CONS(keyvars[4],env0);           /*  BUFFER-SIZE             */
   CLV3 = env0 = CONS(keyvars[5],env0);           /*  LINEWISE                */
  }
  {
   cl_object v6;
   v6 = ecl_make_cclosure_va((cl_objectfn)LC4595__lambda3514,env0,Cblock,1);
   T0 = v6;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[838]))->cfun.entry(10, v1pathname, T0, ECL_SYM("ELEMENT-TYPE",1255), ECL_CONS_CAR(CLV1), ECL_SYM("EXTERNAL-FORMAT",1267), v3uiop_run_program__external_format, ECL_SYM("IF-EXISTS",1279), v4uiop_run_program__if_exists, ECL_SYM("IF-DOES-NOT-EXIST",1277), v5uiop_run_program__if_does_not_exist) /*  CALL-WITH-OUTPUT-FILE */;
  return value0;
 }
}
/* local function SLURP-INPUT-STREAM                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4597slurp_input_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1127]);
 {
  cl_object v3uiop_run_program__linewise;
  cl_object v4uiop_run_program__prefix;
  cl_object v5uiop_run_program__element_type;
  cl_object v6uiop_run_program__buffer_size;
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,LC4597slurp_input_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3uiop_run_program__linewise = keyvars[0];
   v4uiop_run_program__prefix = keyvars[1];
   if (Null(keyvars[6])) {
    v5uiop_run_program__element_type = ECL_SYM("CHARACTER",224);
   } else {
    v5uiop_run_program__element_type = keyvars[2];
   }
   v6uiop_run_program__buffer_size = keyvars[3];
  }
  value0 = cl_error(3, VV[1138], VV[1127], v1uiop_run_program__x);
  return value0;
 }
}
/* local function VOMIT-OUTPUT-STREAM                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4598vomit_output_stream(cl_narg narg, cl_object v1function, cl_object v2uiop_run_program__output_stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1139]);
 {
  ecl_va_list args; ecl_va_start(args,v2uiop_run_program__output_stream,narg,2);
  cl_parse_key(args,0,NULL,NULL,NULL,TRUE);
  ecl_va_end(args);
  value0 = ecl_function_dispatch(cl_env_copy,v1function)(1, v2uiop_run_program__output_stream);
  return value0;
 }
}
/* local function VOMIT-OUTPUT-STREAM                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4599vomit_output_stream(cl_narg narg, cl_object v1list, cl_object v2uiop_run_program__output_stream, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1139]);
 {
  ecl_va_list args; ecl_va_start(args,v2uiop_run_program__output_stream,narg,2);
  cl_parse_key(args,0,NULL,NULL,NULL,TRUE);
  ecl_va_end(args);
  T0 = ecl_car(v1list);
  T1 = ecl_cdr(v1list);
  value0 = cl_apply(3, T0, v2uiop_run_program__output_stream, T1);
  return value0;
 }
}
/* local function VOMIT-OUTPUT-STREAM                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4600vomit_output_stream(cl_narg narg, cl_object v1uiop_run_program__input_stream, cl_object v2uiop_run_program__output_stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1139]);
 {
  cl_object v3uiop_run_program__linewise;
  cl_object v4uiop_run_program__prefix;
  cl_object v5uiop_run_program__element_type;
  cl_object v6uiop_run_program__buffer_size;
  ecl_va_list args; ecl_va_start(args,v2uiop_run_program__output_stream,narg,2);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,LC4600vomit_output_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3uiop_run_program__linewise = keyvars[0];
   v4uiop_run_program__prefix = keyvars[1];
   if (Null(keyvars[6])) {
    v5uiop_run_program__element_type = ECL_SYM("CHARACTER",224);
   } else {
    v5uiop_run_program__element_type = keyvars[2];
   }
   v6uiop_run_program__buffer_size = keyvars[3];
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[888]))->cfun.entry(10, v1uiop_run_program__input_stream, v2uiop_run_program__output_stream, VV[1130], v3uiop_run_program__linewise, VV[100], v4uiop_run_program__prefix, ECL_SYM("ELEMENT-TYPE",1255), v5uiop_run_program__element_type, VV[1131], v6uiop_run_program__buffer_size) /*  COPY-STREAM-TO-STREAM */;
  return value0;
 }
}
/* local function VOMIT-OUTPUT-STREAM                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4601vomit_output_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1139]);
 {
  cl_object v3fresh_line;
  cl_object v4terpri;
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,LC4601vomit_output_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3fresh_line = keyvars[0];
   v4terpri = keyvars[1];
  }
  ecl_princ(v1uiop_run_program__x,v2stream);
  if (Null(v3fresh_line)){
   goto L2;
  }
  cl_fresh_line(1, v2stream);
L2:;
  if (Null(v4terpri)){
   goto L4;
  }
  (ecl_terpri(v2stream));
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
}
/* local function VOMIT-OUTPUT-STREAM                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4602vomit_output_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1139]);
 {
  cl_object v3uiop_run_program__keys;
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3uiop_run_program__keys,TRUE);
  ecl_va_end(args);
  value0 = cl_apply(4, VV[1139], ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-INPUT*",68)), v2stream, v3uiop_run_program__keys);
  return value0;
 }
}
/* local function VOMIT-OUTPUT-STREAM                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4603vomit_output_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1139]);
 {
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  cl_parse_key(args,0,NULL,NULL,NULL,TRUE);
  ecl_va_end(args);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
}
/* local function VOMIT-OUTPUT-STREAM                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4605vomit_output_stream(cl_narg narg, cl_object v1pathname, cl_object v2uiop_run_program__input, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1139]);
 {
  cl_object v3uiop_run_program__external_format;
  cl_object v4uiop_run_program__if_exists;
  cl_object v5uiop_run_program__if_does_not_exist;
  ecl_va_list args; ecl_va_start(args,v2uiop_run_program__input,narg,2);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v2uiop_run_program__input,env0); /*  INPUT               */
  {
   cl_object keyvars[12];
   cl_parse_key(args,6,LC4605vomit_output_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   if (Null(keyvars[6])) {
    CLV1 = env0 = CONS(ecl_cmp_symbol_value(cl_env_copy,VV[804]),env0); /*  ELEMENT-TYPE */
   } else {
    CLV1 = env0 = CONS(keyvars[0],env0);          /*  ELEMENT-TYPE            */
   }
   if (Null(keyvars[7])) {
    v3uiop_run_program__external_format = ecl_cmp_symbol_value(cl_env_copy,VV[815]);
   } else {
    v3uiop_run_program__external_format = keyvars[1];
   }
   if (Null(keyvars[8])) {
    v4uiop_run_program__if_exists = ECL_SYM("RENAME-AND-DELETE",1338);
   } else {
    v4uiop_run_program__if_exists = keyvars[2];
   }
   if (Null(keyvars[9])) {
    v5uiop_run_program__if_does_not_exist = ECL_SYM("CREATE",1244);
   } else {
    v5uiop_run_program__if_does_not_exist = keyvars[3];
   }
   CLV2 = env0 = CONS(keyvars[4],env0);           /*  BUFFER-SIZE             */
   CLV3 = env0 = CONS(keyvars[5],env0);           /*  LINEWISE                */
  }
  {
   cl_object v6;
   v6 = ecl_make_cclosure_va((cl_objectfn)LC4604__lambda3524,env0,Cblock,1);
   T0 = v6;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[838]))->cfun.entry(10, v1pathname, T0, ECL_SYM("ELEMENT-TYPE",1255), ECL_CONS_CAR(CLV1), ECL_SYM("EXTERNAL-FORMAT",1267), v3uiop_run_program__external_format, ECL_SYM("IF-EXISTS",1279), v4uiop_run_program__if_exists, ECL_SYM("IF-DOES-NOT-EXIST",1277), v5uiop_run_program__if_does_not_exist) /*  CALL-WITH-OUTPUT-FILE */;
  return value0;
 }
}
/* local function VOMIT-OUTPUT-STREAM                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4606vomit_output_stream(cl_narg narg, cl_object v1uiop_run_program__x, cl_object v2stream, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1139]);
 {
  cl_object v3uiop_run_program__linewise;
  cl_object v4uiop_run_program__prefix;
  cl_object v5uiop_run_program__element_type;
  cl_object v6uiop_run_program__buffer_size;
  ecl_va_list args; ecl_va_start(args,v2stream,narg,2);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,LC4606vomit_output_streamkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3uiop_run_program__linewise = keyvars[0];
   v4uiop_run_program__prefix = keyvars[1];
   if (Null(keyvars[6])) {
    v5uiop_run_program__element_type = ECL_SYM("CHARACTER",224);
   } else {
    v5uiop_run_program__element_type = keyvars[2];
   }
   v6uiop_run_program__buffer_size = keyvars[3];
  }
  value0 = cl_error(3, VV[1141], VV[1139], v1uiop_run_program__x);
  return value0;
 }
}
/* local function LAMBDA3527                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4608__lambda3527()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC4607__lambda3529_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4608__lambda3527_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1143]);
 {
  return LC4608__lambda3527();
 }
}
/* function definition for %CMD-SHELL-PATHNAME                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4609_cmd_shell_pathname()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(1, VV[1150]);
 return value0;
}
static cl_object L4609_cmd_shell_pathname_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1149]);
 {
  return L4609_cmd_shell_pathname();
 }
}
/* function definition for %NORMALIZE-COMMAND                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4610_normalize_command(cl_object v1uiop_run_program__command)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_STRINGP(v1uiop_run_program__command))){
  goto L2;
 }
 value0 = cl_list(3, VV[1153], VV[1154], v1uiop_run_program__command);
 return value0;
L2:;
 if (!(ECL_LISTP(v1uiop_run_program__command))){
  goto L4;
 }
 value0 = v1uiop_run_program__command;
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 value0 = si_etypecase_error(v1uiop_run_program__command, VV[1117]);
 return value0;
}
static cl_object L4610_normalize_command_va(cl_narg narg, cl_object v2uiop_run_program__command, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1152]);
 {
  return L4610_normalize_command(v2uiop_run_program__command);
 }
}
/* function definition for %ACTIVE-IO-SPECIFIER-P                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4611_active_io_specifier_p(cl_object v1uiop_run_program__specifier)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_make_bool(v1uiop_run_program__specifier==ECL_NIL);
 if (value0!=ECL_NIL) {
  goto L4;
 }
 value0 = ecl_make_bool(ECL_STRINGP(v1uiop_run_program__specifier));
 if (value0!=ECL_NIL) {
  goto L4;
 }
 value0 = cl_pathnamep(v1uiop_run_program__specifier);
 if (value0!=ECL_NIL) {
  goto L4;
 }
 if (!((v1uiop_run_program__specifier)==(ECL_SYM("INTERACTIVE",1290)))){
  goto L12;
 }
 value0 = VV[1157];
 goto L10;
L12:;
 value0 = ECL_NIL;
 goto L10;
L10:;
 if (value0!=ECL_NIL) {
  goto L9;
 }
 if (!((v1uiop_run_program__specifier)==(ECL_SYM("OUTPUT",1319)))){
  goto L15;
 }
 T0 = VV[1158];
 goto L2;
L15:;
 T0 = ECL_NIL;
 goto L2;
L9:;
 T0 = value0;
 goto L2;
L4:;
 T0 = value0;
 goto L2;
L2:;
 value0 = Null(T0)?ECL_T:ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4611_active_io_specifier_p_va(cl_narg narg, cl_object v2uiop_run_program__specifier, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1156]);
 {
  return L4611_active_io_specifier_p(v2uiop_run_program__specifier);
 }
}
/* function definition for %NORMALIZE-IO-SPECIFIER                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4612_normalize_io_specifier(cl_narg narg, cl_object v1uiop_run_program__specifier, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1160]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1160]);
 {
  cl_object v2uiop_run_program__role;
  va_list args; va_start(args,v1uiop_run_program__specifier);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_run_program__role = ECL_NIL;
   } else {
    i++;
    v2uiop_run_program__role = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (!(v1uiop_run_program__specifier==ECL_NIL)){
   goto L2;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  if (!(ECL_STRINGP(v1uiop_run_program__specifier))){
   goto L4;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[658]))->cfun.entry(1, v1uiop_run_program__specifier) /*  PARSE-NATIVE-NAMESTRING */;
  return value0;
L4:;
  if (Null(cl_pathnamep(v1uiop_run_program__specifier))){
   goto L6;
  }
  value0 = v1uiop_run_program__specifier;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  if (Null(cl_streamp(v1uiop_run_program__specifier))){
   goto L8;
  }
  value0 = v1uiop_run_program__specifier;
  cl_env_copy->nvalues = 1;
  return value0;
L8:;
  if (Null(cl_typep(2, v1uiop_run_program__specifier, VV[1161]))){
   goto L10;
  }
  value0 = ECL_SYM("STREAM",1350);
  cl_env_copy->nvalues = 1;
  return value0;
L10:;
  if (Null(cl_typep(2, v1uiop_run_program__specifier, VV[1162]))){
   goto L12;
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L12:;
  if (Null(cl_typep(2, v1uiop_run_program__specifier, VV[1163]))){
   goto L14;
  }
  if (!((v2uiop_run_program__role)==(VV[1164]))){
   goto L16;
  }
  value0 = ECL_SYM("OUTPUT",1319);
  cl_env_copy->nvalues = 1;
  return value0;
L16:;
  value0 = cl_error(3, VV[1165], v1uiop_run_program__specifier, v2uiop_run_program__role);
  return value0;
L14:;
  value0 = si_etypecase_error(v1uiop_run_program__specifier, VV[1166]);
  return value0;
 }
}
/* function definition for %NORMALIZE-IF-EXISTS                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4613_normalize_if_exists(cl_object v1uiop_run_program__action)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v1uiop_run_program__action)==(ECL_SYM("SUPERSEDE",1351)))){
  goto L2;
 }
 value0 = v1uiop_run_program__action;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!((v1uiop_run_program__action)==(ECL_SYM("APPEND",1228)))){
  goto L9;
 }
 goto L6;
L9:;
 goto L7;
L7:;
 if (!((v1uiop_run_program__action)==(ECL_SYM("ERROR",1260)))){
  goto L4;
 }
 goto L5;
L6:;
L5:;
 value0 = v1uiop_run_program__action;
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 value0 = si_ecase_error(v1uiop_run_program__action, VV[1171]);
 return value0;
}
static cl_object L4613_normalize_if_exists_va(cl_narg narg, cl_object v2uiop_run_program__action, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1168]);
 {
  return L4613_normalize_if_exists(v2uiop_run_program__action);
 }
}
/* function definition for %INTERACTIVEP                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4614_interactivep(cl_object v1uiop_run_program__input, cl_object v2uiop_run_program__output, cl_object v3uiop_run_program__error_output)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;
  cl_object v5;
  cl_object v6;
  v4 = cl_list(3, v1uiop_run_program__input, v2uiop_run_program__output, v3uiop_run_program__error_output);
  v5 = ECL_SYM("INTERACTIVE",1290);
  v6 = v4;
  value0 = ecl_memql(v5,v6);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4614_interactivep_va(cl_narg narg, cl_object v7uiop_run_program__input, cl_object v8uiop_run_program__output, cl_object v9uiop_run_program__error_output, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[1173]);
 {
  return L4614_interactivep(v7uiop_run_program__input, v8uiop_run_program__output, v9uiop_run_program__error_output);
 }
}
/* function definition for %SIGNAL-TO-EXIT-CODE                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4615_signal_to_exit_code(cl_object v1signum)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_plus(ecl_make_uint8_t(128),v1signum);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4615_signal_to_exit_code_va(cl_narg narg, cl_object v2signum, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1175]);
 {
  return L4615_signal_to_exit_code(v2signum);
 }
}
/* function definition for %RUN-PROGRAM                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4620_run_program(cl_narg narg, cl_object v1uiop_run_program__command, ...)
{
 cl_object T0, T1;
 volatile cl_object lex0[1];
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1178]);
 {
  cl_object v2uiop_run_program__keys;
  cl_object v3uiop_run_program__input;
  cl_object v4uiop_run_program__output;
  cl_object v5uiop_run_program__if_output_exists;
  cl_object v6uiop_run_program__error_output;
  cl_object v7directory;
  ecl_va_list args; ecl_va_start(args,v1uiop_run_program__command,narg,1);
  {
   cl_object keyvars[16];
   cl_parse_key(args,8,L4620_run_programkeys,keyvars,(cl_object*)&v2uiop_run_program__keys,TRUE);
   env0 = ECL_NIL;
   CLV0 = env0 = CONS(v2uiop_run_program__keys,env0); /*  KEYS                */
   ecl_va_end(args);
   v3uiop_run_program__input = keyvars[0];
   if (Null(keyvars[9])) {
    CLV1 = env0 = CONS(ECL_SYM("ERROR",1260),env0); /*  IF-INPUT-DOES-NOT-EXIST */
   } else {
    CLV1 = env0 = CONS(keyvars[1],env0);          /*  IF-INPUT-DOES-NOT-EXIST */
   }
   v4uiop_run_program__output = keyvars[2];
   if (Null(keyvars[11])) {
    v5uiop_run_program__if_output_exists = ECL_SYM("SUPERSEDE",1351);
   } else {
    v5uiop_run_program__if_output_exists = keyvars[3];
   }
   v6uiop_run_program__error_output = keyvars[4];
   if (Null(keyvars[13])) {
    CLV2 = env0 = CONS(ECL_SYM("SUPERSEDE",1351),env0); /*  IF-ERROR-OUTPUT-EXISTS */
   } else {
    CLV2 = env0 = CONS(keyvars[5],env0);          /*  IF-ERROR-OUTPUT-EXISTS  */
   }
   v7directory = keyvars[6];
   CLV3 = env0 = CONS(keyvars[7],env0);           /*  WAIT                    */
  }
  {
   cl_object v8;
   v8 = ecl_make_cfun_va((cl_objectfn)LC4616__lambda3596_va,ECL_NIL,Cblock,1);
   T0 = v8;
  }
  T1 = cl_list(3, v3uiop_run_program__input, v4uiop_run_program__output, v6uiop_run_program__error_output);
  if (Null(cl_some(2, T0, T1))){
   goto L2;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[416]))->cfun.entry(2, VV[1180], VV[1178]) /*  PARAMETER-ERROR */;
L2:;
  {
   cl_object v8uiop_run_program__process_;
   cl_object env1 = env0;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1152]))->cfun.entry(1, v1uiop_run_program__command) /*  %NORMALIZE-COMMAND */;
   CLV4 = env1 = CONS(T0,env1);                   /*  %COMMAND                */
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1168]))->cfun.entry(1, v5uiop_run_program__if_output_exists) /*  %NORMALIZE-IF-EXISTS */;
   CLV5 = env1 = CONS(T0,env1);                   /*  %IF-OUTPUT-EXISTS       */
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1160]))->cfun.entry(2, v3uiop_run_program__input, ECL_SYM("INPUT",1289)) /*  %NORMALIZE-IO-SPECIFIER */;
   CLV6 = env1 = CONS(T0,env1);                   /*  %INPUT                  */
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1160]))->cfun.entry(2, v4uiop_run_program__output, ECL_SYM("OUTPUT",1319)) /*  %NORMALIZE-IO-SPECIFIER */;
   CLV7 = env1 = CONS(T0,env1);                   /*  %OUTPUT                 */
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1160]))->cfun.entry(2, v6uiop_run_program__error_output, VV[1164]) /*  %NORMALIZE-IO-SPECIFIER */;
   CLV8 = env1 = CONS(T0,env1);                   /*  %ERROR-OUTPUT           */
   {
    cl_object v9;
    v9 = ecl_make_cclosure_va((cl_objectfn)LC4617__lambda3598,env1,Cblock,0);
    T0 = v9;
   }
   v8uiop_run_program__process_ = (cl_env_copy->function=ecl_fdefinition(VV[756]))->cfun.entry(2, v7directory, T0) /*  CALL-WITH-CURRENT-DIRECTORY */;
   T0 = (cl_env_copy->function=(ECL_SYM("MAKE-INSTANCE",953)->symbol.gfdef))->cfun.entry(1, VV[1177]) /*  MAKE-INSTANCE */;
   lex0[0] = T0;                                  /*  PROCESS-INFO            */
   {
    cl_object v9;
    cl_object v10stream;
    cl_object v11uiop_run_program__code;
    cl_object v12uiop_run_program__process;
    v9 = v8uiop_run_program__process_;
    if (!(v9==ECL_NIL)){
     goto L10;
    }
    si_dm_too_few_arguments(v8uiop_run_program__process_);
L10:;
    {
     cl_object v13;
     v13 = ecl_car(v9);
     v9 = ecl_cdr(v9);
     v10stream = v13;
    }
    if (!(v9==ECL_NIL)){
     goto L16;
    }
    si_dm_too_few_arguments(v8uiop_run_program__process_);
L16:;
    {
     cl_object v13;
     v13 = ecl_car(v9);
     v9 = ecl_cdr(v9);
     v11uiop_run_program__code = v13;
    }
    if (!(v9==ECL_NIL)){
     goto L22;
    }
    si_dm_too_few_arguments(v8uiop_run_program__process_);
L22:;
    {
     cl_object v13;
     v13 = ecl_car(v9);
     v9 = ecl_cdr(v9);
     v12uiop_run_program__process = v13;
    }
    if (Null(v9)){
     goto L27;
    }
    si_dm_too_many_arguments(v8uiop_run_program__process_);
L27:;
    {
     cl_object v13uiop_run_program__mode;
     if (!((v3uiop_run_program__input)==(ECL_SYM("STREAM",1350)))){
      goto L32;
     }
     T0 = ecl_make_int8_t(1);
     goto L31;
L32:;
     T0 = ecl_make_int8_t(0);
L31:;
     if (!((v4uiop_run_program__output)==(ECL_SYM("STREAM",1350)))){
      goto L35;
     }
     T1 = ecl_make_int8_t(2);
     goto L34;
L35:;
     T1 = ecl_make_int8_t(0);
L34:;
     v13uiop_run_program__mode = ecl_plus(T0,T1);
     {
      cl_object v14;
      v14 = ecl_make_bool(ecl_zerop(v13uiop_run_program__mode));
      if (Null(v14)){
       goto L38;
      }
      goto L29;
L38:;
      if (!(v8uiop_run_program__process_==ECL_NIL)){
       goto L40;
      }
      LC4619store_codes(1, lex0, ecl_make_int8_t(-1));
      goto L29;
L40:;
      if (!((v13uiop_run_program__mode)==(ecl_make_int8_t(1)))){
       goto L43;
      }
      T0 = VV[1188];
      goto L42;
L43:;
      if (!((v13uiop_run_program__mode)==(ecl_make_int8_t(2)))){
       goto L45;
      }
      T0 = VV[1189];
      goto L42;
L45:;
      if (!((v13uiop_run_program__mode)==(ecl_make_int8_t(3)))){
       goto L47;
      }
      T0 = VV[1190];
      goto L42;
L47:;
      T0 = ECL_NIL;
L42:;
      LC4618prop(lex0, T0, v10stream);
     }
    }
L29:;
    if (Null(v11uiop_run_program__code)){
     goto L49;
    }
    {
     cl_object v13signum;
     T0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("EXTERNAL-PROCESS-WAIT",1850)))->cfun.entry(1, v12uiop_run_program__process) /*  EXTERNAL-PROCESS-WAIT */;
     if (!((T0)==(ECL_SYM("SIGNALED",1854)))){
      goto L53;
     }
     v13signum = v11uiop_run_program__code;
     goto L51;
L53:;
     v13signum = ECL_NIL;
     goto L51;
L51:;
     LC4619store_codes(2, lex0, v11uiop_run_program__code, v13signum);
    }
L49:;
    if (Null(v12uiop_run_program__process)){
     goto L7;
    }
    LC4618prop(lex0, VV[1191], v12uiop_run_program__process);
   }
L7:;
   value0 = lex0[0];
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for PROCESS-INFO-ERROR-OUTPUT                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4621process_info_error_output(cl_object v1uiop_run_program__process_info)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_slot_value(v1uiop_run_program__process_info, VV[1194]);
 return value0;
}
static cl_object L4621process_info_error_output_va(cl_narg narg, cl_object v2uiop_run_program__process_info, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1193]);
 {
  return L4621process_info_error_output(v2uiop_run_program__process_info);
 }
}
/* function definition for PROCESS-INFO-INPUT                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4622process_info_input(cl_object v1uiop_run_program__process_info)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_slot_value(v1uiop_run_program__process_info, VV[1190]);
 if (value0!=ECL_NIL) {
  goto L3;
 }
 value0 = cl_slot_value(v1uiop_run_program__process_info, VV[1188]);
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4622process_info_input_va(cl_narg narg, cl_object v2uiop_run_program__process_info, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1196]);
 {
  return L4622process_info_input(v2uiop_run_program__process_info);
 }
}
/* function definition for PROCESS-INFO-OUTPUT                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4623process_info_output(cl_object v1uiop_run_program__process_info)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_slot_value(v1uiop_run_program__process_info, VV[1190]);
 if (value0!=ECL_NIL) {
  goto L3;
 }
 value0 = cl_slot_value(v1uiop_run_program__process_info, VV[1189]);
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4623process_info_output_va(cl_narg narg, cl_object v2uiop_run_program__process_info, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1198]);
 {
  return L4623process_info_output(v2uiop_run_program__process_info);
 }
}
/* function definition for PROCESS-INFO-PID                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4624process_info_pid(cl_object v1uiop_run_program__process_info)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_run_program__process;
  v2uiop_run_program__process = cl_slot_value(v1uiop_run_program__process_info, VV[1191]);
  value0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("EXTERNAL-PROCESS-PID",1845)))->cfun.entry(1, v2uiop_run_program__process) /*  EXTERNAL-PROCESS-PID */;
  return value0;
 }
}
static cl_object L4624process_info_pid_va(cl_narg narg, cl_object v3uiop_run_program__process_info, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1200]);
 {
  return L4624process_info_pid(v3uiop_run_program__process_info);
 }
}
/* function definition for %PROCESS-STATUS                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4625_process_status(cl_object v1uiop_run_program__process_info)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_run_program__exit_code;
  v2uiop_run_program__exit_code = cl_slot_value(v1uiop_run_program__process_info, VV[1186]);
  if (Null(v2uiop_run_program__exit_code)){
   goto L2;
  }
  {
   cl_object v3uiop_run_program__signal_code;
   v3uiop_run_program__signal_code = cl_slot_value(v1uiop_run_program__process_info, VV[1187]);
   if (Null(v3uiop_run_program__signal_code)){
    goto L6;
   }
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = v3uiop_run_program__signal_code;
   cl_env_copy->values[0] = ECL_SYM("SIGNALED",1854);
   return cl_env_copy->values[0];
L6:;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = v2uiop_run_program__exit_code;
   cl_env_copy->values[0] = ECL_SYM("EXITED",1853);
   return cl_env_copy->values[0];
  }
 }
L2:;
 {
  cl_object v2uiop_run_program__process;
  v2uiop_run_program__process = cl_slot_value(v1uiop_run_program__process_info, VV[1191]);
  if (Null(v2uiop_run_program__process)){
   goto L9;
  }
  {
   cl_object v3;                                  /*  STATUS                  */
   cl_object v4;                                  /*  CODE                    */
   value0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("EXTERNAL-PROCESS-STATUS",1849)))->cfun.entry(1, v2uiop_run_program__process) /*  EXTERNAL-PROCESS-STATUS */;
   {
    const int v5 = cl_env_copy->nvalues;
    v3 = value0;
    cl_object v6;
    v6 = (v5<=1)? ECL_NIL : cl_env_copy->values[1];
    v4 = v6;
   }
   if (!((v3)==(ECL_SYM("EXITED",1853)))){
    goto L13;
   }
   (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v4, v1uiop_run_program__process_info, VV[1186]) /*  (SETF SLOT-VALUE) */;
   goto L12;
L13:;
   if (!((v3)==(ECL_SYM("SIGNALED",1854)))){
    goto L12;
   }
   {
    cl_object v5uiop_run_program___code;
    v5uiop_run_program___code = (cl_env_copy->function=ecl_fdefinition(VV[1175]))->cfun.entry(1, v4) /*  %SIGNAL-TO-EXIT-CODE */;
    (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v5uiop_run_program___code, v1uiop_run_program__process_info, VV[1186]) /*  (SETF SLOT-VALUE) */;
    (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v4, v1uiop_run_program__process_info, VV[1187]) /*  (SETF SLOT-VALUE) */;
   }
L12:;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = v4;
   cl_env_copy->values[0] = v3;
   return cl_env_copy->values[0];
  }
L9:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4625_process_status_va(cl_narg narg, cl_object v3uiop_run_program__process_info, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1202]);
 {
  return L4625_process_status(v3uiop_run_program__process_info);
 }
}
/* function definition for PROCESS-ALIVE-P                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4626process_alive_p(cl_object v1uiop_run_program__process_info)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (cl_slot_value(v1uiop_run_program__process_info, VV[1186])!=ECL_NIL) {
  goto L2;
 }
 {
  cl_object v2;
  v2 = (cl_env_copy->function=ecl_fdefinition(VV[1202]))->cfun.entry(1, v1uiop_run_program__process_info) /*  %PROCESS-STATUS */;
  if (!((v2)==(ECL_SYM("RUNNING",1852)))){
   goto L9;
  }
  value0 = VV[1205];
  goto L7;
L9:;
  value0 = ECL_NIL;
  goto L7;
L7:;
  if (value0!=ECL_NIL) {
   goto L6;
  }
  if (!((v2)==(VV[1206]))){
   goto L12;
  }
  value0 = VV[1207];
  cl_env_copy->nvalues = 1;
  return value0;
L12:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4626process_alive_p_va(cl_narg narg, cl_object v3uiop_run_program__process_info, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1204]);
 {
  return L4626process_alive_p(v3uiop_run_program__process_info);
 }
}
/* function definition for WAIT-PROCESS                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4627wait_process(cl_object v1uiop_run_program__process_info)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_run_program__exit_code;
  v2uiop_run_program__exit_code = cl_slot_value(v1uiop_run_program__process_info, VV[1186]);
  if (Null(v2uiop_run_program__exit_code)){
   goto L3;
  }
  {
   cl_object v3uiop_run_program__signal_code;
   v3uiop_run_program__signal_code = cl_slot_value(v1uiop_run_program__process_info, VV[1187]);
   if (Null(v3uiop_run_program__signal_code)){
    goto L6;
   }
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = v3uiop_run_program__signal_code;
   cl_env_copy->values[0] = v2uiop_run_program__exit_code;
   return cl_env_copy->values[0];
L6:;
   value0 = v2uiop_run_program__exit_code;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L3:;
  {
   cl_object v4uiop_run_program__process;
   v4uiop_run_program__process = cl_slot_value(v1uiop_run_program__process_info, VV[1191]);
   if (Null(v4uiop_run_program__process)){
    goto L9;
   }
   {
    cl_object v5;                                 /*  EXIT-CODE               */
    cl_object v6;                                 /*  SIGNAL-CODE             */
    {
     cl_object v7;                                /*  STATUS                  */
     cl_object v8;                                /*  CODE                    */
     value0 = (cl_env_copy->function=ecl_fdefinition(ECL_SYM("EXTERNAL-PROCESS-WAIT",1850)))->cfun.entry(2, v4uiop_run_program__process, ECL_T) /*  EXTERNAL-PROCESS-WAIT */;
     {
      const int v9 = cl_env_copy->nvalues;
      v7 = value0;
      cl_object v10;
      v10 = (v9<=1)? ECL_NIL : cl_env_copy->values[1];
      v8 = v10;
     }
     if (!((v7)==(ECL_SYM("SIGNALED",1854)))){
      goto L13;
     }
     cl_env_copy->nvalues = 2;
     cl_env_copy->values[1] = v8;
     cl_env_copy->values[0] = ECL_NIL;
     value0 = cl_env_copy->values[0];
     goto L11;
L13:;
     value0 = v8;
     cl_env_copy->nvalues = 1;
    }
L11:;
    {
     const int v7 = cl_env_copy->nvalues;
     v5 = value0;
     cl_object v8;
     v8 = (v7<=1)? ECL_NIL : cl_env_copy->values[1];
     v6 = v8;
    }
    if (Null(v6)){
     goto L15;
    }
    {
     cl_object v7uiop_run_program___exit_code;
     v7uiop_run_program___exit_code = (cl_env_copy->function=ecl_fdefinition(VV[1175]))->cfun.entry(1, v6) /*  %SIGNAL-TO-EXIT-CODE */;
     (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v7uiop_run_program___exit_code, v1uiop_run_program__process_info, VV[1186]) /*  (SETF SLOT-VALUE) */;
     (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v6, v1uiop_run_program__process_info, VV[1187]) /*  (SETF SLOT-VALUE) */;
     cl_env_copy->nvalues = 2;
     cl_env_copy->values[1] = v6;
     cl_env_copy->values[0] = v7uiop_run_program___exit_code;
     return cl_env_copy->values[0];
    }
L15:;
    (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v5, v1uiop_run_program__process_info, VV[1186]) /*  (SETF SLOT-VALUE) */;
    value0 = v5;
    cl_env_copy->nvalues = 1;
    return value0;
   }
L9:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4627wait_process_va(cl_narg narg, cl_object v5uiop_run_program__process_info, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1209]);
 {
  return L4627wait_process(v5uiop_run_program__process_info);
 }
}
/* function definition for %CHECK-RESULT                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4628_check_result(cl_narg narg, cl_object v1uiop_run_program__exit_code, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1211]);
 {
  cl_object v2uiop_run_program__command;
  cl_object v3uiop_run_program__process;
  cl_object v4uiop_run_program__ignore_error_status;
  ecl_va_list args; ecl_va_start(args,v1uiop_run_program__exit_code,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L4628_check_resultkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2uiop_run_program__command = keyvars[0];
   v3uiop_run_program__process = keyvars[1];
   v4uiop_run_program__ignore_error_status = keyvars[2];
  }
  if (v4uiop_run_program__ignore_error_status!=ECL_NIL) {
   goto L1;
  }
  if ((v1uiop_run_program__exit_code)==(ecl_make_int8_t(0))) {
   goto L1;
  }
  cl_cerror(8, VV[1212], VV[1142], VV[1213], v2uiop_run_program__command, ECL_SYM("CODE",1914), v1uiop_run_program__exit_code, ECL_SYM("PROCESS",1331), v3uiop_run_program__process);
L1:;
  value0 = v1uiop_run_program__exit_code;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for CLOSE-STREAMS                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4629close_streams(cl_object v1uiop_run_program__process_info)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  T0 = cl_slot_value(v1uiop_run_program__process_info, VV[1194]);
  {
   cl_object v3uiop_run_program__bidir_stream;
   v3uiop_run_program__bidir_stream = cl_slot_value(v1uiop_run_program__process_info, VV[1190]);
   if (Null(v3uiop_run_program__bidir_stream)){
    goto L5;
   }
   T1 = ecl_list1(v3uiop_run_program__bidir_stream);
   goto L3;
L5:;
   T2 = cl_slot_value(v1uiop_run_program__process_info, VV[1188]);
   T3 = cl_slot_value(v1uiop_run_program__process_info, VV[1189]);
   T1 = cl_list(2, T2, T3);
  }
L3:;
  v2 = CONS(T0,T1);
  goto L9;
L8:;
  {
   cl_object v3stream;
   v3stream = ecl_car(v2);
   if (Null(v3stream)){
    goto L13;
   }
   cl_close(1, v3stream);
L13:;
  }
  v2 = ecl_cdr(v2);
L9:;
  if (Null(v2)){
   goto L17;
  }
  goto L8;
L17:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4629close_streams_va(cl_narg narg, cl_object v3uiop_run_program__process_info, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1215]);
 {
  return L4629close_streams(v3uiop_run_program__process_info);
 }
}
/* function definition for %POSIX-SEND-SIGNAL                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4630_posix_send_signal(cl_object v1uiop_run_program__process_info, cl_object v2signal)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3uiop_run_program__pid;
  v3uiop_run_program__pid = (cl_env_copy->function=ecl_fdefinition(VV[1200]))->cfun.entry(1, v1uiop_run_program__process_info) /*  PROCESS-INFO-PID */;
  if (Null(v3uiop_run_program__pid)){
   goto L3;
  }
  T0 = cl_format(4, ECL_NIL, VV[1218], v2signal, v3uiop_run_program__pid);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1178]))->cfun.entry(3, T0, ECL_SYM("WAIT",1367), ECL_T) /*  %RUN-PROGRAM */;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4630_posix_send_signal_va(cl_narg narg, cl_object v4uiop_run_program__process_info, cl_object v5signal, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1217]);
 {
  return L4630_posix_send_signal(v4uiop_run_program__process_info, v5signal);
 }
}
/* function definition for TERMINATE-PROCESS                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4631terminate_process(cl_narg narg, cl_object v1uiop_run_program__process_info, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1220]);
 {
  cl_object v2uiop_run_program__urgent;
  ecl_va_list args; ecl_va_start(args,v1uiop_run_program__process_info,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4631terminate_processkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2uiop_run_program__urgent = keyvars[0];
  }
  T0 = cl_slot_value(v1uiop_run_program__process_info, VV[1191]);
  value0 = L4199symbol_call(4, VV[1221], VV[1222], T0, v2uiop_run_program__urgent);
  return value0;
 }
}
/* function definition for %CALL-WITH-PROGRAM-IO                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4638_call_with_program_io(cl_narg narg, cl_object v1uiop_run_program__gf, cl_object v2uiop_run_program__tval, cl_object v3uiop_run_program__stream_easy_p, cl_object v4uiop_run_program__fun, cl_object v5uiop_run_program__direction, cl_object v6uiop_run_program__spec, cl_object v7uiop_run_program__activep, cl_object v8uiop_run_program__returner, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<8)) FEwrong_num_arguments(VV[1224]);
 {
  ecl_va_list args; ecl_va_start(args,v8uiop_run_program__returner,narg,8);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1uiop_run_program__gf,env0); /*  GF                     */
  CLV1 = env0 = CONS(v4uiop_run_program__fun,env0); /*  FUN                   */
  CLV2 = env0 = CONS(v5uiop_run_program__direction,env0); /*  DIRECTION       */
  CLV3 = env0 = CONS(v7uiop_run_program__activep,env0); /*  ACTIVEP           */
  CLV4 = env0 = CONS(v8uiop_run_program__returner,env0); /*  RETURNER         */
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4638_call_with_program_iokeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   CLV5 = env0 = CONS(keyvars[0],env0);           /*  ELEMENT-TYPE            */
   CLV6 = env0 = CONS(keyvars[1],env0);           /*  EXTERNAL-FORMAT         */
  }
  {
   cl_object env1 = env0;
   if (!((v6uiop_run_program__spec)==(ECL_T))){
    goto L2;
   }
   T0 = v2uiop_run_program__tval;
   goto L1;
L2:;
   T0 = v6uiop_run_program__spec;
L1:;
   CLV7 = env1 = CONS(T0,env1);                   /*  ACTUAL-SPEC             */
   if (!((ECL_CONS_CAR(CLV7))==(ECL_SYM("OUTPUT",1319)))){
    goto L5;
   }
   if (!((ECL_CONS_CAR(CLV2))==(ECL_SYM("INPUT",1289)))){
    goto L12;
   }
   goto L9;
L12:;
   goto L10;
L10:;
   if (!((ECL_CONS_CAR(CLV2))==(ECL_SYM("OUTPUT",1319)))){
    goto L7;
   }
   goto L8;
L9:;
L8:;
   T0 = cl_error(4, VV[1226], ECL_SYM("OUTPUT",1319), VV[1227], ECL_CONS_CAR(CLV2));
   goto L4;
L7:;
   if (!((ECL_CONS_CAR(CLV2))==(VV[1164]))){
    goto L15;
   }
   T0 = ECL_NIL;
   goto L4;
L15:;
   T0 = si_ecase_error(ECL_CONS_CAR(CLV2), VV[1229]);
   goto L4;
L5:;
   T0 = ECL_CONS_CAR(CLV7);
L4:;
   CLV8 = env1 = CONS(T0,env1);                   /*  ACTIVITY-SPEC           */
   CLV9 = env1 = CONS(ECL_NIL,env1);
   ECL_CONS_CAR(CLV9) = ecl_make_cclosure_va((cl_objectfn)LC4632activity,env1,Cblock,1);
   if (ECL_CONS_CAR(CLV8)==ECL_NIL) {
    goto L20;
   }
   if (ECL_STRINGP(ECL_CONS_CAR(CLV8))) {
    goto L20;
   }
   if (cl_pathnamep(ECL_CONS_CAR(CLV8))!=ECL_NIL) {
    goto L20;
   }
   if (Null(cl_typep(2, ECL_CONS_CAR(CLV8), VV[1162]))){
    goto L18;
   }
   goto L19;
L20:;
L19:;
   value0 = (aux_closure.env=env1,cl_env_copy->function=(cl_object)&aux_closure,LC4633easy_case(0));
   return value0;
L18:;
   value0 = (aux_closure.env=env1,cl_env_copy->function=(cl_object)&aux_closure,LC4637hard_case(0));
   return value0;
  }
 }
}
/* local function PLACE-SETTER                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4639place_setter(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4uiop_run_program__place;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4uiop_run_program__place = v5;
  }
  if (Null(v3)){
   goto L9;
  }
  si_dm_too_many_arguments(v1);
L9:;
  if (Null(v4uiop_run_program__place)){
   goto L11;
  }
  {
   cl_object v5uiop_run_program__value;
   v5uiop_run_program__value = cl_gensym(0);
   T0 = ecl_list1(v5uiop_run_program__value);
   T1 = cl_list(3, ECL_SYM("SETF",753), v4uiop_run_program__place, v5uiop_run_program__value);
   T2 = cl_list(3, ECL_SYM("LAMBDA",454), T0, T1);
   value0 = cl_list(2, ECL_SYM("FUNCTION",398), T2);
   return value0;
  }
L11:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4639place_setter_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1239]);
 {
  return LC4639place_setter(v6, v7);
 }
}
/* local function WITH-PROGRAM-INPUT                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4640with_program_input(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  cl_object v8uiop_run_program__reduced_input_var;
  cl_object v9uiop_run_program__input_activity_var;
  cl_object v10uiop_run_program__iavp;
  cl_object v11uiop_run_program__input_form;
  cl_object v12;
  cl_object v13setf;
  cl_object v14;
  cl_object v15uiop_run_program__stream_easy_p;
  cl_object v16;
  cl_object v17uiop_run_program__active;
  cl_object v18;
  cl_object v19uiop_run_program__keys;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v20;
   v20 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v20;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v20;
   v20 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6 = v20;
  }
  v7 = v6;
  if (!(v7==ECL_NIL)){
   goto L18;
  }
  si_dm_too_few_arguments(v1);
L18:;
  {
   cl_object v20;
   v20 = ecl_car(v7);
   v7 = ecl_cdr(v7);
   v8uiop_run_program__reduced_input_var = v20;
  }
  if (Null(v7)){
   goto L24;
  }
  v9uiop_run_program__input_activity_var = ecl_car(v7);
  goto L23;
L24:;
  v9uiop_run_program__input_activity_var = cl_gensym(0);
L23:;
  if (Null(v7)){
   goto L28;
  }
  v7 = ecl_cdr(v7);
  v10uiop_run_program__iavp = ECL_T;
  goto L26;
L28:;
  v10uiop_run_program__iavp = ECL_NIL;
  goto L26;
L26:;
  if (!(v5==ECL_NIL)){
   goto L33;
  }
  si_dm_too_few_arguments(v1);
L33:;
  {
   cl_object v20;
   v20 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v11uiop_run_program__input_form = v20;
  }
  v12 = si_search_keyword(v5, VV[1241]);
  if (!((v12)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L40;
  }
  v13setf = ECL_NIL;
  goto L39;
L40:;
  v13setf = v12;
L39:;
  v14 = si_search_keyword(v5, VV[1242]);
  if (!((v14)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L44;
  }
  v15uiop_run_program__stream_easy_p = ECL_NIL;
  goto L43;
L44:;
  v15uiop_run_program__stream_easy_p = v14;
L43:;
  v16 = si_search_keyword(v5, VV[1243]);
  if (!((v16)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L48;
  }
  v17uiop_run_program__active = ECL_NIL;
  goto L47;
L48:;
  v17uiop_run_program__active = v16;
L47:;
  v18 = si_search_keyword(v5, VV[1244]);
  if (!((v18)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L52;
  }
  v19uiop_run_program__keys = ECL_NIL;
  goto L51;
L52:;
  v19uiop_run_program__keys = v18;
L51:;
  si_check_keyword(2, v5, VV[1246]);
  if (Null(v7)){
   goto L55;
  }
  si_dm_too_many_arguments(v1);
L55:;
  T0 = cl_list(2, v8uiop_run_program__reduced_input_var, v9uiop_run_program__input_activity_var);
  if (v10uiop_run_program__iavp!=ECL_NIL) {
   goto L58;
  }
  T2 = cl_list(2, ECL_SYM("IGNORE",430), v9uiop_run_program__input_activity_var);
  T3 = cl_list(2, ECL_SYM("DECLARE",276), T2);
  T1 = ecl_list1(T3);
  goto L57;
L58:;
  T1 = ECL_NIL;
L57:;
  T2 = ecl_append(T1,v3);
  T3 = cl_listX(3, ECL_SYM("LAMBDA",454), T0, T2);
  T4 = cl_list(2, ECL_SYM("FUNCTION",398), T3);
  T5 = cl_list(2, VV[1239], v13setf);
  value0 = cl_list(11, ECL_SYM("APPLY",91), VV[1247], VV[1248], ECL_SYM("*STANDARD-INPUT*",68), v15uiop_run_program__stream_easy_p, T4, ECL_SYM("INPUT",1289), v11uiop_run_program__input_form, v17uiop_run_program__active, T5, v19uiop_run_program__keys);
  return value0;
 }
}
static cl_object LC4640with_program_input_va(cl_narg narg, cl_object v20, cl_object v21, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1245]);
 {
  return LC4640with_program_input(v20, v21);
 }
}
/* local function WITH-PROGRAM-OUTPUT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4641with_program_output(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  cl_object v8uiop_run_program__reduced_output_var;
  cl_object v9uiop_run_program__output_activity_var;
  cl_object v10uiop_run_program__oavp;
  cl_object v11uiop_run_program__output_form;
  cl_object v12;
  cl_object v13setf;
  cl_object v14;
  cl_object v15uiop_run_program__stream_easy_p;
  cl_object v16;
  cl_object v17uiop_run_program__active;
  cl_object v18;
  cl_object v19uiop_run_program__keys;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v20;
   v20 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v20;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v20;
   v20 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6 = v20;
  }
  v7 = v6;
  if (!(v7==ECL_NIL)){
   goto L18;
  }
  si_dm_too_few_arguments(v1);
L18:;
  {
   cl_object v20;
   v20 = ecl_car(v7);
   v7 = ecl_cdr(v7);
   v8uiop_run_program__reduced_output_var = v20;
  }
  if (Null(v7)){
   goto L24;
  }
  v9uiop_run_program__output_activity_var = ecl_car(v7);
  goto L23;
L24:;
  v9uiop_run_program__output_activity_var = cl_gensym(0);
L23:;
  if (Null(v7)){
   goto L28;
  }
  v7 = ecl_cdr(v7);
  v10uiop_run_program__oavp = ECL_T;
  goto L26;
L28:;
  v10uiop_run_program__oavp = ECL_NIL;
  goto L26;
L26:;
  if (!(v5==ECL_NIL)){
   goto L33;
  }
  si_dm_too_few_arguments(v1);
L33:;
  {
   cl_object v20;
   v20 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v11uiop_run_program__output_form = v20;
  }
  v12 = si_search_keyword(v5, VV[1241]);
  if (!((v12)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L40;
  }
  v13setf = ECL_NIL;
  goto L39;
L40:;
  v13setf = v12;
L39:;
  v14 = si_search_keyword(v5, VV[1242]);
  if (!((v14)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L44;
  }
  v15uiop_run_program__stream_easy_p = ECL_NIL;
  goto L43;
L44:;
  v15uiop_run_program__stream_easy_p = v14;
L43:;
  v16 = si_search_keyword(v5, VV[1243]);
  if (!((v16)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L48;
  }
  v17uiop_run_program__active = ECL_NIL;
  goto L47;
L48:;
  v17uiop_run_program__active = v16;
L47:;
  v18 = si_search_keyword(v5, VV[1244]);
  if (!((v18)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L52;
  }
  v19uiop_run_program__keys = ECL_NIL;
  goto L51;
L52:;
  v19uiop_run_program__keys = v18;
L51:;
  si_check_keyword(2, v5, VV[1246]);
  if (Null(v7)){
   goto L55;
  }
  si_dm_too_many_arguments(v1);
L55:;
  T0 = cl_list(2, v8uiop_run_program__reduced_output_var, v9uiop_run_program__output_activity_var);
  if (v10uiop_run_program__oavp!=ECL_NIL) {
   goto L58;
  }
  T2 = cl_list(2, ECL_SYM("IGNORE",430), v9uiop_run_program__output_activity_var);
  T3 = cl_list(2, ECL_SYM("DECLARE",276), T2);
  T1 = ecl_list1(T3);
  goto L57;
L58:;
  T1 = ECL_NIL;
L57:;
  T2 = ecl_append(T1,v3);
  T3 = cl_listX(3, ECL_SYM("LAMBDA",454), T0, T2);
  T4 = cl_list(2, ECL_SYM("FUNCTION",398), T3);
  T5 = cl_list(2, VV[1239], v13setf);
  value0 = cl_list(11, ECL_SYM("APPLY",91), VV[1247], VV[1251], ECL_SYM("*STANDARD-OUTPUT*",69), v15uiop_run_program__stream_easy_p, T4, ECL_SYM("OUTPUT",1319), v11uiop_run_program__output_form, v17uiop_run_program__active, T5, v19uiop_run_program__keys);
  return value0;
 }
}
static cl_object LC4641with_program_output_va(cl_narg narg, cl_object v20, cl_object v21, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1250]);
 {
  return LC4641with_program_output(v20, v21);
 }
}
/* local function WITH-PROGRAM-ERROR-OUTPUT                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4642with_program_error_output(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7;
  cl_object v8uiop_run_program__reduced_error_output_var;
  cl_object v9uiop_run_program__error_output_activity_var;
  cl_object v10uiop_run_program__eoavp;
  cl_object v11uiop_run_program__error_output_form;
  cl_object v12;
  cl_object v13setf;
  cl_object v14;
  cl_object v15uiop_run_program__stream_easy_p;
  cl_object v16;
  cl_object v17uiop_run_program__active;
  cl_object v18;
  cl_object v19uiop_run_program__keys;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v20;
   v20 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v20;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v20;
   v20 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6 = v20;
  }
  v7 = v6;
  if (!(v7==ECL_NIL)){
   goto L18;
  }
  si_dm_too_few_arguments(v1);
L18:;
  {
   cl_object v20;
   v20 = ecl_car(v7);
   v7 = ecl_cdr(v7);
   v8uiop_run_program__reduced_error_output_var = v20;
  }
  if (Null(v7)){
   goto L24;
  }
  v9uiop_run_program__error_output_activity_var = ecl_car(v7);
  goto L23;
L24:;
  v9uiop_run_program__error_output_activity_var = cl_gensym(0);
L23:;
  if (Null(v7)){
   goto L28;
  }
  v7 = ecl_cdr(v7);
  v10uiop_run_program__eoavp = ECL_T;
  goto L26;
L28:;
  v10uiop_run_program__eoavp = ECL_NIL;
  goto L26;
L26:;
  if (!(v5==ECL_NIL)){
   goto L33;
  }
  si_dm_too_few_arguments(v1);
L33:;
  {
   cl_object v20;
   v20 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v11uiop_run_program__error_output_form = v20;
  }
  v12 = si_search_keyword(v5, VV[1241]);
  if (!((v12)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L40;
  }
  v13setf = ECL_NIL;
  goto L39;
L40:;
  v13setf = v12;
L39:;
  v14 = si_search_keyword(v5, VV[1242]);
  if (!((v14)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L44;
  }
  v15uiop_run_program__stream_easy_p = ECL_NIL;
  goto L43;
L44:;
  v15uiop_run_program__stream_easy_p = v14;
L43:;
  v16 = si_search_keyword(v5, VV[1243]);
  if (!((v16)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L48;
  }
  v17uiop_run_program__active = ECL_NIL;
  goto L47;
L48:;
  v17uiop_run_program__active = v16;
L47:;
  v18 = si_search_keyword(v5, VV[1244]);
  if (!((v18)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L52;
  }
  v19uiop_run_program__keys = ECL_NIL;
  goto L51;
L52:;
  v19uiop_run_program__keys = v18;
L51:;
  si_check_keyword(2, v5, VV[1246]);
  if (Null(v7)){
   goto L55;
  }
  si_dm_too_many_arguments(v1);
L55:;
  T0 = cl_list(2, v8uiop_run_program__reduced_error_output_var, v9uiop_run_program__error_output_activity_var);
  if (v10uiop_run_program__eoavp!=ECL_NIL) {
   goto L58;
  }
  T2 = cl_list(2, ECL_SYM("IGNORE",430), v9uiop_run_program__error_output_activity_var);
  T3 = cl_list(2, ECL_SYM("DECLARE",276), T2);
  T1 = ecl_list1(T3);
  goto L57;
L58:;
  T1 = ECL_NIL;
L57:;
  T2 = ecl_append(T1,v3);
  T3 = cl_listX(3, ECL_SYM("LAMBDA",454), T0, T2);
  T4 = cl_list(2, ECL_SYM("FUNCTION",398), T3);
  T5 = cl_list(2, VV[1239], v13setf);
  value0 = cl_list(11, ECL_SYM("APPLY",91), VV[1247], VV[1251], ECL_SYM("*ERROR-OUTPUT*",35), v15uiop_run_program__stream_easy_p, T4, VV[1164], v11uiop_run_program__error_output_form, v17uiop_run_program__active, T5, v19uiop_run_program__keys);
  return value0;
 }
}
static cl_object LC4642with_program_error_output_va(cl_narg narg, cl_object v20, cl_object v21, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1253]);
 {
  return LC4642with_program_error_output(v20, v21);
 }
}
/* function definition for %USE-RUN-PROGRAM                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4650_use_run_program(volatile cl_narg narg, cl_object volatile v1uiop_run_program__command, ...)
{
 cl_object T0, T1, T2;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1255]);
 {
  cl_object volatile v2uiop_run_program__keys;
  cl_object volatile v3uiop_run_program__output;
  cl_object volatile v4uiop_run_program__ignore_error_status;
  ecl_va_list args; ecl_va_start(args,v1uiop_run_program__command,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1uiop_run_program__command,env0); /*  COMMAND           */
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L4650_use_run_programkeys,keyvars,(cl_object*)&v2uiop_run_program__keys,TRUE);
   CLV1 = env0 = CONS(v2uiop_run_program__keys,env0); /*  KEYS                */
   ecl_va_end(args);
   CLV2 = env0 = CONS(keyvars[0],env0);           /*  INPUT                   */
   v3uiop_run_program__output = keyvars[1];
   CLV3 = env0 = CONS(keyvars[2],env0);           /*  ERROR-OUTPUT            */
   v4uiop_run_program__ignore_error_status = keyvars[3];
  }
  goto L3;
L2:;
  si_assert_failure(1, VV[1256]);
L3:;
  {
   cl_object v5;
   cl_object v6;
   cl_object v7;
   v5 = cl_list(3, ECL_CONS_CAR(CLV2), v3uiop_run_program__output, ECL_CONS_CAR(CLV3));
   v6 = ECL_SYM("STREAM",1350);
   v7 = v5;
   if (Null(ecl_memql(v6,v7))){
    goto L6;
   }
  }
  goto L2;
L6:;
  {
   volatile cl_object v5uiop_run_program__active_input_p;
   volatile cl_object v6uiop_run_program__active_output_p;
   volatile cl_object v7uiop_run_program__active_error_output_p;
   volatile cl_object env1 = env0;
   v5uiop_run_program__active_input_p = (cl_env_copy->function=ecl_fdefinition(VV[1156]))->cfun.entry(1, ECL_CONS_CAR(CLV2)) /*  %ACTIVE-IO-SPECIFIER-P */;
   v6uiop_run_program__active_output_p = (cl_env_copy->function=ecl_fdefinition(VV[1156]))->cfun.entry(1, v3uiop_run_program__output) /*  %ACTIVE-IO-SPECIFIER-P */;
   v7uiop_run_program__active_error_output_p = (cl_env_copy->function=ecl_fdefinition(VV[1156]))->cfun.entry(1, ECL_CONS_CAR(CLV3)) /*  %ACTIVE-IO-SPECIFIER-P */;
   if (Null(v6uiop_run_program__active_output_p)){
    goto L15;
   }
   T0 = ECL_SYM("OUTPUT",1319);
   goto L14;
L15:;
   if (Null(v5uiop_run_program__active_input_p)){
    goto L17;
   }
   T0 = ECL_SYM("INPUT",1289);
   goto L14;
L17:;
   if (Null(v7uiop_run_program__active_error_output_p)){
    goto L19;
   }
   T0 = VV[1164];
   goto L14;
L19:;
   T0 = ECL_NIL;
L14:;
   CLV4 = env1 = CONS(T0,env1);                   /*  ACTIVITY                */
   T0 = Null(ECL_CONS_CAR(CLV4))?ECL_T:ECL_NIL;
   CLV5 = env1 = CONS(T0,env1);                   /*  WAIT                    */
   CLV6 = env1 = CONS(ECL_NIL,env1);              /*  OUTPUT-RESULT           */
   CLV7 = env1 = CONS(ECL_NIL,env1);              /*  ERROR-OUTPUT-RESULT     */
   CLV8 = env1 = CONS(ECL_NIL,env1);              /*  EXIT-CODE               */
   CLV9 = env1 = CONS(ECL_NIL,env1);              /*  PROCESS-INFO            */
   T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69));
   {
    cl_object volatile v8;
    v8 = ecl_make_cclosure_va((cl_objectfn)LC4648__lambda3870,env1,Cblock,2);
    T1 = v8;
   }
   {
    bool v8;
    v8 = (ECL_CONS_CAR(CLV4))==(ECL_SYM("OUTPUT",1319));
    {
     cl_object volatile v9;
     v9 = ecl_make_cclosure_va((cl_objectfn)LC4649__lambda3897,env1,Cblock,1);
     T2 = v9;
    }
    cl_apply(10, VV[1224], VV[1127], T0, ECL_T, T1, ECL_SYM("OUTPUT",1319), v3uiop_run_program__output, ecl_make_bool(v8), T2, ECL_CONS_CAR(CLV1));
   }
   T0 = ECL_CONS_CAR(CLV8);
   T1 = ECL_CONS_CAR(CLV9);
   (cl_env_copy->function=ecl_fdefinition(VV[1211]))->cfun.entry(7, T0, VV[1213], ECL_CONS_CAR(CLV0), ECL_SYM("PROCESS",1331), T1, VV[1266], v4uiop_run_program__ignore_error_status) /*  %CHECK-RESULT */;
   T0 = ECL_CONS_CAR(CLV6);
   T1 = ECL_CONS_CAR(CLV7);
   cl_env_copy->nvalues = 3;
   cl_env_copy->values[2] = ECL_CONS_CAR(CLV8);
   cl_env_copy->values[1] = T1;
   cl_env_copy->values[0] = T0;
   return cl_env_copy->values[0];
  }
 }
}
/* function definition for %NORMALIZE-SYSTEM-COMMAND                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4651_normalize_system_command(cl_object v1uiop_run_program__command)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_STRINGP(v1uiop_run_program__command))){
  goto L2;
 }
 value0 = v1uiop_run_program__command;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!(ECL_LISTP(v1uiop_run_program__command))){
  goto L4;
 }
 T0 = CONS(VV[1269],v1uiop_run_program__command);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1123]))->cfun.entry(1, T0) /*  ESCAPE-SHELL-COMMAND */;
 return value0;
L4:;
 value0 = si_etypecase_error(v1uiop_run_program__command, VV[1117]);
 return value0;
}
static cl_object L4651_normalize_system_command_va(cl_narg narg, cl_object v2uiop_run_program__command, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1268]);
 {
  return L4651_normalize_system_command(v2uiop_run_program__command);
 }
}
/* function definition for %REDIRECTED-SYSTEM-COMMAND                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4653_redirected_system_command(cl_object v1uiop_run_program__command, cl_object v2uiop_run_program__in, cl_object v3uiop_run_program__out, cl_object v4uiop_run_program__err, cl_object v5directory)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v6uiop_run_program__redirections;
  cl_object v7uiop_run_program__normalized;
  cl_object v8chdir;
  T0 = LC4652redirect(v2uiop_run_program__in, VV[1277]);
  T1 = LC4652redirect(v3uiop_run_program__out, VV[1278]);
  T2 = LC4652redirect(v4uiop_run_program__err, VV[1274]);
  v6uiop_run_program__redirections = cl_append(3, T0, T1, T2);
  v7uiop_run_program__normalized = (cl_env_copy->function=ecl_fdefinition(VV[1268]))->cfun.entry(1, v1uiop_run_program__command) /*  %NORMALIZE-SYSTEM-COMMAND */;
  if (Null(v5directory)){
   goto L8;
  }
  {
   cl_object v9uiop_run_program__dir_arg;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[656]))->cfun.entry(1, v5directory) /*  NATIVE-NAMESTRING */;
   v9uiop_run_program__dir_arg = (cl_env_copy->function=ecl_fdefinition(VV[1113]))->cfun.entry(1, T0) /*  ESCAPE-SHELL-TOKEN */;
   v8chdir = cl_list(3, VV[1279], v9uiop_run_program__dir_arg, VV[1280]);
   goto L7;
  }
L8:;
  v8chdir = ECL_NIL;
L7:;
  if (Null(v6uiop_run_program__redirections)){
   goto L12;
  }
  T1 = ecl_append(v6uiop_run_program__redirections,VV[1282]);
  T0 = CONS(VV[1281],T1);
  goto L11;
L12:;
  T0 = ECL_NIL;
L11:;
  T1 = ecl_list1(v7uiop_run_program__normalized);
  T2 = cl_append(3, T0, v8chdir, T1);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[280]))->cfun.entry(1, T2) /*  REDUCE/STRCAT */;
  return value0;
 }
}
static cl_object L4653_redirected_system_command_va(cl_narg narg, cl_object v9uiop_run_program__command, cl_object v10uiop_run_program__in, cl_object v11uiop_run_program__out, cl_object v12uiop_run_program__err, cl_object v13directory, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[1271]);
 {
  return L4653_redirected_system_command(v9uiop_run_program__command, v10uiop_run_program__in, v11uiop_run_program__out, v12uiop_run_program__err, v13directory);
 }
}
/* function definition for %SYSTEM                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4655_system(cl_narg narg, cl_object v1uiop_run_program__command, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1284]);
 {
  cl_object v2uiop_run_program__input;
  cl_object v3uiop_run_program__output;
  cl_object v4uiop_run_program__error_output;
  cl_object v5directory;
  ecl_va_list args; ecl_va_start(args,v1uiop_run_program__command,narg,1);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L4655_systemkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2uiop_run_program__input = keyvars[0];
   v3uiop_run_program__output = keyvars[1];
   v4uiop_run_program__error_output = keyvars[2];
   v5directory = keyvars[3];
  }
  {
   cl_object env1 = env0;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1271]))->cfun.entry(5, v1uiop_run_program__command, v2uiop_run_program__input, v3uiop_run_program__output, v4uiop_run_program__error_output, v5directory) /*  %REDIRECTED-SYSTEM-COMMAND */;
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(T0,env1);                   /*  %COMMAND                */
   {
    cl_object v6;
    v6 = ecl_make_cclosure_va((cl_objectfn)LC4654__lambda3912,env1,Cblock,0);
    T0 = v6;
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[756]))->cfun.entry(2, ECL_NIL, T0) /*  CALL-WITH-CURRENT-DIRECTORY */;
   return value0;
  }
 }
}
/* function definition for %USE-SYSTEM                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4661_use_system(cl_narg narg, cl_object v1uiop_run_program__command, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1287]);
 {
  cl_object v2uiop_run_program__keys;
  cl_object v3uiop_run_program__output;
  cl_object v4uiop_run_program__ignore_error_status;
  ecl_va_list args; ecl_va_start(args,v1uiop_run_program__command,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1uiop_run_program__command,env0); /*  COMMAND           */
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L4661_use_systemkeys,keyvars,(cl_object*)&v2uiop_run_program__keys,TRUE);
   CLV1 = env0 = CONS(v2uiop_run_program__keys,env0); /*  KEYS                */
   ecl_va_end(args);
   CLV2 = env0 = CONS(keyvars[0],env0);           /*  INPUT                   */
   v3uiop_run_program__output = keyvars[1];
   CLV3 = env0 = CONS(keyvars[2],env0);           /*  ERROR-OUTPUT            */
   v4uiop_run_program__ignore_error_status = keyvars[3];
  }
  {
   cl_object env1 = env0;
   CLV4 = env1 = CONS(ECL_NIL,env1);              /*  OUTPUT-RESULT           */
   CLV5 = env1 = CONS(ECL_NIL,env1);              /*  ERROR-OUTPUT-RESULT     */
   CLV6 = env1 = CONS(ECL_NIL,env1);              /*  EXIT-CODE               */
   {
    cl_object v5;
    v5 = ecl_make_cclosure_va((cl_objectfn)LC4659__lambda3935,env1,Cblock,2);
    T0 = v5;
   }
   {
    cl_object v5;
    v5 = ecl_make_cclosure_va((cl_objectfn)LC4660__lambda3949,env1,Cblock,1);
    T1 = v5;
   }
   cl_apply(10, VV[1224], VV[1127], ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69)), ECL_NIL, T0, ECL_SYM("OUTPUT",1319), v3uiop_run_program__output, ECL_NIL, T1, ECL_CONS_CAR(CLV1));
   T0 = ECL_CONS_CAR(CLV6);
   (cl_env_copy->function=ecl_fdefinition(VV[1211]))->cfun.entry(5, T0, VV[1213], ECL_CONS_CAR(CLV0), VV[1266], v4uiop_run_program__ignore_error_status) /*  %CHECK-RESULT */;
   T0 = ECL_CONS_CAR(CLV4);
   T1 = ECL_CONS_CAR(CLV5);
   cl_env_copy->nvalues = 3;
   cl_env_copy->values[2] = ECL_CONS_CAR(CLV6);
   cl_env_copy->values[1] = T1;
   cl_env_copy->values[0] = T0;
   return cl_env_copy->values[0];
  }
 }
}
/* function definition for LAUNCH-PROGRAM                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4662launch_program(cl_narg narg, cl_object v1uiop_run_program__command, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1294]);
 {
  cl_object v2uiop_run_program__keys;
  cl_object v3uiop_run_program__input;
  cl_object v4uiop_run_program__if_input_does_not_exist;
  cl_object v5uiop_run_program__output;
  cl_object v6uiop_run_program__if_output_exists;
  cl_object v7uiop_run_program__error_output;
  cl_object v8uiop_run_program__if_error_output_exists;
  cl_object v9uiop_run_program__element_type;
  cl_object v10uiop_run_program__external_format;
  ecl_va_list args; ecl_va_start(args,v1uiop_run_program__command,narg,1);
  {
   cl_object keyvars[16];
   cl_parse_key(args,8,L4662launch_programkeys,keyvars,(cl_object*)&v2uiop_run_program__keys,TRUE);
   ecl_va_end(args);
   v3uiop_run_program__input = keyvars[0];
   if (Null(keyvars[9])) {
    v4uiop_run_program__if_input_does_not_exist = ECL_SYM("ERROR",1260);
   } else {
    v4uiop_run_program__if_input_does_not_exist = keyvars[1];
   }
   v5uiop_run_program__output = keyvars[2];
   if (Null(keyvars[11])) {
    v6uiop_run_program__if_output_exists = ECL_SYM("SUPERSEDE",1351);
   } else {
    v6uiop_run_program__if_output_exists = keyvars[3];
   }
   v7uiop_run_program__error_output = keyvars[4];
   if (Null(keyvars[13])) {
    v8uiop_run_program__if_error_output_exists = ECL_SYM("SUPERSEDE",1351);
   } else {
    v8uiop_run_program__if_error_output_exists = keyvars[5];
   }
   if (Null(keyvars[14])) {
    v9uiop_run_program__element_type = ecl_cmp_symbol_value(cl_env_copy,VV[804]);
   } else {
    v9uiop_run_program__element_type = keyvars[6];
   }
   if (Null(keyvars[15])) {
    v10uiop_run_program__external_format = ecl_cmp_symbol_value(cl_env_copy,VV[815]);
   } else {
    v10uiop_run_program__external_format = keyvars[7];
   }
  }
  value0 = cl_apply(21, VV[1178], v1uiop_run_program__command, ECL_SYM("WAIT",1367), ECL_NIL, ECL_SYM("INPUT",1289), v3uiop_run_program__input, ECL_SYM("IF-INPUT-DOES-NOT-EXIST",1280), v4uiop_run_program__if_input_does_not_exist, ECL_SYM("OUTPUT",1319), v5uiop_run_program__output, ECL_SYM("IF-OUTPUT-EXISTS",1281), v6uiop_run_program__if_output_exists, VV[1164], v7uiop_run_program__error_output, VV[1295], v8uiop_run_program__if_error_output_exists, ECL_SYM("ELEMENT-TYPE",1255), v9uiop_run_program__element_type, ECL_SYM("EXTERNAL-FORMAT",1267), v10uiop_run_program__external_format, v2uiop_run_program__keys);
  return value0;
 }
}
/* function definition for RUN-PROGRAM                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4664run_program(cl_narg narg, cl_object v1uiop_run_program__command, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1227]);
 {
  cl_object v2uiop_run_program__keys;
  cl_object v3uiop_run_program__ignore_error_status;
  cl_object v4uiop_run_program__force_shell;
  cl_object v5uiop_run_program__force_shell_suppliedp;
  cl_object v6uiop_run_program__input;
  cl_object v7uiop_run_program__inputp;
  cl_object v8uiop_run_program__if_input_does_not_exist;
  cl_object v9uiop_run_program__output;
  cl_object v10uiop_run_program__if_output_exists;
  cl_object v11uiop_run_program__error_output;
  cl_object v12uiop_run_program__error_output_p;
  cl_object v13uiop_run_program__if_error_output_exists;
  cl_object v14uiop_run_program__element_type;
  cl_object v15uiop_run_program__external_format;
  ecl_va_list args; ecl_va_start(args,v1uiop_run_program__command,narg,1);
  {
   cl_object keyvars[20];
   cl_parse_key(args,10,L4664run_programkeys,keyvars,(cl_object*)&v2uiop_run_program__keys,TRUE);
   ecl_va_end(args);
   v3uiop_run_program__ignore_error_status = keyvars[0];
   v4uiop_run_program__force_shell = keyvars[1];
   v5uiop_run_program__force_shell_suppliedp = keyvars[11];
   v6uiop_run_program__input = keyvars[2];
   v7uiop_run_program__inputp = keyvars[12];
   if (Null(keyvars[13])) {
    v8uiop_run_program__if_input_does_not_exist = ECL_SYM("ERROR",1260);
   } else {
    v8uiop_run_program__if_input_does_not_exist = keyvars[3];
   }
   v9uiop_run_program__output = keyvars[4];
   if (Null(keyvars[15])) {
    v10uiop_run_program__if_output_exists = ECL_SYM("SUPERSEDE",1351);
   } else {
    v10uiop_run_program__if_output_exists = keyvars[5];
   }
   v11uiop_run_program__error_output = keyvars[6];
   v12uiop_run_program__error_output_p = keyvars[16];
   if (Null(keyvars[17])) {
    v13uiop_run_program__if_error_output_exists = ECL_SYM("SUPERSEDE",1351);
   } else {
    v13uiop_run_program__if_error_output_exists = keyvars[7];
   }
   if (Null(keyvars[18])) {
    v14uiop_run_program__element_type = ecl_cmp_symbol_value(cl_env_copy,VV[804]);
   } else {
    v14uiop_run_program__element_type = keyvars[8];
   }
   if (Null(keyvars[19])) {
    v15uiop_run_program__external_format = ecl_cmp_symbol_value(cl_env_copy,VV[815]);
   } else {
    v15uiop_run_program__external_format = keyvars[9];
   }
  }
  if (!(ECL_STRINGP(v1uiop_run_program__command))){
   goto L6;
  }
  if (v5uiop_run_program__force_shell_suppliedp!=ECL_NIL) {
   goto L6;
  }
  v4uiop_run_program__force_shell = ECL_T;
L6:;
  if (v4uiop_run_program__force_shell!=ECL_NIL) {
   goto L13;
  }
  goto L11;
L13:;
  T0 = VV[1287];
  goto L10;
L11:;
  T0 = VV[1255];
L10:;
  T1 = LC4663default(v6uiop_run_program__input, v7uiop_run_program__inputp, v9uiop_run_program__output);
  T2 = LC4663default(v11uiop_run_program__error_output, v12uiop_run_program__error_output_p, v9uiop_run_program__output);
  value0 = cl_apply(17, T0, v1uiop_run_program__command, ECL_SYM("INPUT",1289), T1, VV[1164], T2, ECL_SYM("IF-INPUT-DOES-NOT-EXIST",1280), v8uiop_run_program__if_input_does_not_exist, ECL_SYM("IF-OUTPUT-EXISTS",1281), v10uiop_run_program__if_output_exists, VV[1295], v13uiop_run_program__if_error_output_exists, ECL_SYM("ELEMENT-TYPE",1255), v14uiop_run_program__element_type, ECL_SYM("EXTERNAL-FORMAT",1267), v15uiop_run_program__external_format, v2uiop_run_program__keys);
  return value0;
 }
}
/* function definition for GET-OPTIMIZATION-SETTINGS                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4665get_optimization_settings()
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2uiop_lisp_build__x;
  cl_object v3;
  v1 = VV[1307];
  v2uiop_lisp_build__x = ECL_NIL;
  v3 = v1;
  {
   cl_object v4;
   cl_object v5uiop_lisp_build__v;
   cl_object v6;
   {
    cl_object v7;
    v7 = ecl_cmp_symbol_value(cl_env_copy,VV[1305]);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   v5uiop_lisp_build__v = ECL_NIL;
   v6 = v4;
   {
    cl_object v7uiop_lisp_build__y;
    v7uiop_lisp_build__y = ECL_NIL;
    {
     cl_object v8;
     cl_object v9;
     v8 = ecl_list1(ECL_NIL);
     v9 = v8;
L13:;
     if (!(ecl_endp(v3))){
      goto L15;
     }
     goto L14;
L15:;
     v2uiop_lisp_build__x = ECL_CONS_CAR(v3);
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v3);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v3 = v10;
     }
     if (!(ecl_endp(v6))){
      goto L23;
     }
     goto L14;
L23:;
     v5uiop_lisp_build__v = ECL_CONS_CAR(v6);
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v6);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v6 = v10;
     }
     v7uiop_lisp_build__y = cl_symbol_value(v5uiop_lisp_build__v);
     if (Null(v7uiop_lisp_build__y)){
      goto L33;
     }
     {
      cl_object v10;
      v10 = v9;
      if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v10;
     }
     T1 = cl_list(2, v2uiop_lisp_build__x, v7uiop_lisp_build__y);
     v9 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v9,T0);
L33:;
     goto L13;
L14:;
     value0 = ecl_cdr(v8);
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
}
static cl_object L4665get_optimization_settings_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1306]);
 {
  return L4665get_optimization_settings();
 }
}
/* function definition for PROCLAIM-OPTIMIZATION-SETTINGS                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4666proclaim_optimization_settings()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = CONS(ECL_SYM("OPTIMIZE",615),ecl_cmp_symbol_value(cl_env_copy,VV[1303]));
 (cl_env_copy->function=(ECL_SYM("PROCLAIM",669)->symbol.gfdef))->cfun.entry(1, T0) /*  PROCLAIM */;
 {
  cl_object v1uiop_lisp_build__settings;
  v1uiop_lisp_build__settings = (cl_env_copy->function=ecl_fdefinition(VV[1306]))->cfun.entry(0) /*  GET-OPTIMIZATION-SETTINGS */;
  if (ecl_equal(ecl_cmp_symbol_value(cl_env_copy,VV[1304]),v1uiop_lisp_build__settings)) {
   goto L4;
  }
  T0 = v1uiop_lisp_build__settings;
  ecl_cmp_setq(cl_env_copy,VV[1304],T0);
  value0 = ecl_cmp_symbol_value(cl_env_copy,VV[1304]);
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4666proclaim_optimization_settings_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1309]);
 {
  return L4666proclaim_optimization_settings();
 }
}
/* local function WITH-OPTIMIZATION-SETTINGS                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4667with_optimization_settings(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_lisp_build__settings;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v7;
   v7 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v7;
  }
  v5 = v4;
  if (Null(v5)){
   goto L11;
  }
  {
   cl_object v7;
   v7 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_lisp_build__settings = v7;
   goto L10;
  }
L11:;
  v6uiop_lisp_build__settings = ecl_cmp_symbol_value(cl_env_copy,VV[1303]);
L10:;
  if (Null(v5)){
   goto L16;
  }
  si_dm_too_many_arguments(v1);
L16:;
  {
   cl_object v7;
   cl_object v8uiop_lisp_build__v;
   cl_object v9;
   {
    cl_object v10;
    v10 = ecl_cmp_symbol_value(cl_env_copy,VV[1305]);
    if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v7 = v10;
   }
   v8uiop_lisp_build__v = ECL_NIL;
   v9 = v7;
   {
    cl_object v10;
    cl_object v11;
    v10 = ecl_list1(ECL_NIL);
    v11 = v10;
L26:;
    if (!(ecl_endp(v9))){
     goto L28;
    }
    goto L27;
L28:;
    v8uiop_lisp_build__v = ECL_CONS_CAR(v9);
    {
     cl_object v12;
     v12 = ECL_CONS_CDR(v9);
     if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v9 = v12;
    }
    {
     cl_object v12;
     v12 = v11;
     if (ecl_unlikely(ECL_ATOM(v12))) FEtype_error_cons(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T1 = v12;
    }
    T2 = cl_list(2, v8uiop_lisp_build__v, v8uiop_lisp_build__v);
    v11 = ecl_list1(T2);
    (ECL_CONS_CDR(T1)=v11,T1);
    goto L26;
L27:;
    T0 = ecl_cdr(v10);
    goto L18;
   }
  }
L18:;
  if (Null(v6uiop_lisp_build__settings)){
   goto L44;
  }
  T2 = cl_list(3, ECL_SYM("LIST*",484), VV[1312], v6uiop_lisp_build__settings);
  T3 = cl_list(2, ECL_SYM("PROCLAIM",669), T2);
  T1 = ecl_list1(T3);
  goto L43;
L44:;
  T1 = ECL_NIL;
L43:;
  T2 = ecl_append(T1,v3);
  value0 = cl_listX(3, ECL_SYM("LET",479), T0, T2);
  return value0;
 }
}
static cl_object LC4667with_optimization_settings_va(cl_narg narg, cl_object v7, cl_object v8, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1311]);
 {
  return LC4667with_optimization_settings(v7, v8);
 }
}
/* function definition for CALL-WITH-MUFFLED-COMPILER-CONDITIONS              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4668call_with_muffled_compiler_conditions(cl_object v1uiop_lisp_build__thunk)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_append(ecl_cmp_symbol_value(cl_env_copy,VV[1315]),ecl_cmp_symbol_value(cl_env_copy,VV[1316]));
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[402]))->cfun.entry(2, v1uiop_lisp_build__thunk, T0) /*  CALL-WITH-MUFFLED-CONDITIONS */;
 return value0;
}
static cl_object L4668call_with_muffled_compiler_conditions_va(cl_narg narg, cl_object v2uiop_lisp_build__thunk, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1318]);
 {
  return L4668call_with_muffled_compiler_conditions(v2uiop_lisp_build__thunk);
 }
}
/* local function WITH-MUFFLED-COMPILER-CONDITIONS                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4669with_muffled_compiler_conditions(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v5;
  }
  if (Null(v4)){
   goto L9;
  }
  si_dm_too_many_arguments(v1);
L9:;
  T0 = cl_listX(3, ECL_SYM("LAMBDA",454), ECL_NIL, v3);
  T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
  value0 = cl_list(2, VV[1318], T1);
  return value0;
 }
}
static cl_object LC4669with_muffled_compiler_conditions_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1320]);
 {
  return LC4669with_muffled_compiler_conditions(v5, v6);
 }
}
/* function definition for CALL-WITH-MUFFLED-LOADER-CONDITIONS                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4670call_with_muffled_loader_conditions(cl_object v1uiop_lisp_build__thunk)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_append(ecl_cmp_symbol_value(cl_env_copy,VV[1315]),ecl_cmp_symbol_value(cl_env_copy,VV[1317]));
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[402]))->cfun.entry(2, v1uiop_lisp_build__thunk, T0) /*  CALL-WITH-MUFFLED-CONDITIONS */;
 return value0;
}
static cl_object L4670call_with_muffled_loader_conditions_va(cl_narg narg, cl_object v2uiop_lisp_build__thunk, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1322]);
 {
  return L4670call_with_muffled_loader_conditions(v2uiop_lisp_build__thunk);
 }
}
/* local function WITH-MUFFLED-LOADER-CONDITIONS                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4671with_muffled_loader_conditions(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v5;
  }
  if (Null(v4)){
   goto L9;
  }
  si_dm_too_many_arguments(v1);
L9:;
  T0 = cl_listX(3, ECL_SYM("LAMBDA",454), ECL_NIL, v3);
  T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
  value0 = cl_list(2, VV[1322], T1);
  return value0;
 }
}
static cl_object LC4671with_muffled_loader_conditions_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1324]);
 {
  return LC4671with_muffled_loader_conditions(v5, v6);
 }
}
/* local function LAMBDA4035                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4673__lambda4035()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC4672__lambda4037_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4673__lambda4035_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1327]);
 {
  return LC4673__lambda4035();
 }
}
/* function definition for CHECK-LISP-COMPILE-WARNINGS                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4674check_lisp_compile_warnings(cl_narg narg, cl_object v1uiop_lisp_build__warnings_p, cl_object v2uiop_lisp_build__failure_p, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1338]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[1338]);
 {
  cl_object v3uiop_lisp_build__context_format;
  cl_object v4uiop_lisp_build__context_arguments;
  va_list args; va_start(args,v2uiop_lisp_build__failure_p);
  {
   int i = 2;
   if (i >= narg) {
    v3uiop_lisp_build__context_format = ECL_NIL;
   } else {
    i++;
    v3uiop_lisp_build__context_format = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4uiop_lisp_build__context_arguments = ECL_NIL;
   } else {
    i++;
    v4uiop_lisp_build__context_arguments = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(v2uiop_lisp_build__failure_p)){
   goto L3;
  }
  {
   cl_object v5;
   v5 = ecl_cmp_symbol_value(cl_env_copy,VV[1301]);
   if (!((v5)==(VV[1300]))){
    goto L6;
   }
   (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(7, VV[1336], ECL_SYM("DESCRIPTION",992), VV[1339], VV[1340], v3uiop_lisp_build__context_format, VV[1341], v4uiop_lisp_build__context_arguments) /*  WARN */;
   goto L3;
L6:;
   if (!((v5)==(ECL_SYM("ERROR",1260)))){
    goto L8;
   }
   cl_error(7, VV[1337], ECL_SYM("DESCRIPTION",992), VV[1339], VV[1340], v3uiop_lisp_build__context_format, VV[1341], v4uiop_lisp_build__context_arguments);
   goto L3;
L8:;
   if (!((v5)==(ECL_SYM("IGNORE",1282)))){
    goto L3;
   }
  }
L3:;
  if (Null(v1uiop_lisp_build__warnings_p)){
   goto L11;
  }
  {
   cl_object v5;
   v5 = ecl_cmp_symbol_value(cl_env_copy,VV[1299]);
   if (!((v5)==(VV[1300]))){
    goto L14;
   }
   value0 = (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(7, VV[1334], ECL_SYM("DESCRIPTION",992), VV[1342], VV[1340], v3uiop_lisp_build__context_format, VV[1341], v4uiop_lisp_build__context_arguments) /*  WARN */;
   return value0;
L14:;
   if (!((v5)==(ECL_SYM("ERROR",1260)))){
    goto L16;
   }
   value0 = cl_error(7, VV[1335], ECL_SYM("DESCRIPTION",992), VV[1342], VV[1340], v3uiop_lisp_build__context_format, VV[1341], v4uiop_lisp_build__context_arguments);
   return value0;
L16:;
   if (!((v5)==(ECL_SYM("IGNORE",1282)))){
    goto L18;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L18:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L11:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for CHECK-LISP-COMPILE-RESULTS                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4675check_lisp_compile_results(cl_narg narg, cl_object v1uiop_lisp_build__output, cl_object v2uiop_lisp_build__warnings_p, cl_object v3uiop_lisp_build__failure_p, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[1344]);
 if (ecl_unlikely(narg>5)) FEwrong_num_arguments(VV[1344]);
 {
  cl_object v4uiop_lisp_build__context_format;
  cl_object v5uiop_lisp_build__context_arguments;
  va_list args; va_start(args,v3uiop_lisp_build__failure_p);
  {
   int i = 3;
   if (i >= narg) {
    v4uiop_lisp_build__context_format = ECL_NIL;
   } else {
    i++;
    v4uiop_lisp_build__context_format = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v5uiop_lisp_build__context_arguments = ECL_NIL;
   } else {
    i++;
    v5uiop_lisp_build__context_arguments = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (v1uiop_lisp_build__output!=ECL_NIL) {
   goto L3;
  }
  cl_error(5, VV[1333], VV[1340], v4uiop_lisp_build__context_format, VV[1341], v5uiop_lisp_build__context_arguments);
L3:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1338]))->cfun.entry(4, v2uiop_lisp_build__warnings_p, v3uiop_lisp_build__failure_p, v4uiop_lisp_build__context_format, v5uiop_lisp_build__context_arguments) /*  CHECK-LISP-COMPILE-WARNINGS */;
  return value0;
 }
}
/* function definition for REIFY-SIMPLE-SEXP                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4676reify_simple_sexp(cl_object v1uiop_lisp_build__sexp)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_SYMBOLP(v1uiop_lisp_build__sexp))){
  goto L2;
 }
 value0 = L4213reify_symbol(1, v1uiop_lisp_build__sexp);
 return value0;
L2:;
 if (ecl_numberp(v1uiop_lisp_build__sexp)) {
  goto L6;
 }
 if (ECL_CHARACTERP(v1uiop_lisp_build__sexp)) {
  goto L6;
 }
 if (cl_simple_string_p(v1uiop_lisp_build__sexp)!=ECL_NIL) {
  goto L6;
 }
 if (Null(cl_pathnamep(v1uiop_lisp_build__sexp))){
  goto L4;
 }
 goto L5;
L6:;
L5:;
 value0 = v1uiop_lisp_build__sexp;
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 if (!(ECL_CONSP(v1uiop_lisp_build__sexp))){
  goto L10;
 }
 T0 = ecl_car(v1uiop_lisp_build__sexp);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1346]))->cfun.entry(1, T0) /*  REIFY-SIMPLE-SEXP */;
 T2 = ecl_cdr(v1uiop_lisp_build__sexp);
 T3 = (cl_env_copy->function=ecl_fdefinition(VV[1346]))->cfun.entry(1, T2) /*  REIFY-SIMPLE-SEXP */;
 value0 = CONS(T1,T3);
 cl_env_copy->nvalues = 1;
 return value0;
L10:;
 if (Null(cl_simple_vector_p(v1uiop_lisp_build__sexp))){
  goto L12;
 }
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = si_coerce_to_list(v1uiop_lisp_build__sexp);
  v3 = ECL_NIL;
  v4 = v2;
  {
   cl_object v5;
   cl_object v6;
   v5 = ecl_list1(ECL_NIL);
   v6 = v5;
L20:;
   if (!(ecl_endp(v4))){
    goto L22;
   }
   goto L21;
L22:;
   v3 = ECL_CONS_CAR(v4);
   {
    cl_object v7;
    v7 = ECL_CONS_CDR(v4);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   {
    cl_object v7;
    v7 = v6;
    if (ecl_unlikely(ECL_ATOM(v7))) FEtype_error_cons(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T1 = v7;
   }
   T2 = ecl_function_dispatch(cl_env_copy,VV[1346])(1, v3);
   v6 = ecl_list1(T2);
   (ECL_CONS_CDR(T1)=v6,T1);
   goto L20;
L21:;
   T0 = ecl_cdr(v5);
   goto L14;
  }
 }
L14:;
 value0 = cl_vector(1, T0);
 return value0;
L12:;
 value0 = si_etypecase_error(v1uiop_lisp_build__sexp, VV[1348]);
 return value0;
}
static cl_object L4676reify_simple_sexp_va(cl_narg narg, cl_object v2uiop_lisp_build__sexp, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1346]);
 {
  return L4676reify_simple_sexp(v2uiop_lisp_build__sexp);
 }
}
/* function definition for UNREIFY-SIMPLE-SEXP                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4677unreify_simple_sexp(cl_object v1uiop_lisp_build__sexp)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (ECL_SYMBOLP(v1uiop_lisp_build__sexp)) {
  goto L4;
 }
 if (ecl_numberp(v1uiop_lisp_build__sexp)) {
  goto L4;
 }
 if (ECL_CHARACTERP(v1uiop_lisp_build__sexp)) {
  goto L4;
 }
 if (cl_simple_string_p(v1uiop_lisp_build__sexp)!=ECL_NIL) {
  goto L4;
 }
 if (Null(cl_pathnamep(v1uiop_lisp_build__sexp))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = v1uiop_lisp_build__sexp;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!(ECL_CONSP(v1uiop_lisp_build__sexp))){
  goto L9;
 }
 T0 = ecl_car(v1uiop_lisp_build__sexp);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1350]))->cfun.entry(1, T0) /*  UNREIFY-SIMPLE-SEXP */;
 T2 = ecl_cdr(v1uiop_lisp_build__sexp);
 T3 = (cl_env_copy->function=ecl_fdefinition(VV[1350]))->cfun.entry(1, T2) /*  UNREIFY-SIMPLE-SEXP */;
 value0 = CONS(T1,T3);
 cl_env_copy->nvalues = 1;
 return value0;
L9:;
 if (Null(cl_typep(2, v1uiop_lisp_build__sexp, VV[47]))){
  goto L11;
 }
 value0 = L4214unreify_symbol(1, v1uiop_lisp_build__sexp);
 return value0;
L11:;
 if (Null(cl_typep(2, v1uiop_lisp_build__sexp, VV[1351]))){
  goto L13;
 }
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  {
   cl_object v5;
   {
    cl_object v6;
    v6 = v1uiop_lisp_build__sexp;
    T1 = v6;
    if (ecl_unlikely(((cl_fixnum)(0))>=(v6)->vector.dim))
           FEwrong_index(ECL_NIL,v6,-1,ecl_make_fixnum((cl_fixnum)(0)),(v6)->vector.dim);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T2 = ecl_make_int8_t(0);
    v5 = ecl_aref_unsafe(T1,ecl_fixnum(T2));
   }
   if (ecl_unlikely(!ECL_LISTP(v5))) FEtype_error_list(v5);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v2 = v5;
  }
  v3 = ECL_NIL;
  v4 = v2;
  {
   cl_object v5;
   cl_object v6;
   v5 = ecl_list1(ECL_NIL);
   v6 = v5;
L28:;
   if (!(ecl_endp(v4))){
    goto L30;
   }
   goto L29;
L30:;
   v3 = ECL_CONS_CAR(v4);
   {
    cl_object v7;
    v7 = ECL_CONS_CDR(v4);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   {
    cl_object v7;
    v7 = v6;
    if (ecl_unlikely(ECL_ATOM(v7))) FEtype_error_cons(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T1 = v7;
   }
   T2 = ecl_function_dispatch(cl_env_copy,VV[1350])(1, v3);
   v6 = ecl_list1(T2);
   (ECL_CONS_CDR(T1)=v6,T1);
   goto L28;
L29:;
   T0 = ecl_cdr(v5);
   goto L15;
  }
 }
L15:;
 value0 = si_coerce_to_vector(T0, ECL_T, ECL_SYM("*",20), ECL_NIL);
 return value0;
L13:;
 value0 = si_etypecase_error(v1uiop_lisp_build__sexp, VV[1352]);
 return value0;
}
static cl_object L4677unreify_simple_sexp_va(cl_narg narg, cl_object v2uiop_lisp_build__sexp, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1350]);
 {
  return L4677unreify_simple_sexp(v2uiop_lisp_build__sexp);
 }
}
/* function definition for REIFY-DEFERRED-WARNINGS                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4678reify_deferred_warnings()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = VV[1355];
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4678reify_deferred_warnings_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1354]);
 {
  return L4678reify_deferred_warnings();
 }
}
/* function definition for UNREIFY-DEFERRED-WARNINGS                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4679unreify_deferred_warnings(cl_object v1uiop_lisp_build__reified_deferred_warnings)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4679unreify_deferred_warnings_va(cl_narg narg, cl_object v2uiop_lisp_build__reified_deferred_warnings, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1357]);
 {
  return L4679unreify_deferred_warnings(v2uiop_lisp_build__reified_deferred_warnings);
 }
}
/* function definition for RESET-DEFERRED-WARNINGS                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4680reset_deferred_warnings()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = VV[1360];
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4680reset_deferred_warnings_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1359]);
 {
  return L4680reset_deferred_warnings();
 }
}
/* function definition for SAVE-DEFERRED-WARNINGS                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4682save_deferred_warnings(cl_object volatile v1uiop_lisp_build__warnings_file)
{
 cl_object T0;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object env1 = env0;
  T0 = cl_open(9, v1uiop_lisp_build__warnings_file, ECL_SYM("DIRECTION",1249), ECL_SYM("OUTPUT",1319), ECL_SYM("IF-EXISTS",1279), ECL_SYM("SUPERSEDE",1351), ECL_SYM("ELEMENT-TYPE",1255), ecl_cmp_symbol_value(cl_env_copy,VV[804]), ECL_SYM("EXTERNAL-FORMAT",1267), ecl_cmp_symbol_value(cl_env_copy,VV[815]));
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(T0,env1);                    /*  S                       */
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    {
     struct ecl_stack_frame _ecl_inner_frame_aux;
     volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
     {
      cl_object volatile v2;
      v2 = ecl_make_cclosure_va((cl_objectfn)LC4681__lambda4071,env1,Cblock,0);
      T0 = v2;
     }
     cl_env_copy->values[0] = (cl_env_copy->function=ecl_fdefinition(VV[831]))->cfun.entry(1, T0) /*  CALL-WITH-SAFE-IO-SYNTAX */;
     ecl_stack_frame_push_values(_ecl_inner_frame);
     if (Null(ECL_CONS_CAR(CLV0))){
      goto L5;
     }
     cl_close(1, ECL_CONS_CAR(CLV0));
L5:;
     ecl_stack_frame_pop_values(_ecl_inner_frame);
     ecl_stack_frame_close(_ecl_inner_frame);
    }
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   if (Null(ECL_CONS_CAR(CLV0))){
    goto L7;
   }
   cl_close(3, ECL_CONS_CAR(CLV0), ECL_SYM("ABORT",1225), ECL_T);
L7:;
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
}
static cl_object L4682save_deferred_warnings_va(cl_narg narg, cl_object v2uiop_lisp_build__warnings_file, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1362]);
 {
  return L4682save_deferred_warnings(v2uiop_lisp_build__warnings_file);
 }
}
/* function definition for WARNINGS-FILE-TYPE                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4683warnings_file_type(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[1365]);
 {
  cl_object v1implementation_type;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1implementation_type = ECL_NIL;
   } else {
    i++;
    v1implementation_type = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v2;
   value0 = v1implementation_type;
   if (value0!=ECL_NIL) {
    goto L4;
   }
   v2 = ecl_cmp_symbol_value(cl_env_copy,VV[462]);
   goto L2;
L4:;
   v2 = value0;
   goto L2;
L2:;
   if (!((v2)==(VV[1367]))){
    goto L11;
   }
   goto L8;
L11:;
   goto L9;
L9:;
   if (!((v2)==(VV[1368]))){
    goto L6;
   }
   goto L7;
L8:;
L7:;
   value0 = VV[1370];
   cl_env_copy->nvalues = 1;
   return value0;
L6:;
   if (!((v2)==(VV[1372]))){
    goto L19;
   }
   goto L16;
L19:;
   goto L17;
L17:;
   if (!((v2)==(VV[1373]))){
    goto L14;
   }
   goto L15;
L16:;
L15:;
   value0 = VV[1375];
   cl_env_copy->nvalues = 1;
   return value0;
L14:;
   if (!((v2)==(VV[1377]))){
    goto L22;
   }
   value0 = VV[1378];
   cl_env_copy->nvalues = 1;
   return value0;
L22:;
   if (!((v2)==(VV[1380]))){
    goto L30;
   }
   goto L27;
L30:;
   goto L28;
L28:;
   if (!((v2)==(VV[1381]))){
    goto L25;
   }
   goto L26;
L27:;
L26:;
   value0 = VV[1383];
   cl_env_copy->nvalues = 1;
   return value0;
L25:;
   if (!((v2)==(VV[1385]))){
    goto L33;
   }
   value0 = VV[1386];
   cl_env_copy->nvalues = 1;
   return value0;
L33:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for ENABLE-DEFERRED-WARNINGS-CHECK                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4684enable_deferred_warnings_check()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1365]))->cfun.entry(0) /*  WARNINGS-FILE-TYPE */;
 ecl_cmp_setq(cl_env_copy,VV[1388],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[1388]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4684enable_deferred_warnings_check_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1389]);
 {
  return L4684enable_deferred_warnings_check();
 }
}
/* function definition for DISABLE-DEFERRED-WARNINGS-CHECK                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4685disable_deferred_warnings_check()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ECL_NIL;
 ecl_cmp_setq(cl_env_copy,VV[1388],T0);
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4685disable_deferred_warnings_check_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1391]);
 {
  return L4685disable_deferred_warnings_check();
 }
}
/* function definition for WARNINGS-FILE-P                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4686warnings_file_p(cl_narg narg, cl_object v1uiop_lisp_build__file, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1393]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1393]);
 {
  cl_object v2implementation_type;
  va_list args; va_start(args,v1uiop_lisp_build__file);
  {
   int i = 1;
   if (i >= narg) {
    v2implementation_type = ECL_NIL;
   } else {
    i++;
    v2implementation_type = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v3type;
   if (Null(v2implementation_type)){
    goto L3;
   }
   v3type = (cl_env_copy->function=ecl_fdefinition(VV[1365]))->cfun.entry(1, v2implementation_type) /*  WARNINGS-FILE-TYPE */;
   goto L2;
L3:;
   v3type = ecl_cmp_symbol_value(cl_env_copy,VV[1388]);
L2:;
   if (Null(v3type)){
    goto L5;
   }
   T0 = cl_pathname_type(1, v1uiop_lisp_build__file);
   value0 = ecl_make_bool(ecl_equal(T0,v3type));
   cl_env_copy->nvalues = 1;
   return value0;
L5:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for CHECK-DEFERRED-WARNINGS                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4690check_deferred_warnings(volatile cl_narg narg, cl_object volatile v1uiop_lisp_build__files, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1395]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[1395]);
 {
  cl_object volatile v2uiop_lisp_build__context_format;
  cl_object volatile v3uiop_lisp_build__context_arguments;
  va_list args; va_start(args,v1uiop_lisp_build__files);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1uiop_lisp_build__files,env0); /*  FILES                */
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_lisp_build__context_format = ECL_NIL;
   } else {
    i++;
    v2uiop_lisp_build__context_format = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v3uiop_lisp_build__context_arguments = ECL_NIL;
   } else {
    i++;
    v3uiop_lisp_build__context_arguments = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   volatile cl_object env1 = env0;
   CLV1 = env1 = CONS(ECL_NIL,env1);              /*  FILE-ERRORS             */
   CLV2 = env1 = CONS(ECL_NIL,env1);              /*  FAILURE-P               */
   CLV3 = env1 = CONS(ECL_NIL,env1);              /*  WARNINGS-P              */
   {
    cl_object volatile v4;
    v4 = ecl_make_cclosure_va((cl_objectfn)LC4687__lambda4158,env1,Cblock,1);
    T0 = v4;
   }
   T1 = CONS(ECL_SYM("WARNING",908),T0);
   T2 = ecl_list1(T1);
   T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
   ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
   {
    cl_object volatile v4;
    v4 = ecl_make_cclosure_va((cl_objectfn)LC4689__lambda4162,env1,Cblock,0);
    T0 = v4;
   }
   (cl_env_copy->function=(VV[1397]->symbol.gfdef))->cfun.entry(3, T0, VV[1401], ECL_T) /*  DO-COMPILATION-UNIT */;
   ecl_bds_unwind1(cl_env_copy);
   {
    cl_object v4;
    v4 = ECL_CONS_CAR(CLV1);
    goto L10;
L9:;
    {
     cl_object v5error;
     v5error = ecl_car(v4);
     cl_error(1, v5error);
    }
    v4 = ecl_cdr(v4);
L10:;
    if (Null(v4)){
     goto L17;
    }
    goto L9;
L17:;
   }
   value0 = ECL_CONS_CAR(CLV2);
   if (value0!=ECL_NIL) {
    goto L21;
   }
   T0 = ECL_CONS_CAR(CLV3);
   goto L19;
L21:;
   T0 = value0;
   goto L19;
L19:;
   T1 = ECL_CONS_CAR(CLV2);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1338]))->cfun.entry(4, T0, T1, v2uiop_lisp_build__context_format, v3uiop_lisp_build__context_arguments) /*  CHECK-LISP-COMPILE-WARNINGS */;
   return value0;
  }
 }
}
/* function definition for CALL-WITH-SAVED-DEFERRED-WARNINGS                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4692call_with_saved_deferred_warnings(volatile cl_narg narg, cl_object volatile v1uiop_lisp_build__thunk, cl_object volatile v2uiop_lisp_build__warnings_file, ...)
{
 cl_object T0;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1403]);
 {
  cl_object volatile v3uiop_lisp_build__source_namestring;
  ecl_va_list args; ecl_va_start(args,v2uiop_lisp_build__warnings_file,narg,2);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1uiop_lisp_build__thunk,env0); /*  THUNK                */
  CLV1 = env0 = CONS(v2uiop_lisp_build__warnings_file,env0); /*  WARNINGS-FILE */
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4692call_with_saved_deferred_warningskeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v3uiop_lisp_build__source_namestring = keyvars[0];
  }
  if (Null(ECL_CONS_CAR(CLV1))){
   goto L1;
  }
  {
   cl_object volatile v4;
   v4 = ecl_make_cclosure_va((cl_objectfn)LC4691__lambda4177,env0,Cblock,0);
   T0 = v4;
  }
  value0 = (cl_env_copy->function=(VV[1397]->symbol.gfdef))->cfun.entry(3, T0, VV[1401], ECL_T) /*  DO-COMPILATION-UNIT */;
  return value0;
L1:;
  value0 = ecl_function_dispatch(cl_env_copy,ECL_CONS_CAR(CLV0))(0);
  return value0;
 }
}
/* local function WITH-SAVED-DEFERRED-WARNINGS                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4693with_saved_deferred_warnings(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6uiop_lisp_build__warnings_file;
  cl_object v7;
  cl_object v8uiop_lisp_build__source_namestring;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v9;
   v9 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v9;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v9;
   v9 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6uiop_lisp_build__warnings_file = v9;
  }
  v7 = si_search_keyword(v5, VV[1406]);
  if (!((v7)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L18;
  }
  v8uiop_lisp_build__source_namestring = ECL_NIL;
  goto L17;
L18:;
  v8uiop_lisp_build__source_namestring = v7;
L17:;
  si_check_keyword(2, v5, VV[1408]);
  T0 = cl_listX(3, ECL_SYM("LAMBDA",454), ECL_NIL, v3);
  T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
  value0 = cl_list(5, VV[1403], T1, v6uiop_lisp_build__warnings_file, VV[1406], v8uiop_lisp_build__source_namestring);
  return value0;
 }
}
static cl_object LC4693with_saved_deferred_warnings_va(cl_narg narg, cl_object v9, cl_object v10, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1407]);
 {
  return LC4693with_saved_deferred_warnings(v9, v10);
 }
}
/* function definition for CURRENT-LISP-FILE-PATHNAME                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4694current_lisp_file_pathname()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*COMPILE-FILE-PATHNAME*",28));
 if (value0!=ECL_NIL) {
  goto L3;
 }
 value0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*LOAD-PATHNAME*",38));
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4694current_lisp_file_pathname_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1410]);
 {
  return L4694current_lisp_file_pathname();
 }
}
/* function definition for LOAD-PATHNAME                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4695load_pathname()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*LOAD-PATHNAME*",38));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4695load_pathname_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1412]);
 {
  return L4695load_pathname();
 }
}
/* function definition for LISPIZE-PATHNAME                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4696lispize_pathname(cl_object v1uiop_lisp_build__input_file)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_make_pathname(4, ECL_SYM("TYPE",1356), VV[1415], ECL_SYM("DEFAULTS",1247), v1uiop_lisp_build__input_file);
 return value0;
}
static cl_object L4696lispize_pathname_va(cl_narg narg, cl_object v2uiop_lisp_build__input_file, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1414]);
 {
  return L4696lispize_pathname(v2uiop_lisp_build__input_file);
 }
}
/* function definition for COMPILE-FILE-TYPE                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4697compile_file_type(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_lisp_build__keys;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_lisp_build__keys = cl_grab_rest_args(args);
  ecl_va_end(args);
  T0 = cl_apply(3, ECL_SYM("COMPILE-FILE-PATHNAME",237), VV[1418], v1uiop_lisp_build__keys);
  value0 = cl_pathname_type(1, T0);
  return value0;
 }
}
/* function definition for CALL-AROUND-HOOK                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4698call_around_hook(cl_object v1uiop_lisp_build__hook, cl_object v2function)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = v1uiop_lisp_build__hook;
 if (value0!=ECL_NIL) {
  goto L4;
 }
 T0 = ECL_SYM("FUNCALL",396);
 goto L2;
L4:;
 T0 = value0;
 goto L2;
L2:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, T0, v2function) /*  CALL-FUNCTION */;
 return value0;
}
static cl_object L4698call_around_hook_va(cl_narg narg, cl_object v3uiop_lisp_build__hook, cl_object v4function, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1420]);
 {
  return L4698call_around_hook(v3uiop_lisp_build__hook, v4function);
 }
}
/* function definition for COMPILE-FILE-PATHNAME*                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4699compile_file_pathname_(cl_narg narg, cl_object v1uiop_lisp_build__input_file, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1422]);
 {
  cl_object v2uiop_lisp_build__keys;
  cl_object v3uiop_lisp_build__output_file;
  ecl_va_list args; ecl_va_start(args,v1uiop_lisp_build__input_file,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4699compile_file_pathname_keys,keyvars,(cl_object*)&v2uiop_lisp_build__keys,TRUE);
   ecl_va_end(args);
   v3uiop_lisp_build__output_file = keyvars[0];
  }
  {
   cl_object v4uiop_lisp_build__keys;
   if (v3uiop_lisp_build__output_file!=ECL_NIL) {
    goto L3;
   }
   T0 = VV[1423];
   goto L2;
L3:;
   T0 = ECL_NIL;
L2:;
   v4uiop_lisp_build__keys = (cl_env_copy->function=ecl_fdefinition(VV[261]))->cfun.entry(2, T0, v2uiop_lisp_build__keys) /*  REMOVE-PLIST-KEYS */;
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v3uiop_lisp_build__output_file) /*  ABSOLUTE-PATHNAME-P */)){
    goto L5;
   }
   {
    cl_object v5type;
    cl_object v6uiop_lisp_build__defaults;
    T0 = cl_apply(2, VV[1417], v4uiop_lisp_build__keys);
    v5type = cl_pathname_type(1, T0);
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(1, v1uiop_lisp_build__input_file) /*  MERGE-PATHNAMES* */;
    v6uiop_lisp_build__defaults = cl_make_pathname(4, ECL_SYM("TYPE",1356), v5type, ECL_SYM("DEFAULTS",1247), T0);
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, v3uiop_lisp_build__output_file, v6uiop_lisp_build__defaults) /*  MERGE-PATHNAMES* */;
    return value0;
   }
L5:;
   T0 = ecl_cmp_symbol_value(cl_env_copy,VV[655]);
   T1 = cl_apply(3, ECL_SYM("COMPILE-FILE-PATHNAME",237), v1uiop_lisp_build__input_file, v4uiop_lisp_build__keys);
   value0 = ecl_function_dispatch(cl_env_copy,T0)(1, T1);
   return value0;
  }
 }
}
/* function definition for COMPILE-FILE*                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4704compile_file_(cl_narg narg, cl_object v1uiop_lisp_build__input_file, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1426]);
 {
  cl_object v2uiop_lisp_build__keys;
  cl_object v3uiop_lisp_build__compile_check;
  cl_object v4uiop_lisp_build__output_file;
  cl_object v5uiop_lisp_build__object_file;
  ecl_va_list args; ecl_va_start(args,v1uiop_lisp_build__input_file,narg,1);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L4704compile_file_keys,keyvars,(cl_object*)&v2uiop_lisp_build__keys,TRUE);
   ecl_va_end(args);
   if (Null(keyvars[4])) {
    v3uiop_lisp_build__compile_check = ecl_cmp_symbol_value(cl_env_copy,VV[1425]);
   } else {
    v3uiop_lisp_build__compile_check = keyvars[0];
   }
   v4uiop_lisp_build__output_file = keyvars[1];
   env0 = ECL_NIL;
   CLV0 = env0 = CONS(keyvars[2],env0);           /*  WARNINGS-FILE           */
   v5uiop_lisp_build__object_file = keyvars[3];
  }
  if (Null(v5uiop_lisp_build__object_file)){
   goto L2;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1417]))->cfun.entry(0) /*  COMPILE-FILE-TYPE */;
  T1 = cl_pathname(v5uiop_lisp_build__object_file);
  if (!(ecl_equal(T0,T1))){
   goto L2;
  }
  cl_format(5, ECL_T, VV[1427], VV[1426], v4uiop_lisp_build__output_file, v5uiop_lisp_build__object_file);
  {
   cl_object v6;
   v6 = v5uiop_lisp_build__object_file;
   {
    cl_object v7;
    v7 = v4uiop_lisp_build__output_file;
    v4uiop_lisp_build__output_file = v6;
    v5uiop_lisp_build__object_file = v7;
   }
  }
L2:;
  {
   cl_object v6uiop_lisp_build__output_file;
   cl_object v7uiop_lisp_build__physical_output_file;
   cl_object env1 = env0;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[261]))->cfun.entry(2, VV[1428], v2uiop_lisp_build__keys) /*  REMOVE-PLIST-KEYS */;
   CLV1 = env1 = CONS(T0,env1);                   /*  KEYWORDS                */
   value0 = v4uiop_lisp_build__output_file;
   if (value0!=ECL_NIL) {
    goto L14;
   }
   v6uiop_lisp_build__output_file = cl_apply(5, VV[1422], v1uiop_lisp_build__input_file, VV[1429], v4uiop_lisp_build__output_file, ECL_CONS_CAR(CLV1));
   goto L12;
L14:;
   v6uiop_lisp_build__output_file = value0;
   goto L12;
L12:;
   v7uiop_lisp_build__physical_output_file = (cl_env_copy->function=ecl_fdefinition(VV[529]))->cfun.entry(1, v6uiop_lisp_build__output_file) /*  PHYSICALIZE-PATHNAME */;
   if (L4251use_ecl_byte_compiler_p()!=ECL_NIL) {
    goto L18;
   }
   value0 = v5uiop_lisp_build__object_file;
   if (value0!=ECL_NIL) {
    goto L21;
   }
   T0 = (cl_env_copy->function=(ECL_SYM("COMPILE-FILE-PATHNAME",237)->symbol.gfdef))->cfun.entry(3, v6uiop_lisp_build__output_file, ECL_SYM("TYPE",1356), ECL_SYM("OBJECT",1315)) /*  COMPILE-FILE-PATHNAME */;
   goto L17;
L21:;
   T0 = value0;
   goto L17;
L18:;
   T0 = ECL_NIL;
L17:;
   CLV2 = env1 = CONS(T0,env1);                   /*  OBJECT-FILE             */
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[979]))->cfun.entry(1, v7uiop_lisp_build__physical_output_file) /*  TMPIZE-PATHNAME */;
   CLV3 = env1 = CONS(T0,env1);                   /*  TMP-FILE                */
   {
    cl_object v8;                                 /*  OUTPUT-TRUENAME         */
    cl_object v9;                                 /*  WARNINGS-P              */
    cl_object v10;                                /*  FAILURE-P               */
    {
     cl_object v11;
     v11 = ecl_make_cclosure_va((cl_objectfn)LC4702__lambda4213,env1,Cblock,1);
     T0 = v11;
    }
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[627]))->cfun.entry(3, v1uiop_lisp_build__input_file, ecl_cmp_symbol_value(cl_env_copy,VV[1302]), T0) /*  CALL-WITH-ENOUGH-PATHNAME */;
    {
     const int v11 = cl_env_copy->nvalues;
     v8 = value0;
     cl_object v12;
     v12 = (v11<=1)? ECL_NIL : cl_env_copy->values[1];
     v9 = v12;
     v12 = (v11<=2)? ECL_NIL : cl_env_copy->values[2];
     v10 = v12;
    }
    if (Null(v8)){
     goto L26;
    }
    if (Null(LC4703check_flag(v10, ecl_cmp_symbol_value(cl_env_copy,VV[1301])))){
     goto L26;
    }
    if (Null(LC4703check_flag(v9, ecl_cmp_symbol_value(cl_env_copy,VV[1299])))){
     goto L26;
    }
    if (Null(ECL_CONS_CAR(CLV2))){
     goto L31;
    }
    T0 = ecl_list1(ECL_CONS_CAR(CLV2));
    v8 = (cl_env_copy->function=ecl_fdefinition(VV[1438]))->cfun.entry(3, ECL_CONS_CAR(CLV3), VV[1075], T0) /*  BUILD-FASL */;
L31:;
    if (Null(v3uiop_lisp_build__compile_check)){
     goto L34;
    }
    if (Null(cl_apply(5, v3uiop_lisp_build__compile_check, v1uiop_lisp_build__input_file, VV[1429], v8, ECL_CONS_CAR(CLV1)))){
     goto L26;
    }
    goto L27;
L34:;
L27:;
    (cl_env_copy->function=ecl_fdefinition(VV[782]))->cfun.entry(1, v7uiop_lisp_build__physical_output_file) /*  DELETE-FILE-IF-EXISTS */;
    if (Null(v8)){
     goto L25;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[786]))->cfun.entry(2, v8, v7uiop_lisp_build__physical_output_file) /*  RENAME-FILE-OVERWRITING-TARGET */;
    v8 = cl_truename(v7uiop_lisp_build__physical_output_file);
    goto L25;
L26:;
    (cl_env_copy->function=ecl_fdefinition(VV[782]))->cfun.entry(1, v8) /*  DELETE-FILE-IF-EXISTS */;
    v8 = ECL_NIL;
L25:;
    cl_env_copy->nvalues = 3;
    cl_env_copy->values[2] = v10;
    cl_env_copy->values[1] = v9;
    cl_env_copy->values[0] = v8;
    return cl_env_copy->values[0];
   }
  }
 }
}
/* function definition for LOAD*                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4706load_(cl_narg narg, cl_object v1uiop_lisp_build__x, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1440]);
 {
  cl_object v2uiop_lisp_build__keys;
  ecl_va_list args; ecl_va_start(args,v1uiop_lisp_build__x,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1uiop_lisp_build__x,env0);  /*  X                       */
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v2uiop_lisp_build__keys,TRUE);
  CLV1 = env0 = CONS(v2uiop_lisp_build__keys,env0); /*  KEYS                  */
  ecl_va_end(args);
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4705__lambda4236,env0,Cblock,0);
   T0 = v3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1322]))->cfun.entry(1, T0) /*  CALL-WITH-MUFFLED-LOADER-CONDITIONS */;
  return value0;
 }
}
/* function definition for LOAD-FROM-STRING                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4707load_from_string(cl_object volatile v1string)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v2uiop_lisp_build__s;
  v2uiop_lisp_build__s = cl_make_string_input_stream(3, v1string, ecl_make_int8_t(0), ECL_NIL);
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    cl_env_copy->values[0] = (cl_env_copy->function=ecl_fdefinition(VV[1440]))->cfun.entry(1, v2uiop_lisp_build__s) /*  LOAD* */;
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   cl_close(1, v2uiop_lisp_build__s);
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
}
static cl_object L4707load_from_string_va(cl_narg narg, cl_object v3string, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1444]);
 {
  return L4707load_from_string(v3string);
 }
}
/* function definition for COMBINE-FASLS                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4708combine_fasls(cl_object v1uiop_lisp_build__inputs, cl_object v2uiop_lisp_build__output)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[459]))->cfun.entry(0) /*  IMPLEMENTATION-TYPE */;
 value0 = cl_error(5, VV[1447], T0, VV[1446], v1uiop_lisp_build__inputs, v2uiop_lisp_build__output);
 return value0;
}
static cl_object L4708combine_fasls_va(cl_narg narg, cl_object v3uiop_lisp_build__inputs, cl_object v4uiop_lisp_build__output, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1446]);
 {
  return L4708combine_fasls(v3uiop_lisp_build__inputs, v4uiop_lisp_build__output);
 }
}
/* local function LAMBDA4242                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4710__lambda4242()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC4709__lambda4244_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4710__lambda4242_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1450]);
 {
  return LC4710__lambda4242();
 }
}
/* function definition for CONFIGURATION-INHERITANCE-DIRECTIVE-P              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4711configuration_inheritance_directive_p(cl_object v1uiop_configuration__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3;
  v2 = v1uiop_configuration__x;
  v3 = VV[1458];
  value0 = ecl_memql(v2,v3);
 }
 if (value0!=ECL_NIL) {
  goto L3;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[253]))->cfun.entry(2, v1uiop_configuration__x, ecl_make_int8_t(1)) /*  LENGTH=N-P */)){
  goto L8;
 }
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_car(v1uiop_configuration__x);
  v3 = v2;
  v4 = VV[1458];
  value0 = ecl_memql(v3,v4);
  cl_env_copy->nvalues = 1;
  return value0;
 }
L8:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4711configuration_inheritance_directive_p_va(cl_narg narg, cl_object v5uiop_configuration__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1457]);
 {
  return L4711configuration_inheritance_directive_p(v5uiop_configuration__x);
 }
}
/* function definition for REPORT-INVALID-FORM                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4712report_invalid_form(cl_narg narg, cl_object v1uiop_configuration__reporter, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1460]);
 {
  cl_object v2uiop_configuration__args;
  ecl_va_list args; ecl_va_start(args,v1uiop_configuration__reporter,narg,1);
  v2uiop_configuration__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (!(v1uiop_configuration__reporter==ECL_NIL)){
   goto L1;
  }
  value0 = cl_apply(3, ECL_SYM("ERROR",339), VV[1449], v2uiop_configuration__args);
  return value0;
L1:;
  if (Null(cl_functionp(v1uiop_configuration__reporter))){
   goto L3;
  }
  value0 = cl_apply(2, v1uiop_configuration__reporter, v2uiop_configuration__args);
  return value0;
L3:;
  if (ECL_SYMBOLP(v1uiop_configuration__reporter)) {
   goto L7;
  }
  if (!(ECL_STRINGP(v1uiop_configuration__reporter))){
   goto L5;
  }
  goto L6;
L7:;
L6:;
  value0 = cl_apply(3, ECL_SYM("ERROR",339), v1uiop_configuration__reporter, v2uiop_configuration__args);
  return value0;
L5:;
  if (!(ECL_CONSP(v1uiop_configuration__reporter))){
   goto L9;
  }
  T0 = ecl_append(v1uiop_configuration__reporter,v2uiop_configuration__args);
  value0 = cl_apply(2, ECL_SYM("APPLY",91), T0);
  return value0;
L9:;
  value0 = si_etypecase_error(v1uiop_configuration__reporter, VV[1461]);
  return value0;
 }
}
/* function definition for VALIDATE-CONFIGURATION-FORM                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4713validate_configuration_form(cl_narg narg, cl_object v1uiop_configuration__form, cl_object v2uiop_configuration__tag, cl_object v3uiop_configuration__directive_validator, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[1464]);
 {
  cl_object v4uiop_configuration__location;
  cl_object v5uiop_configuration__invalid_form_reporter;
  ecl_va_list args; ecl_va_start(args,v3uiop_configuration__directive_validator,narg,3);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4713validate_configuration_formkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v4uiop_configuration__location = keyvars[0];
   v5uiop_configuration__invalid_form_reporter = keyvars[1];
  }
  if (!(ECL_CONSP(v1uiop_configuration__form))){
   goto L4;
  }
  T0 = ecl_car(v1uiop_configuration__form);
  if ((T0)==(v2uiop_configuration__tag)) {
   goto L1;
  }
  goto L2;
L4:;
  goto L2;
L2:;
  T0 = ECL_T;
  ecl_cmp_setq(cl_env_copy,VV[1463],T0);
  (cl_env_copy->function=ecl_fdefinition(VV[1460]))->cfun.entry(5, v5uiop_configuration__invalid_form_reporter, VV[1135], v1uiop_configuration__form, ECL_SYM("LOCATION",1003), v4uiop_configuration__location) /*  REPORT-INVALID-FORM */;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L1:;
  {
   cl_object v6uiop_configuration__inherit;
   v6uiop_configuration__inherit = ecl_make_int8_t(0);
   {
    cl_object v7uiop_configuration__ignore_invalid_p;
    v7uiop_configuration__ignore_invalid_p = ECL_NIL;
    {
     cl_object v8uiop_configuration__x;
     v8uiop_configuration__x = ecl_list1(v2uiop_configuration__tag);
     {
      cl_object v9;
      cl_object v10uiop_configuration__directive;
      cl_object v11;
      {
       cl_object v12;
       v12 = ecl_cdr(v1uiop_configuration__form);
       if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v9 = v12;
      }
      v10uiop_configuration__directive = ECL_NIL;
      v11 = v9;
L17:;
      if (!(ecl_endp(v11))){
       goto L19;
      }
      goto L18;
L19:;
      v10uiop_configuration__directive = ECL_CONS_CAR(v11);
      {
       cl_object v12;
       v12 = ECL_CONS_CDR(v11);
       if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v11 = v12;
      }
      if (Null((cl_env_copy->function=ecl_fdefinition(VV[1457]))->cfun.entry(1, v10uiop_configuration__directive) /*  CONFIGURATION-INHERITANCE-DIRECTIVE-P */)){
       goto L29;
      }
      v6uiop_configuration__inherit = ecl_plus(v6uiop_configuration__inherit,ecl_make_int8_t(1));
      goto L28;
L29:;
      if (!((v10uiop_configuration__directive)==(VV[1465]))){
       goto L33;
      }
      v7uiop_configuration__ignore_invalid_p = ECL_T;
      goto L28;
L33:;
      if (Null(ecl_function_dispatch(cl_env_copy,v3uiop_configuration__directive_validator)(1, v10uiop_configuration__directive))){
       goto L37;
      }
      goto L28;
L37:;
      if (Null(v7uiop_configuration__ignore_invalid_p)){
       goto L39;
      }
      goto L27;
L39:;
      T0 = ECL_T;
      ecl_cmp_setq(cl_env_copy,VV[1463],T0);
      (cl_env_copy->function=ecl_fdefinition(VV[1460]))->cfun.entry(5, v5uiop_configuration__invalid_form_reporter, VV[1135], v10uiop_configuration__directive, ECL_SYM("LOCATION",1003), v4uiop_configuration__location) /*  REPORT-INVALID-FORM */;
      goto L27;
L28:;
      v8uiop_configuration__x = CONS(v10uiop_configuration__directive,v8uiop_configuration__x);
L27:;
      goto L17;
L18:;
      if (ecl_number_equalp(v6uiop_configuration__inherit,ecl_make_int8_t(1))) {
       goto L47;
      }
      (cl_env_copy->function=ecl_fdefinition(VV[1460]))->cfun.entry(9, v5uiop_configuration__invalid_form_reporter, VV[1135], v1uiop_configuration__form, ECL_SYM("LOCATION",1003), v4uiop_configuration__location, VV[1466], VV[1467], VV[1468], VV[1458]) /*  REPORT-INVALID-FORM */;
L47:;
      value0 = cl_nreverse(v8uiop_configuration__x);
      return value0;
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 1;
      return value0;
     }
    }
   }
  }
 }
}
/* function definition for VALIDATE-CONFIGURATION-FILE                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4714validate_configuration_file(cl_narg narg, cl_object v1uiop_configuration__file, cl_object v2uiop_configuration__validator, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1470]);
 {
  cl_object v3uiop_configuration__description;
  ecl_va_list args; ecl_va_start(args,v2uiop_configuration__validator,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4714validate_configuration_filekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v3uiop_configuration__description = keyvars[0];
  }
  {
   cl_object v4uiop_configuration__forms;
   v4uiop_configuration__forms = (cl_env_copy->function=ecl_fdefinition(VV[913]))->cfun.entry(1, v1uiop_configuration__file) /*  READ-FILE-FORMS */;
   if ((cl_env_copy->function=ecl_fdefinition(VV[253]))->cfun.entry(2, v4uiop_configuration__forms, ecl_make_int8_t(1)) /*  LENGTH=N-P */!=ECL_NIL) {
    goto L2;
   }
   cl_error(3, VV[1471], v3uiop_configuration__description, v4uiop_configuration__forms);
L2:;
   T0 = ecl_car(v4uiop_configuration__forms);
   value0 = ecl_function_dispatch(cl_env_copy,v2uiop_configuration__validator)(3, T0, ECL_SYM("LOCATION",1003), v1uiop_configuration__file);
   return value0;
  }
 }
}
/* function definition for VALIDATE-CONFIGURATION-DIRECTORY                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4716validate_configuration_directory(volatile cl_narg narg, cl_object volatile v1directory, cl_object volatile v2uiop_configuration__tag, cl_object volatile v3uiop_configuration__validator, ...)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[1473]);
 {
  cl_object volatile v4uiop_configuration__invalid_form_reporter;
  ecl_va_list args; ecl_va_start(args,v3uiop_configuration__validator,narg,3);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4716validate_configuration_directorykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v4uiop_configuration__invalid_form_reporter = keyvars[0];
  }
  {
   volatile cl_object v5uiop_configuration__files;
   {
    volatile cl_object env1 = env0;
    env1 = ECL_NIL;
    CLV0 = env1 = CONS(ECL_NIL,env1);
    {
     volatile cl_object env2 = env1;
     CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY      */
     {
      ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
      if (__ecl_frs_push_result!=0) {
      if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
       goto L3;
      }
      ecl_internal_error("GO found an inexistent tag");
      } else {
      {
       cl_object v6;
       v6 = ecl_make_cclosure_va((cl_objectfn)LC4715__lambda4320,env2,Cblock,1);
       T1 = v6;
      }
      T2 = CONS(ECL_SYM("ERROR",339),T1);
      T3 = ecl_list1(T2);
      T4 = CONS(T3,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
      ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T4); /*  *HANDLER-CLUSTERS* */
      T1 = cl_make_pathname(6, ECL_SYM("NAME",1309), ecl_cmp_symbol_value(cl_env_copy,VV[632]), ECL_SYM("TYPE",1356), VV[1476], ECL_SYM("DEFAULTS",1247), v1directory);
      T2 = (cl_env_copy->function=ecl_fdefinition(VV[685]))->cfun.entry(1, T1) /*  DIRECTORY* */;
      T0 = cl_remove_if(2, VV[548], T2);
      ecl_frs_pop_n(cl_env_copy, 1);
      ecl_bds_unwind1(cl_env_copy);
      goto L2;
L3:;
      {
       cl_object v6condition;
       v6condition = ECL_CONS_CAR(CLV0);
       cl_env_copy->nvalues = 2;
       cl_env_copy->values[1] = v6condition;
       cl_env_copy->values[0] = ECL_NIL;
       T0 = cl_env_copy->values[0];
       ecl_frs_pop_n(cl_env_copy, 1);
       goto L2;
      }
      }
     }
    }
   }
L2:;
   T1 = (ECL_SYM("STRING<",823)->symbol.gfdef);
   T2 = (ECL_SYM("NAMESTRING",581)->symbol.gfdef);
   v5uiop_configuration__files = cl_sort(4, T0, T1, ECL_SYM("KEY",1297), T2);
   {
    cl_object v6;
    cl_object v7uiop_configuration__file;
    cl_object v8;
    {
     cl_object v9;
     v9 = v5uiop_configuration__files;
     if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v6 = v9;
    }
    v7uiop_configuration__file = ECL_NIL;
    v8 = v6;
    {
     cl_object v9;
     cl_object v10;
     v9 = ecl_list1(ECL_NIL);
     v10 = v9;
L18:;
     if (!(ecl_endp(v8))){
      goto L20;
     }
     goto L19;
L20:;
     v7uiop_configuration__file = ECL_CONS_CAR(v8);
     {
      cl_object v11;
      v11 = ECL_CONS_CDR(v8);
      if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v8 = v11;
     }
     {
      cl_object v11;
      {
       cl_object v12uiop_configuration__ignore_invalid_p;
       v12uiop_configuration__ignore_invalid_p = ECL_NIL;
       {
        cl_object v13;
        cl_object v14uiop_configuration__form;
        cl_object v15;
        {
         cl_object v16;
         v16 = (cl_env_copy->function=ecl_fdefinition(VV[913]))->cfun.entry(1, v7uiop_configuration__file) /*  READ-FILE-FORMS */;
         if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         v13 = v16;
        }
        v14uiop_configuration__form = ECL_NIL;
        v15 = v13;
        {
         cl_object v16;
         cl_object v17;
         v16 = ecl_list1(ECL_NIL);
         v17 = v16;
L40:;
         if (!(ecl_endp(v15))){
          goto L42;
         }
         goto L41;
L42:;
         v14uiop_configuration__form = ECL_CONS_CAR(v15);
         {
          cl_object v18;
          v18 = ECL_CONS_CDR(v15);
          if (ecl_unlikely(!ECL_LISTP(v18))) FEtype_error_list(v18);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          v15 = v18;
         }
         if (!((v14uiop_configuration__form)==(VV[1465]))){
          goto L51;
         }
         v12uiop_configuration__ignore_invalid_p = ECL_T;
         goto L50;
L51:;
         if (Null(ecl_function_dispatch(cl_env_copy,v3uiop_configuration__validator)(1, v14uiop_configuration__form))){
          goto L54;
         }
         {
          cl_object v18;
          v18 = v17;
          if (ecl_unlikely(ECL_ATOM(v18))) FEtype_error_cons(v18);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T2 = v18;
         }
         v17 = ecl_list1(v14uiop_configuration__form);
         (ECL_CONS_CDR(T2)=v17,T2);
         goto L50;
L54:;
         if (Null(v12uiop_configuration__ignore_invalid_p)){
          goto L60;
         }
         T2 = ECL_T;
         ecl_cmp_setq(cl_env_copy,VV[1463],T2);
         goto L50;
L60:;
         (cl_env_copy->function=ecl_fdefinition(VV[1460]))->cfun.entry(5, v4uiop_configuration__invalid_form_reporter, VV[1135], v14uiop_configuration__form, ECL_SYM("LOCATION",1003), v7uiop_configuration__file) /*  REPORT-INVALID-FORM */;
L50:;
         goto L40;
L41:;
         T1 = ecl_cdr(v16);
         goto L31;
        }
       }
      }
L31:;
      v11 = cl_copy_list(T1);
      {
       cl_object v12;
       v12 = v10;
       if (ecl_unlikely(ECL_ATOM(v12))) FEtype_error_cons(v12);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T1 = v12;
      }
      (ECL_CONS_CDR(T1)=v11,T1);
      if (Null(v11)){
       goto L28;
      }
     }
     T1 = ecl_cdr(v10);
     v10 = ecl_last(T1,1);
L28:;
     goto L18;
L19:;
     T0 = ecl_cdr(v9);
     goto L10;
    }
   }
L10:;
   T1 = ecl_append(T0,VV[1477]);
   value0 = CONS(v2uiop_configuration__tag,T1);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for RESOLVE-RELATIVE-LOCATION                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4717resolve_relative_location(cl_narg narg, cl_object v1uiop_configuration__x, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1479]);
 {
  cl_object v2uiop_configuration__ensure_directory;
  cl_object v3wilden;
  ecl_va_list args; ecl_va_start(args,v1uiop_configuration__x,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4717resolve_relative_locationkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2uiop_configuration__ensure_directory = keyvars[0];
   v3wilden = keyvars[1];
  }
  if (!(v1uiop_configuration__x==ECL_NIL)){
   goto L2;
  }
  T0 = ECL_NIL;
  goto L1;
L2:;
  if (Null(cl_pathnamep(v1uiop_configuration__x))){
   goto L4;
  }
  T0 = v1uiop_configuration__x;
  goto L1;
L4:;
  if (!(ECL_STRINGP(v1uiop_configuration__x))){
   goto L6;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(3, v1uiop_configuration__x, VV[595], v2uiop_configuration__ensure_directory) /*  PARSE-UNIX-NAMESTRING */;
  goto L1;
L6:;
  if (!(ECL_CONSP(v1uiop_configuration__x))){
   goto L8;
  }
  T1 = ecl_cdr(v1uiop_configuration__x);
  if (!(T1==ECL_NIL)){
   goto L10;
  }
  T1 = ecl_car(v1uiop_configuration__x);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1479]))->cfun.entry(5, T1, VV[595], v2uiop_configuration__ensure_directory, VV[1480], v3wilden) /*  RESOLVE-RELATIVE-LOCATION */;
  goto L1;
L10:;
  {
   cl_object v4car;
   T1 = ecl_car(v1uiop_configuration__x);
   v4car = (cl_env_copy->function=ecl_fdefinition(VV[1479]))->cfun.entry(5, T1, VV[595], ECL_T, VV[1480], ECL_NIL) /*  RESOLVE-RELATIVE-LOCATION */;
   T1 = ecl_cdr(v1uiop_configuration__x);
   T2 = (cl_env_copy->function=ecl_fdefinition(VV[1479]))->cfun.entry(5, T1, VV[595], v2uiop_configuration__ensure_directory, VV[1480], v3wilden) /*  RESOLVE-RELATIVE-LOCATION */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, T2, v4car) /*  MERGE-PATHNAMES* */;
   goto L1;
  }
L8:;
  if (Null(cl_typep(2, v1uiop_configuration__x, VV[1481]))){
   goto L13;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,VV[637]);
  goto L1;
L13:;
  if (Null(cl_typep(2, v1uiop_configuration__x, VV[1482]))){
   goto L15;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,VV[638]);
  goto L1;
L15:;
  if (Null(cl_typep(2, v1uiop_configuration__x, VV[1483]))){
   goto L17;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,VV[635]);
  goto L1;
L17:;
  if (Null(cl_typep(2, v1uiop_configuration__x, VV[1484]))){
   goto L19;
  }
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[472]))->cfun.entry(0) /*  IMPLEMENTATION-IDENTIFIER */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(3, T1, VV[595], ECL_T) /*  PARSE-UNIX-NAMESTRING */;
  goto L1;
L19:;
  if (Null(cl_typep(2, v1uiop_configuration__x, VV[1485]))){
   goto L21;
  }
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[459]))->cfun.entry(0) /*  IMPLEMENTATION-TYPE */;
  T2 = cl_string_downcase(1, T1);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(3, T2, VV[595], ECL_T) /*  PARSE-UNIX-NAMESTRING */;
  goto L1;
L21:;
  if (Null(cl_typep(2, v1uiop_configuration__x, VV[1486]))){
   goto L23;
  }
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[477]))->cfun.entry(0) /*  HOSTNAME */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(3, T1, VV[595], ECL_T) /*  PARSE-UNIX-NAMESTRING */;
  goto L1;
L23:;
  T0 = si_etypecase_error(v1uiop_configuration__x, VV[1487]);
L1:;
  if (Null(v3wilden)){
   goto L27;
  }
  if (cl_pathnamep(v1uiop_configuration__x)!=ECL_NIL) {
   goto L27;
  }
  if (!((v1uiop_configuration__x)==(VV[1489]))){
   goto L35;
  }
  value0 = VV[1488];
  goto L33;
L35:;
  value0 = ECL_NIL;
  goto L33;
L33:;
  if (value0!=ECL_NIL) {
   goto L32;
  }
  if (!((v1uiop_configuration__x)==(VV[1490]))){
   goto L39;
  }
  value0 = VV[1491];
  goto L37;
L39:;
  value0 = ECL_NIL;
  goto L37;
L37:;
  if (value0!=ECL_NIL) {
   goto L32;
  }
  if (!((v1uiop_configuration__x)==(VV[1492]))){
   goto L42;
  }
  T2 = VV[1493];
  goto L30;
L42:;
  T2 = ECL_NIL;
  goto L30;
L32:;
  T2 = value0;
  goto L30;
L30:;
  T1 = Null(T2)?ECL_T:ECL_NIL;
  goto L25;
L27:;
  T1 = ECL_NIL;
  goto L25;
L25:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[596]))->cfun.entry(5, T0, VV[1480], T1, VV[609], ECL_T) /*  ENSURE-PATHNAME */;
  return value0;
 }
}
/* function definition for RESOLVE-ABSOLUTE-LOCATION                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4718resolve_absolute_location(cl_narg narg, cl_object v1uiop_configuration__x, ...)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1497]);
 {
  cl_object v2uiop_configuration__ensure_directory;
  cl_object v3wilden;
  ecl_va_list args; ecl_va_start(args,v1uiop_configuration__x,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4718resolve_absolute_locationkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2uiop_configuration__ensure_directory = keyvars[0];
   v3wilden = keyvars[1];
  }
  if (!(v1uiop_configuration__x==ECL_NIL)){
   goto L2;
  }
  T0 = ECL_NIL;
  goto L1;
L2:;
  if (Null(cl_pathnamep(v1uiop_configuration__x))){
   goto L4;
  }
  T0 = v1uiop_configuration__x;
  goto L1;
L4:;
  if (!(ECL_STRINGP(v1uiop_configuration__x))){
   goto L6;
  }
  {
   cl_object v4uiop_configuration__p;
   v4uiop_configuration__p = cl_parse_namestring(1, v1uiop_configuration__x);
   if (Null(v2uiop_configuration__ensure_directory)){
    goto L9;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[565]))->cfun.entry(1, v4uiop_configuration__p) /*  ENSURE-DIRECTORY-PATHNAME */;
   goto L1;
L9:;
   T0 = v4uiop_configuration__p;
   goto L1;
  }
L6:;
  if (!(ECL_CONSP(v1uiop_configuration__x))){
   goto L11;
  }
  T1 = ecl_cdr(v1uiop_configuration__x);
  if (!(T1==ECL_NIL)){
   goto L13;
  }
  T1 = ecl_car(v1uiop_configuration__x);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1497]))->cfun.entry(5, T1, VV[595], v2uiop_configuration__ensure_directory, VV[1480], v3wilden) /*  RESOLVE-ABSOLUTE-LOCATION */;
  return value0;
L13:;
  T1 = ecl_cdr(v1uiop_configuration__x);
  T2 = (cl_env_copy->function=ecl_fdefinition(VV[1479]))->cfun.entry(5, T1, VV[595], v2uiop_configuration__ensure_directory, VV[1480], v3wilden) /*  RESOLVE-RELATIVE-LOCATION */;
  T3 = ecl_car(v1uiop_configuration__x);
  T4 = (cl_env_copy->function=ecl_fdefinition(VV[1497]))->cfun.entry(5, T3, VV[595], ECL_T, VV[1480], ECL_NIL) /*  RESOLVE-ABSOLUTE-LOCATION */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, T2, T4) /*  MERGE-PATHNAMES* */;
  return value0;
L11:;
  if (Null(cl_typep(2, v1uiop_configuration__x, VV[1498]))){
   goto L15;
  }
  {
   cl_object v5uiop_configuration__p;
   v5uiop_configuration__p = cl_make_pathname(2, ECL_SYM("DIRECTORY",1250), VV[499]);
   if (Null(v3wilden)){
    goto L18;
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[640]))->cfun.entry(1, v5uiop_configuration__p) /*  WILDEN */;
   return value0;
L18:;
   value0 = v5uiop_configuration__p;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L15:;
  if (Null(cl_typep(2, v1uiop_configuration__x, VV[1499]))){
   goto L20;
  }
  T0 = cl_user_homedir_pathname(0);
  goto L1;
L20:;
  if (Null(cl_typep(2, v1uiop_configuration__x, VV[1500]))){
   goto L22;
  }
  value0 = ecl_cmp_symbol_value(cl_env_copy,VV[1495]);
  if (value0!=ECL_NIL) {
   goto L26;
  }
  T2 = (cl_env_copy->function=ecl_fdefinition(VV[1412]))->cfun.entry(0) /*  LOAD-PATHNAME */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[555]))->cfun.entry(1, T2) /*  PATHNAME-DIRECTORY-PATHNAME */;
  goto L24;
L26:;
  T1 = value0;
  goto L24;
L24:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1497]))->cfun.entry(5, T1, VV[595], ECL_T, VV[1480], ECL_NIL) /*  RESOLVE-ABSOLUTE-LOCATION */;
  goto L1;
L22:;
  if (Null(cl_typep(2, v1uiop_configuration__x, VV[1501]))){
   goto L28;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1497]))->cfun.entry(5, ecl_cmp_symbol_value(cl_env_copy,VV[1496]), VV[595], ECL_T, VV[1480], ECL_NIL) /*  RESOLVE-ABSOLUTE-LOCATION */;
  goto L1;
L28:;
  T0 = si_etypecase_error(v1uiop_configuration__x, VV[1502]);
L1:;
  if (Null(v3wilden)){
   goto L32;
  }
  T2 = cl_pathnamep(v1uiop_configuration__x);
  T1 = Null(T2)?ECL_T:ECL_NIL;
  goto L30;
L32:;
  T1 = ECL_NIL;
  goto L30;
L30:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[596]))->cfun.entry(7, T0, VV[1480], T1, ECL_SYM("RESOLVE-SYMLINKS",1950), ecl_cmp_symbol_value(cl_env_copy,VV[715]), VV[737], ECL_T) /*  ENSURE-PATHNAME */;
  return value0;
 }
}
/* function definition for RESOLVE-LOCATION                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4719resolve_location(cl_narg narg, cl_object v1uiop_configuration__x, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1504]);
 {
  cl_object v2uiop_configuration__ensure_directory;
  cl_object v3wilden;
  cl_object v4directory;
  ecl_va_list args; ecl_va_start(args,v1uiop_configuration__x,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L4719resolve_locationkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2uiop_configuration__ensure_directory = keyvars[0];
   v3wilden = keyvars[1];
   v4directory = keyvars[2];
  }
  {
   cl_object v5uiop_configuration__dirp;
   value0 = v4directory;
   if (value0!=ECL_NIL) {
    goto L3;
   }
   v5uiop_configuration__dirp = v2uiop_configuration__ensure_directory;
   goto L1;
L3:;
   v5uiop_configuration__dirp = value0;
   goto L1;
L1:;
   {
    cl_object v6;
    if (!(ECL_ATOM(v1uiop_configuration__x))){
     goto L6;
    }
    v6 = ecl_list1(v1uiop_configuration__x);
    goto L5;
L6:;
    v6 = v1uiop_configuration__x;
L5:;
    {
     cl_object v7;
     cl_object v8first;
     v7 = v6;
     if (!(v7==ECL_NIL)){
      goto L10;
     }
     si_dm_too_few_arguments(v6);
L10:;
     {
      cl_object v9;
      v9 = ecl_car(v7);
      v7 = ecl_cdr(v7);
      v8first = v9;
     }
     {
      cl_object v9uiop_configuration__path;
      if (v5uiop_configuration__dirp!=ECL_NIL) {
       goto L23;
      }
      if (Null(v7)){
       goto L21;
      }
      goto L22;
L23:;
L22:;
      T0 = ECL_T;
      goto L19;
L21:;
      T0 = ECL_NIL;
      goto L19;
L19:;
      if (Null(v3wilden)){
       goto L27;
      }
      T1 = ecl_make_bool(v7==ECL_NIL);
      goto L25;
L27:;
      T1 = ECL_NIL;
      goto L25;
L25:;
      value0 = (cl_env_copy->function=ecl_fdefinition(VV[1497]))->cfun.entry(5, v8first, VV[595], T0, VV[1480], T1) /*  RESOLVE-ABSOLUTE-LOCATION */;
      if (value0!=ECL_NIL) {
       goto L17;
      }
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 1;
      return value0;
L17:;
      v9uiop_configuration__path = value0;
      goto L15;
L15:;
      {
       cl_object v10;
       cl_object v11uiop_configuration__element;
       cl_object v12uiop_configuration__morep;
       v10 = v7;
       v11uiop_configuration__element = ECL_NIL;
       v12uiop_configuration__morep = ECL_NIL;
       {
        cl_object v13uiop_configuration__dir;
        v13uiop_configuration__dir = ECL_NIL;
        {
         cl_object v14uiop_configuration__wild;
         v14uiop_configuration__wild = ECL_NIL;
         {
          cl_object v15uiop_configuration__sub;
          v15uiop_configuration__sub = ECL_NIL;
L35:;
          if (!(ECL_ATOM(v10))){
          goto L37;
          }
          goto L36;
L37:;
          {
          cl_object v16;
          v16 = v10;
          v11uiop_configuration__element = ecl_car(v16);
          v16 = ecl_cdr(v16);
          v12uiop_configuration__morep = v16;
          }
          v10 = ECL_CONS_CDR(v10);
          if (v12uiop_configuration__morep!=ECL_NIL) {
          goto L53;
          }
          if (Null(v5uiop_configuration__dirp)){
          goto L51;
          }
          goto L52;
L53:;
L52:;
          v13uiop_configuration__dir = ECL_T;
          goto L49;
L51:;
          v13uiop_configuration__dir = ECL_NIL;
          goto L49;
L49:;
          if (Null(v3wilden)){
          goto L58;
          }
          v14uiop_configuration__wild = Null(v12uiop_configuration__morep)?ECL_T:ECL_NIL;
          goto L56;
L58:;
          v14uiop_configuration__wild = ECL_NIL;
          goto L56;
L56:;
          T0 = (cl_env_copy->function=ecl_fdefinition(VV[1479]))->cfun.entry(5, v11uiop_configuration__element, VV[595], v13uiop_configuration__dir, VV[1480], v14uiop_configuration__wild) /*  RESOLVE-RELATIVE-LOCATION */;
          v15uiop_configuration__sub = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, T0, v9uiop_configuration__path) /*  MERGE-PATHNAMES* */;
          if (Null((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v15uiop_configuration__sub) /*  ABSOLUTE-PATHNAME-P */)){
          goto L64;
          }
          v9uiop_configuration__path = (cl_env_copy->function=ecl_fdefinition(VV[716]))->cfun.entry(1, v15uiop_configuration__sub) /*  RESOLVE-SYMLINKS* */;
          goto L63;
L64:;
          v9uiop_configuration__path = v15uiop_configuration__sub;
L63:;
          goto L35;
L36:;
          value0 = v9uiop_configuration__path;
          cl_env_copy->nvalues = 1;
          return value0;
         }
        }
       }
      }
     }
    }
   }
  }
 }
}
/* function definition for LOCATION-DESIGNATOR-P                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4722location_designator_p(cl_object v1uiop_configuration__x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = ecl_make_cfun_va((cl_objectfn)LC4721relative_component_p_va,ECL_NIL,Cblock,1);
  if (!((v1uiop_configuration__x)==(ECL_NIL))){
   goto L9;
  }
  value0 = VV[137];
  goto L7;
L9:;
  value0 = ECL_NIL;
  goto L7;
L7:;
  if (value0!=ECL_NIL) {
   goto L6;
  }
  if (!((v1uiop_configuration__x)==(ECL_T))){
   goto L12;
  }
  value0 = VV[138];
  goto L4;
L12:;
  value0 = ECL_NIL;
  goto L4;
L6:;
  goto L4;
L4:;
  if (value0!=ECL_NIL) {
   goto L3;
  }
  value0 = LC4720absolute_component_p(v1uiop_configuration__x);
  if (value0!=ECL_NIL) {
   goto L3;
  }
  if (!(ECL_CONSP(v1uiop_configuration__x))){
   goto L16;
  }
  T0 = ecl_car(v1uiop_configuration__x);
  if (Null(LC4720absolute_component_p(T0))){
   goto L16;
  }
  T0 = ecl_cdr(v1uiop_configuration__x);
  value0 = cl_every(2, v2, T0);
  return value0;
L16:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4722location_designator_p_va(cl_narg narg, cl_object v3uiop_configuration__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1506]);
 {
  return L4722location_designator_p(v3uiop_configuration__x);
 }
}
/* function definition for LOCATION-FUNCTION-P                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4723location_function_p(cl_object v1uiop_configuration__x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[253]))->cfun.entry(2, v1uiop_configuration__x, ecl_make_int8_t(2)) /*  LENGTH=N-P */)){
  goto L3;
 }
 T0 = ecl_car(v1uiop_configuration__x);
 value0 = ecl_make_bool((T0)==(ECL_SYM("FUNCTION",1273)));
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4723location_function_p_va(cl_narg narg, cl_object v2uiop_configuration__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1519]);
 {
  return L4723location_function_p(v2uiop_configuration__x);
 }
}
/* function definition for REGISTER-CLEAR-CONFIGURATION-HOOK                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4724register_clear_configuration_hook(cl_narg narg, cl_object v1uiop_configuration__hook_function, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1522]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1522]);
 {
  cl_object v2uiop_configuration__call_now_p;
  va_list args; va_start(args,v1uiop_configuration__hook_function);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_configuration__call_now_p = ECL_NIL;
   } else {
    i++;
    v2uiop_configuration__call_now_p = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[359]))->cfun.entry(3, VV[1521], v1uiop_configuration__hook_function, v2uiop_configuration__call_now_p) /*  REGISTER-HOOK-FUNCTION */;
  return value0;
 }
}
/* function definition for CLEAR-CONFIGURATION                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4725clear_configuration()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[357]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[1521])) /*  CALL-FUNCTIONS */;
 return value0;
}
static cl_object L4725clear_configuration_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1524]);
 {
  return L4725clear_configuration();
 }
}
/* function definition for UPGRADE-CONFIGURATION                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4726upgrade_configuration()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1463]))){
  goto L2;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[1524]))->cfun.entry(0) /*  CLEAR-CONFIGURATION */;
 T0 = ECL_NIL;
 ecl_cmp_setq(cl_env_copy,VV[1463],T0);
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4726upgrade_configuration_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1526]);
 {
  return L4726upgrade_configuration();
 }
}
/* function definition for GET-FOLDER-PATH                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4727get_folder_path(cl_object v1uiop_configuration__folder)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v1uiop_configuration__folder)==(VV[1529]))){
  goto L2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[771]))->cfun.entry(1, VV[1530]) /*  GETENV-ABSOLUTE-DIRECTORY */;
 if (value0!=ECL_NIL) {
  goto L5;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1528]))->cfun.entry(1, VV[1531]) /*  GET-FOLDER-PATH */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[611]))->cfun.entry(2, T0, VV[1532]) /*  SUBPATHNAME* */;
 return value0;
L5:;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!((v1uiop_configuration__folder)==(VV[1531]))){
  goto L7;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[771]))->cfun.entry(1, VV[1533]) /*  GETENV-ABSOLUTE-DIRECTORY */;
 return value0;
L7:;
 if (!((v1uiop_configuration__folder)==(VV[1534]))){
  goto L9;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[771]))->cfun.entry(1, VV[1535]) /*  GETENV-ABSOLUTE-DIRECTORY */;
 if (value0!=ECL_NIL) {
  goto L12;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[771]))->cfun.entry(1, VV[1536]) /*  GETENV-ABSOLUTE-DIRECTORY */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[611]))->cfun.entry(2, T0, VV[1537]) /*  SUBPATHNAME* */;
 return value0;
L12:;
 cl_env_copy->nvalues = 1;
 return value0;
L9:;
 value0 = si_ecase_error(v1uiop_configuration__folder, VV[1538]);
 return value0;
}
static cl_object L4727get_folder_path_va(cl_narg narg, cl_object v2uiop_configuration__folder, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1528]);
 {
  return L4727get_folder_path(v2uiop_configuration__folder);
 }
}
/* function definition for XDG-DATA-HOME                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4728xdg_data_home(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_configuration__more;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_configuration__more = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[771]))->cfun.entry(1, VV[1541]) /*  GETENV-ABSOLUTE-DIRECTORY */;
  if (value0!=ECL_NIL) {
   goto L3;
  }
  T1 = cl_user_homedir_pathname(0);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(2, T1, VV[1542]) /*  SUBPATHNAME */;
  goto L1;
L3:;
  T0 = value0;
  goto L1;
L1:;
  T1 = cl_list(2, T0, v1uiop_configuration__more);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1497]))->cfun.entry(1, T1) /*  RESOLVE-ABSOLUTE-LOCATION */;
  return value0;
 }
}
/* function definition for XDG-CONFIG-HOME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4729xdg_config_home(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_configuration__more;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_configuration__more = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[771]))->cfun.entry(1, VV[1545]) /*  GETENV-ABSOLUTE-DIRECTORY */;
  if (value0!=ECL_NIL) {
   goto L3;
  }
  T1 = cl_user_homedir_pathname(0);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(2, T1, VV[1546]) /*  SUBPATHNAME */;
  goto L1;
L3:;
  T0 = value0;
  goto L1;
L1:;
  T1 = cl_list(2, T0, v1uiop_configuration__more);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1497]))->cfun.entry(1, T1) /*  RESOLVE-ABSOLUTE-LOCATION */;
  return value0;
 }
}
/* function definition for XDG-DATA-DIRS                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4731xdg_data_dirs(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_configuration__more;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_configuration__more = cl_grab_rest_args(args);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1uiop_configuration__more,env0); /*  MORE               */
  ecl_va_end(args);
  {
   cl_object v2;
   {
    cl_object v3;
    v3 = ecl_make_cclosure_va((cl_objectfn)LC4730__lambda4428,env0,Cblock,1);
    v2 = v3;
   }
   {
    cl_object v3;
    cl_object v4;
    cl_object v5;
    {
     cl_object v6;
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[773]))->cfun.entry(1, VV[1550]) /*  GETENV-ABSOLUTE-DIRECTORIES */;
     if (value0!=ECL_NIL) {
      goto L5;
     }
     {
      cl_object v7;
      cl_object v8;
      v7 = ECL_NIL;
      v8 = VV[1551];
      {
       cl_object v9;
       cl_object v10;
       v9 = ecl_list1(ECL_NIL);
       v10 = v9;
L11:;
       v7 = ECL_CONS_CAR(v8);
       {
        cl_object v11;
        v11 = ECL_CONS_CDR(v8);
        if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v8 = v11;
       }
       {
        cl_object v11;
        v11 = v10;
        if (ecl_unlikely(ECL_ATOM(v11))) FEtype_error_cons(v11);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T0 = v11;
       }
       T1 = ecl_function_dispatch(cl_env_copy,VV[590])(1, v7);
       v10 = ecl_list1(T1);
       (ECL_CONS_CDR(T0)=v10,T0);
       if (!(ecl_endp(v8))){
        goto L25;
       }
       goto L12;
L25:;
       goto L11;
L12:;
       v6 = ecl_cdr(v9);
       goto L3;
      }
     }
L5:;
     v6 = value0;
     goto L3;
L3:;
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v3 = v6;
    }
    v4 = ECL_NIL;
    v5 = v3;
    {
     cl_object v6;
     cl_object v7;
     v6 = ecl_list1(ECL_NIL);
     v7 = v6;
L34:;
     if (!(ecl_endp(v5))){
      goto L36;
     }
     goto L35;
L36:;
     v4 = ECL_CONS_CAR(v5);
     {
      cl_object v8;
      v8 = ECL_CONS_CDR(v5);
      if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v5 = v8;
     }
     {
      cl_object v8;
      v8 = v7;
      if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v8;
     }
     T1 = ecl_function_dispatch(cl_env_copy,v2)(1, v4);
     v7 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v7,T0);
     goto L34;
L35:;
     value0 = ecl_cdr(v6);
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
}
/* function definition for XDG-CONFIG-DIRS                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4733xdg_config_dirs(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_configuration__more;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_configuration__more = cl_grab_rest_args(args);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1uiop_configuration__more,env0); /*  MORE               */
  ecl_va_end(args);
  {
   cl_object v2;
   {
    cl_object v3;
    v3 = ecl_make_cclosure_va((cl_objectfn)LC4732__lambda4452,env0,Cblock,1);
    v2 = v3;
   }
   {
    cl_object v3;
    cl_object v4;
    cl_object v5;
    {
     cl_object v6;
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[773]))->cfun.entry(1, VV[1555]) /*  GETENV-ABSOLUTE-DIRECTORIES */;
     if (value0!=ECL_NIL) {
      goto L5;
     }
     {
      cl_object v7;
      cl_object v8;
      v7 = ECL_NIL;
      v8 = VV[1556];
      {
       cl_object v9;
       cl_object v10;
       v9 = ecl_list1(ECL_NIL);
       v10 = v9;
L11:;
       v7 = ECL_CONS_CAR(v8);
       {
        cl_object v11;
        v11 = ECL_CONS_CDR(v8);
        if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v8 = v11;
       }
       {
        cl_object v11;
        v11 = v10;
        if (ecl_unlikely(ECL_ATOM(v11))) FEtype_error_cons(v11);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T0 = v11;
       }
       T1 = ecl_function_dispatch(cl_env_copy,VV[590])(1, v7);
       v10 = ecl_list1(T1);
       (ECL_CONS_CDR(T0)=v10,T0);
       if (!(ecl_endp(v8))){
        goto L25;
       }
       goto L12;
L25:;
       goto L11;
L12:;
       v6 = ecl_cdr(v9);
       goto L3;
      }
     }
L5:;
     v6 = value0;
     goto L3;
L3:;
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v3 = v6;
    }
    v4 = ECL_NIL;
    v5 = v3;
    {
     cl_object v6;
     cl_object v7;
     v6 = ecl_list1(ECL_NIL);
     v7 = v6;
L34:;
     if (!(ecl_endp(v5))){
      goto L36;
     }
     goto L35;
L36:;
     v4 = ECL_CONS_CAR(v5);
     {
      cl_object v8;
      v8 = ECL_CONS_CDR(v5);
      if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v5 = v8;
     }
     {
      cl_object v8;
      v8 = v7;
      if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v8;
     }
     T1 = ecl_function_dispatch(cl_env_copy,v2)(1, v4);
     v7 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v7,T0);
     goto L34;
L35:;
     value0 = ecl_cdr(v6);
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
}
/* function definition for XDG-CACHE-HOME                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4734xdg_cache_home(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_configuration__more;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_configuration__more = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[771]))->cfun.entry(1, VV[1559]) /*  GETENV-ABSOLUTE-DIRECTORY */;
  if (value0!=ECL_NIL) {
   goto L3;
  }
  T1 = cl_user_homedir_pathname(0);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[611]))->cfun.entry(2, T1, VV[1560]) /*  SUBPATHNAME* */;
  goto L1;
L3:;
  T0 = value0;
  goto L1;
L1:;
  T1 = cl_list(2, T0, v1uiop_configuration__more);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1497]))->cfun.entry(1, T1) /*  RESOLVE-ABSOLUTE-LOCATION */;
  return value0;
 }
}
/* function definition for XDG-RUNTIME-DIR                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4735xdg_runtime_dir(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_configuration__more;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_configuration__more = cl_grab_rest_args(args);
  ecl_va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[771]))->cfun.entry(1, VV[1563]) /*  GETENV-ABSOLUTE-DIRECTORY */;
  T1 = cl_list(2, T0, v1uiop_configuration__more);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1497]))->cfun.entry(1, T1) /*  RESOLVE-ABSOLUTE-LOCATION */;
  return value0;
 }
}
/* function definition for SYSTEM-CONFIG-PATHNAMES                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4736system_config_pathnames(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_configuration__more;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_configuration__more = cl_grab_rest_args(args);
  ecl_va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(1, VV[1566]) /*  PARSE-UNIX-NAMESTRING */;
  T1 = cl_list(2, T0, v1uiop_configuration__more);
  T2 = (cl_env_copy->function=ecl_fdefinition(VV[1497]))->cfun.entry(1, T1) /*  RESOLVE-ABSOLUTE-LOCATION */;
  value0 = ecl_list1(T2);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for FILTER-PATHNAME-SET                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4737filter_pathname_set(cl_object v1uiop_configuration__dirs)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_fdefinition(VV[544]);
 T1 = cl_remove_if_not(2, T0, v1uiop_configuration__dirs);
 value0 = cl_remove_duplicates(5, T1, VV[91], ECL_T, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
 return value0;
}
static cl_object L4737filter_pathname_set_va(cl_narg narg, cl_object v2uiop_configuration__dirs, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1568]);
 {
  return L4737filter_pathname_set(v2uiop_configuration__dirs);
 }
}
/* function definition for XDG-DATA-PATHNAMES                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4738xdg_data_pathnames(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_configuration__more;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_configuration__more = cl_grab_rest_args(args);
  ecl_va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1540]))->cfun.entry(1, v1uiop_configuration__more) /*  XDG-DATA-HOME */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[1548]))->cfun.entry(1, v1uiop_configuration__more) /*  XDG-DATA-DIRS */;
  T2 = CONS(T0,T1);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1568]))->cfun.entry(1, T2) /*  FILTER-PATHNAME-SET */;
  return value0;
 }
}
/* function definition for XDG-CONFIG-PATHNAMES                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4739xdg_config_pathnames(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1uiop_configuration__more;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_configuration__more = cl_grab_rest_args(args);
  ecl_va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1544]))->cfun.entry(1, v1uiop_configuration__more) /*  XDG-CONFIG-HOME */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[1553]))->cfun.entry(1, v1uiop_configuration__more) /*  XDG-CONFIG-DIRS */;
  T2 = CONS(T0,T1);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1568]))->cfun.entry(1, T2) /*  FILTER-PATHNAME-SET */;
  return value0;
 }
}
/* function definition for FIND-PREFERRED-FILE                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4740find_preferred_file(cl_narg narg, cl_object v1uiop_configuration__files, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1574]);
 {
  cl_object v2uiop_configuration__direction;
  ecl_va_list args; ecl_va_start(args,v1uiop_configuration__files,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4740find_preferred_filekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v2uiop_configuration__direction = ECL_SYM("INPUT",1289);
   } else {
    v2uiop_configuration__direction = keyvars[0];
   }
  }
  if (!((v2uiop_configuration__direction)==(ECL_SYM("PROBE",1330)))){
   goto L8;
  }
  goto L5;
L8:;
  goto L6;
L6:;
  if (!((v2uiop_configuration__direction)==(ECL_SYM("INPUT",1289)))){
   goto L3;
  }
  goto L4;
L5:;
L4:;
  T0 = VV[669];
  goto L2;
L3:;
  if (!((v2uiop_configuration__direction)==(ECL_SYM("OUTPUT",1319)))){
   goto L16;
  }
  goto L13;
L16:;
  goto L14;
L14:;
  if (!((v2uiop_configuration__direction)==(ECL_SYM("IO",1295)))){
   goto L11;
  }
  goto L12;
L13:;
L12:;
  T0 = ECL_SYM("IDENTITY",428);
  goto L2;
L11:;
  T0 = si_ecase_error(v2uiop_configuration__direction, VV[1577]);
L2:;
  value0 = cl_find_if(2, T0, v1uiop_configuration__files);
  return value0;
 }
}
/* function definition for XDG-DATA-PATHNAME                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4741xdg_data_pathname(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1579]);
 {
  cl_object v1uiop_configuration__more;
  cl_object v2uiop_configuration__direction;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1uiop_configuration__more = ECL_NIL;
   } else {
    i++;
    v1uiop_configuration__more = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v2uiop_configuration__direction = ECL_SYM("INPUT",1289);
   } else {
    i++;
    v2uiop_configuration__direction = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1570]))->cfun.entry(1, v1uiop_configuration__more) /*  XDG-DATA-PATHNAMES */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1574]))->cfun.entry(3, T0, ECL_SYM("DIRECTION",1249), v2uiop_configuration__direction) /*  FIND-PREFERRED-FILE */;
  return value0;
 }
}
/* function definition for XDG-CONFIG-PATHNAME                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4742xdg_config_pathname(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1581]);
 {
  cl_object v1uiop_configuration__more;
  cl_object v2uiop_configuration__direction;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1uiop_configuration__more = ECL_NIL;
   } else {
    i++;
    v1uiop_configuration__more = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v2uiop_configuration__direction = ECL_SYM("INPUT",1289);
   } else {
    i++;
    v2uiop_configuration__direction = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1572]))->cfun.entry(1, v1uiop_configuration__more) /*  XDG-CONFIG-PATHNAMES */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1574]))->cfun.entry(3, T0, ECL_SYM("DIRECTION",1249), v2uiop_configuration__direction) /*  FIND-PREFERRED-FILE */;
  return value0;
 }
}
/* function definition for COMPUTE-USER-CACHE                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4743compute_user_cache()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1558]))->cfun.entry(2, VV[1584], VV[1585]) /*  XDG-CACHE-HOME */;
 ecl_cmp_setq(cl_env_copy,VV[1496],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[1496]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4743compute_user_cache_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1583]);
 {
  return L4743compute_user_cache();
 }
}
/* function definition for COERCE-PATHNAME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4744coerce_pathname(cl_narg narg, cl_object v1uiop_backward_driver__name, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1587]);
 {
  cl_object v2type;
  cl_object v3uiop_backward_driver__defaults;
  ecl_va_list args; ecl_va_start(args,v1uiop_backward_driver__name,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4744coerce_pathnamekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2type = keyvars[0];
   v3uiop_backward_driver__defaults = keyvars[1];
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(5, v1uiop_backward_driver__name, ECL_SYM("TYPE",1356), v2type, ECL_SYM("DEFAULTS",1247), v3uiop_backward_driver__defaults) /*  PARSE-UNIX-NAMESTRING */;
  return value0;
 }
}
/* function definition for USER-CONFIGURATION-DIRECTORIES                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4745user_configuration_directories()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1572]))->cfun.entry(1, VV[1584]) /*  XDG-CONFIG-PATHNAMES */;
 return value0;
}
static cl_object L4745user_configuration_directories_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1589]);
 {
  return L4745user_configuration_directories();
 }
}
/* function definition for SYSTEM-CONFIGURATION-DIRECTORIES                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4746system_configuration_directories()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1565]))->cfun.entry(1, VV[1584]) /*  SYSTEM-CONFIG-PATHNAMES */;
 return value0;
}
static cl_object L4746system_configuration_directories_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1591]);
 {
  return L4746system_configuration_directories();
 }
}
/* function definition for IN-FIRST-DIRECTORY                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4748in_first_directory(cl_narg narg, cl_object v1uiop_backward_driver__dirs, cl_object v2uiop_backward_driver__x, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1593]);
 {
  cl_object v3uiop_backward_driver__direction;
  ecl_va_list args; ecl_va_start(args,v2uiop_backward_driver__x,narg,2);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v2uiop_backward_driver__x,env0); /*  X                   */
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4748in_first_directorykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v3uiop_backward_driver__direction = ECL_SYM("INPUT",1289);
   } else {
    v3uiop_backward_driver__direction = keyvars[0];
   }
  }
  {
   cl_object v4;
   {
    cl_object v5;
    v5 = ecl_make_cclosure_va((cl_objectfn)LC4747__lambda4516,env0,Cblock,1);
    v4 = v5;
   }
   {
    cl_object v5;
    cl_object v6;
    cl_object v7;
    {
     cl_object v8;
     v8 = v1uiop_backward_driver__dirs;
     if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v8;
    }
    v6 = ECL_NIL;
    v7 = v5;
    {
     cl_object v8;
     cl_object v9;
     v8 = ecl_list1(ECL_NIL);
     v9 = v8;
L11:;
     if (!(ecl_endp(v7))){
      goto L13;
     }
     goto L12;
L13:;
     v6 = ECL_CONS_CAR(v7);
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v7);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v7 = v10;
     }
     {
      cl_object v10;
      v10 = v9;
      if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T1 = v10;
     }
     T2 = ecl_function_dispatch(cl_env_copy,v4)(1, v6);
     v9 = ecl_list1(T2);
     (ECL_CONS_CDR(T1)=v9,T1);
     goto L11;
L12:;
     T0 = ecl_cdr(v8);
     goto L2;
    }
   }
  }
L2:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1574]))->cfun.entry(3, T0, ECL_SYM("DIRECTION",1249), v3uiop_backward_driver__direction) /*  FIND-PREFERRED-FILE */;
  return value0;
 }
}
/* function definition for IN-USER-CONFIGURATION-DIRECTORY                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4749in_user_configuration_directory(cl_narg narg, cl_object v1uiop_backward_driver__x, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1596]);
 {
  cl_object v2uiop_backward_driver__direction;
  ecl_va_list args; ecl_va_start(args,v1uiop_backward_driver__x,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4749in_user_configuration_directorykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v2uiop_backward_driver__direction = ECL_SYM("INPUT",1289);
   } else {
    v2uiop_backward_driver__direction = keyvars[0];
   }
  }
  T0 = cl_list(2, VV[1584], v1uiop_backward_driver__x);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1581]))->cfun.entry(2, T0, v2uiop_backward_driver__direction) /*  XDG-CONFIG-PATHNAME */;
  return value0;
 }
}
/* function definition for IN-SYSTEM-CONFIGURATION-DIRECTORY                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4750in_system_configuration_directory(cl_narg narg, cl_object v1uiop_backward_driver__x, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1598]);
 {
  cl_object v2uiop_backward_driver__direction;
  ecl_va_list args; ecl_va_start(args,v1uiop_backward_driver__x,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4750in_system_configuration_directorykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v2uiop_backward_driver__direction = ECL_SYM("INPUT",1289);
   } else {
    v2uiop_backward_driver__direction = keyvars[0];
   }
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1565]))->cfun.entry(2, VV[1584], v1uiop_backward_driver__x) /*  SYSTEM-CONFIG-PATHNAMES */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1574]))->cfun.entry(3, T0, ECL_SYM("DIRECTION",1249), v2uiop_backward_driver__direction) /*  FIND-PREFERRED-FILE */;
  return value0;
 }
}
/* function definition for ASDF-VERSION                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4751asdf_version()
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_find_package(VV[1601]))){
  goto L2;
 }
 T0 = cl_string(VV[1602]);
 T1 = cl_find_symbol(2, T0, VV[1601]);
 value0 = cl_symbol_value(T1);
 if (value0!=ECL_NIL) {
  goto L5;
 }
 {
  cl_object v1asdf_upgrade__revsym;
  cl_object v2asdf_upgrade__rev;
  T0 = cl_string(VV[1603]);
  v1asdf_upgrade__revsym = cl_find_symbol(2, T0, VV[1601]);
  if (Null(v1asdf_upgrade__revsym)){
   goto L10;
  }
  if (!(ecl_boundp(cl_env_copy,v1asdf_upgrade__revsym))){
   goto L10;
  }
  v2asdf_upgrade__rev = cl_symbol_value(v1asdf_upgrade__revsym);
  goto L8;
L10:;
  v2asdf_upgrade__rev = ECL_NIL;
  goto L8;
L8:;
  if (!(ECL_STRINGP(v2asdf_upgrade__rev))){
   goto L13;
  }
  value0 = v2asdf_upgrade__rev;
  cl_env_copy->nvalues = 1;
  return value0;
L13:;
  if (!(ECL_CONSP(v2asdf_upgrade__rev))){
   goto L15;
  }
  value0 = cl_format(3, ECL_NIL, VV[372], v2asdf_upgrade__rev);
  return value0;
L15:;
  if (!(v2asdf_upgrade__rev==ECL_NIL)){
   goto L17;
  }
  value0 = VV[1604];
  cl_env_copy->nvalues = 1;
  return value0;
L17:;
  value0 = si_etypecase_error(v2asdf_upgrade__rev, VV[1605]);
  return value0;
 }
L5:;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4751asdf_version_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1600]);
 {
  return L4751asdf_version();
 }
}
/* function definition for ASDF-MESSAGE                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4752asdf_message(cl_narg narg, cl_object v1asdf_upgrade__format_string, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1611]);
 {
  cl_object v2asdf_upgrade__format_args;
  ecl_va_list args; ecl_va_start(args,v1asdf_upgrade__format_string,narg,1);
  v2asdf_upgrade__format_args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1610]))){
   goto L1;
  }
  value0 = cl_apply(4, ECL_SYM("FORMAT",389), ecl_cmp_symbol_value(cl_env_copy,VV[1610]), v1asdf_upgrade__format_string, v2asdf_upgrade__format_args);
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for UPGRADING-P                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4753upgrading_p(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[1615]);
 {
  cl_object v1asdf_upgrade__oldest_compatible_version;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1asdf_upgrade__oldest_compatible_version = ecl_cmp_symbol_value(cl_env_copy,VV[1609]);
   } else {
    i++;
    v1asdf_upgrade__oldest_compatible_version = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1607]))){
   goto L3;
  }
  T0 = ecl_car(ecl_cmp_symbol_value(cl_env_copy,VV[1607]));
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[385]))->cfun.entry(2, T0, v1asdf_upgrade__oldest_compatible_version) /*  VERSION< */;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function DEFPARAMETER*                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4754defparameter_(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4asdf_upgrade__var;
  cl_object v5asdf_upgrade__value;
  cl_object v6asdf_upgrade__docstring;
  cl_object v7asdf_upgrade__version;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4asdf_upgrade__var = v8;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5asdf_upgrade__value = v8;
  }
  if (Null(v3)){
   goto L16;
  }
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v6asdf_upgrade__docstring = v8;
   goto L15;
  }
L16:;
  v6asdf_upgrade__docstring = ECL_NIL;
L15:;
  if (Null(v3)){
   goto L22;
  }
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v7asdf_upgrade__version = v8;
   goto L21;
  }
L22:;
  v7asdf_upgrade__version = ecl_cmp_symbol_value(cl_env_copy,VV[1609]);
L21:;
  if (Null(v3)){
   goto L27;
  }
  si_dm_too_many_arguments(v1);
L27:;
  {
   cl_object v8asdf_upgrade__name;
   cl_object v9asdf_upgrade__valfun;
   v8asdf_upgrade__name = cl_string_trim(VV[1618], v4asdf_upgrade__var);
   T0 = cl_format(5, ECL_NIL, VV[1619], VV[1620], v8asdf_upgrade__name, ECL_SYM("VALUE",2074));
   v9asdf_upgrade__valfun = cl_intern(1, T0);
   T0 = cl_list(4, ECL_SYM("DEFUN",291), v9asdf_upgrade__valfun, ECL_NIL, v5asdf_upgrade__value);
   T1 = ecl_list1(v9asdf_upgrade__valfun);
   T2 = (cl_env_copy->function=ecl_fdefinition(VV[257]))->cfun.entry(1, v6asdf_upgrade__docstring) /*  ENSURE-LIST */;
   T3 = cl_listX(4, ECL_SYM("DEFVAR",292), v4asdf_upgrade__var, T1, T2);
   T4 = cl_list(2, VV[1615], v7asdf_upgrade__version);
   T5 = ecl_list1(v9asdf_upgrade__valfun);
   T6 = cl_list(3, ECL_SYM("SETF",753), v4asdf_upgrade__var, T5);
   T7 = cl_list(3, ECL_SYM("WHEN",909), T4, T6);
   value0 = cl_list(4, ECL_SYM("PROGN",674), T0, T3, T7);
   return value0;
  }
 }
}
static cl_object LC4754defparameter__va(cl_narg narg, cl_object v10, cl_object v11, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1617]);
 {
  return LC4754defparameter_(v10, v11);
 }
}
/* local function WHEN-UPGRADING                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4755when_upgrading(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6asdf_upgrade__version;
  cl_object v7;
  cl_object v8upgrading_p;
  cl_object v9;
  cl_object v10when;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v11;
   v11 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v11;
  }
  v5 = si_search_keyword(v4, ECL_SYM("VERSION",1364));
  if (!((v5)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L11;
  }
  v6asdf_upgrade__version = ecl_cmp_symbol_value(cl_env_copy,VV[1609]);
  goto L10;
L11:;
  v6asdf_upgrade__version = v5;
L10:;
  v7 = si_search_keyword(v4, VV[1622]);
  if (!((v7)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L15;
  }
  v8upgrading_p = cl_list(2, VV[1615], v6asdf_upgrade__version);
  goto L14;
L15:;
  v8upgrading_p = v7;
L14:;
  v9 = si_search_keyword(v4, VV[1623]);
  if (!((v9)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L19;
  }
  v10when = ECL_NIL;
  goto L18;
L19:;
  v10when = v9;
L18:;
  si_check_keyword(2, v4, VV[1625]);
  if (Null(v10when)){
   goto L23;
  }
  T0 = ecl_list1(v10when);
  goto L22;
L23:;
  T0 = ECL_NIL;
L22:;
  T1 = cl_listX(3, ECL_SYM("AND",89), v8upgrading_p, T0);
  T2 = CONS(ECL_SYM("PROGN",674),v3);
  T3 = cl_list(2, ECL_SYM("QUOTE",682), T2);
  T4 = cl_list(2, ECL_SYM("EVAL",341), T3);
  T5 = cl_list(3, ECL_SYM("HANDLER-BIND",419), VV[1626], T4);
  T6 = cl_list(3, ECL_SYM("WHEN",909), T1, T5);
  value0 = cl_list(3, VV[223], ECL_NIL, T6);
  return value0;
 }
}
static cl_object LC4755when_upgrading_va(cl_narg narg, cl_object v11, cl_object v12, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1624]);
 {
  return LC4755when_upgrading(v11, v12);
 }
}
/* function definition for CLEANUP-UPGRADED-ASDF                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4756cleanup_upgraded_asdf(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[1628]);
 {
  cl_object v1asdf_upgrade__old_version;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1asdf_upgrade__old_version = ecl_car(ecl_cmp_symbol_value(cl_env_copy,VV[1607]));
   } else {
    i++;
    v1asdf_upgrade__old_version = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v2asdf_upgrade__new_version;
   v2asdf_upgrade__new_version = (cl_env_copy->function=ecl_fdefinition(VV[1600]))->cfun.entry(0) /*  ASDF-VERSION */;
   if (ecl_equal(v1asdf_upgrade__old_version,v2asdf_upgrade__new_version)) {
    goto L3;
   }
   T0 = CONS(v2asdf_upgrade__new_version,ecl_cmp_symbol_value(cl_env_copy,VV[1607]));
   ecl_cmp_setq(cl_env_copy,VV[1607],T0);
   if (Null(v1asdf_upgrade__old_version)){
    goto L7;
   }
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[387]))->cfun.entry(2, v2asdf_upgrade__new_version, v1asdf_upgrade__old_version) /*  VERSION<= */)){
    goto L10;
   }
   cl_error(3, VV[1629], v1asdf_upgrade__old_version, v2asdf_upgrade__new_version);
   goto L9;
L10:;
   (cl_env_copy->function=ecl_fdefinition(VV[1611]))->cfun.entry(3, VV[1630], v1asdf_upgrade__old_version, v2asdf_upgrade__new_version) /*  ASDF-MESSAGE */;
L9:;
   if ((cl_env_copy->function=ecl_fdefinition(VV[387]))->cfun.entry(2, ecl_cmp_symbol_value(cl_env_copy,VV[1609]), v1asdf_upgrade__old_version) /*  VERSION<= */!=ECL_NIL) {
    goto L12;
   }
   T0 = cl_reverse(ecl_cmp_symbol_value(cl_env_copy,VV[1613]));
   (cl_env_copy->function=ecl_fdefinition(VV[357]))->cfun.entry(1, T0) /*  CALL-FUNCTIONS */;
L12:;
   value0 = ECL_T;
   cl_env_copy->nvalues = 1;
   return value0;
L7:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L3:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for UPGRADE-ASDF                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4757upgrade_asdf()
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*LOAD-PRINT*",39),ECL_NIL); /*  *LOAD-PRINT* */
 ecl_bds_bind(cl_env_copy,ECL_SYM("*COMPILE-PRINT*",30),ECL_NIL); /*  *COMPILE-PRINT* */
 T0 = (ECL_SYM("MUFFLE-WARNING",573)->symbol.gfdef);
 T1 = CONS(VV[1633],T0);
 T2 = ecl_list1(T1);
 T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
 ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
 value0 = L4199symbol_call(5, VV[1601], VV[1634], VV[1601], ECL_SYM("VERBOSE",1363), ECL_NIL);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L4757upgrade_asdf_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1632]);
 {
  return L4757upgrade_asdf();
 }
}
/* local function COMPONENT-PARENT                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4758component_parent(cl_object v1asdf_component_component)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4758component_parent_va(cl_narg narg, cl_object v2asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1644]);
 {
  return LC4758component_parent(v2asdf_component_component);
 }
}
/* local function LAMBDA4571                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4760__lambda4571()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC4759__lambda4573_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4760__lambda4571_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1648]);
 {
  return LC4760__lambda4571();
 }
}
/* local function LAMBDA4575                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4761__lambda4575()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_make_hash_table(0);
 return value0;
}
static cl_object LC4761__lambda4575_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1653]);
 {
  return LC4761__lambda4575();
 }
}
/* function definition for COMPONENT-FIND-PATH                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4762component_find_path(cl_object v1asdf_component_component)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = v1asdf_component_component;
  if (v2==ECL_NIL) {
   goto L4;
  }
  if (si_of_class_p(2, v2, VV[1652])!=ECL_NIL) {
   goto L4;
  }
  v1asdf_component_component = si_do_check_type(v2, VV[1655], ECL_NIL, VV[1652]);
L4:;
 }
 {
  cl_object v2asdf_component__c;
  v2asdf_component__c = ECL_NIL;
  {
   cl_object v3;
   cl_object v4;
   v3 = ecl_list1(ECL_NIL);
   v4 = v3;
   v2asdf_component__c = v1asdf_component_component;
L12:;
   if (v2asdf_component__c!=ECL_NIL) {
    goto L16;
   }
   goto L13;
L16:;
   {
    cl_object v5;
    v5 = v4;
    if (ecl_unlikely(ECL_ATOM(v5))) FEtype_error_cons(v5);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T1 = v5;
   }
   T2 = (cl_env_copy->function=ecl_fdefinition(VV[1636]))->cfun.entry(1, v2asdf_component__c) /*  COMPONENT-NAME */;
   v4 = ecl_list1(T2);
   (ECL_CONS_CDR(T1)=v4,T1);
   v2asdf_component__c = (cl_env_copy->function=ecl_fdefinition(VV[1644]))->cfun.entry(1, v2asdf_component__c) /*  COMPONENT-PARENT */;
   goto L12;
L13:;
   T0 = ecl_cdr(v3);
   goto L8;
  }
 }
L8:;
 value0 = cl_reverse(T0);
 return value0;
}
static cl_object L4762component_find_path_va(cl_narg narg, cl_object v2asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1654]);
 {
  return L4762component_find_path(v2asdf_component_component);
 }
}
/* local function PRINT-OBJECT                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4764print_object(cl_object v1asdf_component__c, cl_object v2stream)
{
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1asdf_component__c,env0);    /*  C                       */
 CLV1 = env0 = CONS(v2stream,env0);               /*  STREAM                  */
 {
  cl_object v3;
  v3 = ecl_make_cclosure_va((cl_objectfn)LC4763si___print_unreadable_object_body_,env0,Cblock,0);
  value0 = si_print_unreadable_object_function(ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1), ECL_T, ECL_NIL, v3);
  return value0;
 }
}
static cl_object LC4764print_object_va(cl_narg narg, cl_object v4asdf_component__c, cl_object v5stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("PRINT-OBJECT",965));
 {
  return LC4764print_object(v4asdf_component__c, v5stream);
 }
}
/* local function COMPONENT-SYSTEM                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4765component_system(cl_object v1asdf_component_component)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_component__system;
  v2asdf_component__system = (cl_env_copy->function=ecl_fdefinition(VV[1644]))->cfun.entry(1, v1asdf_component_component) /*  COMPONENT-PARENT */;
  if (Null(v2asdf_component__system)){
   goto L3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1637]))->cfun.entry(1, v2asdf_component__system) /*  COMPONENT-SYSTEM */;
  return value0;
L3:;
  value0 = v1asdf_component_component;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4765component_system_va(cl_narg narg, cl_object v3asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1637]);
 {
  return LC4765component_system(v3asdf_component_component);
 }
}
/* function definition for COMPUTE-CHILDREN-BY-NAME                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4766compute_children_by_name(cl_narg narg, cl_object v1asdf_component_parent, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1668]);
 {
  cl_object v2asdf_component__only_if_needed_p;
  ecl_va_list args; ecl_va_start(args,v1asdf_component_parent,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4766compute_children_by_namekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2asdf_component__only_if_needed_p = keyvars[0];
  }
  if (Null(v2asdf_component__only_if_needed_p)){
   goto L4;
  }
  if (cl_slot_boundp(v1asdf_component_parent, VV[1669])!=ECL_NIL) {
   goto L1;
  }
  goto L2;
L4:;
  goto L2;
L2:;
  {
   cl_object v3asdf_component__hash;
   v3asdf_component__hash = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
   (cl_env_copy->function=ecl_fdefinition(VV[1671]))->cfun.entry(2, v3asdf_component__hash, v1asdf_component_parent) /*  (SETF COMPONENT-CHILDREN-BY-NAME) */;
   {
    cl_object v4;
    cl_object v5asdf_component__c;
    cl_object v6;
    {
     cl_object v7;
     v7 = (cl_env_copy->function=ecl_fdefinition(VV[1672]))->cfun.entry(1, v1asdf_component_parent) /*  COMPONENT-CHILDREN */;
     if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v4 = v7;
    }
    v5asdf_component__c = ECL_NIL;
    v6 = v4;
    {
     cl_object v7asdf_component_name;
     v7asdf_component_name = ECL_NIL;
     {
      cl_object v8asdf_component__previous;
      v8asdf_component__previous = ECL_NIL;
L16:;
      if (!(ecl_endp(v6))){
       goto L18;
      }
      goto L17;
L18:;
      v5asdf_component__c = ECL_CONS_CAR(v6);
      {
       cl_object v9;
       v9 = ECL_CONS_CDR(v6);
       if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v6 = v9;
      }
      v7asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1636]))->cfun.entry(1, v5asdf_component__c) /*  COMPONENT-NAME */;
      v8asdf_component__previous = ecl_gethash_safe(v7asdf_component_name,v3asdf_component__hash,ECL_NIL);
      if (Null(v8asdf_component__previous)){
       goto L31;
      }
      cl_error(3, VV[1647], ECL_SYM("NAME",1309), v7asdf_component_name);
L31:;
      si_hash_set(v7asdf_component_name, v3asdf_component__hash, v5asdf_component__c);
      goto L16;
L17:;
     }
    }
   }
   value0 = v3asdf_component__hash;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function COMPONENT-PARENT-PATHNAME                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4767component_parent_pathname(cl_object v1asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1644]))->cfun.entry(1, v1asdf_component_component) /*  COMPONENT-PARENT */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1638]))->cfun.entry(1, T0) /*  COMPONENT-PATHNAME */;
 return value0;
}
static cl_object LC4767component_parent_pathname_va(cl_narg narg, cl_object v2asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1675]);
 {
  return LC4767component_parent_pathname(v2asdf_component_component);
 }
}
/* local function COMPONENT-PATHNAME                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4768component_pathname(cl_object v1asdf_component_component)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_slot_boundp(v1asdf_component_component, VV[1676]))){
  goto L2;
 }
 value0 = cl_slot_value(v1asdf_component_component, VV[1676]);
 return value0;
L2:;
 {
  cl_object v2pathname;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1639]))->cfun.entry(1, v1asdf_component_component) /*  COMPONENT-RELATIVE-PATHNAME */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[1675]))->cfun.entry(1, v1asdf_component_component) /*  COMPONENT-PARENT-PATHNAME */;
  T2 = (cl_env_copy->function=ecl_fdefinition(VV[555]))->cfun.entry(1, T1) /*  PATHNAME-DIRECTORY-PATHNAME */;
  v2pathname = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, T0, T2) /*  MERGE-PATHNAMES* */;
  if (v2pathname==ECL_NIL) {
   goto L5;
  }
  if ((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v2pathname) /*  ABSOLUTE-PATHNAME-P */!=ECL_NIL) {
   goto L5;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1654]))->cfun.entry(1, v1asdf_component_component) /*  COMPONENT-FIND-PATH */;
  cl_error(3, VV[1677], v2pathname, T0);
L5:;
  (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v2pathname, v1asdf_component_component, VV[1676]) /*  (SETF SLOT-VALUE) */;
  value0 = v2pathname;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4768component_pathname_va(cl_narg narg, cl_object v3asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1638]);
 {
  return LC4768component_pathname(v3asdf_component_component);
 }
}
/* local function COMPONENT-RELATIVE-PATHNAME                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4769component_relative_pathname(cl_object v1asdf_component_component)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_slot_boundp(v1asdf_component_component, VV[1678]))){
  goto L7;
 }
 value0 = cl_slot_value(v1asdf_component_component, VV[1678]);
 goto L5;
L7:;
 value0 = ECL_NIL;
 goto L5;
L5:;
 if (value0!=ECL_NIL) {
  goto L4;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1636]))->cfun.entry(1, v1asdf_component_component) /*  COMPONENT-NAME */;
 goto L2;
L4:;
 T0 = value0;
 goto L2;
L2:;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1637]))->cfun.entry(1, v1asdf_component_component) /*  COMPONENT-SYSTEM */;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[1645]))->cfun.entry(2, v1asdf_component_component, T1) /*  SOURCE-FILE-TYPE */;
 T3 = (cl_env_copy->function=ecl_fdefinition(VV[1675]))->cfun.entry(1, v1asdf_component_component) /*  COMPONENT-PARENT-PATHNAME */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(7, T0, VV[609], ECL_T, ECL_SYM("TYPE",1356), T2, ECL_SYM("DEFAULTS",1247), T3) /*  PARSE-UNIX-NAMESTRING */;
 return value0;
}
static cl_object LC4769component_relative_pathname_va(cl_narg narg, cl_object v2asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1639]);
 {
  return LC4769component_relative_pathname(v2asdf_component_component);
 }
}
/* local function SOURCE-FILE-TYPE                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4770source_file_type(cl_object v1asdf_component_component, cl_object v2asdf_component__system)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_SYM("DIRECTORY",1250);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4770source_file_type_va(cl_narg narg, cl_object v3asdf_component_component, cl_object v4asdf_component__system, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1645]);
 {
  return LC4770source_file_type(v3asdf_component_component, v4asdf_component__system);
 }
}
/* local function SOURCE-FILE-TYPE                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4771source_file_type(cl_object v1asdf_component_component, cl_object v2asdf_component__system)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1679]))->cfun.entry(1, v1asdf_component_component) /*  FILE-TYPE */;
 return value0;
}
static cl_object LC4771source_file_type_va(cl_narg narg, cl_object v3asdf_component_component, cl_object v4asdf_component__system, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1645]);
 {
  return LC4771source_file_type(v3asdf_component_component, v4asdf_component__system);
 }
}
/* local function COMPONENT-ENCODING                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4772component_encoding(cl_object v1asdf_component__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_component__x;
  v2asdf_component__x = ECL_NIL;
  {
   cl_object v3;
   v3 = ECL_NIL;
   v2asdf_component__x = v1asdf_component__c;
L7:;
   if (v2asdf_component__x!=ECL_NIL) {
    goto L11;
   }
   goto L8;
L11:;
   v3 = (cl_env_copy->function=ecl_fdefinition(VV[1680]))->cfun.entry(1, v2asdf_component__x) /*  %COMPONENT-ENCODING */;
   if (Null(v3)){
    goto L13;
   }
   value0 = v3;
   goto L4;
L13:;
   v2asdf_component__x = (cl_env_copy->function=ecl_fdefinition(VV[1644]))->cfun.entry(1, v2asdf_component__x) /*  COMPONENT-PARENT */;
   goto L7;
L8:;
   value0 = ECL_NIL;
  }
 }
L4:;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1638]))->cfun.entry(1, v1asdf_component__c) /*  COMPONENT-PATHNAME */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[819]))->cfun.entry(1, T0) /*  DETECT-ENCODING */;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4772component_encoding_va(cl_narg narg, cl_object v2asdf_component__c, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1641]);
 {
  return LC4772component_encoding(v2asdf_component__c);
 }
}
/* local function COMPONENT-EXTERNAL-FORMAT                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4773component_external_format(cl_object v1asdf_component__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1641]))->cfun.entry(1, v1asdf_component__c) /*  COMPONENT-ENCODING */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[826]))->cfun.entry(1, T0) /*  ENCODING-EXTERNAL-FORMAT */;
 return value0;
}
static cl_object LC4773component_external_format_va(cl_narg narg, cl_object v2asdf_component__c, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1640]);
 {
  return LC4773component_external_format(v2asdf_component__c);
 }
}
/* local function AROUND-COMPILE-HOOK                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4774around_compile_hook(cl_object v1asdf_component__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_slot_boundp(v1asdf_component__c, VV[1682]))){
  goto L2;
 }
 value0 = cl_slot_value(v1asdf_component__c, VV[1682]);
 return value0;
L2:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[1644]))->cfun.entry(1, v1asdf_component__c) /*  COMPONENT-PARENT */)){
  goto L4;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1644]))->cfun.entry(1, v1asdf_component__c) /*  COMPONENT-PARENT */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1681]))->cfun.entry(1, T0) /*  AROUND-COMPILE-HOOK */;
 return value0;
L4:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4774around_compile_hook_va(cl_narg narg, cl_object v2asdf_component__c, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1681]);
 {
  return LC4774around_compile_hook(v2asdf_component__c);
 }
}
/* local function VERSION-SATISFIES                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4775version_satisfies(cl_object v1asdf_component__c, cl_object v2asdf_component_version)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4775version_satisfies_va(cl_narg narg, cl_object v3asdf_component__c, cl_object v4asdf_component_version, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1642]);
 {
  return LC4775version_satisfies(v3asdf_component__c, v4asdf_component_version);
 }
}
/* local function VERSION-SATISFIES                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4776version_satisfies(cl_object v1asdf_component__c, cl_object v2asdf_component_version)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v2asdf_component_version)){
  goto L5;
 }
 if (Null(cl_slot_boundp(v1asdf_component__c, VV[1683]))){
  goto L5;
 }
 if ((cl_env_copy->function=ecl_fdefinition(VV[1643]))->cfun.entry(1, v1asdf_component__c) /*  COMPONENT-VERSION */!=ECL_NIL) {
  goto L2;
 }
 goto L3;
L5:;
 goto L3;
L3:;
 if (Null(v2asdf_component_version)){
  goto L8;
 }
 (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(3, VV[1684], v2asdf_component_version, v1asdf_component__c) /*  WARN */;
L8:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1643]))->cfun.entry(1, v1asdf_component__c) /*  COMPONENT-VERSION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1642]))->cfun.entry(2, T0, v2asdf_component_version) /*  VERSION-SATISFIES */;
 return value0;
}
static cl_object LC4776version_satisfies_va(cl_narg narg, cl_object v3asdf_component__c, cl_object v4asdf_component_version, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1642]);
 {
  return LC4776version_satisfies(v3asdf_component__c, v4asdf_component_version);
 }
}
/* local function VERSION-SATISFIES                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4777version_satisfies(cl_object v1asdf_component__cver, cl_object v2asdf_component_version)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[387]))->cfun.entry(2, v2asdf_component_version, v1asdf_component__cver) /*  VERSION<= */;
 return value0;
}
static cl_object LC4777version_satisfies_va(cl_narg narg, cl_object v3asdf_component__cver, cl_object v4asdf_component_version, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1642]);
 {
  return LC4777version_satisfies(v3asdf_component__cver, v4asdf_component_version);
 }
}
/* function definition for SUB-COMPONENTS                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4780sub_components(cl_narg narg, cl_object v1asdf_component_component, ...)
{
 cl_object env0 = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1685]);
 {
  ecl_va_list args; ecl_va_start(args,v1asdf_component_component,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4780sub_componentskeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(ECL_T,env0);               /*  TYPE                    */
   } else {
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(keyvars[0],env0);          /*  TYPE                    */
   }
  }
  {
   cl_object env1 = env0;
   CLV1 = env1 = CONS(ECL_NIL,env1);
   {cl_object env2 = env1;
    CLV2 = env2 = CONS(ECL_NIL,env2);
    ECL_CONS_CAR(CLV2) = ecl_make_cclosure_va((cl_objectfn)LC4779recurse,env2,Cblock,1);
    (aux_closure.env=env2,cl_env_copy->function=(cl_object)&aux_closure,LC4779recurse(1, v1asdf_component_component));
   }
   value0 = cl_reverse(ECL_CONS_CAR(CLV1));
   return value0;
  }
 }
}
/* local function COMPONENT-ENTRY-POINT                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4781component_entry_point(cl_object v1asdf_system__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4781component_entry_point_va(cl_narg narg, cl_object v2asdf_system__c, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1693]);
 {
  return LC4781component_entry_point(v2asdf_system__c);
 }
}
/* function definition for RESET-SYSTEM                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4782reset_system(cl_narg narg, cl_object v1asdf_system_system, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1696]);
 {
  cl_object v2asdf_system__keys;
  ecl_va_list args; ecl_va_start(args,v1asdf_system_system,narg,1);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v2asdf_system__keys,TRUE);
  ecl_va_end(args);
  T0 = (cl_env_copy->function=(ECL_SYM("CHANGE-CLASS",936)->symbol.gfdef))->cfun.entry(2, v1asdf_system_system, VV[1694]) /*  CHANGE-CLASS */;
  (cl_env_copy->function=(ECL_SYM("CHANGE-CLASS",936)->symbol.gfdef))->cfun.entry(2, T0, VV[1695]) /*  CHANGE-CLASS */;
  value0 = cl_apply(3, ECL_SYM("REINITIALIZE-INSTANCE",967), v1asdf_system_system, v2asdf_system__keys);
  return value0;
 }
}
/* local function SYSTEM-SOURCE-FILE                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4783system_source_file(cl_object v1asdf_system__system_name)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1690]))->cfun.entry(1, v1asdf_system__system_name) /*  FIND-SYSTEM */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, T0) /*  SYSTEM-SOURCE-FILE */;
 return value0;
}
static cl_object LC4783system_source_file_va(cl_narg narg, cl_object v2asdf_system__system_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1691]);
 {
  return LC4783system_source_file(v2asdf_system__system_name);
 }
}
/* local function SYSTEM-SOURCE-FILE                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4784system_source_file(cl_object v1asdf_system__system_name)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1690]))->cfun.entry(1, v1asdf_system__system_name) /*  FIND-SYSTEM */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, T0) /*  SYSTEM-SOURCE-FILE */;
 return value0;
}
static cl_object LC4784system_source_file_va(cl_narg narg, cl_object v2asdf_system__system_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1691]);
 {
  return LC4784system_source_file(v2asdf_system__system_name);
 }
}
/* function definition for SYSTEM-SOURCE-DIRECTORY                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4785system_source_directory(cl_object v1asdf_system__system_designator)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, v1asdf_system__system_designator) /*  SYSTEM-SOURCE-FILE */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[555]))->cfun.entry(1, T0) /*  PATHNAME-DIRECTORY-PATHNAME */;
 return value0;
}
static cl_object L4785system_source_directory_va(cl_narg narg, cl_object v2asdf_system__system_designator, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1698]);
 {
  return L4785system_source_directory(v2asdf_system__system_designator);
 }
}
/* function definition for SYSTEM-RELATIVE-PATHNAME                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4786system_relative_pathname(cl_narg narg, cl_object v1asdf_system_system, cl_object v2asdf_component_name, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1700]);
 {
  cl_object v3type;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_name,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4786system_relative_pathnamekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v3type = keyvars[0];
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1698]))->cfun.entry(1, v1asdf_system_system) /*  SYSTEM-SOURCE-DIRECTORY */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(4, T0, v2asdf_component_name, ECL_SYM("TYPE",1356), v3type) /*  SUBPATHNAME */;
  return value0;
 }
}
/* local function COMPONENT-PATHNAME                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4789component_pathname(cl_object v1asdf_system_system)
{
 cl_object T0, T1;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 {
  cl_object v2pathname;
  value0 = LC4787call_next_method(0, lex0);
  if (value0!=ECL_NIL) {
   goto L8;
  }
  v2pathname = (cl_env_copy->function=ecl_fdefinition(VV[1698]))->cfun.entry(1, v1asdf_system_system) /*  SYSTEM-SOURCE-DIRECTORY */;
  goto L6;
L8:;
  v2pathname = value0;
  goto L6;
L6:;
  if (Null(cl_slot_boundp(v1asdf_system_system, VV[1678]))){
   goto L13;
  }
  if (cl_slot_value(v1asdf_system_system, VV[1678])!=ECL_NIL) {
   goto L10;
  }
  goto L11;
L13:;
  goto L11;
L11:;
  (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v2pathname, v1asdf_system_system, VV[1678]) /*  (SETF SLOT-VALUE) */;
L10:;
  value0 = v2pathname;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4789component_pathname_va(cl_narg narg, cl_object v3asdf_system_system, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1638]);
 {
  return LC4789component_pathname(v3asdf_system_system);
 }
}
/* local function COMPONENT-RELATIVE-PATHNAME                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4790component_relative_pathname(cl_object v1asdf_system_system)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_slot_boundp(v1asdf_system_system, VV[1678]))){
  goto L4;
 }
 T0 = cl_slot_value(v1asdf_system_system, VV[1678]);
 goto L2;
L4:;
 T0 = ECL_NIL;
 goto L2;
L2:;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1698]))->cfun.entry(1, v1asdf_system_system) /*  SYSTEM-SOURCE-DIRECTORY */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(9, T0, VV[609], ECL_T, ECL_SYM("TYPE",1356), ECL_SYM("DIRECTORY",1250), VV[675], ECL_T, ECL_SYM("DEFAULTS",1247), T1) /*  PARSE-UNIX-NAMESTRING */;
 return value0;
}
static cl_object LC4790component_relative_pathname_va(cl_narg narg, cl_object v2asdf_system_system, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1639]);
 {
  return LC4790component_relative_pathname(v2asdf_system_system);
 }
}
/* local function COMPONENT-PARENT-PATHNAME                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4791component_parent_pathname(cl_object v1asdf_system_system)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1698]))->cfun.entry(1, v1asdf_system_system) /*  SYSTEM-SOURCE-DIRECTORY */;
 return value0;
}
static cl_object LC4791component_parent_pathname_va(cl_narg narg, cl_object v2asdf_system_system, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1675]);
 {
  return LC4791component_parent_pathname(v2asdf_system_system);
 }
}
/* local function COMPONENT-BUILD-PATHNAME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4792component_build_pathname(cl_object v1asdf_system__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4792component_build_pathname_va(cl_narg narg, cl_object v2asdf_system__c, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1692]);
 {
  return LC4792component_build_pathname(v2asdf_system__c);
 }
}
/* function definition for SET-ASDF-CACHE-ENTRY                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4793set_asdf_cache_entry(cl_object v1asdf_cache__key, cl_object v2asdf_cache__value_list)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1703]))){
  goto L3;
 }
 T0 = si_hash_set(v1asdf_cache__key, ecl_cmp_symbol_value(cl_env_copy,VV[1703]), v2asdf_cache__value_list);
 goto L2;
L3:;
 T0 = v2asdf_cache__value_list;
L2:;
 value0 = cl_values_list(T0);
 return value0;
}
static cl_object L4793set_asdf_cache_entry_va(cl_narg narg, cl_object v3asdf_cache__key, cl_object v4asdf_cache__value_list, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1704]);
 {
  return L4793set_asdf_cache_entry(v3asdf_cache__key, v4asdf_cache__value_list);
 }
}
/* function definition for UNSET-ASDF-CACHE-ENTRY                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4794unset_asdf_cache_entry(cl_object v1asdf_cache__key)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1703]))){
  goto L2;
 }
 value0 = cl_remhash(v1asdf_cache__key, ecl_cmp_symbol_value(cl_env_copy,VV[1703]));
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4794unset_asdf_cache_entry_va(cl_narg narg, cl_object v2asdf_cache__key, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1706]);
 {
  return L4794unset_asdf_cache_entry(v2asdf_cache__key);
 }
}
/* function definition for CONSULT-ASDF-CACHE                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4795consult_asdf_cache(cl_narg narg, cl_object v1asdf_cache__key, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1708]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1708]);
 {
  cl_object v2asdf_cache__thunk;
  va_list args; va_start(args,v1asdf_cache__key);
  {
   int i = 1;
   if (i >= narg) {
    v2asdf_cache__thunk = ECL_NIL;
   } else {
    i++;
    v2asdf_cache__thunk = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1703]))){
   goto L2;
  }
  {
   cl_object v3;                                  /*  RESULTS                 */
   cl_object v4;                                  /*  FOUNDP                  */
   value0 = cl_gethash(2, v1asdf_cache__key, ecl_cmp_symbol_value(cl_env_copy,VV[1703]));
   {
    v3 = value0;
    v4 = cl_env_copy->values[1];
   }
   if (Null(v4)){
    goto L5;
   }
   value0 = cl_values_list(v3);
   return value0;
L5:;
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    cl_env_copy->values[0] = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(1, v2asdf_cache__thunk) /*  CALL-FUNCTION */;
    ecl_stack_frame_push_values(_ecl_inner_frame);
    T0 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
    ecl_stack_frame_close(_ecl_inner_frame);
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1704]))->cfun.entry(2, v1asdf_cache__key, T0) /*  SET-ASDF-CACHE-ENTRY */;
   return value0;
  }
L2:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(1, v2asdf_cache__thunk) /*  CALL-FUNCTION */;
  return value0;
 }
}
/* local function DO-ASDF-CACHE                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4796do_asdf_cache(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4asdf_cache__key;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4asdf_cache__key = v5;
  }
  T0 = cl_listX(3, ECL_SYM("LAMBDA",454), ECL_NIL, v3);
  T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
  value0 = cl_list(3, VV[1708], v4asdf_cache__key, T1);
  return value0;
 }
}
static cl_object LC4796do_asdf_cache_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1710]);
 {
  return LC4796do_asdf_cache(v5, v6);
 }
}
/* function definition for CALL-WITH-ASDF-CACHE                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4802call_with_asdf_cache(volatile cl_narg narg, cl_object volatile v1asdf_cache__thunk, ...)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1712]);
 {
  cl_object volatile v2asdf_cache__override;
  ecl_va_list args; ecl_va_start(args,v1asdf_cache__thunk,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1asdf_cache__thunk,env0);   /*  THUNK                   */
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4802call_with_asdf_cachekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2asdf_cache__override = keyvars[0];
   CLV1 = env0 = CONS(keyvars[1],env0);           /*  KEY                     */
  }
  {
   volatile cl_object v3asdf_cache__fun;
   if (Null(ECL_CONS_CAR(CLV1))){
    goto L2;
   }
   {
    cl_object volatile v4;
    v4 = ecl_make_cclosure_va((cl_objectfn)LC4797__lambda4723,env0,Cblock,0);
    v3asdf_cache__fun = v4;
    goto L1;
   }
L2:;
   v3asdf_cache__fun = ECL_CONS_CAR(CLV0);
L1:;
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1703]))){
    goto L4;
   }
   if (v2asdf_cache__override!=ECL_NIL) {
    goto L4;
   }
   value0 = ecl_function_dispatch(cl_env_copy,v3asdf_cache__fun)(0);
   return value0;
L4:;
L7:;
   {
    volatile cl_object env1 = env0;
    CLV2 = env1 = CONS(ECL_NIL,env1);
    {
     volatile cl_object env2 = env1;
     CLV3 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY      */
     {
      ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV3));
      if (__ecl_frs_push_result!=0) {
      if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
       goto L9;
      }
      if (cl_env_copy->values[0]==ecl_make_int8_t(1)) {
       goto L10;
      }
      ecl_internal_error("GO found an inexistent tag");
      } else {
      {
       cl_object v4;
       v4 = ecl_make_cclosure_va((cl_objectfn)LC4798__lambda4731,env2,Cblock,0);
       T0 = v4;
      }
      {
       cl_object v4;
       v4 = ecl_make_cfun_va((cl_objectfn)LC4799__lambda4733_va,ECL_NIL,Cblock,1);
       T1 = v4;
      }
      T2 = (cl_env_copy->function=(VV[1715]->symbol.gfdef))->cfun.entry(6, ECL_SYM("NAME",1309), VV[1716], ECL_SYM("FUNCTION",1273), T0, VV[1718], T1) /*  MAKE-RESTART */;
      {
       cl_object v4;
       v4 = ecl_make_cclosure_va((cl_objectfn)LC4800__lambda4735,env2,Cblock,0);
       T3 = v4;
      }
      {
       cl_object v4;
       v4 = ecl_make_cfun_va((cl_objectfn)LC4801__lambda4737_va,ECL_NIL,Cblock,1);
       T4 = v4;
      }
      T5 = (cl_env_copy->function=(VV[1715]->symbol.gfdef))->cfun.entry(6, ECL_SYM("NAME",1309), VV[1721], ECL_SYM("FUNCTION",1273), T3, VV[1718], T4) /*  MAKE-RESTART */;
      T6 = cl_list(2, T2, T5);
      T7 = CONS(T6,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5)));
      ecl_bds_bind(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5),T7); /*  *RESTART-CLUSTERS* */
      T0 = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
      ecl_bds_bind(cl_env_copy,VV[1703],T0);      /*  *ASDF-CACHE*            */
      value0 = ecl_function_dispatch(cl_env_copy,v3asdf_cache__fun)(0);
      ecl_frs_pop_n(cl_env_copy, 1);
      ecl_bds_unwind1(cl_env_copy);
      ecl_bds_unwind1(cl_env_copy);
      return value0;
L9:;
      {
       cl_object v4;
       v4 = ECL_CONS_CAR(CLV2);
       if (Null(v4)){
        ecl_frs_pop_n(cl_env_copy, 1);
        goto L8;
       }
       si_dm_too_many_arguments(ECL_NIL);
       ecl_frs_pop_n(cl_env_copy, 1);
       goto L8;
      }
L10:;
      {
       cl_object v4;
       v4 = ECL_CONS_CAR(CLV2);
       if (Null(v4)){
        goto L21;
       }
       si_dm_too_many_arguments(ECL_NIL);
L21:;
       (cl_env_copy->function=ecl_fdefinition(VV[1524]))->cfun.entry(0) /*  CLEAR-CONFIGURATION */;
       ecl_frs_pop_n(cl_env_copy, 1);
       goto L8;
      }
      }
     }
    }
   }
L8:;
   goto L7;
  }
 }
}
/* local function WITH-ASDF-CACHE                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4803with_asdf_cache(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6asdf_cache__key;
  cl_object v7;
  cl_object v8asdf_cache__override;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v9;
   v9 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v9;
  }
  v5 = si_search_keyword(v4, ECL_SYM("KEY",1297));
  if (!((v5)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L11;
  }
  v6asdf_cache__key = ECL_NIL;
  goto L10;
L11:;
  v6asdf_cache__key = v5;
L10:;
  v7 = si_search_keyword(v4, VV[1401]);
  if (!((v7)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L15;
  }
  v8asdf_cache__override = ECL_NIL;
  goto L14;
L15:;
  v8asdf_cache__override = v7;
L14:;
  si_check_keyword(2, v4, VV[1727]);
  T0 = cl_listX(3, ECL_SYM("LAMBDA",454), ECL_NIL, v3);
  T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
  value0 = cl_list(6, VV[1712], T1, VV[1401], v8asdf_cache__override, ECL_SYM("KEY",1297), v6asdf_cache__key);
  return value0;
 }
}
static cl_object LC4803with_asdf_cache_va(cl_narg narg, cl_object v9, cl_object v10, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1726]);
 {
  return LC4803with_asdf_cache(v9, v10);
 }
}
/* function definition for NORMALIZE-NAMESTRING                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4804normalize_namestring(cl_object v1pathname)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_cache__resolved;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[529]))->cfun.entry(1, v1pathname) /*  PHYSICALIZE-PATHNAME */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[617]))->cfun.entry(2, T0, VV[676]) /*  ENSURE-ABSOLUTE-PATHNAME */;
  v2asdf_cache__resolved = (cl_env_copy->function=ecl_fdefinition(VV[716]))->cfun.entry(1, T1) /*  RESOLVE-SYMLINKS* */;
  ecl_bds_bind(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34),ecl_cmp_symbol_value(cl_env_copy,VV[533])); /*  *DEFAULT-PATHNAME-DEFAULTS* */
  value0 = cl_namestring(v2asdf_cache__resolved);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object L4804normalize_namestring_va(cl_narg narg, cl_object v3pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1729]);
 {
  return L4804normalize_namestring(v3pathname);
 }
}
/* function definition for COMPUTE-FILE-STAMP                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4805compute_file_stamp(cl_object v1asdf_cache__normalized_namestring)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34),ecl_cmp_symbol_value(cl_env_copy,VV[533])); /*  *DEFAULT-PATHNAME-DEFAULTS* */
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[665]))->cfun.entry(1, v1asdf_cache__normalized_namestring) /*  SAFE-FILE-WRITE-DATE */;
 ecl_bds_unwind1(cl_env_copy);
 return value0;
}
static cl_object L4805compute_file_stamp_va(cl_narg narg, cl_object v2asdf_cache__normalized_namestring, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1731]);
 {
  return L4805compute_file_stamp(v2asdf_cache__normalized_namestring);
 }
}
/* function definition for REGISTER-FILE-STAMP                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4806register_file_stamp(cl_narg narg, cl_object v1asdf_cache__file, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1733]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1733]);
 {
  cl_object v2asdf_cache__stamp;
  cl_object v3asdf_cache__stampp;
  va_list args; va_start(args,v1asdf_cache__file);
  {
   int i = 1;
   if (i >= narg) {
    v2asdf_cache__stamp = ECL_NIL;
    v3asdf_cache__stampp = ECL_NIL;
   } else {
    i++;
    v2asdf_cache__stamp = va_arg(args,cl_object);
    v3asdf_cache__stampp = ECL_T;
   }
  }
  va_end(args);
  {
   cl_object v4namestring;
   cl_object v5asdf_cache__stamp;
   v4namestring = (cl_env_copy->function=ecl_fdefinition(VV[1729]))->cfun.entry(1, v1asdf_cache__file) /*  NORMALIZE-NAMESTRING */;
   if (Null(v3asdf_cache__stampp)){
    goto L4;
   }
   v5asdf_cache__stamp = v2asdf_cache__stamp;
   goto L3;
L4:;
   v5asdf_cache__stamp = (cl_env_copy->function=ecl_fdefinition(VV[1731]))->cfun.entry(1, v4namestring) /*  COMPUTE-FILE-STAMP */;
L3:;
   T0 = cl_list(2, VV[1734], v4namestring);
   T1 = ecl_list1(v5asdf_cache__stamp);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1704]))->cfun.entry(2, T0, T1) /*  SET-ASDF-CACHE-ENTRY */;
   return value0;
  }
 }
}
/* function definition for GET-FILE-STAMP                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4808get_file_stamp(cl_object v1asdf_cache__file)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1asdf_cache__file)){
  goto L2;
 }
 {
  cl_object env1 = env0;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1729]))->cfun.entry(1, v1asdf_cache__file) /*  NORMALIZE-NAMESTRING */;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(T0,env1);                    /*  NAMESTRING              */
  T0 = cl_list(2, VV[1734], ECL_CONS_CAR(CLV0));
  {
   cl_object v2;
   v2 = ecl_make_cclosure_va((cl_objectfn)LC4807__lambda4761,env1,Cblock,0);
   T1 = v2;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1708]))->cfun.entry(2, T0, T1) /*  CONSULT-ASDF-CACHE */;
  return value0;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4808get_file_stamp_va(cl_narg narg, cl_object v2asdf_cache__file, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1734]);
 {
  return L4808get_file_stamp(v2asdf_cache__file);
 }
}
/* local function LAMBDA4763                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4810__lambda4763()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC4809__lambda4765_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4810__lambda4763_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1740]);
 {
  return LC4810__lambda4763();
 }
}
/* local function LAMBDA4767                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4812__lambda4767()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC4811__lambda4769_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4812__lambda4767_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1745]);
 {
  return LC4812__lambda4767();
 }
}
/* function definition for SYSDEF-ERROR                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4813sysdef_error(cl_narg narg, cl_object v1format, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1751]);
 {
  cl_object v2asdf_find_system__arguments;
  ecl_va_list args; ecl_va_start(args,v1format,narg,1);
  v2asdf_find_system__arguments = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = cl_error(5, VV[1739], ECL_SYM("FORMAT-CONTROL",1272), v1format, ECL_SYM("FORMAT-ARGUMENTS",1271), v2asdf_find_system__arguments);
  return value0;
 }
}
/* function definition for COERCE-NAME                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4814coerce_name(cl_object v1asdf_component_name)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_of_class_p(2, v1asdf_component_name, VV[1652]))){
  goto L2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1636]))->cfun.entry(1, v1asdf_component_name) /*  COMPONENT-NAME */;
 return value0;
L2:;
 if (!(ECL_SYMBOLP(v1asdf_component_name))){
  goto L4;
 }
 value0 = cl_string_downcase(1, v1asdf_component_name);
 return value0;
L4:;
 if (!(ECL_STRINGP(v1asdf_component_name))){
  goto L6;
 }
 value0 = v1asdf_component_name;
 cl_env_copy->nvalues = 1;
 return value0;
L6:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1751]))->cfun.entry(2, VV[1754], v1asdf_component_name) /*  SYSDEF-ERROR */;
 return value0;
}
static cl_object L4814coerce_name_va(cl_narg narg, cl_object v2asdf_component_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1753]);
 {
  return L4814coerce_name(v2asdf_component_name);
 }
}
/* function definition for PRIMARY-SYSTEM-NAME                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4815primary_system_name(cl_object v1asdf_component_name)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_component_name) /*  COERCE-NAME */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[289]))->cfun.entry(3, T0, VV[377], VV[579]) /*  SPLIT-STRING */;
 value0 = ecl_car(T1);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4815primary_system_name_va(cl_narg narg, cl_object v2asdf_component_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1756]);
 {
  return L4815primary_system_name(v2asdf_component_name);
 }
}
/* function definition for COERCE-FILENAME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4816coerce_filename(cl_object v1asdf_component_name)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_component_name) /*  COERCE-NAME */;
 value0 = L4256frob_substrings(3, T0, VV[1759], VV[1045]);
 return value0;
}
static cl_object L4816coerce_filename_va(cl_narg narg, cl_object v2asdf_component_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1758]);
 {
  return L4816coerce_filename(v2asdf_component_name);
 }
}
/* function definition for SYSTEM-REGISTERED-P                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4817system_registered_p(cl_object v1asdf_component_name)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_component_name) /*  COERCE-NAME */;
 value0 = cl_gethash(2, T0, ecl_cmp_symbol_value(cl_env_copy,VV[1761]));
 return value0;
}
static cl_object L4817system_registered_p_va(cl_narg narg, cl_object v2asdf_component_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1762]);
 {
  return L4817system_registered_p(v2asdf_component_name);
 }
}
/* function definition for REGISTERED-SYSTEM                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4818registered_system(cl_object v1asdf_component_name)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1762]))->cfun.entry(1, v1asdf_component_name) /*  SYSTEM-REGISTERED-P */;
 value0 = ecl_cdr(T0);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4818registered_system_va(cl_narg narg, cl_object v2asdf_component_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1764]);
 {
  return L4818registered_system(v2asdf_component_name);
 }
}
/* function definition for REGISTERED-SYSTEMS*                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4819registered_systems_()
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2;
  cl_object v3asdf_find_system__registered;
  cl_object v4;
  v1 = ecl_cmp_symbol_value(cl_env_copy,VV[1761]);
  v2 = ECL_NIL;
  v3asdf_find_system__registered = ECL_NIL;
  v4 = ECL_NIL;
  {
   cl_object v5;
   v5 = si_hash_table_iterator(v1);
   {
    cl_object v6;
    cl_object v7;
    v6 = ecl_list1(ECL_NIL);
    v7 = v6;
L9:;
    {
     cl_object v8;
     cl_object v9;
     cl_object v10;
     value0 = ecl_function_dispatch(cl_env_copy,v5)(0);
     {
      const int v11 = cl_env_copy->nvalues;
      v8 = value0;
      cl_object v12;
      v12 = (v11<=1)? ECL_NIL : cl_env_copy->values[1];
      v9 = v12;
      v12 = (v11<=2)? ECL_NIL : cl_env_copy->values[2];
      v10 = v12;
     }
     if (Null(v8)){
      goto L14;
     }
     v3asdf_find_system__registered = v10;
     v4 = v9;
L14:;
     v2 = v8;
     if (v2!=ECL_NIL) {
      goto L11;
     }
    }
    goto L10;
L11:;
    {
     cl_object v8;
     v8 = v7;
     if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T0 = v8;
    }
    T1 = ecl_cdr(v3asdf_find_system__registered);
    v7 = ecl_list1(T1);
    (ECL_CONS_CDR(T0)=v7,T0);
    goto L9;
L10:;
    value0 = ecl_cdr(v6);
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
static cl_object L4819registered_systems__va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1766]);
 {
  return L4819registered_systems_();
 }
}
/* function definition for REGISTERED-SYSTEMS                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4820registered_systems()
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  {
   cl_object v4;
   v4 = (cl_env_copy->function=ecl_fdefinition(VV[1766]))->cfun.entry(0) /*  REGISTERED-SYSTEMS* */;
   if (ecl_unlikely(!ECL_LISTP(v4))) FEtype_error_list(v4);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v1 = v4;
  }
  v2 = ECL_NIL;
  v3 = v1;
  {
   cl_object v4;
   cl_object v5;
   v4 = ecl_list1(ECL_NIL);
   v5 = v4;
L9:;
   if (!(ecl_endp(v3))){
    goto L11;
   }
   goto L10;
L11:;
   v2 = ECL_CONS_CAR(v3);
   {
    cl_object v6;
    v6 = ECL_CONS_CDR(v3);
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v6;
   }
   {
    cl_object v6;
    v6 = v5;
    if (ecl_unlikely(ECL_ATOM(v6))) FEtype_error_cons(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T0 = v6;
   }
   T1 = ecl_function_dispatch(cl_env_copy,VV[1753])(1, v2);
   v5 = ecl_list1(T1);
   (ECL_CONS_CDR(T0)=v5,T0);
   goto L9;
L10:;
   value0 = ecl_cdr(v4);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4820registered_systems_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1769]);
 {
  return L4820registered_systems();
 }
}
/* function definition for REGISTER-SYSTEM                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4822register_system(cl_object volatile v1asdf_system_system)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = v1asdf_system_system;
  if (si_of_class_p(2, v2, VV[1695])!=ECL_NIL) {
   goto L4;
  }
  v1asdf_system_system = si_do_check_type(v2, VV[1695], ECL_NIL, VV[1695]);
L4:;
 }
 {
  volatile cl_object v2asdf_component_name;
  v2asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1636]))->cfun.entry(1, v1asdf_system_system) /*  COMPONENT-NAME */;
  {
   cl_object v3;
   v3 = v2asdf_component_name;
   if (ECL_STRINGP(v3)) {
    goto L10;
   }
   v2asdf_component_name = si_do_check_type(v3, ECL_SYM("STRING",808), ECL_NIL, VV[1772]);
L10:;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[1611]))->cfun.entry(2, VV[1773], v1asdf_system_system) /*  ASDF-MESSAGE */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1764]))->cfun.entry(1, v2asdf_component_name) /*  REGISTERED-SYSTEM */;
  if ((v1asdf_system_system)==(T0)) {
   goto L14;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,VV[1761]);
  {
   volatile cl_object env1 = env0;
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(ECL_NIL,env1);
   {
    volatile cl_object env2 = env1;
    CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY       */
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
     if (__ecl_frs_push_result!=0) {
     if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
      goto L18;
     }
     ecl_internal_error("GO found an inexistent tag");
     } else {
     {
      cl_object v3;
      v3 = ecl_make_cclosure_va((cl_objectfn)LC4821__lambda4860,env2,Cblock,1);
      T2 = v3;
     }
     T3 = CONS(ECL_SYM("ERROR",339),T2);
     T4 = ecl_list1(T3);
     T5 = CONS(T4,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
     ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T5); /*  *HANDLER-CLUSTERS* */
     T2 = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, v1asdf_system_system) /*  SYSTEM-SOURCE-FILE */;
     T1 = (cl_env_copy->function=ecl_fdefinition(VV[1734]))->cfun.entry(1, T2) /*  GET-FILE-STAMP */;
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     goto L17;
L18:;
     {
      cl_object v3condition;
      v3condition = ECL_CONS_CAR(CLV0);
      cl_env_copy->nvalues = 2;
      cl_env_copy->values[1] = v3condition;
      cl_env_copy->values[0] = ECL_NIL;
      T1 = cl_env_copy->values[0];
      ecl_frs_pop_n(cl_env_copy, 1);
      goto L17;
     }
     }
    }
   }
  }
L17:;
  T2 = CONS(T1,v1asdf_system_system);
  value0 = si_hash_set(v2asdf_component_name, T0, T2);
  return value0;
L14:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4822register_system_va(cl_narg narg, cl_object v3asdf_system_system, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1771]);
 {
  return L4822register_system(v3asdf_system_system);
 }
}
/* function definition for MAKE-PRELOADED-SYSTEM                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4823make_preloaded_system(cl_object v1asdf_component_name, cl_object v2asdf_find_system__keys)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_system_system;
  T0 = cl_getf(3, v2asdf_find_system__keys, VV[1779], VV[1695]);
  T1 = cl_getf(2, v2asdf_find_system__keys, VV[1780]);
  T2 = (cl_env_copy->function=ecl_fdefinition(VV[261]))->cfun.entry(2, VV[1781], v2asdf_find_system__keys) /*  REMOVE-PLIST-KEYS */;
  v3asdf_system_system = cl_apply(7, ECL_SYM("MAKE-INSTANCE",953), T0, ECL_SYM("NAME",1309), v1asdf_component_name, VV[1780], T1, T2);
  (cl_env_copy->function=ecl_fdefinition(VV[1782]))->cfun.entry(1, v3asdf_system_system) /*  MARK-COMPONENT-PRELOADED */;
  value0 = v3asdf_system_system;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4823make_preloaded_system_va(cl_narg narg, cl_object v4asdf_component_name, cl_object v5asdf_find_system__keys, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1778]);
 {
  return L4823make_preloaded_system(v4asdf_component_name, v5asdf_find_system__keys);
 }
}
/* function definition for SYSDEF-PRELOADED-SYSTEM-SEARCH                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4824sysdef_preloaded_system_search(cl_object v1asdf_find_system__requested)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_component_name;
  v2asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_find_system__requested) /*  COERCE-NAME */;
  {
   cl_object v3;                                  /*  KEYS                    */
   cl_object v4;                                  /*  FOUNDP                  */
   value0 = cl_gethash(2, v2asdf_component_name, ecl_cmp_symbol_value(cl_env_copy,VV[1777]));
   {
    v3 = value0;
    v4 = cl_env_copy->values[1];
   }
   if (Null(v4)){
    goto L4;
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1778]))->cfun.entry(2, v2asdf_component_name, v3) /*  MAKE-PRELOADED-SYSTEM */;
   return value0;
L4:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4824sysdef_preloaded_system_search_va(cl_narg narg, cl_object v3asdf_find_system__requested, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1784]);
 {
  return L4824sysdef_preloaded_system_search(v3asdf_find_system__requested);
 }
}
/* function definition for ENSURE-PRELOADED-SYSTEM-REGISTERED                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4825ensure_preloaded_system_registered(cl_object v1asdf_component_name)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_system_system;
  if ((cl_env_copy->function=ecl_fdefinition(VV[1764]))->cfun.entry(1, v1asdf_component_name) /*  REGISTERED-SYSTEM */!=ECL_NIL) {
   goto L4;
  }
  v2asdf_system_system = (cl_env_copy->function=ecl_fdefinition(VV[1784]))->cfun.entry(1, v1asdf_component_name) /*  SYSDEF-PRELOADED-SYSTEM-SEARCH */;
  goto L2;
L4:;
  v2asdf_system_system = ECL_NIL;
  goto L2;
L2:;
  if (Null(v2asdf_system_system)){
   goto L6;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1771]))->cfun.entry(1, v2asdf_system_system) /*  REGISTER-SYSTEM */;
  return value0;
L6:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4825ensure_preloaded_system_registered_va(cl_narg narg, cl_object v3asdf_component_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1786]);
 {
  return L4825ensure_preloaded_system_registered(v3asdf_component_name);
 }
}
/* function definition for ENSURE-ALL-PRELOADED-SYSTEMS-REGISTERED            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4826ensure_all_preloaded_systems_registered()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2;
  cl_object v3asdf_component_name;
  cl_object v4;
  v1 = ecl_cmp_symbol_value(cl_env_copy,VV[1777]);
  v2 = ECL_NIL;
  v3asdf_component_name = ECL_NIL;
  v4 = ECL_NIL;
  {
   cl_object v5;
   v5 = si_hash_table_iterator(v1);
L7:;
   {
    cl_object v6;
    cl_object v7;
    cl_object v8;
    value0 = ecl_function_dispatch(cl_env_copy,v5)(0);
    {
     const int v9 = cl_env_copy->nvalues;
     v6 = value0;
     cl_object v10;
     v10 = (v9<=1)? ECL_NIL : cl_env_copy->values[1];
     v7 = v10;
     v10 = (v9<=2)? ECL_NIL : cl_env_copy->values[2];
     v8 = v10;
    }
    if (Null(v6)){
     goto L12;
    }
    v4 = v8;
    v3asdf_component_name = v7;
L12:;
    v2 = v6;
    if (v2!=ECL_NIL) {
     goto L9;
    }
   }
   goto L8;
L9:;
   (cl_env_copy->function=ecl_fdefinition(VV[1786]))->cfun.entry(1, v3asdf_component_name) /*  ENSURE-PRELOADED-SYSTEM-REGISTERED */;
   goto L7;
L8:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4826ensure_all_preloaded_systems_registered_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1788]);
 {
  return L4826ensure_all_preloaded_systems_registered();
 }
}
/* function definition for REGISTER-PRELOADED-SYSTEM                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4827register_preloaded_system(cl_narg narg, cl_object v1asdf_find_system__system_name, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1791]);
 {
  cl_object v2asdf_find_system__keys;
  cl_object v3asdf_component_version;
  ecl_va_list args; ecl_va_start(args,v1asdf_find_system__system_name,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4827register_preloaded_systemkeys,keyvars,(cl_object*)&v2asdf_find_system__keys,TRUE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v3asdf_component_version = ECL_T;
   } else {
    v3asdf_component_version = keyvars[0];
   }
  }
  {
   cl_object v4asdf_component_name;
   v4asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_find_system__system_name) /*  COERCE-NAME */;
   if (!((v3asdf_component_version)==(ECL_T))){
    goto L3;
   }
   {
    cl_object v5asdf_system_system;
    v5asdf_system_system = (cl_env_copy->function=ecl_fdefinition(VV[1764]))->cfun.entry(1, v4asdf_component_name) /*  REGISTERED-SYSTEM */;
    if (Null(v5asdf_system_system)){
     goto L3;
    }
    {
     cl_object v6;
     v6 = (cl_env_copy->function=ecl_fdefinition(VV[1643]))->cfun.entry(1, v5asdf_system_system) /*  COMPONENT-VERSION */;
     {
      cl_object v7;
      v7 = si_put_f(v2asdf_find_system__keys, v6, ECL_SYM("VERSION",1364));
      v2asdf_find_system__keys = v7;
     }
    }
   }
L3:;
   si_hash_set(v4asdf_component_name, ecl_cmp_symbol_value(cl_env_copy,VV[1777]), v2asdf_find_system__keys);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1786]))->cfun.entry(1, v1asdf_find_system__system_name) /*  ENSURE-PRELOADED-SYSTEM-REGISTERED */;
   return value0;
  }
 }
}
/* function definition for SYSDEF-IMMUTABLE-SYSTEM-SEARCH                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4828sysdef_immutable_system_search(cl_object v1asdf_find_system__requested)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_component_name;
  v2asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_find_system__requested) /*  COERCE-NAME */;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1793]))){
   goto L3;
  }
  if (Null(ecl_gethash_safe(v2asdf_component_name,ecl_cmp_symbol_value(cl_env_copy,VV[1793]),ECL_NIL))){
   goto L3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1764]))->cfun.entry(1, v1asdf_find_system__requested) /*  REGISTERED-SYSTEM */;
  if (value0!=ECL_NIL) {
   goto L7;
  }
  T0 = ecl_list1(v2asdf_component_name);
  value0 = cl_error(5, VV[1739], ECL_SYM("FORMAT-CONTROL",1272), VV[1795], ECL_SYM("FORMAT-ARGUMENTS",1271), T0);
  return value0;
L7:;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4828sysdef_immutable_system_search_va(cl_narg narg, cl_object v3asdf_find_system__requested, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1794]);
 {
  return L4828sysdef_immutable_system_search(v3asdf_find_system__requested);
 }
}
/* function definition for REGISTER-IMMUTABLE-SYSTEM                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4829register_immutable_system(cl_narg narg, cl_object v1asdf_find_system__system_name, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1797]);
 {
  cl_object v2asdf_find_system__keys;
  ecl_va_list args; ecl_va_start(args,v1asdf_find_system__system_name,narg,1);
  v2asdf_find_system__keys = cl_grab_rest_args(args);
  ecl_va_end(args);
  {
   cl_object v3asdf_find_system__system_name;
   v3asdf_find_system__system_name = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_find_system__system_name) /*  COERCE-NAME */;
   cl_apply(3, VV[1791], v3asdf_find_system__system_name, v2asdf_find_system__keys);
   if (ecl_cmp_symbol_value(cl_env_copy,VV[1793])!=ECL_NIL) {
    goto L3;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[369]))->cfun.entry(1, ECL_NIL) /*  LIST-TO-HASH-SET */;
   ecl_cmp_setq(cl_env_copy,VV[1793],T0);
L3:;
   value0 = si_hash_set(v3asdf_find_system__system_name, ecl_cmp_symbol_value(cl_env_copy,VV[1793]), ECL_T);
   return value0;
  }
 }
}
/* function definition for CLEAR-SYSTEM                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4830clear_system(cl_object v1asdf_system_system)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_component_name;
  v2asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_system_system) /*  COERCE-NAME */;
  cl_remhash(v2asdf_component_name, ecl_cmp_symbol_value(cl_env_copy,VV[1761]));
  T0 = cl_list(2, VV[1690], v2asdf_component_name);
  (cl_env_copy->function=ecl_fdefinition(VV[1706]))->cfun.entry(1, T0) /*  UNSET-ASDF-CACHE-ENTRY */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1786]))->cfun.entry(1, v2asdf_component_name) /*  ENSURE-PRELOADED-SYSTEM-REGISTERED */;
  value0 = Null(T0)?ECL_T:ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4830clear_system_va(cl_narg narg, cl_object v3asdf_system_system, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1799]);
 {
  return L4830clear_system(v3asdf_system_system);
 }
}
/* function definition for CLEAR-DEFINED-SYSTEMS                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4831clear_defined_systems()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2;
  cl_object v3asdf_component_name;
  cl_object v4;
  v1 = ecl_cmp_symbol_value(cl_env_copy,VV[1761]);
  v2 = ECL_NIL;
  v3asdf_component_name = ECL_NIL;
  v4 = ECL_NIL;
  {
   cl_object v5;
   v5 = si_hash_table_iterator(v1);
L7:;
   {
    cl_object v6;
    cl_object v7;
    cl_object v8;
    value0 = ecl_function_dispatch(cl_env_copy,v5)(0);
    {
     const int v9 = cl_env_copy->nvalues;
     v6 = value0;
     cl_object v10;
     v10 = (v9<=1)? ECL_NIL : cl_env_copy->values[1];
     v7 = v10;
     v10 = (v9<=2)? ECL_NIL : cl_env_copy->values[2];
     v8 = v10;
    }
    if (Null(v6)){
     goto L12;
    }
    v4 = v8;
    v3asdf_component_name = v7;
L12:;
    v2 = v6;
    if (v2!=ECL_NIL) {
     goto L9;
    }
   }
   goto L8;
L9:;
   if (ecl_equal(v3asdf_component_name,VV[1803])) {
    goto L18;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[1799]))->cfun.entry(1, v3asdf_component_name) /*  CLEAR-SYSTEM */;
L18:;
   goto L7;
L8:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4831clear_defined_systems_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1801]);
 {
  return L4831clear_defined_systems();
 }
}
/* function definition for MAP-SYSTEMS                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4832map_systems(cl_object v1asdf_find_system__fn)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3;
  cl_object v4asdf_find_system__registered;
  cl_object v5;
  v2 = ecl_cmp_symbol_value(cl_env_copy,VV[1761]);
  v3 = ECL_NIL;
  v4asdf_find_system__registered = ECL_NIL;
  v5 = ECL_NIL;
  {
   cl_object v6;
   v6 = si_hash_table_iterator(v2);
L7:;
   {
    cl_object v7;
    cl_object v8;
    cl_object v9;
    value0 = ecl_function_dispatch(cl_env_copy,v6)(0);
    {
     const int v10 = cl_env_copy->nvalues;
     v7 = value0;
     cl_object v11;
     v11 = (v10<=1)? ECL_NIL : cl_env_copy->values[1];
     v8 = v11;
     v11 = (v10<=2)? ECL_NIL : cl_env_copy->values[2];
     v9 = v11;
    }
    if (Null(v7)){
     goto L12;
    }
    v4asdf_find_system__registered = v9;
    v5 = v8;
L12:;
    v3 = v7;
    if (v3!=ECL_NIL) {
     goto L9;
    }
   }
   goto L8;
L9:;
   T0 = ecl_cdr(v4asdf_find_system__registered);
   ecl_function_dispatch(cl_env_copy,v1asdf_find_system__fn)(1, T0);
   goto L7;
L8:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4832map_systems_va(cl_narg narg, cl_object v7asdf_find_system__fn, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1805]);
 {
  return L4832map_systems(v7asdf_find_system__fn);
 }
}
/* function definition for CLEANUP-SYSTEM-DEFINITION-SEARCH-FUNCTIONS         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4835cleanup_system_definition_search_functions()
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(VV[1810],env1);              /*  OBSOLETE                */
  {
   cl_object v1;
   v1 = ecl_make_cclosure_va((cl_objectfn)LC4833__lambda5029,env1,Cblock,1);
   T1 = v1;
  }
  T0 = cl_remove_if(2, T1, ecl_cmp_symbol_value(cl_env_copy,VV[1808]));
 }
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC4834__lambda5041_va,ECL_NIL,Cblock,1);
  T1 = v1;
 }
 T2 = cl_remove_if(2, T1, VV[1813]);
 T3 = ecl_append(T0,T2);
 ecl_cmp_setq(cl_env_copy,VV[1808],T3);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[1808]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4835cleanup_system_definition_search_functions_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1809]);
 {
  return L4835cleanup_system_definition_search_functions();
 }
}
/* function definition for SEARCH-FOR-SYSTEM-DEFINITION                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4837search_for_system_definition(cl_object volatile v1asdf_system_system)
{
 cl_object T0;
 cl_object volatile env0 = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env0); /*  SEARCH-FOR-SYSTEM-DEFINITION */
  {
   ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV0));
   if (__ecl_frs_push_result!=0) {
   ecl_frs_pop_n(cl_env_copy, 1);
   return cl_env_copy->values[0];
   } else {
   {
    cl_object env1 = env0;
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_system_system) /*  COERCE-NAME */;
    CLV1 = env1 = CONS(T0,env1);                  /*  NAME                    */
    {
     cl_object v2;
     v2 = ecl_make_cclosure_va((cl_objectfn)LC4836try,env1,Cblock,1);
     (aux_closure.env=env1,cl_env_copy->function=(cl_object)&aux_closure,LC4836try(1, VV[1817]));
     (aux_closure.env=env1,cl_env_copy->function=(cl_object)&aux_closure,LC4836try(1, VV[1794]));
     value0 = cl_map(3, ECL_NIL, v2, ecl_cmp_symbol_value(cl_env_copy,VV[1808]));
     ecl_frs_pop_n(cl_env_copy, 1);
     return value0;
    }
   }
   }
  }
 }
}
static cl_object L4837search_for_system_definition_va(cl_narg narg, cl_object v2asdf_system_system, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1815]);
 {
  return L4837search_for_system_definition(v2asdf_system_system);
 }
}
/* function definition for PROBE-ASD                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4839probe_asd(cl_narg narg, cl_object v1asdf_component_name, cl_object v2asdf_find_system__defaults, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1820]);
 {
  cl_object v3truename;
  ecl_va_list args; ecl_va_start(args,v2asdf_find_system__defaults,narg,2);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v2asdf_find_system__defaults,env0); /*  DEFAULTS         */
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L4839probe_asdkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v3truename = keyvars[0];
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  DIRECTORY-PATHNAME-P */)){
   goto L1;
  }
  {
   cl_object v4asdf_find_system__file;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(3, v1asdf_component_name, ECL_SYM("TYPE",1356), VV[1821]) /*  PARSE-UNIX-NAMESTRING */;
   {
    cl_object v5;
    v5 = ecl_make_cclosure_va((cl_objectfn)LC4838__lambda5056,env0,Cblock,0);
    T1 = v5;
   }
   T2 = (cl_env_copy->function=ecl_fdefinition(VV[617]))->cfun.entry(3, T0, T1, ECL_NIL) /*  ENSURE-ABSOLUTE-PATHNAME */;
   v4asdf_find_system__file = (cl_env_copy->function=ecl_fdefinition(VV[669]))->cfun.entry(3, T2, VV[681], v3truename) /*  PROBE-FILE* */;
   if (Null(v4asdf_find_system__file)){
    goto L3;
   }
   value0 = v4asdf_find_system__file;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for SYSDEF-CENTRAL-REGISTRY-SEARCH                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4845sysdef_central_registry_search(cl_object volatile v1asdf_system_system)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v2;
  volatile cl_object v3asdf_find_system__to_remove;
  volatile cl_object v4asdf_find_system__to_replace;
  v2 = (cl_env_copy->function=ecl_fdefinition(VV[1756]))->cfun.entry(1, v1asdf_system_system) /*  PRIMARY-SYSTEM-NAME */;
  v3asdf_find_system__to_remove = ECL_NIL;
  v4asdf_find_system__to_replace = ECL_NIL;
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    {
     volatile cl_object v5;
     v5 = ecl_cmp_symbol_value(cl_env_copy,VV[1819]);
     goto L9;
L8:;
     {
      volatile cl_object env1 = env0;
      T0 = ecl_car(v5);
      env1 = ECL_NIL;
      CLV0 = env1 = CONS(T0,env1);                /*  DIR                     */
      {
       volatile cl_object v6;
       volatile cl_object env2 = env1;
       v6 = cl_eval(ECL_CONS_CAR(CLV0));
       CLV1 = env2 = CONS(v6,env2);               /*  DEFAULTS                */
       CLV2 = env2 = CONS(ECL_NIL,env2);          /*  DIRECTORIZED            */
       if (Null(ECL_CONS_CAR(CLV1))){
        goto L12;
       }
       if (Null((cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, ECL_CONS_CAR(CLV1)) /*  DIRECTORY-PATHNAME-P */)){
        goto L15;
       }
       {
        cl_object v7asdf_find_system__file;
        v7asdf_find_system__file = (cl_env_copy->function=ecl_fdefinition(VV[1820]))->cfun.entry(4, v2, ECL_CONS_CAR(CLV1), VV[681], ecl_cmp_symbol_value(cl_env_copy,VV[715])) /*  PROBE-ASD */;
        if (Null(v7asdf_find_system__file)){
         goto L12;
        }
        cl_env_copy->values[0] = v7asdf_find_system__file;
        cl_env_copy->nvalues = 1;
        goto L5;
       }
L15:;
       {
        volatile cl_object env3 = env2;
        CLV3 = env3 = CONS(ECL_NIL,env3);
        {
         volatile cl_object env4 = env3;
         CLV4 = env4 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env4); /*  TAGBODY  */
         {
          ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV4));
          if (__ecl_frs_push_result!=0) {
          if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
          goto L19;
          }
          if (cl_env_copy->values[0]==ecl_make_int8_t(1)) {
          goto L20;
          }
          ecl_internal_error("GO found an inexistent tag");
          } else {
          {
          cl_object v8;
          v8 = ecl_make_cclosure_va((cl_objectfn)LC4840__lambda5119,env4,Cblock,0);
          T0 = v8;
          }
          {
          cl_object v8;
          v8 = ecl_make_cfun_va((cl_objectfn)LC4841__lambda5121_va,ECL_NIL,Cblock,1);
          T1 = v8;
          }
          T2 = (cl_env_copy->function=(VV[1715]->symbol.gfdef))->cfun.entry(6, ECL_SYM("NAME",1309), VV[1826], ECL_SYM("FUNCTION",1273), T0, VV[1718], T1) /*  MAKE-RESTART */;
          {
          cl_object v8;
          v8 = ecl_make_cclosure_va((cl_objectfn)LC4842__lambda5123,env4,Cblock,0);
          T3 = v8;
          }
          {
          cl_object v8;
          v8 = ecl_make_cclosure_va((cl_objectfn)LC4843__lambda5125,env4,Cblock,1);
          T4 = v8;
          }
          {
          cl_object v8;
          v8 = ecl_make_cclosure_va((cl_objectfn)LC4844__lambda5127,env4,Cblock,1);
          T5 = v8;
          }
          T6 = (cl_env_copy->function=(VV[1715]->symbol.gfdef))->cfun.entry(8, ECL_SYM("NAME",1309), VV[1830], ECL_SYM("FUNCTION",1273), T3, VV[1718], T4, VV[1834], T5) /*  MAKE-RESTART */;
          T7 = cl_list(2, T2, T6);
          T8 = CONS(T7,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5)));
          ecl_bds_bind(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5),T8); /*  *RESTART-CLUSTERS* */
          {
          cl_object v8asdf_find_system__message;
          ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-CIRCLE*",49),ECL_NIL); /*  *PRINT-CIRCLE* */
          v8asdf_find_system__message = cl_format(5, ECL_NIL, VV[1836], v1asdf_system_system, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1));
          cl_error(1, v8asdf_find_system__message);
          ecl_frs_pop_n(cl_env_copy, 1);
          ecl_bds_unwind1(cl_env_copy);
          ecl_bds_unwind1(cl_env_copy);
          goto L12;
          }
L19:;
          {
          cl_object v8;
          v8 = ECL_CONS_CAR(CLV3);
          if (Null(v8)){
          goto L30;
          }
          si_dm_too_many_arguments(ECL_NIL);
L30:;
          v3asdf_find_system__to_remove = CONS(ECL_CONS_CAR(CLV0),v3asdf_find_system__to_remove);
          ecl_frs_pop_n(cl_env_copy, 1);
          goto L12;
          }
L20:;
          {
          cl_object v8;
          v8 = ECL_CONS_CAR(CLV3);
          if (Null(v8)){
          goto L35;
          }
          si_dm_too_many_arguments(ECL_NIL);
L35:;
          T0 = CONS(ECL_CONS_CAR(CLV0),ECL_CONS_CAR(CLV2));
          v4asdf_find_system__to_replace = CONS(T0,v4asdf_find_system__to_replace);
          ecl_frs_pop_n(cl_env_copy, 1);
          goto L12;
          }
          }
         }
        }
       }
      }
L12:;
     }
     v5 = ecl_cdr(v5);
L9:;
     if (Null(v5)){
      goto L40;
     }
     goto L8;
L40:;
     cl_env_copy->values[0] = ECL_NIL;
     cl_env_copy->nvalues = 1;
    }
L5:;
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   {
    cl_object v5;
    v5 = v3asdf_find_system__to_remove;
    goto L47;
L46:;
    {
     cl_object v6asdf_find_system__dir;
     v6asdf_find_system__dir = ecl_car(v5);
     T0 = cl_remove(2, v6asdf_find_system__dir, ecl_cmp_symbol_value(cl_env_copy,VV[1819]));
     ecl_cmp_setq(cl_env_copy,VV[1819],T0);
    }
    v5 = ecl_cdr(v5);
L47:;
    if (Null(v5)){
     goto L55;
    }
    goto L46;
L55:;
   }
   {
    cl_object v5;
    v5 = v4asdf_find_system__to_replace;
    goto L60;
L59:;
    {
     cl_object v6asdf_find_system__pair;
     v6asdf_find_system__pair = ecl_car(v5);
     {
      cl_object v7asdf_find_system__current;
      cl_object v8asdf_find_system__new;
      cl_object v9position;
      v7asdf_find_system__current = ecl_car(v6asdf_find_system__pair);
      v8asdf_find_system__new = ecl_cdr(v6asdf_find_system__pair);
      v9position = cl_position(2, v7asdf_find_system__current, ecl_cmp_symbol_value(cl_env_copy,VV[1819]));
      T0 = cl_subseq(3, ecl_cmp_symbol_value(cl_env_copy,VV[1819]), ecl_make_int8_t(0), v9position);
      T1 = ecl_list1(v8asdf_find_system__new);
      T2 = ecl_cmp_symbol_value(cl_env_copy,VV[1819]);
      T3 = ecl_one_plus(v9position);
      T4 = cl_subseq(2, T2, T3);
      T5 = cl_append(3, T0, T1, T4);
      ecl_cmp_setq(cl_env_copy,VV[1819],T5);
     }
    }
    v5 = ecl_cdr(v5);
L60:;
    if (Null(v5)){
     goto L72;
    }
    goto L59;
L72:;
   }
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
}
static cl_object L4845sysdef_central_registry_search_va(cl_narg narg, cl_object v5asdf_system_system, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1824]);
 {
  return L4845sysdef_central_registry_search(v5asdf_system_system);
 }
}
/* local function FIND-SYSTEM                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4846find_system(cl_narg narg, cl_object v1asdf_component_name, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1690]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1690]);
 {
  cl_object v2asdf_find_system__error_p;
  va_list args; va_start(args,v1asdf_component_name);
  {
   int i = 1;
   if (i >= narg) {
    v2asdf_find_system__error_p = ECL_T;
   } else {
    i++;
    v2asdf_find_system__error_p = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(v2asdf_find_system__error_p)){
   goto L2;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1751]))->cfun.entry(1, VV[1838]) /*  SYSDEF-ERROR */;
  return value0;
L2:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function FIND-SYSTEM                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4847find_system(cl_narg narg, cl_object v1asdf_component_name, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1690]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1690]);
 {
  cl_object v2asdf_find_system__error_p;
  va_list args; va_start(args,v1asdf_component_name);
  {
   int i = 1;
   if (i >= narg) {
    v2asdf_find_system__error_p = ECL_T;
   } else {
    i++;
    v2asdf_find_system__error_p = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_component_name) /*  COERCE-NAME */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1690]))->cfun.entry(2, T0, v2asdf_find_system__error_p) /*  FIND-SYSTEM */;
  return value0;
 }
}
/* function definition for FIND-SYSTEM-IF-BEING-DEFINED                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4848find_system_if_being_defined(cl_object v1asdf_component_name)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_component_name) /*  COERCE-NAME */;
 T1 = cl_list(2, VV[1690], T0);
 T2 = cl_gethash(2, T1, ecl_cmp_symbol_value(cl_env_copy,VV[1703]));
 value0 = ecl_car(T2);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4848find_system_if_being_defined_va(cl_narg narg, cl_object v2asdf_component_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1817]);
 {
  return L4848find_system_if_being_defined(v2asdf_component_name);
 }
}
/* function definition for LOAD-ASD                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4851load_asd(cl_narg narg, cl_object v1pathname, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1840]);
 {
  ecl_va_list args; ecl_va_start(args,v1pathname,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1pathname,env0);            /*  PATHNAME                */
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L4851load_asdkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   CLV1 = env0 = CONS(keyvars[0],env0);           /*  NAME                    */
   if (Null(keyvars[3])) {
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[819]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  DETECT-ENCODING */;
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[826]))->cfun.entry(1, T0) /*  ENCODING-EXTERNAL-FORMAT */;
    CLV2 = env0 = CONS(T1,env0);                  /*  EXTERNAL-FORMAT         */
   } else {
    CLV2 = env0 = CONS(keyvars[1],env0);          /*  EXTERNAL-FORMAT         */
   }
  }
  {
   cl_object env1 = env0;
   CLV3 = env1 = CONS(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*READTABLE*",67)),env1); /*  READTABLE */
   CLV4 = env1 = CONS(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PRINT-PPRINT-DISPATCH*",56)),env1); /*  PRINT-PPRINT-DISPATCH */
   {
    cl_object v2;
    v2 = ecl_make_cclosure_va((cl_objectfn)LC4850__lambda5146,env1,Cblock,0);
    T0 = v2;
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1712]))->cfun.entry(5, T0, VV[1401], ECL_NIL, ECL_SYM("KEY",1297), ECL_NIL) /*  CALL-WITH-ASDF-CACHE */;
   return value0;
  }
 }
}
/* function definition for CHECK-NOT-OLD-ASDF-SYSTEM                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4853check_not_old_asdf_system(cl_object v1asdf_component_name, cl_object v2pathname)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v2pathname,env0);             /*  PATHNAME                */
 {
  bool v3;
  v3 = ecl_equal(v1asdf_component_name,VV[1803]);
  value0 = (v3)?ECL_NIL:ECL_T;
 }
 if (value0!=ECL_NIL) {
  goto L2;
 }
 value0 = ecl_make_bool(ECL_CONS_CAR(CLV0)==ECL_NIL);
 if (value0!=ECL_NIL) {
  goto L2;
 }
 {
  cl_object v3asdf_find_system__version_pathname;
  cl_object env1 = env0;
  v3asdf_find_system__version_pathname = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(2, ECL_CONS_CAR(CLV0), VV[1849]) /*  SUBPATHNAME */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[669]))->cfun.entry(3, v3asdf_find_system__version_pathname, VV[681], ECL_NIL) /*  PROBE-FILE* */)){
   goto L8;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[916]))->cfun.entry(1, v3asdf_find_system__version_pathname) /*  READ-FILE-FORM */;
  goto L6;
L8:;
  T0 = ECL_NIL;
  goto L6;
L6:;
  CLV1 = env1 = CONS(T0,env1);                    /*  VERSION                 */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1600]))->cfun.entry(0) /*  ASDF-VERSION */;
  CLV2 = env1 = CONS(T0,env1);                    /*  OLD-VERSION             */
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[385]))->cfun.entry(2, ECL_CONS_CAR(CLV2), ECL_CONS_CAR(CLV1)) /*  VERSION< */)){
   goto L10;
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L10:;
  if (!(ecl_equal(ECL_CONS_CAR(CLV2),ECL_CONS_CAR(CLV1)))){
   goto L12;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L12:;
  T0 = cl_namestring(ECL_CONS_CAR(CLV0));
  T1 = cl_list(2, T0, ECL_CONS_CAR(CLV1));
  {
   cl_object v4;
   v4 = ecl_make_cclosure_va((cl_objectfn)LC4852__lambda5156,env1,Cblock,0);
   T2 = v4;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[367]))->cfun.entry(3, T1, ecl_cmp_symbol_value(cl_env_copy,VV[1847]), T2) /*  ENSURE-GETHASH */;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L2:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4853check_not_old_asdf_system_va(cl_narg narg, cl_object v4asdf_component_name, cl_object v5pathname, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1848]);
 {
  return L4853check_not_old_asdf_system(v4asdf_component_name, v5pathname);
 }
}
/* function definition for LOCATE-SYSTEM                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4855locate_system(cl_object v1asdf_component_name)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1asdf_component_name,env0);  /*  NAME                    */
 {
  cl_object v2;
  v2 = ecl_make_cclosure_va((cl_objectfn)LC4854__lambda5171,env0,Cblock,0);
  T0 = v2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1712]))->cfun.entry(5, T0, VV[1401], ECL_NIL, ECL_SYM("KEY",1297), ECL_NIL) /*  CALL-WITH-ASDF-CACHE */;
 return value0;
}
static cl_object L4855locate_system_va(cl_narg narg, cl_object v2asdf_component_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1853]);
 {
  return L4855locate_system(v2asdf_component_name);
 }
}
/* local function FIND-SYSTEM                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4857find_system(volatile cl_narg narg, cl_object volatile v1asdf_component_name, ...)
{
 cl_object T0, T1;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1690]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1690]);
 {
  va_list args; va_start(args,v1asdf_component_name);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1asdf_component_name,env0); /*  NAME                    */
  {
   int i = 1;
   if (i >= narg) {
    CLV1 = env0 = CONS(ECL_T,env0);               /*  ERROR-P                 */
   } else {
    i++;
    CLV1 = env0 = CONS(va_arg(args,cl_object),env0); /*  ERROR-P              */
   }
  }
  va_end(args);
  {
   CLV2 = env0 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env0); /*  FIND-SYSTEM    */
   {
    ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV2));
    if (__ecl_frs_push_result!=0) {
    ecl_frs_pop_n(cl_env_copy, 1);
    return cl_env_copy->values[0];
    } else {
    {
     cl_object volatile v2;
     v2 = ecl_make_cclosure_va((cl_objectfn)LC4856__lambda5190,env0,Cblock,0);
     T0 = v2;
    }
    T1 = cl_list(2, VV[1690], ECL_CONS_CAR(CLV0));
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[1712]))->cfun.entry(5, T0, VV[1401], ECL_NIL, ECL_SYM("KEY",1297), T1) /*  CALL-WITH-ASDF-CACHE */;
    ecl_frs_pop_n(cl_env_copy, 1);
    return value0;
    }
   }
  }
 }
}
/* local function PRINT-OBJECT                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4860print_object(cl_object v1asdf_find_component__c, cl_object v2asdf_find_component__s)
{
 cl_object T0, T1;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 T0 = LC4858call_next_method(2, lex0, v1asdf_find_component__c, ECL_NIL);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1866]))->cfun.entry(1, v1asdf_find_component__c) /*  MISSING-REQUIRED-BY */;
 value0 = cl_format(4, v2asdf_find_component__s, VV[1865], T0, T1);
 return value0;
}
static cl_object LC4860print_object_va(cl_narg narg, cl_object v3asdf_find_component__c, cl_object v4asdf_find_component__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("PRINT-OBJECT",965));
 {
  return LC4860print_object(v3asdf_find_component__c, v4asdf_find_component__s);
 }
}
/* local function PRINT-OBJECT                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4861print_object(cl_object v1asdf_find_component__c, cl_object v2asdf_find_component__s)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1869]))->cfun.entry(1, v1asdf_find_component__c) /*  MISSING-REQUIRES */;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[1870]))->cfun.entry(1, v1asdf_find_component__c) /*  MISSING-PARENT */)){
  goto L3;
 }
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[1870]))->cfun.entry(1, v1asdf_find_component__c) /*  MISSING-PARENT */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, T2) /*  COERCE-NAME */;
 goto L2;
L3:;
 T1 = ECL_NIL;
L2:;
 value0 = cl_format(4, v2asdf_find_component__s, VV[1868], T0, T1);
 return value0;
}
static cl_object LC4861print_object_va(cl_narg narg, cl_object v3asdf_find_component__c, cl_object v4asdf_find_component__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("PRINT-OBJECT",965));
 {
  return LC4861print_object(v3asdf_find_component__c, v4asdf_find_component__s);
 }
}
/* local function PRINT-OBJECT                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4862print_object(cl_object v1asdf_find_component__c, cl_object v2asdf_find_component__s)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1869]))->cfun.entry(1, v1asdf_find_component__c) /*  MISSING-REQUIRES */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1872]))->cfun.entry(1, v1asdf_find_component__c) /*  MISSING-VERSION */;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[1870]))->cfun.entry(1, v1asdf_find_component__c) /*  MISSING-PARENT */)){
  goto L3;
 }
 T3 = (cl_env_copy->function=ecl_fdefinition(VV[1870]))->cfun.entry(1, v1asdf_find_component__c) /*  MISSING-PARENT */;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, T3) /*  COERCE-NAME */;
 goto L2;
L3:;
 T2 = ECL_NIL;
L2:;
 value0 = cl_format(5, v2asdf_find_component__s, VV[1871], T0, T1, T2);
 return value0;
}
static cl_object LC4862print_object_va(cl_narg narg, cl_object v3asdf_find_component__c, cl_object v4asdf_find_component__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("PRINT-OBJECT",965));
 {
  return LC4862print_object(v3asdf_find_component__c, v4asdf_find_component__s);
 }
}
/* local function FIND-COMPONENT                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4863find_component(cl_narg narg, cl_object v1asdf_find_component__base, cl_object v2asdf_find_component__path, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1873]);
 {
  cl_object v3asdf_find_component__registered;
  ecl_va_list args; ecl_va_start(args,v2asdf_find_component__path,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4863find_componentkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3asdf_find_component__registered = keyvars[0];
  }
  {
   cl_object v4asdf_find_component__s;
   if (Null(v3asdf_find_component__registered)){
    goto L2;
   }
   v4asdf_find_component__s = (cl_env_copy->function=ecl_fdefinition(VV[1764]))->cfun.entry(1, v1asdf_find_component__base) /*  REGISTERED-SYSTEM */;
   goto L1;
L2:;
   v4asdf_find_component__s = (cl_env_copy->function=ecl_fdefinition(VV[1690]))->cfun.entry(2, v1asdf_find_component__base, ECL_NIL) /*  FIND-SYSTEM */;
L1:;
   if (Null(v4asdf_find_component__s)){
    goto L4;
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(4, v4asdf_find_component__s, v2asdf_find_component__path, VV[1875], v3asdf_find_component__registered) /*  FIND-COMPONENT */;
   return value0;
L4:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function FIND-COMPONENT                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4864find_component(cl_narg narg, cl_object v1asdf_find_component__base, cl_object v2asdf_find_component__path, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1873]);
 {
  cl_object v3asdf_find_component__registered;
  ecl_va_list args; ecl_va_start(args,v2asdf_find_component__path,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4864find_componentkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3asdf_find_component__registered = keyvars[0];
  }
  if (Null(v1asdf_find_component__base)){
   goto L1;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_find_component__base) /*  COERCE-NAME */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(4, T0, v2asdf_find_component__path, VV[1875], v3asdf_find_component__registered) /*  FIND-COMPONENT */;
  return value0;
L1:;
  if (Null(v2asdf_find_component__path)){
   goto L3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(4, v2asdf_find_component__path, ECL_NIL, VV[1875], v3asdf_find_component__registered) /*  FIND-COMPONENT */;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function FIND-COMPONENT                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4865find_component(cl_narg narg, cl_object v1asdf_find_component__base, cl_object v2asdf_find_component__path, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1873]);
 {
  cl_object v3asdf_find_component__registered;
  ecl_va_list args; ecl_va_start(args,v2asdf_find_component__path,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4865find_componentkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3asdf_find_component__registered = keyvars[0];
  }
  T0 = ecl_car(v1asdf_find_component__base);
  T1 = ecl_cdr(v1asdf_find_component__base);
  T2 = CONS(T1,v2asdf_find_component__path);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(4, T0, T2, VV[1875], v3asdf_find_component__registered) /*  FIND-COMPONENT */;
  return value0;
 }
}
/* local function FIND-COMPONENT                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4866find_component(cl_narg narg, cl_object v1asdf_component_parent, cl_object v2asdf_component_name, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1873]);
 {
  cl_object v3asdf_find_component__registered;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_name,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4866find_componentkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3asdf_find_component__registered = keyvars[0];
  }
  (cl_env_copy->function=ecl_fdefinition(VV[1668]))->cfun.entry(3, v1asdf_component_parent, VV[1876], ECL_T) /*  COMPUTE-CHILDREN-BY-NAME */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1670]))->cfun.entry(1, v1asdf_component_parent) /*  COMPONENT-CHILDREN-BY-NAME */;
  value0 = ecl_gethash_safe(v2asdf_component_name,T0,ECL_NIL);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function FIND-COMPONENT                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4867find_component(cl_narg narg, cl_object v1asdf_find_component__base, cl_object v2asdf_component_name, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1873]);
 {
  cl_object v3asdf_find_component__registered;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_name,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4867find_componentkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3asdf_find_component__registered = keyvars[0];
  }
  if (Null(v2asdf_component_name)){
   goto L1;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v2asdf_component_name) /*  COERCE-NAME */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(4, v1asdf_find_component__base, T0, VV[1875], v3asdf_find_component__registered) /*  FIND-COMPONENT */;
  return value0;
L1:;
  value0 = v1asdf_find_component__base;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function FIND-COMPONENT                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4868find_component(cl_narg narg, cl_object v1asdf_find_component__c, cl_object v2asdf_component_name, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1873]);
 {
  cl_object v3asdf_find_component__registered;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_name,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4868find_componentkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3asdf_find_component__registered = keyvars[0];
  }
  T0 = ecl_car(v2asdf_component_name);
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(4, v1asdf_find_component__c, T0, VV[1875], v3asdf_find_component__registered) /*  FIND-COMPONENT */;
  T2 = ecl_cdr(v2asdf_component_name);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(4, T1, T2, VV[1875], v3asdf_find_component__registered) /*  FIND-COMPONENT */;
  return value0;
 }
}
/* local function FIND-COMPONENT                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4869find_component(cl_narg narg, cl_object v1asdf_find_component__base, cl_object v2asdf_find_component__actual, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1873]);
 {
  cl_object v3asdf_find_component__registered;
  ecl_va_list args; ecl_va_start(args,v2asdf_find_component__actual,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC4869find_componentkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3asdf_find_component__registered = keyvars[0];
  }
  value0 = v2asdf_find_component__actual;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for RESOLVE-DEPENDENCY-NAME                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4873resolve_dependency_name(volatile cl_narg narg, cl_object volatile v1asdf_component_component, cl_object volatile v2asdf_component_name, ...)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1877]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[1877]);
 {
  cl_object volatile v3asdf_component_version;
  va_list args; va_start(args,v2asdf_component_name);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1asdf_component_component,env0); /*  COMPONENT          */
  CLV1 = env0 = CONS(v2asdf_component_name,env0); /*  NAME                    */
  {
   int i = 2;
   if (i >= narg) {
    v3asdf_component_version = ECL_NIL;
   } else {
    i++;
    v3asdf_component_version = va_arg(args,cl_object);
   }
  }
  va_end(args);
L2:;
  {
   volatile cl_object env1 = env0;
   CLV2 = env1 = CONS(ECL_NIL,env1);
   {
    volatile cl_object env2 = env1;
    CLV3 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY       */
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV3));
     if (__ecl_frs_push_result!=0) {
     if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
      goto L4;
     }
     ecl_internal_error("GO found an inexistent tag");
     } else {
     {
      cl_object v4;
      v4 = ecl_make_cclosure_va((cl_objectfn)LC4870__lambda5228,env2,Cblock,0);
      T0 = v4;
     }
     {
      cl_object v4;
      v4 = ecl_make_cclosure_va((cl_objectfn)LC4871__lambda5230,env2,Cblock,1);
      T1 = v4;
     }
     {
      cl_object v4;
      v4 = ecl_make_cclosure_va((cl_objectfn)LC4872__lambda5232,env2,Cblock,1);
      T2 = v4;
     }
     T3 = (cl_env_copy->function=(VV[1715]->symbol.gfdef))->cfun.entry(8, ECL_SYM("NAME",1309), VV[1716], ECL_SYM("FUNCTION",1273), T0, VV[1834], T1, VV[1718], T2) /*  MAKE-RESTART */;
     T4 = ecl_list1(T3);
     T5 = CONS(T4,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5)));
     ecl_bds_bind(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5),T5); /*  *RESTART-CLUSTERS* */
     {
      cl_object v4asdf_find_component__comp;
      T0 = (cl_env_copy->function=ecl_fdefinition(VV[1644]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  COMPONENT-PARENT */;
      v4asdf_find_component__comp = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, T0, ECL_CONS_CAR(CLV1)) /*  FIND-COMPONENT */;
      if (v4asdf_find_component__comp!=ECL_NIL) {
       goto L10;
      }
      cl_error(5, VV[1864], VV[1883], ECL_CONS_CAR(CLV0), VV[1862], ECL_CONS_CAR(CLV1));
L10:;
      if (Null(v3asdf_component_version)){
       goto L12;
      }
      if ((cl_env_copy->function=ecl_fdefinition(VV[1642]))->cfun.entry(2, v4asdf_find_component__comp, v3asdf_component_version) /*  VERSION-SATISFIES */!=ECL_NIL) {
       goto L12;
      }
      cl_error(7, VV[1867], VV[1883], ECL_CONS_CAR(CLV0), ECL_SYM("VERSION",1364), v3asdf_component_version, VV[1862], ECL_CONS_CAR(CLV1));
L12:;
      value0 = v4asdf_find_component__comp;
      cl_env_copy->nvalues = 1;
      ecl_frs_pop_n(cl_env_copy, 1);
      ecl_bds_unwind1(cl_env_copy);
      return value0;
     }
L4:;
     {
      cl_object v4;
      v4 = ECL_CONS_CAR(CLV2);
      if (Null(v4)){
       goto L17;
      }
      si_dm_too_many_arguments(ECL_NIL);
L17:;
      if ((cl_env_copy->function=ecl_fdefinition(VV[1644]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  COMPONENT-PARENT */!=ECL_NIL) {
       ecl_frs_pop_n(cl_env_copy, 1);
       goto L3;
      }
      {
       cl_object v5asdf_component_name;
       v5asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, ECL_CONS_CAR(CLV1)) /*  COERCE-NAME */;
       T0 = cl_list(2, VV[1690], v5asdf_component_name);
       (cl_env_copy->function=ecl_fdefinition(VV[1706]))->cfun.entry(1, T0) /*  UNSET-ASDF-CACHE-ENTRY */;
       T0 = cl_list(2, VV[1853], v5asdf_component_name);
       (cl_env_copy->function=ecl_fdefinition(VV[1706]))->cfun.entry(1, T0) /*  UNSET-ASDF-CACHE-ENTRY */;
       ecl_frs_pop_n(cl_env_copy, 1);
       goto L3;
      }
     }
     }
    }
   }
  }
L3:;
  goto L2;
 }
}
/* function definition for RESOLVE-DEPENDENCY-SPEC                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4874resolve_dependency_spec(cl_object v1asdf_component_component, cl_object v2asdf_find_component__dep_spec)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_component_component;
  v3asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v1asdf_component_component) /*  FIND-COMPONENT */;
  if (!(ECL_ATOM(v2asdf_find_component__dep_spec))){
   goto L3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1877]))->cfun.entry(2, v3asdf_component_component, v2asdf_find_component__dep_spec) /*  RESOLVE-DEPENDENCY-NAME */;
  return value0;
L3:;
  T0 = ecl_car(v2asdf_find_component__dep_spec);
  T1 = ecl_cdr(v2asdf_find_component__dep_spec);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1874]))->cfun.entry(3, v3asdf_component_component, T0, T1) /*  RESOLVE-DEPENDENCY-COMBINATION */;
  return value0;
 }
}
static cl_object L4874resolve_dependency_spec_va(cl_narg narg, cl_object v4asdf_component_component, cl_object v5asdf_find_component__dep_spec, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1885]);
 {
  return L4874resolve_dependency_spec(v4asdf_component_component, v5asdf_find_component__dep_spec);
 }
}
/* local function RESOLVE-DEPENDENCY-COMBINATION                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4875resolve_dependency_combination(cl_object v1asdf_component_component, cl_object v2asdf_find_component__combinator, cl_object v3asdf_find_component__arguments)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = CONS(v2asdf_find_component__combinator,v3asdf_find_component__arguments);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[416]))->cfun.entry(4, VV[1887], VV[1874], T0, v1asdf_component_component) /*  PARAMETER-ERROR */;
 return value0;
}
static cl_object LC4875resolve_dependency_combination_va(cl_narg narg, cl_object v4asdf_component_component, cl_object v5asdf_find_component__combinator, cl_object v6asdf_find_component__arguments, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[1874]);
 {
  return LC4875resolve_dependency_combination(v4asdf_component_component, v5asdf_find_component__combinator, v6asdf_find_component__arguments);
 }
}
/* local function RESOLVE-DEPENDENCY-COMBINATION                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4876resolve_dependency_combination(cl_object v1asdf_component_component, cl_object v2asdf_find_component__combinator, cl_object v3asdf_find_component__arguments)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_car(v3asdf_find_component__arguments);
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[420]))->cfun.entry(1, T0) /*  FEATUREP */)){
  goto L2;
 }
 T0 = ecl_cadr(v3asdf_find_component__arguments);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1885]))->cfun.entry(2, v1asdf_component_component, T0) /*  RESOLVE-DEPENDENCY-SPEC */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4876resolve_dependency_combination_va(cl_narg narg, cl_object v4asdf_component_component, cl_object v5asdf_find_component__combinator, cl_object v6asdf_find_component__arguments, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[1874]);
 {
  return LC4876resolve_dependency_combination(v4asdf_component_component, v5asdf_find_component__combinator, v6asdf_find_component__arguments);
 }
}
/* local function RESOLVE-DEPENDENCY-COMBINATION                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4877resolve_dependency_combination(cl_object v1asdf_component_component, cl_object v2asdf_find_component__combinator, cl_object v3asdf_find_component__arguments)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_car(v3asdf_find_component__arguments);
 T1 = ecl_cadr(v3asdf_find_component__arguments);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1877]))->cfun.entry(3, v1asdf_component_component, T0, T1) /*  RESOLVE-DEPENDENCY-NAME */;
 return value0;
}
static cl_object LC4877resolve_dependency_combination_va(cl_narg narg, cl_object v4asdf_component_component, cl_object v5asdf_find_component__combinator, cl_object v6asdf_find_component__arguments, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[1874]);
 {
  return LC4877resolve_dependency_combination(v4asdf_component_component, v5asdf_find_component__combinator, v6asdf_find_component__arguments);
 }
}
/* local function INITIALIZE-INSTANCE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4878initialize_instance(cl_narg narg, cl_object v1asdf_operation__o, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("INITIALIZE-INSTANCE",951));
 {
  cl_object v2asdf_operation__initargs;
  cl_object v3asdf_operation__force;
  cl_object v4asdf_operation__force_not;
  cl_object v5asdf_operation__system;
  cl_object v6asdf_operation__verbose;
  ecl_va_list args; ecl_va_start(args,v1asdf_operation__o,narg,1);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,LC4878initialize_instancekeys,keyvars,(cl_object*)&v2asdf_operation__initargs,TRUE);
   ecl_va_end(args);
   v3asdf_operation__force = keyvars[0];
   v4asdf_operation__force_not = keyvars[1];
   v5asdf_operation__system = keyvars[2];
   v6asdf_operation__verbose = keyvars[3];
  }
  if (cl_slot_boundp(v1asdf_operation__o, VV[1890])!=ECL_NIL) {
   goto L1;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1892]))->cfun.entry(2, v2asdf_operation__initargs, v1asdf_operation__o) /*  (SETF OPERATION-ORIGINAL-INITARGS) */;
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function PRINT-OBJECT                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4881print_object(cl_object volatile v1asdf_operation__o, cl_object volatile v2stream)
{
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1asdf_operation__o,env0);    /*  O                       */
 CLV1 = env0 = CONS(v2stream,env0);               /*  STREAM                  */
 {
  cl_object volatile v3;
  v3 = ecl_make_cclosure_va((cl_objectfn)LC4880si___print_unreadable_object_body_,env0,Cblock,0);
  value0 = si_print_unreadable_object_function(ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1), ECL_T, ECL_NIL, v3);
  return value0;
 }
}
static cl_object LC4881print_object_va(cl_narg narg, cl_object v4asdf_operation__o, cl_object v5stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("PRINT-OBJECT",965));
 {
  return LC4881print_object(v4asdf_operation__o, v5stream);
 }
}
/* function definition for %COMPUTE-OPERATIONS-VALUE                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4882_compute_operations_value()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
 return value0;
}
static cl_object L4882_compute_operations_value_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1895]);
 {
  return L4882_compute_operations_value();
 }
}
/* function definition for MAKE-OPERATION                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4883make_operation(cl_narg narg, cl_object v1asdf_operation__operation_class, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1898]);
 {
  cl_object v2asdf_operation__initargs;
  ecl_va_list args; ecl_va_start(args,v1asdf_operation__operation_class,narg,1);
  v2asdf_operation__initargs = cl_grab_rest_args(args);
  ecl_va_end(args);
  {
   cl_object v3class;
   v3class = (cl_env_copy->function=ecl_fdefinition(VV[361]))->cfun.entry(7, v1asdf_operation__operation_class, ECL_SYM("PACKAGE",1321), VV[1899], VV[1900], VV[1889], ECL_SYM("ERROR",1260), VV[1751]) /*  COERCE-CLASS */;
   T0 = CONS(v3class,v2asdf_operation__initargs);
   T1 = ecl_cmp_symbol_value(cl_env_copy,VV[1897]);
   T2 = cl_listX(3, ECL_SYM("MAKE-INSTANCE",953), v3class, v2asdf_operation__initargs);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[367]))->cfun.entry(3, T0, T1, T2) /*  ENSURE-GETHASH */;
   return value0;
  }
 }
}
/* local function FIND-OPERATION                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4884find_operation(cl_object v1asdf_operation__context, cl_object v2asdf_operation__spec)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = v2asdf_operation__spec;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4884find_operation_va(cl_narg narg, cl_object v3asdf_operation__context, cl_object v4asdf_operation__spec, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1902]);
 {
  return LC4884find_operation(v3asdf_operation__context, v4asdf_operation__spec);
 }
}
/* local function FIND-OPERATION                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4885find_operation(cl_object v1asdf_operation__context, cl_object v2asdf_operation__spec)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v2asdf_operation__spec)){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1891]))->cfun.entry(1, v1asdf_operation__context) /*  OPERATION-ORIGINAL-INITARGS */;
 value0 = cl_apply(3, VV[1898], v2asdf_operation__spec, T0);
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4885find_operation_va(cl_narg narg, cl_object v3asdf_operation__context, cl_object v4asdf_operation__spec, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1902]);
 {
  return LC4885find_operation(v3asdf_operation__context, v4asdf_operation__spec);
 }
}
/* local function FIND-OPERATION                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4886find_operation(cl_object v1asdf_operation__context, cl_object v2asdf_operation__spec)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1891]))->cfun.entry(1, v1asdf_operation__context) /*  OPERATION-ORIGINAL-INITARGS */;
 value0 = cl_apply(3, VV[1898], v2asdf_operation__spec, T0);
 return value0;
}
static cl_object LC4886find_operation_va(cl_narg narg, cl_object v3asdf_operation__context, cl_object v4asdf_operation__spec, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1902]);
 {
  return LC4886find_operation(v3asdf_operation__context, v4asdf_operation__spec);
 }
}
/* local function OPERATION-ORIGINAL-INITARGS                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4887operation_original_initargs(cl_object v1asdf_operation__context)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4887operation_original_initargs_va(cl_narg narg, cl_object v2asdf_operation__context, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1891]);
 {
  return LC4887operation_original_initargs(v2asdf_operation__context);
 }
}
/* local function LAMBDA5292                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4888__lambda5292(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = VV[1905];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4888__lambda5292_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1904]);
 {
  return LC4888__lambda5292(v4, v5);
 }
}
/* local function LAMBDA5297                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4889__lambda5297(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = VV[1908];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4889__lambda5297_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1907]);
 {
  return LC4889__lambda5297(v4, v5);
 }
}
/* function definition for ACTION-PATH                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4890action_path(cl_object v1asdf_action_action)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3asdf_action__o;
  v2 = v1asdf_action_action;
  if (!(v2==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1asdf_action_action);
L4:;
  {
   cl_object v4;
   v4 = ecl_car(v2);
   v2 = ecl_cdr(v2);
   v3asdf_action__o = v4;
  }
  T0 = cl_type_of(v3asdf_action__o);
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[1654]))->cfun.entry(1, v2) /*  COMPONENT-FIND-PATH */;
  value0 = CONS(T0,T1);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4890action_path_va(cl_narg narg, cl_object v4asdf_action_action, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1912]);
 {
  return L4890action_path(v4asdf_action_action);
 }
}
/* function definition for FIND-ACTION                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4891find_action(cl_object v1asdf_action__path)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3asdf_action__o;
  v2 = v1asdf_action__path;
  if (!(v2==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1asdf_action__path);
L4:;
  {
   cl_object v4;
   v4 = ecl_car(v2);
   v2 = ecl_cdr(v2);
   v3asdf_action__o = v4;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, v3asdf_action__o) /*  MAKE-OPERATION */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2) /*  FIND-COMPONENT */;
  value0 = CONS(T0,T1);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4891find_action_va(cl_narg narg, cl_object v4asdf_action__path, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1914]);
 {
  return L4891find_action(v4asdf_action__path);
 }
}
/* local function DEFINE-CONVENIENCE-ACTION-METHODS                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4893define_convenience_action_methods(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22, T23, T24, T25, T26, T27, T28, T29, T30;
 volatile cl_object lex0[5];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4asdf_action__formals;
  cl_object v5;
  cl_object v6asdf_action__if_no_operation;
  cl_object v7;
  cl_object v8asdf_action__if_no_component;
  cl_object v9;
  cl_object v10asdf_action__operation_initargs;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L3;
  }
  si_dm_too_few_arguments(v1);
L3:;
  {
   cl_object v11;
   v11 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   T0 = v11;
  }
  lex0[0] = T0;                                   /*  FUNCTION                */
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v11;
   v11 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4asdf_action__formals = v11;
  }
  v5 = si_search_keyword(v3, VV[1916]);
  if (!((v5)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L17;
  }
  v6asdf_action__if_no_operation = ECL_NIL;
  goto L16;
L17:;
  v6asdf_action__if_no_operation = v5;
L16:;
  v7 = si_search_keyword(v3, VV[1917]);
  if (!((v7)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L21;
  }
  v8asdf_action__if_no_component = ECL_NIL;
  goto L20;
L21:;
  v8asdf_action__if_no_component = v7;
L20:;
  v9 = si_search_keyword(v3, VV[1918]);
  if (!((v9)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L25;
  }
  v10asdf_action__operation_initargs = ECL_NIL;
  goto L24;
L25:;
  v10asdf_action__operation_initargs = v9;
L24:;
  si_check_keyword(2, v3, VV[1920]);
  {
   cl_object v11asdf_action__found;
   cl_object v12asdf_action__formals_no_key;
   cl_object v13asdf_action__len;
   cl_object v14asdf_action__opix;
   cl_object v15asdf_action__coix;
   cl_object v16asdf_action__more_args;
   T0 = cl_gensym(1, VV[1921]);
   lex0[1] = T0;                                  /*  REST                    */
   v11asdf_action__found = cl_gensym(1, VV[1922]);
   T0 = ecl_last(v4asdf_action__formals,1);
   {
    bool v17;
    v17 = ecl_equal(T0,VV[1923]);
    lex0[2] = ecl_make_bool(v17);                 /*  KEYP                    */
   }
   if (Null(lex0[2])){
    goto L30;
   }
   v12asdf_action__formals_no_key = ecl_butlast(v4asdf_action__formals,1);
   goto L29;
L30:;
   v12asdf_action__formals_no_key = v4asdf_action__formals;
L29:;
   v13asdf_action__len = ecl_make_fixnum(ecl_length(v12asdf_action__formals_no_key));
   v14asdf_action__opix = cl_position(2, VV[1889], v4asdf_action__formals);
   v15asdf_action__coix = cl_position(2, VV[1652], v4asdf_action__formals);
   T0 = cl_subseq(3, v4asdf_action__formals, ecl_make_int8_t(0), v14asdf_action__opix);
   lex0[3] = T0;                                  /*  PREFIX                  */
   T0 = ecl_one_plus(v15asdf_action__coix);
   T1 = cl_subseq(3, v4asdf_action__formals, T0, v13asdf_action__len);
   lex0[4] = T1;                                  /*  SUFFIX                  */
   if (Null(lex0[2])){
    goto L36;
   }
   v16asdf_action__more_args = cl_listX(3, ECL_SYM("&REST",14), lex0[1], VV[1924]);
   goto L35;
L36:;
   v16asdf_action__more_args = ECL_NIL;
L35:;
   goto L40;
L39:;
   si_assert_failure(1, VV[1925]);
L40:;
   if (!(ECL_FIXNUMP(v14asdf_action__opix)||ECL_BIGNUMP(v14asdf_action__opix))){
    goto L46;
   }
   if (!(ECL_FIXNUMP(v15asdf_action__coix)||ECL_BIGNUMP(v15asdf_action__coix))){
    goto L46;
   }
   T0 = ecl_one_plus(v14asdf_action__opix);
   if (ecl_number_equalp(v15asdf_action__coix,T0)) {
    goto L43;
   }
   goto L44;
L46:;
   goto L44;
L44:;
   goto L39;
L43:;
   T0 = cl_list(2, VV[1889], ECL_SYM("STRING",808));
   T1 = ecl_append(lex0[4],v16asdf_action__more_args);
   T2 = cl_listX(3, T0, VV[1652], T1);
   T3 = ecl_append(lex0[3],T2);
   T4 = cl_list(3, VV[1873], ECL_NIL, VV[1652]);
   T5 = cl_list(2, VV[1652], T4);
   T6 = ecl_list1(T5);
   T8 = cl_listX(3, VV[834], VV[1889], VV[1927]);
   T7 = LC4892next_method(lex0, T8, VV[1652]);
   T8 = cl_list(3, ECL_SYM("LET",479), T6, T7);
   T9 = cl_list(4, ECL_SYM("DEFMETHOD",944), lex0[0], T3, T8);
   T10 = cl_list(2, VV[1889], ECL_SYM("SYMBOL",843));
   T11 = ecl_append(lex0[4],v16asdf_action__more_args);
   T12 = cl_listX(3, T10, VV[1652], T11);
   T13 = ecl_append(lex0[3],T12);
   if (Null(v10asdf_action__operation_initargs)){
    goto L52;
   }
   T15 = cl_list(6, ECL_SYM("APPLY",91), VV[1928], VV[1889], VV[1929], lex0[1], lex0[1]);
   goto L51;
L52:;
   T15 = cl_list(2, VV[1898], VV[1889]);
L51:;
   T16 = cl_list(3, VV[1873], ECL_NIL, VV[1652]);
   T17 = cl_list(3, ECL_SYM("OR",616), T16, v8asdf_action__if_no_component);
   T14 = LC4892next_method(lex0, T15, T17);
   T15 = cl_list(4, ECL_SYM("IF",950), VV[1889], T14, v6asdf_action__if_no_operation);
   T16 = cl_list(4, ECL_SYM("DEFMETHOD",944), lex0[0], T13, T15);
   T17 = cl_list(2, VV[1889], VV[1889]);
   T18 = ecl_append(lex0[4],v16asdf_action__more_args);
   T19 = cl_listX(3, T17, VV[1652], T18);
   T20 = ecl_append(lex0[3],T19);
   T21 = cl_list(3, ECL_SYM("TYPEP",878), VV[1652], VV[1930]);
   T22 = cl_list(2, ECL_SYM("QUOTE",682), lex0[0]);
   T23 = cl_list(3, ECL_SYM("CONS",253), VV[1889], VV[1652]);
   T24 = cl_list(4, ECL_SYM("ERROR",339), VV[1931], T22, T23);
   T25 = cl_list(3, VV[1873], ECL_NIL, VV[1652]);
   T26 = cl_list(2, v11asdf_action__found, T25);
   T27 = LC4892next_method(lex0, VV[1889], v11asdf_action__found);
   T28 = cl_list(4, VV[239], T26, T27, v8asdf_action__if_no_component);
   T29 = cl_list(4, ECL_SYM("IF",950), T21, T24, T28);
   T30 = cl_list(4, ECL_SYM("DEFMETHOD",944), lex0[0], T20, T29);
   value0 = cl_list(4, ECL_SYM("PROGN",674), T9, T16, T30);
   return value0;
  }
 }
}
static cl_object LC4893define_convenience_action_methods_va(cl_narg narg, cl_object v17, cl_object v18, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1919]);
 {
  return LC4893define_convenience_action_methods(v17, v18);
 }
}
/* local function ACTION-DESCRIPTION                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4894action_description(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_type_of(v1asdf_operation_operation);
 value0 = cl_format(4, ECL_NIL, VV[1934], T0, v2asdf_component_component);
 return value0;
}
static cl_object LC4894action_description_va(cl_narg narg, cl_object v3asdf_operation_operation, cl_object v4asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1933]);
 {
  return LC4894action_description(v3asdf_operation_operation, v4asdf_component_component);
 }
}
/* local function EXPLAIN                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4895explain(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1933]))->cfun.entry(2, v1asdf_action__o, v2asdf_action__c) /*  ACTION-DESCRIPTION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1611]))->cfun.entry(2, VV[1936], T0) /*  ASDF-MESSAGE */;
 return value0;
}
static cl_object LC4895explain_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1935]);
 {
  return LC4895explain(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function EXPLAIN                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4896explain(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_component_component;
  v3asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[834]))->cfun.entry(3, v1asdf_operation_operation, ECL_SYM("PACKAGE",1321), VV[1899]) /*  SAFE-READ-FROM-STRING */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1935]))->cfun.entry(2, T0, v3asdf_component_component) /*  EXPLAIN */;
  return value0;
 }
}
static cl_object LC4896explain_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1935]);
 {
  return LC4896explain(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function EXPLAIN                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4897explain(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1asdf_operation_operation)){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, v1asdf_operation_operation) /*  MAKE-OPERATION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
 if (value0!=ECL_NIL) {
  goto L6;
 }
 T1 = ECL_NIL;
 goto L4;
L6:;
 T1 = value0;
 goto L4;
L4:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1935]))->cfun.entry(2, T0, T1) /*  EXPLAIN */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4897explain_va(cl_narg narg, cl_object v3asdf_operation_operation, cl_object v4asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1935]);
 {
  return LC4897explain(v3asdf_operation_operation, v4asdf_component_component);
 }
}
/* local function EXPLAIN                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4898explain(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_of_class_p(2, v2asdf_component_component, VV[1652]))){
  goto L2;
 }
 T0 = CONS(v1asdf_operation_operation,v2asdf_component_component);
 value0 = cl_error(3, VV[1931], VV[1935], T0);
 return value0;
L2:;
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  if (Null(v3)){
   goto L5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1935]))->cfun.entry(2, v1asdf_operation_operation, v3) /*  EXPLAIN */;
  return value0;
L5:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4898explain_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1935]);
 {
  return LC4898explain(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* function definition for FORMAT-ACTION                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4899format_action(cl_narg narg, cl_object v1stream, cl_object v2asdf_action_action, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1937]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[1937]);
 {
  cl_object v3asdf_action__colon_p;
  cl_object v4asdf_action__at_sign_p;
  va_list args; va_start(args,v2asdf_action_action);
  {
   int i = 2;
   if (i >= narg) {
    v3asdf_action__colon_p = ECL_NIL;
   } else {
    i++;
    v3asdf_action__colon_p = va_arg(args,cl_object);
   }
   if (i >= narg) {
    v4asdf_action__at_sign_p = ECL_NIL;
   } else {
    i++;
    v4asdf_action__at_sign_p = va_arg(args,cl_object);
   }
  }
  va_end(args);
  goto L5;
L4:;
  si_assert_failure(1, VV[1938]);
L5:;
  if (v3asdf_action__colon_p==ECL_NIL) {
   goto L8;
  }
  goto L4;
L8:;
  goto L12;
L11:;
  si_assert_failure(1, VV[1939]);
L12:;
  if (v4asdf_action__at_sign_p==ECL_NIL) {
   goto L15;
  }
  goto L11;
L15:;
  {
   cl_object v5;
   cl_object v6asdf_operation_operation;
   v5 = v2asdf_action_action;
   if (!(v5==ECL_NIL)){
    goto L19;
   }
   si_dm_too_few_arguments(v2asdf_action_action);
L19:;
   {
    cl_object v7;
    v7 = ecl_car(v5);
    v5 = ecl_cdr(v5);
    v6asdf_operation_operation = v7;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1933]))->cfun.entry(2, v6asdf_operation_operation, v5) /*  ACTION-DESCRIPTION */;
   value0 = ecl_princ(T0,v1stream);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4900component_depends_on(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_component_component;
  v3asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[834]))->cfun.entry(3, v1asdf_operation_operation, ECL_SYM("PACKAGE",1321), VV[1899]) /*  SAFE-READ-FROM-STRING */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1941]))->cfun.entry(2, T0, v3asdf_component_component) /*  COMPONENT-DEPENDS-ON */;
  return value0;
 }
}
static cl_object LC4900component_depends_on_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC4900component_depends_on(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4901component_depends_on(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1asdf_operation_operation)){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, v1asdf_operation_operation) /*  MAKE-OPERATION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
 if (value0!=ECL_NIL) {
  goto L6;
 }
 T1 = ECL_NIL;
 goto L4;
L6:;
 T1 = value0;
 goto L4;
L4:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1941]))->cfun.entry(2, T0, T1) /*  COMPONENT-DEPENDS-ON */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4901component_depends_on_va(cl_narg narg, cl_object v3asdf_operation_operation, cl_object v4asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC4901component_depends_on(v3asdf_operation_operation, v4asdf_component_component);
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4902component_depends_on(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_of_class_p(2, v2asdf_component_component, VV[1652]))){
  goto L2;
 }
 T0 = CONS(v1asdf_operation_operation,v2asdf_component_component);
 value0 = cl_error(3, VV[1931], VV[1941], T0);
 return value0;
L2:;
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  if (Null(v3)){
   goto L5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1941]))->cfun.entry(2, v1asdf_operation_operation, v3) /*  COMPONENT-DEPENDS-ON */;
  return value0;
L5:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4902component_depends_on_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC4902component_depends_on(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4906component_depends_on(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object env1 = env0;
  if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
   goto L3;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
  goto L2;
L3:;
  T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
  T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(T0,env1);                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
  CLV1 = env1 = CONS(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)),env1); /*  .NEXT-METHODS. */
  T0 = cl_list(3, VV[1941], v1asdf_action__o, v2asdf_action__c);
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4905__lambda5360,env1,Cblock,0);
   T1 = v3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1708]))->cfun.entry(2, T0, T1) /*  CONSULT-ASDF-CACHE */;
  return value0;
 }
}
static cl_object LC4906component_depends_on_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC4906component_depends_on(v3asdf_action__o, v4asdf_action__c);
 }
}
/* function definition for DOWNWARD-OPERATION-DEPENDS-ON                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4907downward_operation_depends_on(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1943]))->cfun.entry(1, v1asdf_action__o) /*  DOWNWARD-OPERATION */;
 if (value0!=ECL_NIL) {
  goto L4;
 }
 T0 = v1asdf_action__o;
 goto L2;
L4:;
 T0 = value0;
 goto L2;
L2:;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1672]))->cfun.entry(1, v2asdf_action__c) /*  COMPONENT-CHILDREN */;
 T2 = CONS(T0,T1);
 value0 = ecl_list1(T2);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4907downward_operation_depends_on_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1944]);
 {
  return L4907downward_operation_depends_on(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4910component_depends_on(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1944]))->cfun.entry(2, v1asdf_action__o, v2asdf_action__c) /*  DOWNWARD-OPERATION-DEPENDS-ON */;
 T1 = LC4908call_next_method(0, lex0);
 value0 = ecl_append(T0,T1);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4910component_depends_on_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC4910component_depends_on(v3asdf_action__o, v4asdf_action__c);
 }
}
/* function definition for UPWARD-OPERATION-DEPENDS-ON                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4911upward_operation_depends_on(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_action__p;
  v3asdf_action__p = (cl_env_copy->function=ecl_fdefinition(VV[1644]))->cfun.entry(1, v2asdf_action__c) /*  COMPONENT-PARENT */;
  if (Null(v3asdf_action__p)){
   goto L3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1946]))->cfun.entry(1, v1asdf_action__o) /*  UPWARD-OPERATION */;
  if (value0!=ECL_NIL) {
   goto L7;
  }
  T0 = v1asdf_action__o;
  goto L5;
L7:;
  T0 = value0;
  goto L5;
L5:;
  T1 = cl_list(2, T0, v3asdf_action__p);
  value0 = ecl_list1(T1);
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4911upward_operation_depends_on_va(cl_narg narg, cl_object v4asdf_action__o, cl_object v5asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1947]);
 {
  return L4911upward_operation_depends_on(v4asdf_action__o, v5asdf_action__c);
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4914component_depends_on(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1947]))->cfun.entry(2, v1asdf_action__o, v2asdf_action__c) /*  UPWARD-OPERATION-DEPENDS-ON */;
 T1 = LC4912call_next_method(0, lex0);
 value0 = ecl_append(T0,T1);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4914component_depends_on_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC4914component_depends_on(v3asdf_action__o, v4asdf_action__c);
 }
}
/* function definition for SIDEWAY-OPERATION-DEPENDS-ON                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4915sideway_operation_depends_on(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1949]))->cfun.entry(1, v1asdf_action__o) /*  SIDEWAY-OPERATION */;
 if (value0!=ECL_NIL) {
  goto L4;
 }
 T0 = v1asdf_action__o;
 goto L2;
L4:;
 T0 = value0;
 goto L2;
L2:;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1951]))->cfun.entry(1, v2asdf_action__c) /*  COMPONENT-SIDEWAY-DEPENDENCIES */;
 T2 = CONS(T0,T1);
 value0 = ecl_list1(T2);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4915sideway_operation_depends_on_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1950]);
 {
  return L4915sideway_operation_depends_on(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4918component_depends_on(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1950]))->cfun.entry(2, v1asdf_action__o, v2asdf_action__c) /*  SIDEWAY-OPERATION-DEPENDS-ON */;
 T1 = LC4916call_next_method(0, lex0);
 value0 = ecl_append(T0,T1);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4918component_depends_on_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC4918component_depends_on(v3asdf_action__o, v4asdf_action__c);
 }
}
/* function definition for SELFWARD-OPERATION-DEPENDS-ON                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4919selfward_operation_depends_on(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4asdf_action__op;
  cl_object v5;
  {
   cl_object v6;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1953]))->cfun.entry(1, v1asdf_action__o) /*  SELFWARD-OPERATION */;
   v6 = (cl_env_copy->function=ecl_fdefinition(VV[257]))->cfun.entry(1, T0) /*  ENSURE-LIST */;
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3 = v6;
  }
  v4asdf_action__op = ECL_NIL;
  v5 = v3;
  {
   cl_object v6;
   cl_object v7;
   v6 = ecl_list1(ECL_NIL);
   v7 = v6;
L9:;
   if (!(ecl_endp(v5))){
    goto L11;
   }
   goto L10;
L11:;
   v4asdf_action__op = ECL_CONS_CAR(v5);
   {
    cl_object v8;
    v8 = ECL_CONS_CDR(v5);
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v8;
   }
   {
    cl_object v8;
    v8 = v7;
    if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T0 = v8;
   }
   T1 = cl_list(2, v4asdf_action__op, v2asdf_action__c);
   v7 = ecl_list1(T1);
   (ECL_CONS_CDR(T0)=v7,T0);
   goto L9;
L10:;
   value0 = ecl_cdr(v6);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4919selfward_operation_depends_on_va(cl_narg narg, cl_object v8asdf_action__o, cl_object v9asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1954]);
 {
  return L4919selfward_operation_depends_on(v8asdf_action__o, v9asdf_action__c);
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4922component_depends_on(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1954]))->cfun.entry(2, v1asdf_action__o, v2asdf_action__c) /*  SELFWARD-OPERATION-DEPENDS-ON */;
 T1 = LC4920call_next_method(0, lex0);
 value0 = ecl_append(T0,T1);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4922component_depends_on_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC4922component_depends_on(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function INITIALIZE-INSTANCE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4923initialize_instance(cl_narg narg, cl_object v1asdf_action__o, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("INITIALIZE-INSTANCE",951));
 {
  ecl_va_list args; ecl_va_start(args,v1asdf_action__o,narg,1);
  cl_parse_key(args,0,NULL,NULL,NULL,TRUE);
  ecl_va_end(args);
  if (si_of_class_p(2, v1asdf_action__o, VV[1943])!=ECL_NIL) {
   goto L1;
  }
  if (si_of_class_p(2, v1asdf_action__o, VV[1946])!=ECL_NIL) {
   goto L1;
  }
  if (si_of_class_p(2, v1asdf_action__o, VV[1949])!=ECL_NIL) {
   goto L1;
  }
  if (si_of_class_p(2, v1asdf_action__o, VV[1953])!=ECL_NIL) {
   goto L1;
  }
  if (si_of_class_p(2, v1asdf_action__o, VV[1956])!=ECL_NIL) {
   goto L1;
  }
  T0 = cl_type_of(v1asdf_action__o);
  T1 = ecl_list1(T0);
  value0 = (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(5, VV[1957], ECL_SYM("FORMAT-CONTROL",1272), VV[1959], ECL_SYM("FORMAT-ARGUMENTS",1271), T1) /*  WARN */;
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function INITIALIZE-INSTANCE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4924initialize_instance(cl_narg narg, cl_object v1asdf_action__o, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("INITIALIZE-INSTANCE",951));
 {
  ecl_va_list args; ecl_va_start(args,v1asdf_action__o,narg,1);
  cl_parse_key(args,0,NULL,NULL,NULL,TRUE);
  ecl_va_end(args);
  if (si_of_class_p(2, v1asdf_action__o, VV[1943])!=ECL_NIL) {
   goto L3;
  }
  if (si_of_class_p(2, v1asdf_action__o, VV[1946])!=ECL_NIL) {
   goto L3;
  }
  if (si_of_class_p(2, v1asdf_action__o, VV[1949])!=ECL_NIL) {
   goto L3;
  }
  if (Null(si_of_class_p(2, v1asdf_action__o, VV[1953]))){
   goto L1;
  }
  goto L2;
L3:;
L2:;
  T0 = cl_type_of(v1asdf_action__o);
  T1 = ecl_list1(T0);
  value0 = cl_error(5, VV[1958], ECL_SYM("FORMAT-CONTROL",1272), VV[1960], ECL_SYM("FORMAT-ARGUMENTS",1271), T1);
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4925component_depends_on(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  v3 = cl_type_of(v1asdf_action__o);
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[1961]))->cfun.entry(1, v2asdf_action__c) /*  COMPONENT-IN-ORDER-TO */;
  v5 = v3;
  v6 = v4;
  T0 = ecl_assql(v5,v6);
 }
 T1 = ecl_cdr(T0);
 if (si_of_class_p(2, v1asdf_action__o, VV[1943])!=ECL_NIL) {
  goto L8;
 }
 if (si_of_class_p(2, v1asdf_action__o, VV[1946])!=ECL_NIL) {
  goto L8;
 }
 if (si_of_class_p(2, v1asdf_action__o, VV[1949])!=ECL_NIL) {
  goto L8;
 }
 if (si_of_class_p(2, v1asdf_action__o, VV[1953])!=ECL_NIL) {
  goto L8;
 }
 if (si_of_class_p(2, v1asdf_action__o, VV[1956])!=ECL_NIL) {
  goto L8;
 }
 T3 = (cl_env_copy->function=ecl_fdefinition(VV[1950]))->cfun.entry(2, v1asdf_action__o, v2asdf_action__c) /*  SIDEWAY-OPERATION-DEPENDS-ON */;
 if (Null(si_of_class_p(2, v2asdf_action__c, VV[1667]))){
  goto L15;
 }
 T4 = (cl_env_copy->function=ecl_fdefinition(VV[1944]))->cfun.entry(2, v1asdf_action__o, v2asdf_action__c) /*  DOWNWARD-OPERATION-DEPENDS-ON */;
 goto L14;
L15:;
 T4 = ECL_NIL;
L14:;
 T2 = ecl_append(T3,T4);
 goto L7;
L8:;
 T2 = ECL_NIL;
L7:;
 value0 = ecl_append(T1,T2);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4925component_depends_on_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC4925component_depends_on(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function DOWNWARD-OPERATION                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4926downward_operation(cl_object v1asdf_action__o)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4926downward_operation_va(cl_narg narg, cl_object v2asdf_action__o, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1943]);
 {
  return LC4926downward_operation(v2asdf_action__o);
 }
}
/* local function SIDEWAY-OPERATION                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4927sideway_operation(cl_object v1asdf_action__o)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4927sideway_operation_va(cl_narg narg, cl_object v2asdf_action__o, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1949]);
 {
  return LC4927sideway_operation(v2asdf_action__o);
 }
}
/* local function OUTPUT-FILES                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4928output_files(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_component_component;
  v3asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[834]))->cfun.entry(3, v1asdf_operation_operation, ECL_SYM("PACKAGE",1321), VV[1899]) /*  SAFE-READ-FROM-STRING */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, T0, v3asdf_component_component) /*  OUTPUT-FILES */;
  return value0;
 }
}
static cl_object LC4928output_files_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1962]);
 {
  return LC4928output_files(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function OUTPUT-FILES                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4929output_files(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1asdf_operation_operation)){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, v1asdf_operation_operation) /*  MAKE-OPERATION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
 if (value0!=ECL_NIL) {
  goto L6;
 }
 T1 = ECL_NIL;
 goto L4;
L6:;
 T1 = value0;
 goto L4;
L4:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, T0, T1) /*  OUTPUT-FILES */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4929output_files_va(cl_narg narg, cl_object v3asdf_operation_operation, cl_object v4asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1962]);
 {
  return LC4929output_files(v3asdf_operation_operation, v4asdf_component_component);
 }
}
/* local function OUTPUT-FILES                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4930output_files(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_of_class_p(2, v2asdf_component_component, VV[1652]))){
  goto L2;
 }
 T0 = CONS(v1asdf_operation_operation,v2asdf_component_component);
 value0 = cl_error(3, VV[1931], VV[1962], T0);
 return value0;
L2:;
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  if (Null(v3)){
   goto L5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, v1asdf_operation_operation, v3) /*  OUTPUT-FILES */;
  return value0;
L5:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4930output_files_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1962]);
 {
  return LC4930output_files(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4931input_files(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_component_component;
  v3asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[834]))->cfun.entry(3, v1asdf_operation_operation, ECL_SYM("PACKAGE",1321), VV[1899]) /*  SAFE-READ-FROM-STRING */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, T0, v3asdf_component_component) /*  INPUT-FILES */;
  return value0;
 }
}
static cl_object LC4931input_files_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC4931input_files(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4932input_files(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1asdf_operation_operation)){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, v1asdf_operation_operation) /*  MAKE-OPERATION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
 if (value0!=ECL_NIL) {
  goto L6;
 }
 T1 = ECL_NIL;
 goto L4;
L6:;
 T1 = value0;
 goto L4;
L4:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, T0, T1) /*  INPUT-FILES */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4932input_files_va(cl_narg narg, cl_object v3asdf_operation_operation, cl_object v4asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC4932input_files(v3asdf_operation_operation, v4asdf_component_component);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4933input_files(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_of_class_p(2, v2asdf_component_component, VV[1652]))){
  goto L2;
 }
 T0 = CONS(v1asdf_operation_operation,v2asdf_component_component);
 value0 = cl_error(3, VV[1931], VV[1963], T0);
 return value0;
L2:;
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  if (Null(v3)){
   goto L5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, v1asdf_operation_operation, v3) /*  INPUT-FILES */;
  return value0;
L5:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4933input_files_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC4933input_files(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function OPERATION-DONE-P                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4934operation_done_p(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_component_component;
  v3asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[834]))->cfun.entry(3, v1asdf_operation_operation, ECL_SYM("PACKAGE",1321), VV[1899]) /*  SAFE-READ-FROM-STRING */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1964]))->cfun.entry(2, T0, v3asdf_component_component) /*  OPERATION-DONE-P */;
  return value0;
 }
}
static cl_object LC4934operation_done_p_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1964]);
 {
  return LC4934operation_done_p(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function OPERATION-DONE-P                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4935operation_done_p(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1asdf_operation_operation)){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, v1asdf_operation_operation) /*  MAKE-OPERATION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
 if (value0!=ECL_NIL) {
  goto L6;
 }
 T1 = ECL_NIL;
 goto L4;
L6:;
 T1 = value0;
 goto L4;
L4:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1964]))->cfun.entry(2, T0, T1) /*  OPERATION-DONE-P */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4935operation_done_p_va(cl_narg narg, cl_object v3asdf_operation_operation, cl_object v4asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1964]);
 {
  return LC4935operation_done_p(v3asdf_operation_operation, v4asdf_component_component);
 }
}
/* local function OPERATION-DONE-P                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4936operation_done_p(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_of_class_p(2, v2asdf_component_component, VV[1652]))){
  goto L2;
 }
 T0 = CONS(v1asdf_operation_operation,v2asdf_component_component);
 value0 = cl_error(3, VV[1931], VV[1964], T0);
 return value0;
L2:;
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  if (Null(v3)){
   goto L5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1964]))->cfun.entry(2, v1asdf_operation_operation, v3) /*  OPERATION-DONE-P */;
  return value0;
L5:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4936operation_done_p_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1964]);
 {
  return LC4936operation_done_p(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function OPERATION-DONE-P                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4937operation_done_p(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4937operation_done_p_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1964]);
 {
  return LC4937operation_done_p(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function OUTPUT-FILES                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4941output_files(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v2asdf_component_component,env0); /*  COMPONENT           */
 {
  cl_object env1 = env0;
  if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
   goto L2;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
  goto L1;
L2:;
  T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
  T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L1:;
  CLV1 = env1 = CONS(T0,env1);                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
  CLV2 = env1 = CONS(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)),env1); /*  .NEXT-METHODS. */
  T0 = cl_list(3, VV[1962], v1asdf_operation_operation, ECL_CONS_CAR(CLV0));
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4940__lambda5438,env1,Cblock,0);
   T1 = v3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1708]))->cfun.entry(2, T0, T1) /*  CONSULT-ASDF-CACHE */;
  return value0;
 }
}
static cl_object LC4941output_files_va(cl_narg narg, cl_object v3asdf_operation_operation, cl_object v4asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1962]);
 {
  return LC4941output_files(v3asdf_operation_operation, v4asdf_component_component);
 }
}
/* local function OUTPUT-FILES                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4942output_files(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4942output_files_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1962]);
 {
  return LC4942output_files(v3asdf_action__o, v4asdf_action__c);
 }
}
/* function definition for OUTPUT-FILE                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4943output_file(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_action__files;
  v3asdf_action__files = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, v1asdf_operation_operation, v2asdf_component_component) /*  OUTPUT-FILES */;
  goto L5;
L4:;
  si_assert_failure(1, VV[1967]);
L5:;
  if ((cl_env_copy->function=ecl_fdefinition(VV[253]))->cfun.entry(2, v3asdf_action__files, ecl_make_int8_t(1)) /*  LENGTH=N-P */!=ECL_NIL) {
   goto L8;
  }
  goto L4;
L8:;
  value0 = ecl_car(v3asdf_action__files);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4943output_file_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1966]);
 {
  return L4943output_file(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4947input_files(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object env1 = env0;
  if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
   goto L3;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
  goto L2;
L3:;
  T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
  T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(T0,env1);                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
  CLV1 = env1 = CONS(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)),env1); /*  .NEXT-METHODS. */
  T0 = cl_list(3, VV[1963], v1asdf_operation_operation, v2asdf_component_component);
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4946__lambda5459,env1,Cblock,0);
   T1 = v3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1708]))->cfun.entry(2, T0, T1) /*  CONSULT-ASDF-CACHE */;
  return value0;
 }
}
static cl_object LC4947input_files_va(cl_narg narg, cl_object v3asdf_operation_operation, cl_object v4asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC4947input_files(v3asdf_operation_operation, v4asdf_component_component);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4948input_files(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4948input_files_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC4948input_files(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4951input_files(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 {
  cl_object v3;
  cl_object v4asdf_action__dep_o;
  cl_object v5;
  {
   cl_object v6;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[1953]))->cfun.entry(1, v1asdf_action__o) /*  SELFWARD-OPERATION */;
   v6 = (cl_env_copy->function=ecl_fdefinition(VV[257]))->cfun.entry(1, T1) /*  ENSURE-LIST */;
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3 = v6;
  }
  v4asdf_action__dep_o = ECL_NIL;
  v5 = v3;
  {
   cl_object v6;
   cl_object v7;
   v6 = ecl_list1(ECL_NIL);
   v7 = v6;
L17:;
   if (!(ecl_endp(v5))){
    goto L19;
   }
   goto L18;
L19:;
   v4asdf_action__dep_o = ECL_CONS_CAR(v5);
   {
    cl_object v8;
    v8 = ECL_CONS_CDR(v5);
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v8;
   }
   {
    cl_object v8;
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, v4asdf_action__dep_o, v2asdf_action__c) /*  OUTPUT-FILES */;
    if (value0!=ECL_NIL) {
     goto L32;
    }
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, v4asdf_action__dep_o, v2asdf_action__c) /*  INPUT-FILES */;
    goto L30;
L32:;
    T1 = value0;
    goto L30;
L30:;
    v8 = cl_copy_list(T1);
    {
     cl_object v9;
     v9 = v7;
     if (ecl_unlikely(ECL_ATOM(v9))) FEtype_error_cons(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T1 = v9;
    }
    (ECL_CONS_CDR(T1)=v8,T1);
    if (Null(v8)){
     goto L27;
    }
   }
   T1 = ecl_cdr(v7);
   v7 = ecl_last(T1,1);
L27:;
   goto L17;
L18:;
   value0 = ecl_cdr(v6);
   goto L9;
  }
 }
L9:;
 if (value0!=ECL_NIL) {
  goto L8;
 }
 {
  cl_object v3pathname;
  v3pathname = (cl_env_copy->function=ecl_fdefinition(VV[1638]))->cfun.entry(1, v2asdf_action__c) /*  COMPONENT-PATHNAME */;
  if (Null(v3pathname)){
   goto L42;
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[550]))->cfun.entry(1, v3pathname) /*  FILE-PATHNAME-P */)){
   goto L45;
  }
  T0 = ecl_list1(v3pathname);
  goto L6;
L45:;
  T0 = ECL_NIL;
  goto L6;
L42:;
  T0 = ECL_NIL;
  goto L6;
 }
L8:;
 T0 = value0;
 goto L6;
L6:;
 T1 = LC4949call_next_method(0, lex0);
 value0 = ecl_append(T0,T1);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4951input_files_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC4951input_files(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function COMPONENT-OPERATION-TIME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4952component_operation_time(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_component_component;
  v3asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[834]))->cfun.entry(3, v1asdf_operation_operation, ECL_SYM("PACKAGE",1321), VV[1899]) /*  SAFE-READ-FROM-STRING */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1970]))->cfun.entry(2, T0, v3asdf_component_component) /*  COMPONENT-OPERATION-TIME */;
  return value0;
 }
}
static cl_object LC4952component_operation_time_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1970]);
 {
  return LC4952component_operation_time(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function COMPONENT-OPERATION-TIME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4953component_operation_time(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1asdf_operation_operation)){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, v1asdf_operation_operation) /*  MAKE-OPERATION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
 if (value0!=ECL_NIL) {
  goto L6;
 }
 T1 = ECL_NIL;
 goto L4;
L6:;
 T1 = value0;
 goto L4;
L4:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1970]))->cfun.entry(2, T0, T1) /*  COMPONENT-OPERATION-TIME */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4953component_operation_time_va(cl_narg narg, cl_object v3asdf_operation_operation, cl_object v4asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1970]);
 {
  return LC4953component_operation_time(v3asdf_operation_operation, v4asdf_component_component);
 }
}
/* local function COMPONENT-OPERATION-TIME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4954component_operation_time(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_of_class_p(2, v2asdf_component_component, VV[1652]))){
  goto L2;
 }
 T0 = CONS(v1asdf_operation_operation,v2asdf_component_component);
 value0 = cl_error(3, VV[1931], VV[1970], T0);
 return value0;
L2:;
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  if (Null(v3)){
   goto L5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1970]))->cfun.entry(2, v1asdf_operation_operation, v3) /*  COMPONENT-OPERATION-TIME */;
  return value0;
L5:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4954component_operation_time_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1970]);
 {
  return LC4954component_operation_time(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function PRINT-OBJECT                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4956print_object(cl_object v1asdf_action__status, cl_object v2stream)
{
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1asdf_action__status,env0);  /*  STATUS                  */
 CLV1 = env0 = CONS(v2stream,env0);               /*  STREAM                  */
 {
  cl_object v3;
  v3 = ecl_make_cclosure_va((cl_objectfn)LC4955si___print_unreadable_object_body_,env0,Cblock,0);
  value0 = si_print_unreadable_object_function(ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1), ECL_T, ECL_NIL, v3);
  return value0;
 }
}
static cl_object LC4956print_object_va(cl_narg narg, cl_object v4asdf_action__status, cl_object v5stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("PRINT-OBJECT",965));
 {
  return LC4956print_object(v4asdf_action__status, v5stream);
 }
}
/* local function COMPONENT-OPERATION-TIME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4957component_operation_time(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_type_of(v1asdf_action__o);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1980]))->cfun.entry(1, v2asdf_action__c) /*  COMPONENT-OPERATION-TIMES */;
 value0 = cl_gethash(2, T0, T1);
 return value0;
}
static cl_object LC4957component_operation_time_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1970]);
 {
  return LC4957component_operation_time(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function COMPONENT-OPERATION-TIME                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4958component_operation_time(cl_object v1asdf_action_stamp, cl_object v2asdf_action__o, cl_object v3asdf_action__c)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_type_of(v2asdf_action__o);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1980]))->cfun.entry(1, v3asdf_action__c) /*  COMPONENT-OPERATION-TIMES */;
 value0 = si_hash_set(T0, T1, v1asdf_action_stamp);
 return value0;
}
static cl_object LC4958component_operation_time_va(cl_narg narg, cl_object v4asdf_action_stamp, cl_object v5asdf_action__o, cl_object v6asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[1970]);
 {
  return LC4958component_operation_time(v4asdf_action_stamp, v5asdf_action__o, v6asdf_action__c);
 }
}
/* local function MARK-OPERATION-DONE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4959mark_operation_done(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[1973]))->cfun.entry(5, ECL_NIL, v1asdf_action__o, v2asdf_action__c, VV[1981], ECL_T) /*  COMPUTE-ACTION-STAMP */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1971]))->cfun.entry(3, v3, v1asdf_action__o, v2asdf_action__c) /*  (SETF COMPONENT-OPERATION-TIME) */;
  return value0;
 }
}
static cl_object LC4959mark_operation_done_va(cl_narg narg, cl_object v4asdf_action__o, cl_object v5asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1972]);
 {
  return LC4959mark_operation_done(v4asdf_action__o, v5asdf_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4960perform(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_component_component;
  v3asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[834]))->cfun.entry(3, v1asdf_operation_operation, ECL_SYM("PACKAGE",1321), VV[1899]) /*  SAFE-READ-FROM-STRING */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1982]))->cfun.entry(2, T0, v3asdf_component_component) /*  PERFORM */;
  return value0;
 }
}
static cl_object LC4960perform_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC4960perform(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4961perform(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1asdf_operation_operation)){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, v1asdf_operation_operation) /*  MAKE-OPERATION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
 if (value0!=ECL_NIL) {
  goto L6;
 }
 T1 = ECL_NIL;
 goto L4;
L6:;
 T1 = value0;
 goto L4;
L4:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1982]))->cfun.entry(2, T0, T1) /*  PERFORM */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4961perform_va(cl_narg narg, cl_object v3asdf_operation_operation, cl_object v4asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC4961perform(v3asdf_operation_operation, v4asdf_component_component);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4962perform(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_of_class_p(2, v2asdf_component_component, VV[1652]))){
  goto L2;
 }
 T0 = CONS(v1asdf_operation_operation,v2asdf_component_component);
 value0 = cl_error(3, VV[1931], VV[1982], T0);
 return value0;
L2:;
 {
  cl_object v3;
  v3 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  if (Null(v3)){
   goto L5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1982]))->cfun.entry(2, v1asdf_operation_operation, v3) /*  PERFORM */;
  return value0;
L5:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4962perform_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC4962perform(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4963perform(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, v1asdf_action__o, v2asdf_action__c) /*  OUTPUT-FILES */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[780]))->cfun.entry(1, T0) /*  ENSURE-ALL-DIRECTORIES-EXIST */;
 return value0;
}
static cl_object LC4963perform_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC4963perform(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4964perform(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1972]))->cfun.entry(2, v1asdf_action__o, v2asdf_action__c) /*  MARK-OPERATION-DONE */;
 return value0;
}
static cl_object LC4964perform_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC4964perform(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4965perform(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4965perform_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC4965perform(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4966perform(cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (si_of_class_p(2, v1asdf_action__o, VV[1943])!=ECL_NIL) {
  goto L4;
 }
 if (si_of_class_p(2, v1asdf_action__o, VV[1946])!=ECL_NIL) {
  goto L4;
 }
 if (si_of_class_p(2, v1asdf_action__o, VV[1949])!=ECL_NIL) {
  goto L4;
 }
 if (si_of_class_p(2, v1asdf_action__o, VV[1953])!=ECL_NIL) {
  goto L4;
 }
 if (Null(si_of_class_p(2, v1asdf_action__o, VV[1956]))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 T0 = CONS(v1asdf_action__o,v2asdf_action__c);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1751]))->cfun.entry(3, VV[1983], VV[1982], T0) /*  SYSDEF-ERROR */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4966perform_va(cl_narg narg, cl_object v3asdf_action__o, cl_object v4asdf_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC4966perform(v3asdf_action__o, v4asdf_action__c);
 }
}
/* local function PERFORM-WITH-RESTARTS                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4967perform_with_restarts(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1982]))->cfun.entry(2, v1asdf_operation_operation, v2asdf_component_component) /*  PERFORM */;
 return value0;
}
static cl_object LC4967perform_with_restarts_va(cl_narg narg, cl_object v3asdf_operation_operation, cl_object v4asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1984]);
 {
  return LC4967perform_with_restarts(v3asdf_operation_operation, v4asdf_component_component);
 }
}
/* local function PERFORM-WITH-RESTARTS                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4974perform_with_restarts(cl_object volatile v1asdf_operation_operation, cl_object volatile v2asdf_component_component)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 volatile cl_object lex0[2];
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1asdf_operation_operation,env0); /*  OPERATION           */
 CLV1 = env0 = CONS(v2asdf_component_component,env0); /*  COMPONENT           */
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L2;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L1;
L2:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L1:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
L5:;
 {
  volatile cl_object env1 = env0;
  CLV2 = env1 = CONS(ECL_NIL,env1);
  {
   volatile cl_object env2 = env1;
   CLV3 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY        */
   {
    ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV3));
    if (__ecl_frs_push_result!=0) {
    if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
     goto L7;
    }
    if (cl_env_copy->values[0]==ecl_make_int8_t(1)) {
     goto L8;
    }
    ecl_internal_error("GO found an inexistent tag");
    } else {
    {
     cl_object v3;
     v3 = ecl_make_cclosure_va((cl_objectfn)LC4970__lambda5617,env2,Cblock,0);
     T0 = v3;
    }
    {
     cl_object v3;
     v3 = ecl_make_cclosure_va((cl_objectfn)LC4971__lambda5619,env2,Cblock,1);
     T1 = v3;
    }
    T2 = (cl_env_copy->function=(VV[1715]->symbol.gfdef))->cfun.entry(6, ECL_SYM("NAME",1309), VV[1716], ECL_SYM("FUNCTION",1273), T0, VV[1718], T1) /*  MAKE-RESTART */;
    {
     cl_object v3;
     v3 = ecl_make_cclosure_va((cl_objectfn)LC4972__lambda5621,env2,Cblock,0);
     T3 = v3;
    }
    {
     cl_object v3;
     v3 = ecl_make_cclosure_va((cl_objectfn)LC4973__lambda5623,env2,Cblock,1);
     T4 = v3;
    }
    T5 = (cl_env_copy->function=(VV[1715]->symbol.gfdef))->cfun.entry(6, ECL_SYM("NAME",1309), VV[1989], ECL_SYM("FUNCTION",1273), T3, VV[1718], T4) /*  MAKE-RESTART */;
    T6 = cl_list(2, T2, T5);
    T7 = CONS(T6,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5)));
    ecl_bds_bind(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5),T7); /*  *RESTART-CLUSTERS* */
    value0 = LC4968call_next_method(0, lex0);
    ecl_frs_pop_n(cl_env_copy, 1);
    ecl_bds_unwind1(cl_env_copy);
    return value0;
L7:;
    {
     cl_object v3;
     v3 = ECL_CONS_CAR(CLV2);
     if (Null(v3)){
      ecl_frs_pop_n(cl_env_copy, 1);
      goto L6;
     }
     si_dm_too_many_arguments(ECL_NIL);
     ecl_frs_pop_n(cl_env_copy, 1);
     goto L6;
    }
L8:;
    {
     cl_object v3;
     v3 = ECL_CONS_CAR(CLV2);
     if (Null(v3)){
      goto L19;
     }
     si_dm_too_many_arguments(ECL_NIL);
L19:;
     (cl_env_copy->function=ecl_fdefinition(VV[1972]))->cfun.entry(2, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1)) /*  MARK-OPERATION-DONE */;
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     ecl_frs_pop_n(cl_env_copy, 1);
     return value0;
    }
    }
   }
  }
 }
L6:;
 goto L5;
}
static cl_object LC4974perform_with_restarts_va(cl_narg narg, cl_object v3asdf_operation_operation, cl_object v4asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1984]);
 {
  return LC4974perform_with_restarts(v3asdf_operation_operation, v4asdf_component_component);
 }
}
/* local function ACTION-DESCRIPTION                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4975action_description(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(3, ECL_NIL, VV[2004], v2asdf_lisp_action__c);
 return value0;
}
static cl_object LC4975action_description_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1933]);
 {
  return LC4975action_description(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4976perform(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4976perform_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC4976perform(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4977input_files(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__s)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_lisp_action__it;
  v3asdf_lisp_action__it = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, v2asdf_lisp_action__s) /*  SYSTEM-SOURCE-FILE */;
  if (Null(v3asdf_lisp_action__it)){
   goto L3;
  }
  value0 = ecl_list1(v3asdf_lisp_action__it);
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4977input_files_va(cl_narg narg, cl_object v4asdf_lisp_action__o, cl_object v5asdf_lisp_action__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC4977input_files(v4asdf_lisp_action__o, v5asdf_lisp_action__s);
 }
}
/* local function ACTION-DESCRIPTION                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4978action_description(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(3, ECL_NIL, VV[2005], v2asdf_lisp_action__c);
 return value0;
}
static cl_object LC4978action_description_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1933]);
 {
  return LC4978action_description(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function ACTION-DESCRIPTION                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4979action_description(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(3, ECL_NIL, VV[2006], v2asdf_lisp_action__c);
 return value0;
}
static cl_object LC4979action_description_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1933]);
 {
  return LC4979action_description(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function CALL-WITH-AROUND-COMPILE-HOOK                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4980call_with_around_compile_hook(cl_object v1asdf_lisp_action__c, cl_object v2function)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1681]))->cfun.entry(1, v1asdf_lisp_action__c) /*  AROUND-COMPILE-HOOK */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1420]))->cfun.entry(2, T0, v2function) /*  CALL-AROUND-HOOK */;
 return value0;
}
static cl_object LC4980call_with_around_compile_hook_va(cl_narg narg, cl_object v3asdf_lisp_action__c, cl_object v4function, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2007]);
 {
  return LC4980call_with_around_compile_hook(v3asdf_lisp_action__c, v4function);
 }
}
/* function definition for PERFORM-LISP-COMPILATION                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4982perform_lisp_compilation(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1asdf_lisp_action__o,env0);  /*  O                       */
 CLV1 = env0 = CONS(v2asdf_lisp_action__c,env0);  /*  C                       */
 {
  cl_object v3;
  cl_object v4;
  cl_object env1 = env0;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1)) /*  INPUT-FILES */;
  v3 = ecl_car(T0);
  v4 = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1)) /*  OUTPUT-FILES */;
  CLV2 = env1 = CONS(v3,env1);                    /*  INPUT-FILE              */
  {
   cl_object v5;                                  /*  OUTPUT                  */
   cl_object v6;                                  /*  WARNINGS-P              */
   cl_object v7;                                  /*  FAILURE-P               */
   {
    cl_object v8;
    cl_object env2 = env1;
    v8 = v4;
    if (!(v8==ECL_NIL)){
     goto L5;
    }
    si_dm_too_few_arguments(v4);
L5:;
    {
     cl_object v9;
     v9 = ecl_car(v8);
     v8 = ecl_cdr(v8);
     T0 = v9;
    }
    CLV3 = env2 = CONS(T0,env2);                  /*  OUTPUT-FILE             */
    if (Null(v8)){
     goto L12;
    }
    {
     cl_object v9;
     v9 = ecl_car(v8);
     v8 = ecl_cdr(v8);
     T0 = v9;
     goto L11;
    }
L12:;
    T0 = ECL_NIL;
L11:;
    CLV4 = env2 = CONS(T0,env2);                  /*  OBJECT-FILE             */
    if (Null(v8)){
     goto L18;
    }
    {
     cl_object v9;
     v9 = ecl_car(v8);
     v8 = ecl_cdr(v8);
     T0 = v9;
     goto L17;
    }
L18:;
    T0 = ECL_NIL;
L17:;
    CLV5 = env2 = CONS(T0,env2);                  /*  WARNINGS-FILE           */
    if (Null(ECL_CONS_CAR(CLV5))){
     goto L23;
    }
    T0 = cl_pathname_type(1, ECL_CONS_CAR(CLV5));
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[1365]))->cfun.entry(0) /*  WARNINGS-FILE-TYPE */;
    if (ecl_equal(T0,T1)) {
     goto L23;
    }
    ECL_CONS_CAR(CLV5) = ECL_NIL;
L23:;
    {
     cl_object v9;
     v9 = ecl_make_cclosure_va((cl_objectfn)LC4981__lambda5648,env2,Cblock,0);
     T0 = v9;
    }
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[2007]))->cfun.entry(2, ECL_CONS_CAR(CLV1), T0) /*  CALL-WITH-AROUND-COMPILE-HOOK */;
   }
   {
    const int v8 = cl_env_copy->nvalues;
    v5 = value0;
    cl_object v9;
    v9 = (v8<=1)? ECL_NIL : cl_env_copy->values[1];
    v6 = v9;
    v9 = (v8<=2)? ECL_NIL : cl_env_copy->values[2];
    v7 = v9;
   }
   T0 = CONS(ECL_CONS_CAR(CLV0),ECL_CONS_CAR(CLV1));
   T1 = ecl_list1(T0);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1344]))->cfun.entry(5, v5, v6, v7, VV[2013], T1) /*  CHECK-LISP-COMPILE-RESULTS */;
   return value0;
  }
 }
}
static cl_object L4982perform_lisp_compilation_va(cl_narg narg, cl_object v5asdf_lisp_action__o, cl_object v6asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2008]);
 {
  return L4982perform_lisp_compilation(v5asdf_lisp_action__o, v6asdf_lisp_action__c);
 }
}
/* function definition for REPORT-FILE-P                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4983report_file_p(cl_object v1asdf_lisp_action__f)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_pathname_type(1, v1asdf_lisp_action__f);
 value0 = ecl_make_bool(ecl_equalp(T0,VV[2016]));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L4983report_file_p_va(cl_narg narg, cl_object v2asdf_lisp_action__f, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2015]);
 {
  return L4983report_file_p(v2asdf_lisp_action__f);
 }
}
/* function definition for PERFORM-LISP-WARNINGS-CHECK                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4984perform_lisp_warnings_check(cl_object volatile v1asdf_lisp_action__o, cl_object volatile v2asdf_lisp_action__c)
{
 cl_object T0, T1;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v3asdf_lisp_action__expected_warnings_files;
  volatile cl_object v4asdf_lisp_action__actual_warnings_files;
  T0 = ecl_fdefinition(VV[1393]);
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, v1asdf_lisp_action__o, v2asdf_lisp_action__c) /*  INPUT-FILES */;
  v3asdf_lisp_action__expected_warnings_files = cl_remove_if_not(2, T0, T1);
  {
   cl_object v5;
   cl_object v6asdf_lisp_action__w;
   cl_object v7;
   {
    cl_object v8;
    v8 = v3asdf_lisp_action__expected_warnings_files;
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v8;
   }
   v6asdf_lisp_action__w = ECL_NIL;
   v7 = v5;
   {
    cl_object v8;
    cl_object v9;
    v8 = ecl_list1(ECL_NIL);
    v9 = v8;
L12:;
    if (!(ecl_endp(v7))){
     goto L14;
    }
    goto L13;
L14:;
    v6asdf_lisp_action__w = ECL_CONS_CAR(v7);
    {
     cl_object v10;
     v10 = ECL_CONS_CDR(v7);
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v7 = v10;
    }
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[1734]))->cfun.entry(1, v6asdf_lisp_action__w) /*  GET-FILE-STAMP */)){
     goto L23;
    }
    {
     cl_object v10;
     v10 = v9;
     if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T0 = v10;
    }
    v9 = ecl_list1(v6asdf_lisp_action__w);
    (ECL_CONS_CDR(T0)=v9,T0);
    goto L22;
L23:;
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[1933]))->cfun.entry(2, v1asdf_lisp_action__o, v2asdf_lisp_action__c) /*  ACTION-DESCRIPTION */;
    (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(3, VV[2019], v6asdf_lisp_action__w, T0) /*  WARN */;
L22:;
    goto L12;
L13:;
    v4asdf_lisp_action__actual_warnings_files = ecl_cdr(v8);
    goto L4;
   }
  }
L4:;
  (cl_env_copy->function=ecl_fdefinition(VV[1395]))->cfun.entry(1, v4asdf_lisp_action__actual_warnings_files) /*  CHECK-DEFERRED-WARNINGS */;
  {
   volatile cl_object v5asdf_lisp_action__output;
   volatile cl_object v6asdf_lisp_action__report;
   v5asdf_lisp_action__output = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, v1asdf_lisp_action__o, v2asdf_lisp_action__c) /*  OUTPUT-FILES */;
   T0 = ecl_fdefinition(VV[2015]);
   v6asdf_lisp_action__report = cl_find_if(2, T0, v5asdf_lisp_action__output);
   if (Null(v6asdf_lisp_action__report)){
    goto L35;
   }
   {
    volatile cl_object v7asdf_lisp_action__s;
    v7asdf_lisp_action__s = cl_open(5, v6asdf_lisp_action__report, ECL_SYM("DIRECTION",1249), ECL_SYM("OUTPUT",1319), ECL_SYM("IF-EXISTS",1279), ECL_SYM("SUPERSEDE",1351));
    {
     struct ecl_stack_frame _ecl_inner_frame_aux;
     volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
     volatile bool unwinding = FALSE;
     ecl_frame_ptr next_fr;
     {
      ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
      if (__ecl_frs_push_result!=0) {
        unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
      } else {
      {
       struct ecl_stack_frame _ecl_inner_frame_aux;
       volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
       cl_env_copy->values[0] = cl_format(2, v7asdf_lisp_action__s, VV[2020]);
       ecl_stack_frame_push_values(_ecl_inner_frame);
       if (Null(v7asdf_lisp_action__s)){
        goto L40;
       }
       cl_close(1, v7asdf_lisp_action__s);
L40:;
       ecl_stack_frame_pop_values(_ecl_inner_frame);
       ecl_stack_frame_close(_ecl_inner_frame);
      }
      }
     }
     ecl_frs_pop(cl_env_copy);
     ecl_stack_frame_push_values(_ecl_inner_frame);
     if (Null(v7asdf_lisp_action__s)){
      goto L42;
     }
     cl_close(3, v7asdf_lisp_action__s, ECL_SYM("ABORT",1225), ECL_T);
L42:;
     ecl_stack_frame_pop_values(_ecl_inner_frame);
     if (unwinding) ecl_unwind(cl_env_copy,next_fr);
     ecl_stack_frame_close(_ecl_inner_frame);
     return cl_env_copy->values[0];
    }
   }
L35:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L4984perform_lisp_warnings_check_va(cl_narg narg, cl_object v8asdf_lisp_action__o, cl_object v9asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2018]);
 {
  return L4984perform_lisp_warnings_check(v8asdf_lisp_action__o, v9asdf_lisp_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4985perform(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2008]))->cfun.entry(2, v1asdf_lisp_action__o, v2asdf_lisp_action__c) /*  PERFORM-LISP-COMPILATION */;
 return value0;
}
static cl_object LC4985perform_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC4985perform(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* function definition for LISP-COMPILATION-OUTPUT-FILES                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L4986lisp_compilation_output_files(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_lisp_action__i;
  cl_object v4asdf_lisp_action__f;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, v1asdf_lisp_action__o, v2asdf_lisp_action__c) /*  INPUT-FILES */;
  v3asdf_lisp_action__i = ecl_car(T0);
  v4asdf_lisp_action__f = (cl_env_copy->function=(ECL_SYM("COMPILE-FILE-PATHNAME",237)->symbol.gfdef))->cfun.entry(3, v3asdf_lisp_action__i, ECL_SYM("TYPE",1356), VV[2023]) /*  COMPILE-FILE-PATHNAME */;
  if (L4251use_ecl_byte_compiler_p()!=ECL_NIL) {
   goto L5;
  }
  T1 = (cl_env_copy->function=(ECL_SYM("COMPILE-FILE-PATHNAME",237)->symbol.gfdef))->cfun.entry(3, v3asdf_lisp_action__i, ECL_SYM("TYPE",1356), ECL_SYM("OBJECT",1315)) /*  COMPILE-FILE-PATHNAME */;
  T0 = ecl_list1(T1);
  goto L4;
L5:;
  T0 = ECL_NIL;
L4:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1388]))){
   goto L8;
  }
  T2 = (cl_env_copy->function=ecl_fdefinition(VV[1637]))->cfun.entry(1, v2asdf_lisp_action__c) /*  COMPONENT-SYSTEM */;
  if ((cl_env_copy->function=ecl_fdefinition(VV[2024]))->cfun.entry(1, T2) /*  BUILTIN-SYSTEM-P */!=ECL_NIL) {
   goto L8;
  }
  T2 = cl_make_pathname(4, ECL_SYM("TYPE",1356), ecl_cmp_symbol_value(cl_env_copy,VV[1388]), ECL_SYM("DEFAULTS",1247), v4asdf_lisp_action__f);
  T1 = ecl_list1(T2);
  goto L7;
L8:;
  T1 = ECL_NIL;
L7:;
  T2 = ecl_append(T0,T1);
  value0 = CONS(v4asdf_lisp_action__f,T2);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L4986lisp_compilation_output_files_va(cl_narg narg, cl_object v5asdf_lisp_action__o, cl_object v6asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2022]);
 {
  return L4986lisp_compilation_output_files(v5asdf_lisp_action__o, v6asdf_lisp_action__c);
 }
}
/* local function OUTPUT-FILES                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4987output_files(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2022]))->cfun.entry(2, v1asdf_lisp_action__o, v2asdf_lisp_action__c) /*  LISP-COMPILATION-OUTPUT-FILES */;
 return value0;
}
static cl_object LC4987output_files_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1962]);
 {
  return LC4987output_files(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4988perform(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4988perform_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC4988perform(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4989perform(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1388]))){
  goto L2;
 }
 if ((cl_env_copy->function=ecl_fdefinition(VV[2024]))->cfun.entry(1, v2asdf_lisp_action__c) /*  BUILTIN-SYSTEM-P */!=ECL_NIL) {
  goto L2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2018]))->cfun.entry(2, v1asdf_lisp_action__o, v2asdf_lisp_action__c) /*  PERFORM-LISP-WARNINGS-CHECK */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4989perform_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC4989perform(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4990input_files(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1388]))){
  goto L2;
 }
 if ((cl_env_copy->function=ecl_fdefinition(VV[2024]))->cfun.entry(1, v2asdf_lisp_action__c) /*  BUILTIN-SYSTEM-P */!=ECL_NIL) {
  goto L2;
 }
 {
  cl_object v3;
  cl_object v4asdf_lisp_action__sub;
  cl_object v5;
  {
   cl_object v6;
   v6 = (cl_env_copy->function=ecl_fdefinition(VV[1685]))->cfun.entry(3, v2asdf_lisp_action__c, ECL_SYM("TYPE",1356), VV[1993]) /*  SUB-COMPONENTS */;
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3 = v6;
  }
  v4asdf_lisp_action__sub = ECL_NIL;
  v5 = v3;
  {
   cl_object v6;
   cl_object v7;
   v6 = ecl_list1(ECL_NIL);
   v7 = v6;
L12:;
   if (!(ecl_endp(v5))){
    goto L14;
   }
   goto L13;
L14:;
   v4asdf_lisp_action__sub = ECL_CONS_CAR(v5);
   {
    cl_object v8;
    v8 = ECL_CONS_CDR(v5);
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v8;
   }
   {
    cl_object v8;
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, v1asdf_lisp_action__o, v4asdf_lisp_action__sub) /*  OUTPUT-FILES */;
    v8 = cl_remove_if_not(2, VV[1393], T0);
    {
     cl_object v9;
     v9 = v7;
     if (ecl_unlikely(ECL_ATOM(v9))) FEtype_error_cons(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T0 = v9;
    }
    (ECL_CONS_CDR(T0)=v8,T0);
    if (Null(v8)){
     goto L22;
    }
   }
   T0 = ecl_cdr(v7);
   v7 = ecl_last(T0,1);
L22:;
   goto L12;
L13:;
   value0 = ecl_cdr(v6);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4990input_files_va(cl_narg narg, cl_object v8asdf_lisp_action__o, cl_object v9asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC4990input_files(v8asdf_lisp_action__o, v9asdf_lisp_action__c);
 }
}
/* local function OUTPUT-FILES                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4991output_files(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1388]))){
  goto L2;
 }
 if ((cl_env_copy->function=ecl_fdefinition(VV[2024]))->cfun.entry(1, v2asdf_lisp_action__c) /*  BUILTIN-SYSTEM-P */!=ECL_NIL) {
  goto L2;
 }
 {
  cl_object v3pathname;
  v3pathname = (cl_env_copy->function=ecl_fdefinition(VV[1638]))->cfun.entry(1, v2asdf_lisp_action__c) /*  COMPONENT-PATHNAME */;
  if (Null(v3pathname)){
   goto L6;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1758]))->cfun.entry(1, v2asdf_lisp_action__c) /*  COERCE-FILENAME */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(4, v3pathname, T0, ECL_SYM("TYPE",1356), VV[2016]) /*  SUBPATHNAME */;
  value0 = ecl_list1(T1);
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4991output_files_va(cl_narg narg, cl_object v4asdf_lisp_action__o, cl_object v5asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1962]);
 {
  return LC4991output_files(v4asdf_lisp_action__o, v5asdf_lisp_action__c);
 }
}
/* local function ACTION-DESCRIPTION                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4992action_description(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(3, ECL_NIL, VV[2026], v2asdf_lisp_action__c);
 return value0;
}
static cl_object LC4992action_description_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1933]);
 {
  return LC4992action_description(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function ACTION-DESCRIPTION                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4993action_description(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(3, ECL_NIL, VV[2027], v2asdf_lisp_action__c);
 return value0;
}
static cl_object LC4993action_description_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1933]);
 {
  return LC4993action_description(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function ACTION-DESCRIPTION                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4994action_description(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(3, ECL_NIL, VV[2028], v2asdf_lisp_action__c);
 return value0;
}
static cl_object LC4994action_description_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1933]);
 {
  return LC4994action_description(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function PERFORM-WITH-RESTARTS                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4999perform_with_restarts(cl_object volatile v1asdf_lisp_action__o, cl_object volatile v2asdf_lisp_action__c)
{
 cl_object T0, T1, T2, T3, T4;
 volatile cl_object lex0[2];
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v2asdf_lisp_action__c,env0);  /*  C                       */
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L2;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L1;
L2:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L1:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
L5:;
 {
  volatile cl_object env1 = env0;
  CLV1 = env1 = CONS(ECL_NIL,env1);
  {
   volatile cl_object env2 = env1;
   CLV2 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY        */
   {
    ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV2));
    if (__ecl_frs_push_result!=0) {
    if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
     goto L7;
    }
    ecl_internal_error("GO found an inexistent tag");
    } else {
    {
     cl_object v3;
     v3 = ecl_make_cclosure_va((cl_objectfn)LC4997__lambda5728,env2,Cblock,0);
     T0 = v3;
    }
    {
     cl_object v3;
     v3 = ecl_make_cclosure_va((cl_objectfn)LC4998__lambda5730,env2,Cblock,1);
     T1 = v3;
    }
    T2 = (cl_env_copy->function=(VV[1715]->symbol.gfdef))->cfun.entry(6, ECL_SYM("NAME",1309), VV[2030], ECL_SYM("FUNCTION",1273), T0, VV[1718], T1) /*  MAKE-RESTART */;
    T3 = ecl_list1(T2);
    T4 = CONS(T3,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5)));
    ecl_bds_bind(cl_env_copy,ECL_SYM("*RESTART-CLUSTERS*",5),T4); /*  *RESTART-CLUSTERS* */
    value0 = LC4995call_next_method(0, lex0);
    ecl_frs_pop_n(cl_env_copy, 1);
    ecl_bds_unwind1(cl_env_copy);
    return value0;
L7:;
    {
     cl_object v3;
     v3 = ECL_CONS_CAR(CLV1);
     if (Null(v3)){
      goto L13;
     }
     si_dm_too_many_arguments(ECL_NIL);
L13:;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[1902]))->cfun.entry(2, v1asdf_lisp_action__o, VV[2000]) /*  FIND-OPERATION */;
     (cl_env_copy->function=ecl_fdefinition(VV[1982]))->cfun.entry(2, T0, ECL_CONS_CAR(CLV0)) /*  PERFORM */;
     ecl_frs_pop_n(cl_env_copy, 1);
     goto L6;
    }
    }
   }
  }
 }
L6:;
 goto L5;
}
static cl_object LC4999perform_with_restarts_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1984]);
 {
  return LC4999perform_with_restarts(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* function definition for PERFORM-LISP-LOAD-FASL                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5000perform_lisp_load_fasl(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_lisp_action__fasl;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, v1asdf_lisp_action__o, v2asdf_lisp_action__c) /*  INPUT-FILES */;
  v3asdf_lisp_action__fasl = ecl_car(T0);
  if (Null(v3asdf_lisp_action__fasl)){
   goto L3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1440]))->cfun.entry(1, v3asdf_lisp_action__fasl) /*  LOAD* */;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L5000perform_lisp_load_fasl_va(cl_narg narg, cl_object v4asdf_lisp_action__o, cl_object v5asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2034]);
 {
  return L5000perform_lisp_load_fasl(v4asdf_lisp_action__o, v5asdf_lisp_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5001perform(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2034]))->cfun.entry(2, v1asdf_lisp_action__o, v2asdf_lisp_action__c) /*  PERFORM-LISP-LOAD-FASL */;
 return value0;
}
static cl_object LC5001perform_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5001perform(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5002perform(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5002perform_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5002perform(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function ACTION-DESCRIPTION                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5003action_description(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(3, ECL_NIL, VV[2036], v2asdf_lisp_action__c);
 return value0;
}
static cl_object LC5003action_description_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1933]);
 {
  return LC5003action_description(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5004input_files(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__s)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_lisp_action__it;
  v3asdf_lisp_action__it = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, v2asdf_lisp_action__s) /*  SYSTEM-SOURCE-FILE */;
  if (Null(v3asdf_lisp_action__it)){
   goto L3;
  }
  value0 = ecl_list1(v3asdf_lisp_action__it);
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC5004input_files_va(cl_narg narg, cl_object v4asdf_lisp_action__o, cl_object v5asdf_lisp_action__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC5004input_files(v4asdf_lisp_action__o, v5asdf_lisp_action__s);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5005perform(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5005perform_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5005perform(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function ACTION-DESCRIPTION                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5006action_description(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(3, ECL_NIL, VV[2037], v2asdf_lisp_action__c);
 return value0;
}
static cl_object LC5006action_description_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1933]);
 {
  return LC5006action_description(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function ACTION-DESCRIPTION                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5007action_description(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(3, ECL_NIL, VV[2038], v2asdf_lisp_action__c);
 return value0;
}
static cl_object LC5007action_description_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1933]);
 {
  return LC5007action_description(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* function definition for PERFORM-LISP-LOAD-SOURCE                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5009perform_lisp_load_source(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1asdf_lisp_action__o,env0);  /*  O                       */
 CLV1 = env0 = CONS(v2asdf_lisp_action__c,env0);  /*  C                       */
 {
  cl_object v3;
  v3 = ecl_make_cclosure_va((cl_objectfn)LC5008__lambda5742,env0,Cblock,0);
  T0 = v3;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2007]))->cfun.entry(2, ECL_CONS_CAR(CLV1), T0) /*  CALL-WITH-AROUND-COMPILE-HOOK */;
 return value0;
}
static cl_object L5009perform_lisp_load_source_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2039]);
 {
  return L5009perform_lisp_load_source(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5010perform(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2039]))->cfun.entry(2, v1asdf_lisp_action__o, v2asdf_lisp_action__c) /*  PERFORM-LISP-LOAD-SOURCE */;
 return value0;
}
static cl_object LC5010perform_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5010perform(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5011perform(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5011perform_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5011perform(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5012perform(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5012perform_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5012perform(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function OPERATION-DONE-P                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5013operation_done_p(cl_object v1asdf_lisp_action__o, cl_object v2asdf_lisp_action__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5013operation_done_p_va(cl_narg narg, cl_object v3asdf_lisp_action__o, cl_object v4asdf_lisp_action__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1964]);
 {
  return LC5013operation_done_p(v3asdf_lisp_action__o, v4asdf_lisp_action__c);
 }
}
/* local function LAMBDA5748                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5014__lambda5748()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
 return value0;
}
static cl_object LC5014__lambda5748_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2044]);
 {
  return LC5014__lambda5748();
 }
}
/* local function LAMBDA5750                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5015__lambda5750()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
 return value0;
}
static cl_object LC5015__lambda5750_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2045]);
 {
  return LC5015__lambda5750();
 }
}
/* local function PRINT-OBJECT                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5017print_object(cl_object v1asdf_plan__status, cl_object v2stream)
{
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1asdf_plan__status,env0);    /*  STATUS                  */
 CLV1 = env0 = CONS(v2stream,env0);               /*  STREAM                  */
 {
  cl_object v3;
  v3 = ecl_make_cclosure_va((cl_objectfn)LC5016si___print_unreadable_object_body_,env0,Cblock,0);
  value0 = si_print_unreadable_object_function(ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1), ECL_T, ECL_NIL, v3);
  return value0;
 }
}
static cl_object LC5017print_object_va(cl_narg narg, cl_object v4asdf_plan__status, cl_object v5stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(ECL_SYM("PRINT-OBJECT",965));
 {
  return LC5017print_object(v4asdf_plan__status, v5stream);
 }
}
/* local function ACTION-PLANNED-P                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5018action_planned_p(cl_object v1asdf_action_action_status)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5018action_planned_p_va(cl_narg narg, cl_object v2asdf_action_action_status, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2053]);
 {
  return LC5018action_planned_p(v2asdf_action_action_status);
 }
}
/* function definition for NODE-FOR                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5019node_for(cl_object v1asdf_plan__o, cl_object v2asdf_plan__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_type_of(v1asdf_plan__o);
 value0 = CONS(T0,v2asdf_plan__c);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5019node_for_va(cl_narg narg, cl_object v3asdf_plan__o, cl_object v4asdf_plan__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2054]);
 {
  return L5019node_for(v3asdf_plan__o, v4asdf_plan__c);
 }
}
/* function definition for ACTION-ALREADY-DONE-P                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5020action_already_done_p(cl_object v1asdf_plan_plan, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2046]))->cfun.entry(3, v1asdf_plan_plan, v2asdf_operation_operation, v3asdf_component_component) /*  PLAN-ACTION-STATUS */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2057]))->cfun.entry(1, T0) /*  ACTION-DONE-P */;
 return value0;
}
static cl_object L5020action_already_done_p_va(cl_narg narg, cl_object v4asdf_plan_plan, cl_object v5asdf_operation_operation, cl_object v6asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[2056]);
 {
  return L5020action_already_done_p(v4asdf_plan_plan, v5asdf_operation_operation, v6asdf_component_component);
 }
}
/* local function PLAN-ACTION-STATUS                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5021plan_action_status(cl_object v1asdf_plan_plan, cl_object v2asdf_plan__o, cl_object v3asdf_plan__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;                                   /*  STAMP                   */
  cl_object v5;                                   /*  DONE-P                  */
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1970]))->cfun.entry(2, v2asdf_plan__o, v3asdf_plan__c) /*  COMPONENT-OPERATION-TIME */;
  {
   const int v6 = cl_env_copy->nvalues;
   v4 = value0;
   cl_object v7;
   v7 = (v6<=1)? ECL_NIL : cl_env_copy->values[1];
   v5 = v7;
  }
  value0 = (cl_env_copy->function=(ECL_SYM("MAKE-INSTANCE",953)->symbol.gfdef))->cfun.entry(5, VV[1974], VV[1976], v4, VV[1978], v5) /*  MAKE-INSTANCE */;
  return value0;
 }
}
static cl_object LC5021plan_action_status_va(cl_narg narg, cl_object v4asdf_plan_plan, cl_object v5asdf_plan__o, cl_object v6asdf_plan__c, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[2046]);
 {
  return LC5021plan_action_status(v4asdf_plan_plan, v5asdf_plan__o, v6asdf_plan__c);
 }
}
/* local function PLAN-ACTION-STATUS                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5022plan_action_status(cl_object v1asdf_plan__new_status, cl_object v2asdf_plan_plan, cl_object v3asdf_plan__o, cl_object v4asdf_plan__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5;
  cl_object v6;
  v5 = cl_type_of(v3asdf_plan__o);
  v6 = (cl_env_copy->function=ecl_fdefinition(VV[1980]))->cfun.entry(1, v4asdf_plan__c) /*  COMPONENT-OPERATION-TIMES */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[2057]))->cfun.entry(1, v1asdf_plan__new_status) /*  ACTION-DONE-P */)){
   goto L5;
  }
  cl_remhash(v5, v6);
  goto L2;
L5:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2059]))->cfun.entry(1, v1asdf_plan__new_status) /*  ACTION-STAMP */;
  si_hash_set(v5, v6, T0);
 }
L2:;
 value0 = v1asdf_plan__new_status;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5022plan_action_status_va(cl_narg narg, cl_object v5asdf_plan__new_status, cl_object v6asdf_plan_plan, cl_object v7asdf_plan__o, cl_object v8asdf_plan__c, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[2046]);
 {
  return LC5022plan_action_status(v5asdf_plan__new_status, v6asdf_plan_plan, v7asdf_plan__o, v8asdf_plan__c);
 }
}
/* function definition for NORMALIZE-FORCED-SYSTEMS                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5023normalize_forced_systems(cl_object v1asdf_plan__force, cl_object v2asdf_system_system)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v1asdf_plan__force)==(ECL_NIL))){
  goto L8;
 }
 goto L4;
L8:;
 goto L6;
L6:;
 if (!((v1asdf_plan__force)==(VV[2064]))){
  goto L11;
 }
 goto L4;
L11:;
 goto L5;
L5:;
 if (cl_hash_table_p(v1asdf_plan__force)!=ECL_NIL) {
  goto L4;
 }
 if (Null(cl_functionp(v1asdf_plan__force))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = v1asdf_plan__force;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!(ECL_CONSP(v1asdf_plan__force))){
  goto L14;
 }
 {
  cl_object v3;
  v3 = ecl_fdefinition(VV[1753]);
  {
   cl_object v4;
   cl_object v5;
   cl_object v6;
   {
    cl_object v7;
    v7 = v1asdf_plan__force;
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   v5 = ECL_NIL;
   v6 = v4;
   {
    cl_object v7;
    cl_object v8;
    v7 = ecl_list1(ECL_NIL);
    v8 = v7;
L25:;
    if (!(ecl_endp(v6))){
     goto L27;
    }
    goto L26;
L27:;
    v5 = ECL_CONS_CAR(v6);
    {
     cl_object v9;
     v9 = ECL_CONS_CDR(v6);
     if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v6 = v9;
    }
    {
     cl_object v9;
     v9 = v8;
     if (ecl_unlikely(ECL_ATOM(v9))) FEtype_error_cons(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T1 = v9;
    }
    T2 = ecl_function_dispatch(cl_env_copy,v3)(1, v5);
    v8 = ecl_list1(T2);
    (ECL_CONS_CDR(T1)=v8,T1);
    goto L25;
L26:;
    T0 = ecl_cdr(v7);
    goto L16;
   }
  }
 }
L16:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[369]))->cfun.entry(1, T0) /*  LIST-TO-HASH-SET */;
 return value0;
L14:;
 if (Null(cl_typep(2, v1asdf_plan__force, VV[40]))){
  goto L43;
 }
 if (Null(v2asdf_system_system)){
  goto L45;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v2asdf_system_system) /*  COERCE-NAME */;
 T1 = ecl_list1(T0);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[369]))->cfun.entry(1, T1) /*  LIST-TO-HASH-SET */;
 return value0;
L45:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L43:;
 value0 = si_etypecase_error(v1asdf_plan__force, VV[2066]);
 return value0;
}
static cl_object L5023normalize_forced_systems_va(cl_narg narg, cl_object v3asdf_plan__force, cl_object v4asdf_system_system, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2062]);
 {
  return L5023normalize_forced_systems(v3asdf_plan__force, v4asdf_system_system);
 }
}
/* function definition for NORMALIZE-FORCED-NOT-SYSTEMS                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5026normalize_forced_not_systems(cl_object v1asdf_plan__force_not, cl_object v2asdf_system_system)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object env1 = env0;
  if (!((v1asdf_plan__force_not)==(ECL_NIL))){
   goto L9;
  }
  goto L5;
L9:;
  goto L7;
L7:;
  if (!((v1asdf_plan__force_not)==(VV[2064]))){
   goto L12;
  }
  goto L5;
L12:;
  goto L6;
L6:;
  if (cl_hash_table_p(v1asdf_plan__force_not)!=ECL_NIL) {
   goto L5;
  }
  if (Null(cl_functionp(v1asdf_plan__force_not))){
   goto L3;
  }
  goto L4;
L5:;
L4:;
  T0 = v1asdf_plan__force_not;
  goto L2;
L3:;
  if (!(ECL_CONSP(v1asdf_plan__force_not))){
   goto L15;
  }
  {
   cl_object v3;
   v3 = ecl_fdefinition(VV[1753]);
   {
    cl_object v4;
    cl_object v5;
    cl_object v6;
    {
     cl_object v7;
     v7 = v1asdf_plan__force_not;
     if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v4 = v7;
    }
    v5 = ECL_NIL;
    v6 = v4;
    {
     cl_object v7;
     cl_object v8;
     v7 = ecl_list1(ECL_NIL);
     v8 = v7;
L26:;
     if (!(ecl_endp(v6))){
      goto L28;
     }
     goto L27;
L28:;
     v5 = ECL_CONS_CAR(v6);
     {
      cl_object v9;
      v9 = ECL_CONS_CDR(v6);
      if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v6 = v9;
     }
     {
      cl_object v9;
      v9 = v8;
      if (ecl_unlikely(ECL_ATOM(v9))) FEtype_error_cons(v9);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T2 = v9;
     }
     T3 = ecl_function_dispatch(cl_env_copy,v3)(1, v5);
     v8 = ecl_list1(T3);
     (ECL_CONS_CDR(T2)=v8,T2);
     goto L26;
L27:;
     T1 = ecl_cdr(v7);
     goto L17;
    }
   }
  }
L17:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[369]))->cfun.entry(1, T1) /*  LIST-TO-HASH-SET */;
  goto L2;
L15:;
  if (Null(cl_typep(2, v1asdf_plan__force_not, VV[40]))){
   goto L44;
  }
  if (Null(v2asdf_system_system)){
   goto L46;
  }
  {
   cl_object env2 = env1;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v2asdf_system_system) /*  COERCE-NAME */;
   env2 = ECL_NIL;
   CLV0 = env2 = CONS(T1,env2);                   /*  NAME                    */
   {
    cl_object v3;
    v3 = ecl_make_cclosure_va((cl_objectfn)LC5024__lambda5893,env2,Cblock,1);
    T0 = v3;
    goto L2;
   }
  }
L46:;
  T0 = VV[2064];
  goto L2;
L44:;
  T0 = si_etypecase_error(v1asdf_plan__force_not, VV[2066]);
L2:;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(T0,env1);                    /*  REQUESTED               */
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1793]))){
   goto L48;
  }
  if (Null(ECL_CONS_CAR(CLV0))){
   goto L48;
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC5025__lambda5895,env1,Cblock,1);
   value0 = v3;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L48:;
  value0 = ecl_cmp_symbol_value(cl_env_copy,VV[1793]);
  if (value0!=ECL_NIL) {
   goto L52;
  }
  value0 = ECL_CONS_CAR(CLV0);
  cl_env_copy->nvalues = 1;
  return value0;
L52:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L5026normalize_forced_not_systems_va(cl_narg narg, cl_object v4asdf_plan__force_not, cl_object v5asdf_system_system, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2068]);
 {
  return L5026normalize_forced_not_systems(v4asdf_plan__force_not, v5asdf_system_system);
 }
}
/* function definition for ACTION-OVERRIDE-P                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5027action_override_p(cl_object v1asdf_plan_plan, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component, cl_object v4asdf_plan__override_accessor)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_function_dispatch(cl_env_copy,v4asdf_plan__override_accessor)(1, v1asdf_plan_plan);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v3asdf_component_component) /*  FIND-COMPONENT */;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[1637]))->cfun.entry(1, T1) /*  COMPONENT-SYSTEM */;
 T3 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, T2) /*  COERCE-NAME */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, T0, T3) /*  CALL-FUNCTION */;
 return value0;
}
static cl_object L5027action_override_p_va(cl_narg narg, cl_object v5asdf_plan_plan, cl_object v6asdf_operation_operation, cl_object v7asdf_component_component, cl_object v8asdf_plan__override_accessor, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[2072]);
 {
  return L5027action_override_p(v5asdf_plan_plan, v6asdf_operation_operation, v7asdf_component_component, v8asdf_plan__override_accessor);
 }
}
/* local function ACTION-FORCED-P                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5028action_forced_p(cl_object v1asdf_plan_plan, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[2072]))->cfun.entry(4, v1asdf_plan_plan, v2asdf_operation_operation, v3asdf_component_component, VV[2074]) /*  ACTION-OVERRIDE-P */)){
  goto L3;
 }
 {
  cl_object v4asdf_system_system;
  v4asdf_system_system = (cl_env_copy->function=ecl_fdefinition(VV[1637]))->cfun.entry(1, v3asdf_component_component) /*  COMPONENT-SYSTEM */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[2024]))->cfun.entry(1, v4asdf_system_system) /*  BUILTIN-SYSTEM-P */)){
   goto L8;
  }
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[2075]))->cfun.entry(1, v1asdf_plan_plan) /*  PLAN-SYSTEM */;
  {
   bool v5;
   v5 = (v4asdf_system_system)==(T1);
   T0 = (v5)?ECL_NIL:ECL_T;
   goto L5;
  }
L8:;
  T0 = ECL_NIL;
  goto L5;
 }
L5:;
 value0 = Null(T0)?ECL_T:ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5028action_forced_p_va(cl_narg narg, cl_object v4asdf_plan_plan, cl_object v5asdf_operation_operation, cl_object v6asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[2060]);
 {
  return LC5028action_forced_p(v4asdf_plan_plan, v5asdf_operation_operation, v6asdf_component_component);
 }
}
/* local function ACTION-FORCED-NOT-P                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5029action_forced_not_p(cl_object v1asdf_plan_plan, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2072]))->cfun.entry(4, v1asdf_plan_plan, v2asdf_operation_operation, v3asdf_component_component, VV[2076]) /*  ACTION-OVERRIDE-P */;
 return value0;
}
static cl_object LC5029action_forced_not_p_va(cl_narg narg, cl_object v4asdf_plan_plan, cl_object v5asdf_operation_operation, cl_object v6asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[2061]);
 {
  return LC5029action_forced_not_p(v4asdf_plan_plan, v5asdf_operation_operation, v6asdf_component_component);
 }
}
/* local function ACTION-FORCED-P                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5030action_forced_p(cl_object v1asdf_plan_plan, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5030action_forced_p_va(cl_narg narg, cl_object v4asdf_plan_plan, cl_object v5asdf_operation_operation, cl_object v6asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[2060]);
 {
  return LC5030action_forced_p(v4asdf_plan_plan, v5asdf_operation_operation, v6asdf_component_component);
 }
}
/* local function ACTION-FORCED-NOT-P                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5031action_forced_not_p(cl_object v1asdf_plan_plan, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5031action_forced_not_p_va(cl_narg narg, cl_object v4asdf_plan_plan, cl_object v5asdf_operation_operation, cl_object v6asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[2061]);
 {
  return LC5031action_forced_not_p(v4asdf_plan_plan, v5asdf_operation_operation, v6asdf_component_component);
 }
}
/* function definition for ACTION-VALID-P                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5032action_valid_p(cl_object v1asdf_operation_operation, cl_object v2asdf_component_component)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1asdf_operation_operation)){
  goto L3;
 }
 if (Null(v2asdf_component_component)){
  goto L3;
 }
 {
  cl_object v3asdf_plan__it;
  v3asdf_plan__it = (cl_env_copy->function=ecl_fdefinition(VV[1688]))->cfun.entry(1, v2asdf_component_component) /*  COMPONENT-IF-FEATURE */;
  if (Null(v3asdf_plan__it)){
   goto L7;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[420]))->cfun.entry(1, v3asdf_plan__it) /*  FEATUREP */;
  return value0;
L7:;
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5032action_valid_p_va(cl_narg narg, cl_object v4asdf_operation_operation, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2077]);
 {
  return L5032action_valid_p(v4asdf_operation_operation, v5asdf_component_component);
 }
}
/* local function NEEDED-IN-IMAGE-P                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5033needed_in_image_p(cl_object v1asdf_plan__o, cl_object v2asdf_plan__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, v1asdf_plan__o, v2asdf_plan__c) /*  OUTPUT-FILES */;
 value0 = Null(T0)?ECL_T:ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5033needed_in_image_p_va(cl_narg narg, cl_object v3asdf_plan__o, cl_object v4asdf_plan__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2079]);
 {
  return LC5033needed_in_image_p(v3asdf_plan__o, v4asdf_plan__c);
 }
}
/* function definition for MAP-DIRECT-DEPENDENCIES                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5034map_direct_dependencies(cl_object v1asdf_plan_plan, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component, cl_object v4asdf_plan__fun)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v5;
  cl_object v6asdf_plan__dep_o_spec;
  cl_object v7asdf_plan__dep_c_specs;
  cl_object v8;
  {
   cl_object v9;
   v9 = (cl_env_copy->function=ecl_fdefinition(VV[1941]))->cfun.entry(2, v2asdf_operation_operation, v3asdf_component_component) /*  COMPONENT-DEPENDS-ON */;
   if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v5 = v9;
  }
  v6asdf_plan__dep_o_spec = ECL_NIL;
  v7asdf_plan__dep_c_specs = ECL_NIL;
  v8 = v5;
  {
   cl_object v9asdf_plan__dep_o;
   v9asdf_plan__dep_o = ECL_NIL;
L9:;
   if (!(ecl_endp(v8))){
    goto L11;
   }
   goto L10;
L11:;
   {
    cl_object v10;
    v10 = ECL_CONS_CAR(v8);
    v6asdf_plan__dep_o_spec = ecl_car(v10);
    v10 = ecl_cdr(v10);
    v7asdf_plan__dep_c_specs = v10;
   }
   {
    cl_object v10;
    v10 = ECL_CONS_CDR(v8);
    if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v8 = v10;
   }
   v9asdf_plan__dep_o = (cl_env_copy->function=ecl_fdefinition(VV[1902]))->cfun.entry(2, v2asdf_operation_operation, v6asdf_plan__dep_o_spec) /*  FIND-OPERATION */;
   if (Null(v9asdf_plan__dep_o)){
    goto L26;
   }
   {
    cl_object v10;
    cl_object v11asdf_plan__dep_c_spec;
    cl_object v12;
    {
     cl_object v13;
     v13 = v7asdf_plan__dep_c_specs;
     if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v10 = v13;
    }
    v11asdf_plan__dep_c_spec = ECL_NIL;
    v12 = v10;
    {
     cl_object v13asdf_plan__dep_c;
     v13asdf_plan__dep_c = ECL_NIL;
L34:;
     if (!(ecl_endp(v12))){
      goto L36;
     }
     goto L35;
L36:;
     v11asdf_plan__dep_c_spec = ECL_CONS_CAR(v12);
     {
      cl_object v14;
      v14 = ECL_CONS_CDR(v12);
      if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v12 = v14;
     }
     if (Null(v11asdf_plan__dep_c_spec)){
      goto L47;
     }
     v13asdf_plan__dep_c = (cl_env_copy->function=ecl_fdefinition(VV[1885]))->cfun.entry(2, v3asdf_component_component, v11asdf_plan__dep_c_spec) /*  RESOLVE-DEPENDENCY-SPEC */;
     goto L45;
L47:;
     v13asdf_plan__dep_c = ECL_NIL;
     goto L45;
L45:;
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[2077]))->cfun.entry(2, v9asdf_plan__dep_o, v13asdf_plan__dep_c) /*  ACTION-VALID-P */)){
      goto L49;
     }
     ecl_function_dispatch(cl_env_copy,v4asdf_plan__fun)(2, v9asdf_plan__dep_o, v13asdf_plan__dep_c);
L49:;
     goto L34;
L35:;
    }
   }
L26:;
   goto L9;
L10:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L5034map_direct_dependencies_va(cl_narg narg, cl_object v10asdf_plan_plan, cl_object v11asdf_operation_operation, cl_object v12asdf_component_component, cl_object v13asdf_plan__fun, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[2080]);
 {
  return L5034map_direct_dependencies(v10asdf_plan_plan, v11asdf_operation_operation, v12asdf_component_component, v13asdf_plan__fun);
 }
}
/* function definition for REDUCE-DIRECT-DEPENDENCIES                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5036reduce_direct_dependencies(cl_object v1asdf_plan_plan, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component, cl_object v4asdf_plan__combinator, cl_object v5asdf_plan__seed)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v4asdf_plan__combinator,env0); /*  COMBINATOR             */
 CLV1 = env0 = CONS(v5asdf_plan__seed,env0);      /*  SEED                    */
 {
  cl_object v6;
  v6 = ecl_make_cclosure_va((cl_objectfn)LC5035__lambda5921,env0,Cblock,2);
  T0 = v6;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[2080]))->cfun.entry(4, v1asdf_plan_plan, v2asdf_operation_operation, v3asdf_component_component, T0) /*  MAP-DIRECT-DEPENDENCIES */;
 value0 = ECL_CONS_CAR(CLV1);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5036reduce_direct_dependencies_va(cl_narg narg, cl_object v6asdf_plan_plan, cl_object v7asdf_operation_operation, cl_object v8asdf_component_component, cl_object v9asdf_plan__combinator, cl_object v10asdf_plan__seed, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[2082]);
 {
  return L5036reduce_direct_dependencies(v6asdf_plan_plan, v7asdf_operation_operation, v8asdf_component_component, v9asdf_plan__combinator, v10asdf_plan__seed);
 }
}
/* function definition for DIRECT-DEPENDENCIES                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5037direct_dependencies(cl_object v1asdf_plan_plan, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (ECL_SYM("ACONS",81)->symbol.gfdef);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2082]))->cfun.entry(5, v1asdf_plan_plan, v2asdf_operation_operation, v3asdf_component_component, T0, ECL_NIL) /*  REDUCE-DIRECT-DEPENDENCIES */;
 return value0;
}
static cl_object L5037direct_dependencies_va(cl_narg narg, cl_object v4asdf_plan_plan, cl_object v5asdf_operation_operation, cl_object v6asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[2085]);
 {
  return L5037direct_dependencies(v4asdf_plan_plan, v5asdf_operation_operation, v6asdf_component_component);
 }
}
/* local function COMPUTE-ACTION-STAMP                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5039compute_action_stamp(cl_narg narg, cl_object v1asdf_plan_plan, cl_object v2asdf_plan__o, cl_object v3asdf_plan__c, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[1973]);
 {
  cl_object v4asdf_plan__just_done;
  ecl_va_list args; ecl_va_start(args,v3asdf_plan__c,narg,3);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1asdf_plan_plan,env0);      /*  PLAN                    */
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC5039compute_action_stampkeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v4asdf_plan__just_done = keyvars[0];
  }
  {
   cl_object v5asdf_plan__dep_stamp;
   {
    cl_object v6;
    v6 = ecl_make_cclosure_va((cl_objectfn)LC5038__lambda5958,env0,Cblock,3);
    T0 = v6;
   }
   v5asdf_plan__dep_stamp = (cl_env_copy->function=ecl_fdefinition(VV[2082]))->cfun.entry(5, ECL_CONS_CAR(CLV0), v2asdf_plan__o, v3asdf_plan__c, T0, ECL_NIL) /*  REDUCE-DIRECT-DEPENDENCIES */;
   if (!((v5asdf_plan__dep_stamp)==(ECL_T))){
    goto L3;
   }
   if (v4asdf_plan__just_done!=ECL_NIL) {
    goto L3;
   }
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = ECL_NIL;
   cl_env_copy->values[0] = ECL_T;
   return cl_env_copy->values[0];
L3:;
   {
    cl_object v6asdf_plan__in_files;
    cl_object v7asdf_plan__in_stamps;
    cl_object v8asdf_plan__missing_in;
    cl_object v9asdf_plan__latest_in;
    v6asdf_plan__in_files = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, v2asdf_plan__o, v3asdf_plan__c) /*  INPUT-FILES */;
    {
     cl_object v10;
     v10 = ecl_fdefinition(VV[1734]);
     {
      cl_object v11;
      cl_object v12;
      cl_object v13;
      {
       cl_object v14;
       v14 = v6asdf_plan__in_files;
       if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v11 = v14;
      }
      v12 = ECL_NIL;
      v13 = v11;
      {
       cl_object v14;
       cl_object v15;
       v14 = ecl_list1(ECL_NIL);
       v15 = v14;
L16:;
       if (!(ecl_endp(v13))){
        goto L18;
       }
       goto L17;
L18:;
       v12 = ECL_CONS_CAR(v13);
       {
        cl_object v16;
        v16 = ECL_CONS_CDR(v13);
        if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v13 = v16;
       }
       {
        cl_object v16;
        v16 = v15;
        if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T0 = v16;
       }
       T1 = ecl_function_dispatch(cl_env_copy,v10)(1, v12);
       v15 = ecl_list1(T1);
       (ECL_CONS_CDR(T0)=v15,T0);
       goto L16;
L17:;
       v7asdf_plan__in_stamps = ecl_cdr(v14);
       goto L7;
      }
     }
    }
L7:;
    {
     cl_object v10;
     cl_object v11asdf_plan__f;
     cl_object v12;
     {
      cl_object v13;
      v13 = v6asdf_plan__in_files;
      if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v10 = v13;
     }
     v11asdf_plan__f = ECL_NIL;
     v12 = v10;
     {
      cl_object v13;
      cl_object v14asdf_plan__s;
      cl_object v15;
      {
       cl_object v16;
       v16 = v7asdf_plan__in_stamps;
       if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v13 = v16;
      }
      v14asdf_plan__s = ECL_NIL;
      v15 = v13;
      {
       cl_object v16;
       cl_object v17;
       v16 = ecl_list1(ECL_NIL);
       v17 = v16;
L47:;
       if (!(ecl_endp(v12))){
        goto L49;
       }
       goto L48;
L49:;
       v11asdf_plan__f = ECL_CONS_CAR(v12);
       {
        cl_object v18;
        v18 = ECL_CONS_CDR(v12);
        if (ecl_unlikely(!ECL_LISTP(v18))) FEtype_error_list(v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v12 = v18;
       }
       if (!(ecl_endp(v15))){
        goto L57;
       }
       goto L48;
L57:;
       v14asdf_plan__s = ECL_CONS_CAR(v15);
       {
        cl_object v18;
        v18 = ECL_CONS_CDR(v15);
        if (ecl_unlikely(!ECL_LISTP(v18))) FEtype_error_list(v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v15 = v18;
       }
       if (v14asdf_plan__s!=ECL_NIL) {
        goto L65;
       }
       {
        cl_object v18;
        v18 = v17;
        if (ecl_unlikely(ECL_ATOM(v18))) FEtype_error_cons(v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T0 = v18;
       }
       v17 = ecl_list1(v11asdf_plan__f);
       (ECL_CONS_CDR(T0)=v17,T0);
L65:;
       goto L47;
L48:;
       v8asdf_plan__missing_in = ecl_cdr(v16);
       goto L34;
      }
     }
    }
L34:;
    T0 = CONS(v5asdf_plan__dep_stamp,v7asdf_plan__in_stamps);
    v9asdf_plan__latest_in = (cl_env_copy->function=ecl_fdefinition(VV[337]))->cfun.entry(1, T0) /*  STAMPS-LATEST */;
    if (Null(v8asdf_plan__missing_in)){
     goto L74;
    }
    if (v4asdf_plan__just_done!=ECL_NIL) {
     goto L74;
    }
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = ECL_NIL;
    cl_env_copy->values[0] = ECL_T;
    return cl_env_copy->values[0];
L74:;
    {
     cl_object v10asdf_plan__out_files;
     cl_object v11asdf_plan__out_stamps;
     cl_object v12asdf_plan__missing_out;
     cl_object v13asdf_plan__earliest_out;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, v2asdf_plan__o, v3asdf_plan__c) /*  OUTPUT-FILES */;
     v10asdf_plan__out_files = cl_remove_if(2, ECL_SYM("NULL",607), T0);
     {
      cl_object v14;
      if (Null(v4asdf_plan__just_done)){
       goto L80;
      }
      v14 = VV[1733];
      goto L79;
L80:;
      v14 = VV[1734];
L79:;
      {
       cl_object v15;
       cl_object v16;
       cl_object v17;
       {
        cl_object v18;
        v18 = v10asdf_plan__out_files;
        if (ecl_unlikely(!ECL_LISTP(v18))) FEtype_error_list(v18);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v15 = v18;
       }
       v16 = ECL_NIL;
       v17 = v15;
       {
        cl_object v18;
        cl_object v19;
        v18 = ecl_list1(ECL_NIL);
        v19 = v18;
L89:;
        if (!(ecl_endp(v17))){
         goto L91;
        }
        goto L90;
L91:;
        v16 = ECL_CONS_CAR(v17);
        {
         cl_object v20;
         v20 = ECL_CONS_CDR(v17);
         if (ecl_unlikely(!ECL_LISTP(v20))) FEtype_error_list(v20);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         v17 = v20;
        }
        {
         cl_object v20;
         v20 = v19;
         if (ecl_unlikely(ECL_ATOM(v20))) FEtype_error_cons(v20);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         T0 = v20;
        }
        T1 = ecl_function_dispatch(cl_env_copy,v14)(1, v16);
        v19 = ecl_list1(T1);
        (ECL_CONS_CDR(T0)=v19,T0);
        goto L89;
L90:;
        v11asdf_plan__out_stamps = ecl_cdr(v18);
        goto L78;
       }
      }
     }
L78:;
     {
      cl_object v14;
      cl_object v15asdf_plan__f;
      cl_object v16;
      {
       cl_object v17;
       v17 = v10asdf_plan__out_files;
       if (ecl_unlikely(!ECL_LISTP(v17))) FEtype_error_list(v17);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v14 = v17;
      }
      v15asdf_plan__f = ECL_NIL;
      v16 = v14;
      {
       cl_object v17;
       cl_object v18asdf_plan__s;
       cl_object v19;
       {
        cl_object v20;
        v20 = v11asdf_plan__out_stamps;
        if (ecl_unlikely(!ECL_LISTP(v20))) FEtype_error_list(v20);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v17 = v20;
       }
       v18asdf_plan__s = ECL_NIL;
       v19 = v17;
       {
        cl_object v20;
        cl_object v21;
        v20 = ecl_list1(ECL_NIL);
        v21 = v20;
L120:;
        if (!(ecl_endp(v16))){
         goto L122;
        }
        goto L121;
L122:;
        v15asdf_plan__f = ECL_CONS_CAR(v16);
        {
         cl_object v22;
         v22 = ECL_CONS_CDR(v16);
         if (ecl_unlikely(!ECL_LISTP(v22))) FEtype_error_list(v22);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         v16 = v22;
        }
        if (!(ecl_endp(v19))){
         goto L130;
        }
        goto L121;
L130:;
        v18asdf_plan__s = ECL_CONS_CAR(v19);
        {
         cl_object v22;
         v22 = ECL_CONS_CDR(v19);
         if (ecl_unlikely(!ECL_LISTP(v22))) FEtype_error_list(v22);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         v19 = v22;
        }
        if (v18asdf_plan__s!=ECL_NIL) {
         goto L138;
        }
        {
         cl_object v22;
         v22 = v21;
         if (ecl_unlikely(ECL_ATOM(v22))) FEtype_error_cons(v22);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         T0 = v22;
        }
        v21 = ecl_list1(v15asdf_plan__f);
        (ECL_CONS_CDR(T0)=v21,T0);
L138:;
        goto L120;
L121:;
        v12asdf_plan__missing_out = ecl_cdr(v20);
        goto L107;
       }
      }
     }
L107:;
     v13asdf_plan__earliest_out = (cl_env_copy->function=ecl_fdefinition(VV[330]))->cfun.entry(1, v11asdf_plan__out_stamps) /*  STAMPS-EARLIEST */;
     if (Null(v12asdf_plan__missing_out)){
      goto L147;
     }
     if (v4asdf_plan__just_done!=ECL_NIL) {
      goto L147;
     }
     cl_env_copy->nvalues = 2;
     cl_env_copy->values[1] = ECL_NIL;
     cl_env_copy->values[0] = ECL_T;
     return cl_env_copy->values[0];
L147:;
     {
      cl_object v14asdf_plan__out_op;
      cl_object v15asdf_plan__op_time;
      cl_object v16asdf_plan__all_present;
      cl_object v17asdf_plan__up_to_date_p;
      cl_object v18asdf_plan__done_stamp;
      if (Null(v10asdf_plan__out_files)){
       goto L152;
      }
      v14asdf_plan__out_op = ECL_T;
      goto L150;
L152:;
      v14asdf_plan__out_op = ECL_NIL;
      goto L150;
L150:;
      value0 = v4asdf_plan__just_done;
      if (value0!=ECL_NIL) {
       goto L156;
      }
      v15asdf_plan__op_time = (cl_env_copy->function=ecl_fdefinition(VV[1970]))->cfun.entry(2, v2asdf_plan__o, v3asdf_plan__c) /*  COMPONENT-OPERATION-TIME */;
      goto L154;
L156:;
      v15asdf_plan__op_time = value0;
      goto L154;
L154:;
      value0 = v8asdf_plan__missing_in;
      if (value0!=ECL_NIL) {
       goto L161;
      }
      T0 = v12asdf_plan__missing_out;
      goto L159;
L161:;
      T0 = value0;
      goto L159;
L159:;
      v16asdf_plan__all_present = Null(T0)?ECL_T:ECL_NIL;
      v17asdf_plan__up_to_date_p = (cl_env_copy->function=ecl_fdefinition(VV[326]))->cfun.entry(2, v9asdf_plan__latest_in, v13asdf_plan__earliest_out) /*  STAMP<= */;
      T0 = CONS(v9asdf_plan__latest_in,v11asdf_plan__out_stamps);
      v18asdf_plan__done_stamp = (cl_env_copy->function=ecl_fdefinition(VV[337]))->cfun.entry(1, T0) /*  STAMPS-LATEST */;
      if (Null(v4asdf_plan__just_done)){
       goto L165;
      }
      if (v16asdf_plan__all_present!=ECL_NIL) {
       goto L165;
      }
      T0 = (cl_env_copy->function=ecl_fdefinition(VV[1933]))->cfun.entry(2, v2asdf_plan__o, v3asdf_plan__c) /*  ACTION-DESCRIPTION */;
      {
       cl_fixnum v19;
       v19 = ecl_length(v8asdf_plan__missing_in);
       if (Null(v8asdf_plan__missing_in)){
        goto L170;
       }
       T1 = v12asdf_plan__missing_out;
       goto L168;
L170:;
       T1 = ECL_NIL;
       goto L168;
L168:;
       {
        cl_fixnum v20;
        v20 = ecl_length(v12asdf_plan__missing_out);
        (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(7, VV[2088], T0, v8asdf_plan__missing_in, ecl_make_fixnum(v19), T1, v12asdf_plan__missing_out, ecl_make_fixnum(v20)) /*  WARN */;
       }
      }
L165:;
      if (v4asdf_plan__just_done!=ECL_NIL) {
       goto L174;
      }
      if (Null(v16asdf_plan__all_present)){
       goto L172;
      }
      if (Null(v17asdf_plan__up_to_date_p)){
       goto L172;
      }
      if (Null((cl_env_copy->function=ecl_fdefinition(VV[1964]))->cfun.entry(2, v2asdf_plan__o, v3asdf_plan__c) /*  OPERATION-DONE-P */)){
       goto L172;
      }
      if ((cl_env_copy->function=ecl_fdefinition(VV[2060]))->cfun.entry(3, ECL_CONS_CAR(CLV0), v2asdf_plan__o, v3asdf_plan__c) /*  ACTION-FORCED-P */!=ECL_NIL) {
       goto L172;
      }
      goto L173;
L174:;
L173:;
      value0 = v4asdf_plan__just_done;
      if (value0!=ECL_NIL) {
       goto L181;
      }
      value0 = v14asdf_plan__out_op;
      if (value0!=ECL_NIL) {
       goto L181;
      }
      if (Null(v15asdf_plan__op_time)){
       goto L185;
      }
      T0 = ecl_make_bool(ecl_eql(v15asdf_plan__op_time,v18asdf_plan__done_stamp));
      goto L179;
L185:;
      T0 = ECL_NIL;
      goto L179;
L181:;
      T0 = value0;
      goto L179;
L179:;
      cl_env_copy->nvalues = 2;
      cl_env_copy->values[1] = T0;
      cl_env_copy->values[0] = v18asdf_plan__done_stamp;
      return cl_env_copy->values[0];
L172:;
      cl_env_copy->nvalues = 2;
      cl_env_copy->values[1] = ECL_NIL;
      cl_env_copy->values[0] = ECL_T;
      return cl_env_copy->values[0];
     }
    }
   }
  }
 }
}
/* local function INITIALIZE-INSTANCE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5040initialize_instance(cl_narg narg, cl_object v1asdf_plan_plan, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("INITIALIZE-INSTANCE",951));
 {
  cl_object v2asdf_plan__force;
  cl_object v3asdf_plan__force_not;
  cl_object v4asdf_system_system;
  ecl_va_list args; ecl_va_start(args,v1asdf_plan_plan,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,LC5040initialize_instancekeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2asdf_plan__force = keyvars[0];
   v3asdf_plan__force_not = keyvars[1];
   v4asdf_system_system = keyvars[2];
  }
  {
   cl_object v5;
   v5 = (cl_env_copy->function=ecl_fdefinition(VV[2062]))->cfun.entry(2, v2asdf_plan__force, v4asdf_system_system) /*  NORMALIZE-FORCED-SYSTEMS */;
   (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v5, v1asdf_plan_plan, VV[2089]) /*  (SETF SLOT-VALUE) */;
  }
  {
   cl_object v5;
   v5 = (cl_env_copy->function=ecl_fdefinition(VV[2068]))->cfun.entry(2, v3asdf_plan__force_not, v4asdf_system_system) /*  NORMALIZE-FORCED-NOT-SYSTEMS */;
   value0 = (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v5, v1asdf_plan_plan, VV[2090]) /*  (SETF SLOT-VALUE) */;
   return value0;
  }
 }
}
/* local function PLAN-ACTIONS                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5041plan_actions(cl_object v1asdf_plan_plan)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = v1asdf_plan_plan;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5041plan_actions_va(cl_narg narg, cl_object v2asdf_plan_plan, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2091]);
 {
  return LC5041plan_actions(v2asdf_plan_plan);
 }
}
/* local function PLAN-ACTION-STATUS                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5042plan_action_status(cl_object v1asdf_plan__new_status, cl_object v2asdf_plan__p, cl_object v3asdf_plan__o, cl_object v4asdf_plan__c)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2054]))->cfun.entry(2, v3asdf_plan__o, v4asdf_plan__c) /*  NODE-FOR */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[2092]))->cfun.entry(1, v2asdf_plan__p) /*  PLAN-VISITED-ACTIONS */;
 value0 = si_hash_set(T0, T1, v1asdf_plan__new_status);
 return value0;
}
static cl_object LC5042plan_action_status_va(cl_narg narg, cl_object v5asdf_plan__new_status, cl_object v6asdf_plan__p, cl_object v7asdf_plan__o, cl_object v8asdf_plan__c, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[2046]);
 {
  return LC5042plan_action_status(v5asdf_plan__new_status, v6asdf_plan__p, v7asdf_plan__o, v8asdf_plan__c);
 }
}
/* local function PLAN-ACTION-STATUS                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5043plan_action_status(cl_object v1asdf_plan__p, cl_object v2asdf_plan__o, cl_object v3asdf_plan__c)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[2061]))->cfun.entry(3, v1asdf_plan__p, v2asdf_plan__o, v3asdf_plan__c) /*  ACTION-FORCED-NOT-P */)){
  goto L6;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2046]))->cfun.entry(3, ECL_NIL, v2asdf_plan__o, v3asdf_plan__c) /*  PLAN-ACTION-STATUS */;
 goto L4;
L6:;
 value0 = ECL_NIL;
 goto L4;
L4:;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2054]))->cfun.entry(2, v2asdf_plan__o, v3asdf_plan__c) /*  NODE-FOR */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[2092]))->cfun.entry(1, v1asdf_plan__p) /*  PLAN-VISITED-ACTIONS */;
 value0 = ecl_gethash_safe(T0,T1,ECL_NIL);
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5043plan_action_status_va(cl_narg narg, cl_object v4asdf_plan__p, cl_object v5asdf_plan__o, cl_object v6asdf_plan__c, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[2046]);
 {
  return LC5043plan_action_status(v4asdf_plan__p, v5asdf_plan__o, v6asdf_plan__c);
 }
}
/* local function LAMBDA6060                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5045__lambda6060()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC5044__lambda6062_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC5045__lambda6060_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2095]);
 {
  return LC5045__lambda6060();
 }
}
/* local function CALL-WHILE-VISITING-ACTION                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5046call_while_visiting_action(cl_object volatile v1asdf_plan_plan, cl_object volatile v2asdf_operation_operation, cl_object volatile v3asdf_component_component, cl_object volatile v4asdf_plan__fun)
{
 cl_object T0, T1;
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v5asdf_action_action;
  v5asdf_action_action = CONS(v2asdf_operation_operation,v3asdf_component_component);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2100]))->cfun.entry(1, v1asdf_plan_plan) /*  PLAN-VISITING-ACTION-SET */;
  if (Null(ecl_gethash_safe(v5asdf_action_action,T0,ECL_NIL))){
   goto L3;
  }
  {
   cl_object v6;
   cl_object v7;
   cl_object v8;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[2102]))->cfun.entry(1, v1asdf_plan_plan) /*  PLAN-VISITING-ACTION-LIST */;
   v6 = cl_reverse(T1);
   v7 = v5asdf_action_action;
   v8 = v6;
   T0 = ecl_member(v7,v8);
  }
  cl_error(3, VV[2094], VV[2101], T0);
L3:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2100]))->cfun.entry(1, v1asdf_plan_plan) /*  PLAN-VISITING-ACTION-SET */;
  si_hash_set(v5asdf_action_action, T0, ECL_T);
  {
   cl_object v6;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[2102]))->cfun.entry(1, v1asdf_plan_plan) /*  PLAN-VISITING-ACTION-LIST */;
   v6 = CONS(v5asdf_action_action,T0);
   (cl_env_copy->function=ecl_fdefinition(VV[2103]))->cfun.entry(2, v6, v1asdf_plan_plan) /*  (SETF PLAN-VISITING-ACTION-LIST) */;
  }
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    cl_env_copy->values[0] = ecl_function_dispatch(cl_env_copy,v4asdf_plan__fun)(0);
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   {
    cl_object v6;
    v6 = (cl_env_copy->function=ecl_fdefinition(VV[2102]))->cfun.entry(1, v1asdf_plan_plan) /*  PLAN-VISITING-ACTION-LIST */;
    {
     cl_object v7;
     v7 = v6;
     {
      bool v8;
      v8 = ECL_LISTP(v7);
      if (ecl_unlikely(!(v8)))
         FEwrong_type_argument(VV[508],v7);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v6)){
     goto L19;
    }
    {
     cl_object v7;
     v7 = ECL_CONS_CDR(v6);
     (cl_env_copy->function=ecl_fdefinition(VV[2103]))->cfun.entry(2, v7, v1asdf_plan_plan) /*  (SETF PLAN-VISITING-ACTION-LIST) */;
     v6 = ECL_CONS_CAR(v6);
    }
L19:;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[2100]))->cfun.entry(1, v1asdf_plan_plan) /*  PLAN-VISITING-ACTION-SET */;
   si_hash_set(v5asdf_action_action, T0, ECL_NIL);
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
}
static cl_object LC5046call_while_visiting_action_va(cl_narg narg, cl_object v6asdf_plan_plan, cl_object v7asdf_operation_operation, cl_object v8asdf_component_component, cl_object v9asdf_plan__fun, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[2099]);
 {
  return LC5046call_while_visiting_action(v6asdf_plan_plan, v7asdf_operation_operation, v8asdf_component_component, v9asdf_plan__fun);
 }
}
/* local function WHILE-VISITING-ACTION                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5047while_visiting_action(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6asdf_plan__p;
  cl_object v7asdf_plan__o;
  cl_object v8asdf_plan__c;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v9;
   v9 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v9;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v9;
   v9 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6asdf_plan__p = v9;
  }
  if (!(v5==ECL_NIL)){
   goto L17;
  }
  si_dm_too_few_arguments(v1);
L17:;
  {
   cl_object v9;
   v9 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7asdf_plan__o = v9;
  }
  if (!(v5==ECL_NIL)){
   goto L23;
  }
  si_dm_too_few_arguments(v1);
L23:;
  {
   cl_object v9;
   v9 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v8asdf_plan__c = v9;
  }
  if (Null(v5)){
   goto L28;
  }
  si_dm_too_many_arguments(v1);
L28:;
  T0 = cl_listX(3, ECL_SYM("LAMBDA",454), ECL_NIL, v3);
  T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
  value0 = cl_list(5, VV[2099], v6asdf_plan__p, v7asdf_plan__o, v8asdf_plan__c, T1);
  return value0;
 }
}
static cl_object LC5047while_visiting_action_va(cl_narg narg, cl_object v9, cl_object v10, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2104]);
 {
  return LC5047while_visiting_action(v9, v10);
 }
}
/* local function TRAVERSE-ACTION                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5051traverse_action(cl_object v1asdf_plan_plan, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component, cl_object v4asdf_plan_needed_in_image_p)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1asdf_plan_plan,env0);       /*  PLAN                    */
 CLV1 = env0 = CONS(v2asdf_operation_operation,env0); /*  OPERATION           */
 CLV2 = env0 = CONS(v3asdf_component_component,env0); /*  COMPONENT           */
 if ((cl_env_copy->function=ecl_fdefinition(VV[2077]))->cfun.entry(2, ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV2)) /*  ACTION-VALID-P */!=ECL_NIL) {
  goto L1;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[2093]))->cfun.entry(3, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV2)) /*  PLAN-RECORD-DEPENDENCY */;
 {
  cl_object env1 = env0;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2079]))->cfun.entry(2, ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV2)) /*  NEEDED-IN-IMAGE-P */;
  CLV3 = env1 = CONS(T0,env1);                    /*  ANIIP                   */
  if (Null(ECL_CONS_CAR(CLV3))){
   goto L6;
  }
  T0 = v4asdf_plan_needed_in_image_p;
  goto L4;
L6:;
  T0 = ECL_NIL;
  goto L4;
L4:;
  CLV4 = env1 = CONS(T0,env1);                    /*  ENIIP                   */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2046]))->cfun.entry(3, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV2)) /*  PLAN-ACTION-STATUS */;
  CLV5 = env1 = CONS(T0,env1);                    /*  STATUS                  */
  if (Null(ECL_CONS_CAR(CLV5))){
   goto L8;
  }
  if ((cl_env_copy->function=ecl_fdefinition(VV[2057]))->cfun.entry(1, ECL_CONS_CAR(CLV5)) /*  ACTION-DONE-P */!=ECL_NIL) {
   goto L11;
  }
  if ((cl_env_copy->function=ecl_fdefinition(VV[2053]))->cfun.entry(1, ECL_CONS_CAR(CLV5)) /*  ACTION-PLANNED-P */!=ECL_NIL) {
   goto L11;
  }
  if (ECL_CONS_CAR(CLV4)!=ECL_NIL) {
   goto L8;
  }
  goto L9;
L11:;
L9:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2059]))->cfun.entry(1, ECL_CONS_CAR(CLV5)) /*  ACTION-STAMP */;
  return value0;
L8:;
  {
   cl_object v5;
   v5 = ecl_make_cclosure_va((cl_objectfn)LC5050__lambda6315,env1,Cblock,0);
   T0 = v5;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2099]))->cfun.entry(4, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV2), T0) /*  CALL-WHILE-VISITING-ACTION */;
  return value0;
 }
}
static cl_object LC5051traverse_action_va(cl_narg narg, cl_object v5asdf_plan_plan, cl_object v6asdf_operation_operation, cl_object v7asdf_component_component, cl_object v8asdf_plan_needed_in_image_p, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[2106]);
 {
  return LC5051traverse_action(v5asdf_plan_plan, v6asdf_operation_operation, v7asdf_component_component, v8asdf_plan_needed_in_image_p);
 }
}
/* local function PLAN-ACTIONS                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5052plan_actions(cl_object v1asdf_plan_plan)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2118]))->cfun.entry(1, v1asdf_plan_plan) /*  PLAN-ACTIONS-R */;
 value0 = cl_reverse(T0);
 return value0;
}
static cl_object LC5052plan_actions_va(cl_narg narg, cl_object v2asdf_plan_plan, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2091]);
 {
  return LC5052plan_actions(v2asdf_plan_plan);
 }
}
/* local function PLAN-RECORD-DEPENDENCY                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5053plan_record_dependency(cl_object v1asdf_plan_plan, cl_object v2asdf_plan__o, cl_object v3asdf_plan__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 0;
 return value0;
}
static cl_object LC5053plan_record_dependency_va(cl_narg narg, cl_object v4asdf_plan_plan, cl_object v5asdf_plan__o, cl_object v6asdf_plan__c, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[2093]);
 {
  return LC5053plan_record_dependency(v4asdf_plan_plan, v5asdf_plan__o, v6asdf_plan__c);
 }
}
/* local function PLAN-ACTION-STATUS                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5054plan_action_status(cl_object v1asdf_plan__new_status, cl_object v2asdf_plan__p, cl_object v3asdf_plan__o, cl_object v4asdf_plan__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[2053]))->cfun.entry(1, v1asdf_plan__new_status) /*  ACTION-PLANNED-P */)){
  goto L2;
 }
 {
  cl_object v5;
  cl_object v6;
  v5 = CONS(v3asdf_plan__o,v4asdf_plan__c);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2118]))->cfun.entry(1, v2asdf_plan__p) /*  PLAN-ACTIONS-R */;
  v6 = CONS(v5,T0);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2119]))->cfun.entry(2, v6, v2asdf_plan__p) /*  (SETF PLAN-ACTIONS-R) */;
  return value0;
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5054plan_action_status_va(cl_narg narg, cl_object v7asdf_plan__new_status, cl_object v8asdf_plan__p, cl_object v9asdf_plan__o, cl_object v10asdf_plan__c, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[2046]);
 {
  return LC5054plan_action_status(v7asdf_plan__new_status, v8asdf_plan__p, v9asdf_plan__o, v10asdf_plan__c);
 }
}
/* local function MAKE-PLAN                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5055make_plan(cl_narg narg, cl_object v1asdf_plan__plan_class, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[2120]);
 {
  cl_object v4;
  ecl_va_list args; ecl_va_start(args,v3asdf_component_component,narg,3);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v4,TRUE);
  ecl_va_end(args);
  {
   cl_object v5asdf_component_component;
   v5asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v3asdf_component_component) /*  FIND-COMPONENT */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[834]))->cfun.entry(3, v2asdf_operation_operation, ECL_SYM("PACKAGE",1321), VV[1899]) /*  SAFE-READ-FROM-STRING */;
   value0 = cl_apply(5, VV[2120], v1asdf_plan__plan_class, T0, v5asdf_component_component, v4);
   return value0;
  }
 }
}
/* local function MAKE-PLAN                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5056make_plan(cl_narg narg, cl_object v1asdf_plan__plan_class, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[2120]);
 {
  cl_object v4;
  ecl_va_list args; ecl_va_start(args,v3asdf_component_component,narg,3);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v4,TRUE);
  ecl_va_end(args);
  if (Null(v2asdf_operation_operation)){
   goto L1;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, v2asdf_operation_operation) /*  MAKE-OPERATION */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v3asdf_component_component) /*  FIND-COMPONENT */;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = ECL_NIL;
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  value0 = cl_apply(5, VV[2120], v1asdf_plan__plan_class, T0, T1, v4);
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function MAKE-PLAN                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5057make_plan(cl_narg narg, cl_object v1asdf_plan__plan_class, cl_object v2asdf_operation_operation, cl_object v3asdf_component_component, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[2120]);
 {
  cl_object v4;
  ecl_va_list args; ecl_va_start(args,v3asdf_component_component,narg,3);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v4,TRUE);
  ecl_va_end(args);
  if (Null(si_of_class_p(2, v3asdf_component_component, VV[1652]))){
   goto L1;
  }
  T0 = CONS(v2asdf_operation_operation,v3asdf_component_component);
  value0 = cl_error(3, VV[1931], VV[2120], T0);
  return value0;
L1:;
  {
   cl_object v5;
   v5 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v3asdf_component_component) /*  FIND-COMPONENT */;
   if (Null(v5)){
    goto L4;
   }
   value0 = cl_apply(5, VV[2120], v1asdf_plan__plan_class, v2asdf_operation_operation, v5, v4);
   return value0;
L4:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function MAKE-PLAN                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5058make_plan(cl_narg narg, cl_object v1asdf_plan__plan_class, cl_object v2asdf_plan__o, cl_object v3asdf_plan__c, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[2120]);
 {
  cl_object v4asdf_plan__keys;
  ecl_va_list args; ecl_va_start(args,v3asdf_plan__c,narg,3);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v4asdf_plan__keys,TRUE);
  ecl_va_end(args);
  {
   cl_object v5asdf_plan_plan;
   value0 = v1asdf_plan__plan_class;
   if (value0!=ECL_NIL) {
    goto L4;
   }
   T0 = ecl_cmp_symbol_value(cl_env_copy,VV[2123]);
   goto L2;
L4:;
   T0 = value0;
   goto L2;
L2:;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[1637]))->cfun.entry(1, v3asdf_plan__c) /*  COMPONENT-SYSTEM */;
   v5asdf_plan_plan = cl_apply(5, ECL_SYM("MAKE-INSTANCE",953), T0, VV[2124], T1, v4asdf_plan__keys);
   (cl_env_copy->function=ecl_fdefinition(VV[2106]))->cfun.entry(4, v5asdf_plan_plan, v2asdf_plan__o, v3asdf_plan__c, ECL_T) /*  TRAVERSE-ACTION */;
   value0 = v5asdf_plan_plan;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function PERFORM-PLAN                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5062perform_plan(cl_narg narg, cl_object v1asdf_plan_plan, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2121]);
 {
  ecl_va_list args; ecl_va_start(args,v1asdf_plan_plan,narg,1);
  cl_parse_key(args,0,NULL,NULL,NULL,TRUE);
  ecl_va_end(args);
  {
   cl_object env1 = env0;
   if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
    goto L2;
   }
   T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
   goto L1;
L2:;
   T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
   T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L1:;
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(T0,env1);                   /*  .CLOSED-COMBINED-METHOD-ARGS. */
   CLV1 = env1 = CONS(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)),env1); /*  .NEXT-METHODS. */
   {
    cl_object v2;
    cl_object v3;
    v2 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PACKAGE*",45));
    v3 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*READTABLE*",67));
    ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),v2); /*  *PACKAGE*       */
    ecl_bds_bind(cl_env_copy,ECL_SYM("*READTABLE*",67),v3); /*  *READTABLE*   */
    {
     cl_object v4;
     v4 = ecl_make_cclosure_va((cl_objectfn)LC5061__lambda6346,env1,Cblock,0);
     T0 = v4;
    }
    value0 = (cl_env_copy->function=(VV[1397]->symbol.gfdef))->cfun.entry(1, T0) /*  DO-COMPILATION-UNIT */;
    ecl_bds_unwind1(cl_env_copy);
    ecl_bds_unwind1(cl_env_copy);
    return value0;
   }
  }
 }
}
/* local function PERFORM-PLAN                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5063perform_plan(cl_narg narg, cl_object v1asdf_plan_plan, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2121]);
 {
  cl_object v2asdf_plan__keys;
  ecl_va_list args; ecl_va_start(args,v1asdf_plan_plan,narg,1);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v2asdf_plan__keys,TRUE);
  ecl_va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2091]))->cfun.entry(1, v1asdf_plan_plan) /*  PLAN-ACTIONS */;
  value0 = cl_apply(3, VV[2121], T0, v2asdf_plan__keys);
  return value0;
 }
}
/* local function PERFORM-PLAN                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5064perform_plan(cl_narg narg, cl_object v1asdf_plan__steps, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2121]);
 {
  cl_object v2asdf_plan__force;
  ecl_va_list args; ecl_va_start(args,v1asdf_plan__steps,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC5064perform_plankeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2asdf_plan__force = keyvars[0];
  }
  {
   cl_object v3;
   cl_object v4asdf_plan__o;
   cl_object v5asdf_plan__c;
   cl_object v6;
   {
    cl_object v7;
    v7 = v1asdf_plan__steps;
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v7;
   }
   v4asdf_plan__o = ECL_NIL;
   v5asdf_plan__c = ECL_NIL;
   v6 = v3;
L7:;
   if (!(ecl_endp(v6))){
    goto L9;
   }
   goto L8;
L9:;
   {
    cl_object v7;
    v7 = ECL_CONS_CAR(v6);
    v4asdf_plan__o = ecl_car(v7);
    v7 = ecl_cdr(v7);
    v5asdf_plan__c = v7;
   }
   {
    cl_object v7;
    v7 = ECL_CONS_CDR(v6);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v6 = v7;
   }
   if (v2asdf_plan__force!=ECL_NIL) {
    goto L24;
   }
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    cl_env_copy->values[0] = (cl_env_copy->function=ecl_fdefinition(VV[1973]))->cfun.entry(3, ECL_NIL, v4asdf_plan__o, v5asdf_plan__c) /*  COMPUTE-ACTION-STAMP */;
    ecl_stack_frame_push_values(_ecl_inner_frame);
    T0 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
    ecl_stack_frame_close(_ecl_inner_frame);
   }
   if (ecl_cadr(T0)!=ECL_NIL) {
    goto L22;
   }
   goto L23;
L24:;
L23:;
   (cl_env_copy->function=ecl_fdefinition(VV[1984]))->cfun.entry(2, v4asdf_plan__o, v5asdf_plan__c) /*  PERFORM-WITH-RESTARTS */;
L22:;
   goto L7;
L8:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function PLAN-OPERATES-ON-P                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5065plan_operates_on_p(cl_object v1asdf_plan_plan, cl_object v2asdf_plan__component_path)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2091]))->cfun.entry(1, v1asdf_plan_plan) /*  PLAN-ACTIONS */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2122]))->cfun.entry(2, T0, v2asdf_plan__component_path) /*  PLAN-OPERATES-ON-P */;
 return value0;
}
static cl_object LC5065plan_operates_on_p_va(cl_narg narg, cl_object v3asdf_plan_plan, cl_object v4asdf_plan__component_path, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2122]);
 {
  return LC5065plan_operates_on_p(v3asdf_plan_plan, v4asdf_plan__component_path);
 }
}
/* local function PLAN-OPERATES-ON-P                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5066plan_operates_on_p(cl_object v1asdf_plan_plan, cl_object v2asdf_plan__component_path)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  {
   cl_object v4;
   cl_object v5;
   cl_object v6;
   {
    cl_object v7;
    v7 = v1asdf_plan_plan;
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   v5 = ECL_NIL;
   v6 = v4;
   {
    cl_object v7;
    cl_object v8;
    v7 = ecl_list1(ECL_NIL);
    v8 = v7;
L10:;
    if (!(ecl_endp(v6))){
     goto L12;
    }
    goto L11;
L12:;
    v5 = ECL_CONS_CAR(v6);
    {
     cl_object v9;
     v9 = ECL_CONS_CDR(v6);
     if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v6 = v9;
    }
    {
     cl_object v9;
     v9 = v8;
     if (ecl_unlikely(ECL_ATOM(v9))) FEtype_error_cons(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T0 = v9;
    }
    T1 = ecl_function_dispatch(cl_env_copy,ECL_SYM("CDR",200))(1, v5);
    v8 = ecl_list1(T1);
    (ECL_CONS_CDR(T0)=v8,T0);
    goto L10;
L11:;
    v3 = ecl_cdr(v7);
    goto L2;
   }
  }
L2:;
  {
   cl_object v4;
   v4 = si_make_seq_iterator(2, v3, ecl_make_int8_t(0));
L29:;
   if (v4!=ECL_NIL) {
    goto L31;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L31:;
   {
    cl_object v5;
    v5 = si_seq_iterator_ref(v3, v4);
    T0 = ecl_function_dispatch(cl_env_copy,VV[1654])(1, v5);
    if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v2asdf_plan__component_path, T0))){
     goto L33;
    }
    value0 = v5;
    cl_env_copy->nvalues = 1;
    return value0;
   }
L33:;
   v4 = si_seq_iterator_next(v3, v4);
   goto L29;
  }
 }
}
static cl_object LC5066plan_operates_on_p_va(cl_narg narg, cl_object v5asdf_plan_plan, cl_object v6asdf_plan__component_path, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2122]);
 {
  return LC5066plan_operates_on_p(v5asdf_plan_plan, v6asdf_plan__component_path);
 }
}
/* local function INITIALIZE-INSTANCE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5067initialize_instance(cl_narg narg, cl_object v1asdf_plan_plan, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("INITIALIZE-INSTANCE",951));
 {
  cl_object v2asdf_plan__force;
  cl_object v3asdf_plan__force_not;
  cl_object v4asdf_plan__other_systems;
  ecl_va_list args; ecl_va_start(args,v1asdf_plan_plan,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,LC5067initialize_instancekeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2asdf_plan__force = keyvars[0];
   v3asdf_plan__force_not = keyvars[1];
   v4asdf_plan__other_systems = keyvars[2];
  }
  {
   cl_object v5;
   if (Null(v4asdf_plan__other_systems)){
    goto L4;
   }
   T0 = VV[2064];
   goto L3;
L4:;
   T0 = ECL_T;
L3:;
   T1 = cl_slot_value(v1asdf_plan_plan, VV[1695]);
   v5 = (cl_env_copy->function=ecl_fdefinition(VV[2062]))->cfun.entry(2, T0, T1) /*  NORMALIZE-FORCED-SYSTEMS */;
   (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v5, v1asdf_plan_plan, VV[2089]) /*  (SETF SLOT-VALUE) */;
  }
  {
   cl_object v5;
   if (Null(v4asdf_plan__other_systems)){
    goto L9;
   }
   T0 = ECL_NIL;
   goto L8;
L9:;
   T0 = ECL_T;
L8:;
   T1 = cl_slot_value(v1asdf_plan_plan, VV[1695]);
   v5 = (cl_env_copy->function=ecl_fdefinition(VV[2068]))->cfun.entry(2, T0, T1) /*  NORMALIZE-FORCED-NOT-SYSTEMS */;
   (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v5, v1asdf_plan_plan, VV[2090]) /*  (SETF SLOT-VALUE) */;
  }
  {
   cl_object v5;
   T0 = cl_slot_value(v1asdf_plan_plan, VV[2127]);
   v5 = (cl_env_copy->function=ecl_fdefinition(VV[344]))->cfun.entry(1, T0) /*  ENSURE-FUNCTION */;
   value0 = (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v5, v1asdf_plan_plan, VV[2127]) /*  (SETF SLOT-VALUE) */;
   return value0;
  }
 }
}
/* local function TRAVERSE-ACTIONS                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5068traverse_actions(cl_narg narg, cl_object v1asdf_plan__actions, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1909]);
 {
  cl_object v2asdf_plan__keys;
  cl_object v3asdf_plan__plan_class;
  ecl_va_list args; ecl_va_start(args,v1asdf_plan__actions,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC5068traverse_actionskeys,keyvars,(cl_object*)&v2asdf_plan__keys,TRUE);
   ecl_va_end(args);
   v3asdf_plan__plan_class = keyvars[0];
  }
  {
   cl_object v4asdf_plan_plan;
   value0 = v3asdf_plan__plan_class;
   if (value0!=ECL_NIL) {
    goto L4;
   }
   T0 = VV[2126];
   goto L2;
L4:;
   T0 = value0;
   goto L2;
L2:;
   v4asdf_plan_plan = cl_apply(3, ECL_SYM("MAKE-INSTANCE",953), T0, v2asdf_plan__keys);
   {
    cl_object v5;
    cl_object v6asdf_plan__o;
    cl_object v7asdf_plan__c;
    cl_object v8;
    {
     cl_object v9;
     v9 = v1asdf_plan__actions;
     if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v9;
    }
    v6asdf_plan__o = ECL_NIL;
    v7asdf_plan__c = ECL_NIL;
    v8 = v5;
L13:;
    if (!(ecl_endp(v8))){
     goto L15;
    }
    goto L14;
L15:;
    {
     cl_object v9;
     v9 = ECL_CONS_CAR(v8);
     v6asdf_plan__o = ecl_car(v9);
     v9 = ecl_cdr(v9);
     v7asdf_plan__c = v9;
    }
    {
     cl_object v9;
     v9 = ECL_CONS_CDR(v8);
     if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v8 = v9;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[2106]))->cfun.entry(4, v4asdf_plan_plan, v6asdf_plan__o, v7asdf_plan__c, ECL_T) /*  TRAVERSE-ACTION */;
    goto L13;
L14:;
   }
   value0 = v4asdf_plan_plan;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function TRAVERSE-SUB-ACTIONS                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5069traverse_sub_actions(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1910]);
 {
  cl_object v3;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3,TRUE);
  ecl_va_end(args);
  {
   cl_object v4asdf_component_component;
   v4asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[834]))->cfun.entry(3, v1asdf_operation_operation, ECL_SYM("PACKAGE",1321), VV[1899]) /*  SAFE-READ-FROM-STRING */;
   value0 = cl_apply(4, VV[1910], T0, v4asdf_component_component, v3);
   return value0;
  }
 }
}
/* local function TRAVERSE-SUB-ACTIONS                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5070traverse_sub_actions(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1910]);
 {
  cl_object v3;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3,TRUE);
  ecl_va_end(args);
  if (Null(v1asdf_operation_operation)){
   goto L1;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, v1asdf_operation_operation) /*  MAKE-OPERATION */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = ECL_NIL;
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  value0 = cl_apply(4, VV[1910], T0, T1, v3);
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function TRAVERSE-SUB-ACTIONS                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5071traverse_sub_actions(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1910]);
 {
  cl_object v3;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3,TRUE);
  ecl_va_end(args);
  if (Null(si_of_class_p(2, v2asdf_component_component, VV[1652]))){
   goto L1;
  }
  T0 = CONS(v1asdf_operation_operation,v2asdf_component_component);
  value0 = cl_error(3, VV[1931], VV[1910], T0);
  return value0;
L1:;
  {
   cl_object v4;
   v4 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
   if (Null(v4)){
    goto L4;
   }
   value0 = cl_apply(4, VV[1910], v1asdf_operation_operation, v4, v3);
   return value0;
L4:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function TRAVERSE-SUB-ACTIONS                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5072traverse_sub_actions(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1910]);
 {
  cl_object v3asdf_plan__keys;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3asdf_plan__keys,TRUE);
  ecl_va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2085]))->cfun.entry(3, ECL_T, v1asdf_operation_operation, v2asdf_component_component) /*  DIRECT-DEPENDENCIES */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[1637]))->cfun.entry(1, v2asdf_component_component) /*  COMPONENT-SYSTEM */;
  value0 = cl_apply(5, VV[1909], T0, VV[2124], T1, v3asdf_plan__keys);
  return value0;
 }
}
/* local function PLAN-ACTIONS                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5075plan_actions(cl_object v1asdf_plan_plan)
{
 cl_object T0, T1;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 {
  cl_object v2;
  cl_object v3asdf_plan__o;
  cl_object v4asdf_plan__c;
  cl_object v5;
  {
   cl_object v6;
   v6 = LC5073call_next_method(0, lex0);
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v2 = v6;
  }
  v3asdf_plan__o = ECL_NIL;
  v4asdf_plan__c = ECL_NIL;
  v5 = v2;
  {
   cl_object v6;
   cl_object v7;
   v6 = ecl_list1(ECL_NIL);
   v7 = v6;
L14:;
   if (!(ecl_endp(v5))){
    goto L16;
   }
   goto L15;
L16:;
   {
    cl_object v8;
    v8 = ECL_CONS_CAR(v5);
    v3asdf_plan__o = ecl_car(v8);
    v8 = ecl_cdr(v8);
    v4asdf_plan__c = v8;
   }
   {
    cl_object v8;
    v8 = ECL_CONS_CDR(v5);
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v8;
   }
   T0 = cl_slot_value(v1asdf_plan_plan, VV[2128]);
   if (Null(cl_typep(2, v3asdf_plan__o, T0))){
    goto L29;
   }
   T0 = cl_slot_value(v1asdf_plan_plan, VV[2129]);
   if (Null(cl_typep(2, v4asdf_plan__c, T0))){
    goto L29;
   }
   {
    cl_object v8;
    v8 = v7;
    if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T0 = v8;
   }
   T1 = CONS(v3asdf_plan__o,v4asdf_plan__c);
   v7 = ecl_list1(T1);
   (ECL_CONS_CDR(T0)=v7,T0);
L29:;
   goto L14;
L15:;
   value0 = ecl_cdr(v6);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object LC5075plan_actions_va(cl_narg narg, cl_object v8asdf_plan_plan, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2091]);
 {
  return LC5075plan_actions(v8asdf_plan_plan);
 }
}
/* local function REQUIRED-COMPONENTS                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5076required_components(cl_narg narg, cl_object v1asdf_system_system, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1911]);
 {
  cl_object v2asdf_plan__keys;
  cl_object v3asdf_plan__goal_operation;
  ecl_va_list args; ecl_va_start(args,v1asdf_system_system,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC5076required_componentskeys,keyvars,(cl_object*)&v2asdf_plan__keys,TRUE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v3asdf_plan__goal_operation = VV[1999];
   } else {
    v3asdf_plan__goal_operation = keyvars[0];
   }
  }
  {
   cl_object v4;
   cl_object v5;
   cl_object v6;
   {
    cl_object v7;
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[259]))->cfun.entry(2, VV[2130], v2asdf_plan__keys) /*  REMOVE-PLIST-KEY */;
    T2 = cl_apply(4, VV[1910], v3asdf_plan__goal_operation, v1asdf_system_system, T1);
    v7 = (cl_env_copy->function=ecl_fdefinition(VV[2091]))->cfun.entry(1, T2) /*  PLAN-ACTIONS */;
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   v5 = ECL_NIL;
   v6 = v4;
   {
    cl_object v7;
    cl_object v8;
    v7 = ecl_list1(ECL_NIL);
    v8 = v7;
L10:;
    if (!(ecl_endp(v6))){
     goto L12;
    }
    goto L11;
L12:;
    v5 = ECL_CONS_CAR(v6);
    {
     cl_object v9;
     v9 = ECL_CONS_CDR(v6);
     if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v6 = v9;
    }
    {
     cl_object v9;
     v9 = v8;
     if (ecl_unlikely(ECL_ATOM(v9))) FEtype_error_cons(v9);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T1 = v9;
    }
    T2 = ecl_function_dispatch(cl_env_copy,ECL_SYM("CDR",200))(1, v5);
    v8 = ecl_list1(T2);
    (ECL_CONS_CDR(T1)=v8,T1);
    goto L10;
L11:;
    T0 = ecl_cdr(v7);
    goto L2;
   }
  }
L2:;
  value0 = cl_remove_duplicates(3, T0, VV[91], ECL_T);
  return value0;
 }
}
/* local function OPERATE                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5077operate(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2131]);
 {
  cl_object v3;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3,TRUE);
  ecl_va_end(args);
  {
   cl_object v4asdf_component_component;
   v4asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[834]))->cfun.entry(3, v1asdf_operation_operation, ECL_SYM("PACKAGE",1321), VV[1899]) /*  SAFE-READ-FROM-STRING */;
   value0 = cl_apply(4, VV[2131], T0, v4asdf_component_component, v3);
   return value0;
  }
 }
}
/* local function OPERATE                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5078operate(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2131]);
 {
  cl_object v3;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3,TRUE);
  ecl_va_end(args);
  if (Null(v1asdf_operation_operation)){
   goto L1;
  }
  T0 = cl_apply(5, VV[1898], v1asdf_operation_operation, VV[1929], v3, v3);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = cl_error(3, VV[1738], VV[1862], v2asdf_component_component);
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  value0 = cl_apply(4, VV[2131], T0, T1, v3);
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function OPERATE                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5079operate(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2131]);
 {
  cl_object v3;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3,TRUE);
  ecl_va_end(args);
  if (Null(si_of_class_p(2, v2asdf_component_component, VV[1652]))){
   goto L1;
  }
  T0 = CONS(v1asdf_operation_operation,v2asdf_component_component);
  value0 = cl_error(3, VV[1931], VV[2131], T0);
  return value0;
L1:;
  {
   cl_object v4;
   v4 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
   if (Null(v4)){
    goto L4;
   }
   value0 = cl_apply(4, VV[2131], v1asdf_operation_operation, v4, v3);
   return value0;
L4:;
   value0 = cl_error(3, VV[1738], VV[1862], v2asdf_component_component);
   return value0;
  }
 }
}
/* local function OPERATE                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5084operate(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2131]);
 {
  cl_object v3asdf_operate__keys;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,LC5084operatekeys,keyvars,(cl_object*)&v3asdf_operate__keys,TRUE);
   ecl_va_end(args);
   env0 = ECL_NIL;
   CLV0 = env0 = CONS(keyvars[0],env0);           /*  VERBOSE                 */
   if (Null(keyvars[4])) {
    CLV1 = env0 = CONS(ecl_cmp_symbol_value(cl_env_copy,VV[1299]),env0); /*  ON-WARNINGS */
   } else {
    CLV1 = env0 = CONS(keyvars[1],env0);          /*  ON-WARNINGS             */
   }
   if (Null(keyvars[5])) {
    CLV2 = env0 = CONS(ecl_cmp_symbol_value(cl_env_copy,VV[1301]),env0); /*  ON-FAILURE */
   } else {
    CLV2 = env0 = CONS(keyvars[2],env0);          /*  ON-FAILURE              */
   }
  }
  {
   cl_object env1 = env0;
   if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
    goto L2;
   }
   T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
   goto L1;
L2:;
   T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
   T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L1:;
   CLV3 = env1 = CONS(T0,env1);                   /*  .CLOSED-COMBINED-METHOD-ARGS. */
   CLV4 = env1 = CONS(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)),env1); /*  .NEXT-METHODS. */
   {
    cl_object v4asdf_operate__systems_being_operated;
    cl_object v5asdf_operate__operation_remaker;
    cl_object v6asdf_operate__component_path;
    v4asdf_operate__systems_being_operated = ecl_cmp_symbol_value(cl_env_copy,VV[2132]);
    value0 = v4asdf_operate__systems_being_operated;
    if (value0!=ECL_NIL) {
     goto L8;
    }
    T0 = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
    goto L6;
L8:;
    T0 = value0;
    goto L6;
L6:;
    ecl_bds_bind(cl_env_copy,VV[2132],T0);        /*  *SYSTEMS-BEING-OPERATED* */
    if (Null(si_of_class_p(2, v1asdf_operation_operation, VV[1889]))){
     goto L11;
    }
    {
     cl_object v7;
     cl_object v8;
     cl_object env2 = env1;
     v7 = cl_type_of(v1asdf_operation_operation);
     v8 = (cl_env_copy->function=ecl_fdefinition(VV[1891]))->cfun.entry(1, v1asdf_operation_operation) /*  OPERATION-ORIGINAL-INITARGS */;
     CLV5 = env2 = CONS(v7,env2);                 /*  NAME                    */
     CLV6 = env2 = CONS(v8,env2);                 /*  INITARGS                */
     {
      cl_object v9;
      v9 = ecl_make_cclosure_va((cl_objectfn)LC5082__lambda6551,env2,Cblock,0);
      v5asdf_operate__operation_remaker = v9;
      goto L10;
     }
    }
L11:;
    if (ECL_SYMBOLP(v1asdf_operation_operation)) {
     goto L17;
    }
    if (!(ECL_STRINGP(v1asdf_operation_operation))){
     goto L15;
    }
    goto L16;
L17:;
L16:;
    v5asdf_operate__operation_remaker = cl_constantly(v1asdf_operation_operation);
    goto L10;
L15:;
    v5asdf_operate__operation_remaker = si_etypecase_error(v1asdf_operation_operation, VV[2134]);
L10:;
    if (Null(si_of_class_p(2, v2asdf_component_component, VV[1652]))){
     goto L20;
    }
    v6asdf_operate__component_path = (cl_env_copy->function=ecl_fdefinition(VV[1654]))->cfun.entry(1, v2asdf_component_component) /*  COMPONENT-FIND-PATH */;
    goto L19;
L20:;
    v6asdf_operate__component_path = v2asdf_component_component;
L19:;
    if (v4asdf_operate__systems_being_operated!=ECL_NIL) {
     goto L22;
    }
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[1632]))->cfun.entry(0) /*  UPGRADE-ASDF */)){
     goto L22;
    }
    T0 = ecl_function_dispatch(cl_env_copy,v5asdf_operate__operation_remaker)(0);
    value0 = cl_apply(4, VV[2131], T0, v6asdf_operate__component_path, v3asdf_operate__keys);
    ecl_bds_unwind1(cl_env_copy);
    return value0;
L22:;
    {
     cl_object v7;
     v7 = ecl_make_cclosure_va((cl_objectfn)LC5083__lambda6555,env1,Cblock,0);
     T0 = v7;
    }
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[1712]))->cfun.entry(5, T0, VV[1401], ECL_NIL, ECL_SYM("KEY",1297), ECL_NIL) /*  CALL-WITH-ASDF-CACHE */;
    ecl_bds_unwind1(cl_env_copy);
    return value0;
   }
  }
 }
}
/* local function OPERATE                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5085operate(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2131]);
 {
  cl_object v3asdf_component_version;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC5085operatekeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v3asdf_component_version = keyvars[0];
  }
  {
   cl_object v4asdf_system_system;
   v4asdf_system_system = (cl_env_copy->function=ecl_fdefinition(VV[1637]))->cfun.entry(1, v2asdf_component_component) /*  COMPONENT-SYSTEM */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v4asdf_system_system) /*  COERCE-NAME */;
   si_hash_set(T0, ecl_cmp_symbol_value(cl_env_copy,VV[2132]), v4asdf_system_system);
  }
  if ((cl_env_copy->function=ecl_fdefinition(VV[1642]))->cfun.entry(2, v2asdf_component_component, v3asdf_component_version) /*  VERSION-SATISFIES */!=ECL_NIL) {
   goto L3;
  }
  value0 = cl_error(5, VV[1863], VV[1862], v2asdf_component_component, ECL_SYM("VERSION",1364), v3asdf_component_version);
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function OPERATE                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5086operate(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2131]);
 {
  cl_object v3asdf_operate__keys;
  cl_object v4asdf_operate__plan_class;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC5086operatekeys,keyvars,(cl_object*)&v3asdf_operate__keys,TRUE);
   ecl_va_end(args);
   v4asdf_operate__plan_class = keyvars[0];
  }
  {
   cl_object v5asdf_plan_plan;
   v5asdf_plan_plan = cl_apply(5, VV[2120], v4asdf_operate__plan_class, v1asdf_operation_operation, v2asdf_component_component, v3asdf_operate__keys);
   cl_apply(3, VV[2121], v5asdf_plan_plan, v3asdf_operate__keys);
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = v5asdf_plan_plan;
   cl_env_copy->values[0] = v1asdf_operation_operation;
   return cl_env_copy->values[0];
  }
 }
}
/* function definition for OOS                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5087oos(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2136]);
 {
  cl_object v3asdf_operate__args;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3asdf_operate__args,TRUE);
  ecl_va_end(args);
  value0 = cl_apply(4, VV[2131], v1asdf_operation_operation, v2asdf_component_component, v3asdf_operate__args);
  return value0;
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5090component_depends_on(cl_object v1asdf_operate__o, cl_object v2asdf_operate__s)
{
 cl_object T0, T1, T2;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 {
  cl_object v3;
  cl_object v4do;
  cl_object v5asdf_operate__dc;
  cl_object v6;
  {
   cl_object v7;
   v7 = LC5088call_next_method(0, lex0);
   if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3 = v7;
  }
  v4do = ECL_NIL;
  v5asdf_operate__dc = ECL_NIL;
  v6 = v3;
  {
   cl_object v7;
   cl_object v8;
   v7 = ecl_list1(ECL_NIL);
   v8 = v7;
L14:;
   if (!(ecl_endp(v6))){
    goto L16;
   }
   goto L15;
L16:;
   {
    cl_object v9;
    v9 = ECL_CONS_CAR(v6);
    v4do = ecl_car(v9);
    v9 = ecl_cdr(v9);
    v5asdf_operate__dc = v9;
   }
   {
    cl_object v9;
    v9 = ECL_CONS_CDR(v6);
    if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v6 = v9;
   }
   {
    cl_object v9;
    v9 = v8;
    if (ecl_unlikely(ECL_ATOM(v9))) FEtype_error_cons(v9);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T0 = v9;
   }
   if (!((v4do)==(VV[1999]))){
    goto L35;
   }
   T1 = ecl_cmp_symbol_value(cl_env_copy,VV[2138]);
   goto L34;
L35:;
   T1 = v4do;
L34:;
   T2 = CONS(T1,v5asdf_operate__dc);
   v8 = ecl_list1(T2);
   (ECL_CONS_CDR(T0)=v8,T0);
   goto L14;
L15:;
   value0 = ecl_cdr(v7);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object LC5090component_depends_on_va(cl_narg narg, cl_object v9asdf_operate__o, cl_object v10asdf_operate__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC5090component_depends_on(v9asdf_operate__o, v10asdf_operate__s);
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5093component_depends_on(cl_object v1asdf_operate__o, cl_object v2asdf_operate__c)
{
 cl_object T0, T1, T2;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2140]))->cfun.entry(1, v2asdf_operate__c) /*  COMPONENT-BUILD-OPERATION */;
 if (value0!=ECL_NIL) {
  goto L8;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,VV[2138]);
 goto L6;
L8:;
 T0 = value0;
 goto L6;
L6:;
 T1 = cl_list(2, T0, v2asdf_operate__c);
 T2 = LC5091call_next_method(0, lex0);
 value0 = CONS(T1,T2);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5093component_depends_on_va(cl_narg narg, cl_object v3asdf_operate__o, cl_object v4asdf_operate__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC5093component_depends_on(v3asdf_operate__o, v4asdf_operate__c);
 }
}
/* function definition for MAKE                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5094make(cl_narg narg, cl_object v1asdf_system_system, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2141]);
 {
  cl_object v2asdf_operate__keys;
  ecl_va_list args; ecl_va_start(args,v1asdf_system_system,narg,1);
  v2asdf_operate__keys = cl_grab_rest_args(args);
  ecl_va_end(args);
  cl_apply(4, VV[2131], VV[2139], v1asdf_system_system, v2asdf_operate__keys);
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for LOAD-SYSTEM                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5095load_system(cl_narg narg, cl_object v1asdf_system_system, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2143]);
 {
  cl_object v2asdf_operate__keys;
  cl_object v3asdf_operate__force;
  cl_object v4asdf_operate__force_not;
  cl_object v5asdf_operate__verbose;
  cl_object v6asdf_component_version;
  ecl_va_list args; ecl_va_start(args,v1asdf_system_system,narg,1);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L5095load_systemkeys,keyvars,(cl_object*)&v2asdf_operate__keys,TRUE);
   ecl_va_end(args);
   v3asdf_operate__force = keyvars[0];
   v4asdf_operate__force_not = keyvars[1];
   v5asdf_operate__verbose = keyvars[2];
   v6asdf_component_version = keyvars[3];
  }
  cl_apply(4, VV[2131], ecl_cmp_symbol_value(cl_env_copy,VV[2138]), v1asdf_system_system, v2asdf_operate__keys);
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for LOAD-SYSTEMS*                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5096load_systems_(cl_narg narg, cl_object v1asdf_operate__systems, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2145]);
 {
  cl_object v2asdf_operate__keys;
  ecl_va_list args; ecl_va_start(args,v1asdf_operate__systems,narg,1);
  v2asdf_operate__keys = cl_grab_rest_args(args);
  ecl_va_end(args);
  {
   cl_object v3;
   v3 = v1asdf_operate__systems;
   goto L4;
L3:;
   {
    cl_object v4asdf_operate__s;
    v4asdf_operate__s = ecl_car(v3);
    cl_apply(3, VV[2143], v4asdf_operate__s, v2asdf_operate__keys);
   }
   v3 = ecl_cdr(v3);
L4:;
   if (Null(v3)){
    goto L11;
   }
   goto L3;
L11:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for LOAD-SYSTEMS                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5097load_systems(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1asdf_operate__systems;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1asdf_operate__systems = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2145]))->cfun.entry(1, v1asdf_operate__systems) /*  LOAD-SYSTEMS* */;
  return value0;
 }
}
/* function definition for COMPILE-SYSTEM                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5098compile_system(cl_narg narg, cl_object v1asdf_system_system, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2149]);
 {
  cl_object v2asdf_operate__args;
  cl_object v3asdf_operate__force;
  cl_object v4asdf_operate__force_not;
  cl_object v5asdf_operate__verbose;
  cl_object v6asdf_component_version;
  ecl_va_list args; ecl_va_start(args,v1asdf_system_system,narg,1);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L5098compile_systemkeys,keyvars,(cl_object*)&v2asdf_operate__args,TRUE);
   ecl_va_end(args);
   v3asdf_operate__force = keyvars[0];
   v4asdf_operate__force_not = keyvars[1];
   v5asdf_operate__verbose = keyvars[2];
   v6asdf_component_version = keyvars[3];
  }
  cl_apply(4, VV[2131], VV[2000], v1asdf_system_system, v2asdf_operate__args);
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for TEST-SYSTEM                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5099test_system(cl_narg narg, cl_object v1asdf_system_system, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2151]);
 {
  cl_object v2asdf_operate__args;
  cl_object v3asdf_operate__force;
  cl_object v4asdf_operate__force_not;
  cl_object v5asdf_operate__verbose;
  cl_object v6asdf_component_version;
  ecl_va_list args; ecl_va_start(args,v1asdf_system_system,narg,1);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L5099test_systemkeys,keyvars,(cl_object*)&v2asdf_operate__args,TRUE);
   ecl_va_end(args);
   v3asdf_operate__force = keyvars[0];
   v4asdf_operate__force_not = keyvars[1];
   v5asdf_operate__verbose = keyvars[2];
   v6asdf_component_version = keyvars[3];
  }
  cl_apply(4, VV[2131], VV[2003], v1asdf_system_system, v2asdf_operate__args);
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for COMPONENT-LOADED-P                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5100component_loaded_p(cl_object v1asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_component_component;
  v2asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(4, v1asdf_component_component, ECL_NIL, VV[1875], ECL_T) /*  FIND-COMPONENT */;
  if (Null(v2asdf_component_component)){
   goto L3;
  }
  T0 = (cl_env_copy->function=(ECL_SYM("MAKE-INSTANCE",953)->symbol.gfdef))->cfun.entry(1, VV[1999]) /*  MAKE-INSTANCE */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2056]))->cfun.entry(3, ECL_NIL, T0, v2asdf_component_component) /*  ACTION-ALREADY-DONE-P */;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L5100component_loaded_p_va(cl_narg narg, cl_object v3asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2153]);
 {
  return L5100component_loaded_p(v3asdf_component_component);
 }
}
/* function definition for ALREADY-LOADED-SYSTEMS                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5101already_loaded_systems()
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2;
  cl_object v3;
  {
   cl_object v4;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1766]))->cfun.entry(0) /*  REGISTERED-SYSTEMS* */;
   v4 = cl_remove_if_not(2, VV[2153], T0);
   if (ecl_unlikely(!ECL_LISTP(v4))) FEtype_error_list(v4);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v1 = v4;
  }
  v2 = ECL_NIL;
  v3 = v1;
  {
   cl_object v4;
   cl_object v5;
   v4 = ecl_list1(ECL_NIL);
   v5 = v4;
L9:;
   if (!(ecl_endp(v3))){
    goto L11;
   }
   goto L10;
L11:;
   v2 = ECL_CONS_CAR(v3);
   {
    cl_object v6;
    v6 = ECL_CONS_CDR(v3);
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v6;
   }
   {
    cl_object v6;
    v6 = v5;
    if (ecl_unlikely(ECL_ATOM(v6))) FEtype_error_cons(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T0 = v6;
   }
   T1 = ecl_function_dispatch(cl_env_copy,VV[1753])(1, v2);
   v5 = ecl_list1(T1);
   (ECL_CONS_CDR(T0)=v5,T0);
   goto L9;
L10:;
   value0 = ecl_cdr(v4);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L5101already_loaded_systems_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2155]);
 {
  return L5101already_loaded_systems();
 }
}
/* function definition for REQUIRE-SYSTEM                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5102require_system(cl_narg narg, cl_object v1asdf_system_system, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2157]);
 {
  cl_object v2asdf_operate__keys;
  ecl_va_list args; ecl_va_start(args,v1asdf_system_system,narg,1);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v2asdf_operate__keys,TRUE);
  ecl_va_end(args);
  if ((cl_env_copy->function=ecl_fdefinition(VV[2153]))->cfun.entry(1, v1asdf_system_system) /*  COMPONENT-LOADED-P */!=ECL_NIL) {
   goto L1;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2155]))->cfun.entry(0) /*  ALREADY-LOADED-SYSTEMS */;
  value0 = cl_apply(5, VV[2143], v1asdf_system_system, VV[2158], T0, v2asdf_operate__keys);
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5103perform(cl_object v1asdf_operate__o, cl_object v2asdf_operate__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5103perform_va(cl_narg narg, cl_object v3asdf_operate__o, cl_object v4asdf_operate__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5103perform(v3asdf_operate__o, v4asdf_operate__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5104perform(cl_object v1asdf_operate__o, cl_object v2asdf_operate__s)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_component_module;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2161]))->cfun.entry(1, v2asdf_operate__s) /*  REQUIRED-MODULE */;
  if (value0!=ECL_NIL) {
   goto L4;
  }
  v3asdf_component_module = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v2asdf_operate__s) /*  COERCE-NAME */;
  goto L2;
L4:;
  v3asdf_component_module = value0;
  goto L2;
L2:;
  T0 = CONS(v3asdf_component_module,ecl_cmp_symbol_value(cl_env_copy,VV[2160]));
  ecl_bds_bind(cl_env_copy,VV[2160],T0);          /*  *MODULES-BEING-REQUIRED* */
  goto L8;
L7:;
  si_assert_failure(1, VV[2162]);
L8:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1672]))->cfun.entry(1, v2asdf_operate__s) /*  COMPONENT-CHILDREN */;
  if (T0==ECL_NIL) {
   goto L11;
  }
  goto L7;
L11:;
  value0 = cl_require(1, v3asdf_component_module);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
}
static cl_object LC5104perform_va(cl_narg narg, cl_object v4asdf_operate__o, cl_object v5asdf_operate__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5104perform(v4asdf_operate__o, v5asdf_operate__s);
 }
}
/* local function RESOLVE-DEPENDENCY-COMBINATION                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5105resolve_dependency_combination(cl_object v1asdf_component_component, cl_object v2asdf_operate__combinator, cl_object v3asdf_operate__arguments)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[253]))->cfun.entry(2, v3asdf_operate__arguments, ecl_make_int8_t(1)) /*  LENGTH=N-P */)){
  goto L5;
 }
 {
  cl_object v4;
  v4 = ecl_car(v3asdf_operate__arguments);
  if (ECL_STRINGP(v4)) {
   goto L2;
  }
  if (!(ECL_SYMBOLP(v4))){
   goto L10;
  }
  if (!(v4==ECL_NIL)){
   goto L2;
  }
  goto L3;
L10:;
  goto L3;
 }
L5:;
 goto L3;
L3:;
 T0 = CONS(v2asdf_operate__combinator,v3asdf_operate__arguments);
 (cl_env_copy->function=ecl_fdefinition(VV[416]))->cfun.entry(5, VV[2164], VV[1874], T0, v1asdf_component_component, v2asdf_operate__combinator) /*  PARAMETER-ERROR */;
L2:;
 {
  cl_object v4asdf_component_module;
  cl_object v5asdf_component_name;
  cl_object v6asdf_system_system;
  v4asdf_component_module = ecl_car(v3asdf_operate__arguments);
  v5asdf_component_name = cl_string_downcase(1, v4asdf_component_module);
  v6asdf_system_system = (cl_env_copy->function=ecl_fdefinition(VV[1690]))->cfun.entry(2, v5asdf_component_name, ECL_NIL) /*  FIND-SYSTEM */;
  value0 = v6asdf_system_system;
  if (value0!=ECL_NIL) {
   goto L16;
  }
  {
   cl_object v7asdf_system_system;
   v7asdf_system_system = (cl_env_copy->function=(ECL_SYM("MAKE-INSTANCE",953)->symbol.gfdef))->cfun.entry(3, VV[2157], ECL_SYM("NAME",1309), v5asdf_component_name) /*  MAKE-INSTANCE */;
   (cl_env_copy->function=ecl_fdefinition(VV[1771]))->cfun.entry(1, v7asdf_system_system) /*  REGISTER-SYSTEM */;
   value0 = v7asdf_system_system;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L16:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC5105resolve_dependency_combination_va(cl_narg narg, cl_object v8asdf_component_component, cl_object v9asdf_operate__combinator, cl_object v10asdf_operate__arguments, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[1874]);
 {
  return LC5105resolve_dependency_combination(v8asdf_component_component, v9asdf_operate__combinator, v10asdf_operate__arguments);
 }
}
/* function definition for MODULE-PROVIDE-ASDF                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5107module_provide_asdf(cl_object v1asdf_component_name)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1asdf_component_name,env0);  /*  NAME                    */
 {
  cl_object v2asdf_component_module;
  v2asdf_component_module = cl_string_downcase(1, ECL_CONS_CAR(CLV0));
  {
   cl_object v3;
   cl_object v4;
   cl_object v5;
   v3 = ecl_cmp_symbol_value(cl_env_copy,VV[2160]);
   v4 = v2asdf_component_module;
   v5 = v3;
   if (ecl_member(v4,v5)!=ECL_NIL) {
    goto L2;
   }
  }
  T0 = CONS(v2asdf_component_module,ecl_cmp_symbol_value(cl_env_copy,VV[2160]));
  ecl_bds_bind(cl_env_copy,VV[2160],T0);          /*  *MODULES-BEING-REQUIRED* */
  T0 = (ECL_SYM("MUFFLE-WARNING",573)->symbol.gfdef);
  T1 = CONS(ECL_SYM("STYLE-WARNING",830),T0);
  T2 = cl_constantly(ECL_NIL);
  T3 = CONS(VV[1738],T2);
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC5106__lambda6639,env0,Cblock,1);
   T4 = v3;
  }
  T5 = CONS(VV[998],T4);
  T6 = cl_list(3, T1, T3, T5);
  T7 = CONS(T6,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
  ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T7); /*  *HANDLER-CLUSTERS* */
  T0 = cl_make_broadcast_stream(0);
  ecl_bds_bind(cl_env_copy,VV[1610],T0);          /*  *VERBOSE-OUT*           */
  {
   cl_object v3asdf_system_system;
   v3asdf_system_system = (cl_env_copy->function=ecl_fdefinition(VV[1690]))->cfun.entry(2, v2asdf_component_module, ECL_NIL) /*  FIND-SYSTEM */;
   if (Null(v3asdf_system_system)){
    goto L10;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[2157]))->cfun.entry(3, v3asdf_system_system, ECL_SYM("VERBOSE",1363), ECL_NIL) /*  REQUIRE-SYSTEM */;
   value0 = ECL_T;
   cl_env_copy->nvalues = 1;
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   return value0;
L10:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   return value0;
  }
L2:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L5107module_provide_asdf_va(cl_narg narg, cl_object v4asdf_component_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2165]);
 {
  return L5107module_provide_asdf(v4asdf_component_name);
 }
}
/* function definition for RESTART-UPGRADED-ASDF                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5108restart_upgraded_asdf()
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1703]))){
  goto L2;
 }
 {
  cl_object v1asdf_operate__l;
  {
   cl_object v2;
   cl_object v3;
   cl_object v4asdf_operate__k;
   cl_object v5;
   v2 = ecl_cmp_symbol_value(cl_env_copy,VV[1703]);
   v3 = ECL_NIL;
   v4asdf_operate__k = ECL_NIL;
   v5 = ECL_NIL;
   {
    cl_object v6;
    v6 = si_hash_table_iterator(v2);
    {
     cl_object v7;
     cl_object v8;
     v7 = ecl_list1(ECL_NIL);
     v8 = v7;
L12:;
     {
      cl_object v9;
      cl_object v10;
      cl_object v11;
      value0 = ecl_function_dispatch(cl_env_copy,v6)(0);
      {
       const int v12 = cl_env_copy->nvalues;
       v9 = value0;
       cl_object v13;
       v13 = (v12<=1)? ECL_NIL : cl_env_copy->values[1];
       v10 = v13;
       v13 = (v12<=2)? ECL_NIL : cl_env_copy->values[2];
       v11 = v13;
      }
      if (Null(v9)){
       goto L17;
      }
      v5 = v11;
      v4asdf_operate__k = v10;
L17:;
      v3 = v9;
      if (v3!=ECL_NIL) {
       goto L14;
      }
     }
     goto L13;
L14:;
     T0 = ecl_car(v4asdf_operate__k);
     if (!((T0)==(VV[1690]))){
      goto L23;
     }
     {
      cl_object v9;
      v9 = v8;
      if (ecl_unlikely(ECL_ATOM(v9))) FEtype_error_cons(v9);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v9;
     }
     T1 = ecl_cadr(v4asdf_operate__k);
     v8 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v8,T0);
L23:;
     goto L12;
L13:;
     v1asdf_operate__l = ecl_cdr(v7);
     goto L4;
    }
   }
  }
L4:;
  cl_clrhash(ecl_cmp_symbol_value(cl_env_copy,VV[1703]));
  {
   cl_object v2;
   v2 = v1asdf_operate__l;
   goto L35;
L34:;
   {
    cl_object v3asdf_operate__s;
    v3asdf_operate__s = ecl_car(v2);
    (cl_env_copy->function=ecl_fdefinition(VV[1690]))->cfun.entry(2, v3asdf_operate__s, ECL_NIL) /*  FIND-SYSTEM */;
   }
   v2 = ecl_cdr(v2);
L35:;
   if (Null(v2)){
    goto L42;
   }
   goto L34;
L42:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5108restart_upgraded_asdf_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2169]);
 {
  return L5108restart_upgraded_asdf();
 }
}
/* function definition for MARK-COMPONENT-PRELOADED                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5109mark_component_preloaded(cl_object v1asdf_component_component)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_component_component;
  v2asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(4, v1asdf_component_component, ECL_NIL, VV[1875], ECL_T) /*  FIND-COMPONENT */;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1672]))->cfun.entry(1, v2asdf_component_component) /*  COMPONENT-CHILDREN */;
  cl_map(3, ECL_NIL, VV[1782], T0);
  {
   cl_object v3asdf_operate__times;
   v3asdf_operate__times = (cl_env_copy->function=ecl_fdefinition(VV[1980]))->cfun.entry(1, v2asdf_component_component) /*  COMPONENT-OPERATION-TIMES */;
   {
    cl_object v4;
    v4 = VV[2172];
    goto L8;
L7:;
    {
     cl_object v5asdf_operate__o;
     v5asdf_operate__o = ecl_car(v4);
     si_hash_set(v5asdf_operate__o, v3asdf_operate__times, ecl_make_int8_t(0));
    }
    v4 = ecl_cdr(v4);
L8:;
    if (Null(v4)){
     goto L15;
    }
    goto L7;
L15:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
static cl_object L5109mark_component_preloaded_va(cl_narg narg, cl_object v5asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1782]);
 {
  return L5109mark_component_preloaded(v5asdf_component_component);
 }
}
/* local function LAMBDA6704                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5110__lambda6704()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = VV[2176];
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5110__lambda6704_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2175]);
 {
  return LC5110__lambda6704();
 }
}
/* function definition for OUTPUT-TRANSLATIONS                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5111output_translations()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_car(ecl_cmp_symbol_value(cl_env_copy,VV[2177]));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5111output_translations_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2178]);
 {
  return L5111output_translations();
 }
}
/* function definition for SET-OUTPUT-TRANSLATIONS                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5113set_output_translations(cl_object v1asdf_output_translations__new_value)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_copy_list(v1asdf_output_translations__new_value);
 T1 = (ECL_SYM(">",77)->symbol.gfdef);
 {
  cl_object v2;
  v2 = ecl_make_cfun_va((cl_objectfn)LC5112__lambda6713_va,ECL_NIL,Cblock,1);
  T2 = v2;
 }
 T3 = cl_stable_sort(4, T0, T1, ECL_SYM("KEY",1297), T2);
 T4 = ecl_list1(T3);
 ecl_cmp_setq(cl_env_copy,VV[2177],T4);
 value0 = v1asdf_output_translations__new_value;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5113set_output_translations_va(cl_narg narg, cl_object v2asdf_output_translations__new_value, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2180]);
 {
  return L5113set_output_translations(v2asdf_output_translations__new_value);
 }
}
/* function definition for (SETF OUTPUT-TRANSLATIONS)                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5114_setf_output_translations_(cl_object v1asdf_output_translations__new_value)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2180]))->cfun.entry(1, v1asdf_output_translations__new_value) /*  SET-OUTPUT-TRANSLATIONS */;
 return value0;
}
static cl_object L5114_setf_output_translations__va(cl_narg narg, cl_object v2asdf_output_translations__new_value, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2184]);
 {
  return L5114_setf_output_translations_(v2asdf_output_translations__new_value);
 }
}
/* function definition for OUTPUT-TRANSLATIONS-INITIALIZED-P                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5115output_translations_initialized_p()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[2177]))){
  goto L3;
 }
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5115output_translations_initialized_p_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2186]);
 {
  return L5115output_translations_initialized_p();
 }
}
/* function definition for CLEAR-OUTPUT-TRANSLATIONS                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5116clear_output_translations()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ECL_NIL;
 ecl_cmp_setq(cl_env_copy,VV[2177],T0);
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 0;
 return value0;
}
static cl_object L5116clear_output_translations_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2188]);
 {
  return L5116clear_output_translations();
 }
}
/* function definition for VALIDATE-OUTPUT-TRANSLATIONS-DIRECTIVE             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5117validate_output_translations_directive(cl_object v1asdf_output_translations__directive)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v1asdf_output_translations__directive)==(VV[2192]))){
  goto L9;
 }
 value0 = VV[2191];
 goto L7;
L9:;
 value0 = ECL_NIL;
 goto L7;
L7:;
 if (value0!=ECL_NIL) {
  goto L6;
 }
 if (!((v1asdf_output_translations__directive)==(VV[2193]))){
  goto L13;
 }
 value0 = VV[2194];
 goto L11;
L13:;
 value0 = ECL_NIL;
 goto L11;
L11:;
 if (value0!=ECL_NIL) {
  goto L6;
 }
 if (!((v1asdf_output_translations__directive)==(ECL_NIL))){
  goto L16;
 }
 value0 = VV[505];
 goto L4;
L16:;
 value0 = ECL_NIL;
 goto L4;
L6:;
 goto L4;
L4:;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 if (!(ECL_CONSP(v1asdf_output_translations__directive))){
  goto L19;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[253]))->cfun.entry(2, v1asdf_output_translations__directive, ecl_make_int8_t(2)) /*  LENGTH=N-P */)){
  goto L25;
 }
 T0 = ecl_car(v1asdf_output_translations__directive);
 if (!((T0)==(ECL_SYM("INCLUDE",1284)))){
  goto L31;
 }
 {
  cl_object v2;
  v2 = ecl_cadr(v1asdf_output_translations__directive);
  value0 = ecl_make_bool(ECL_STRINGP(v2));
  if (value0!=ECL_NIL) {
   goto L35;
  }
  value0 = cl_pathnamep(v2);
  if (value0!=ECL_NIL) {
   goto L35;
  }
  value0 = ecl_make_bool(v2==ECL_NIL);
  goto L29;
L35:;
  goto L29;
 }
L31:;
 value0 = ECL_NIL;
 goto L29;
L29:;
 if (value0!=ECL_NIL) {
  goto L28;
 }
 T0 = ecl_car(v1asdf_output_translations__directive);
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[1506]))->cfun.entry(1, T0) /*  LOCATION-DESIGNATOR-P */)){
  goto L39;
 }
 T0 = ecl_cadr(v1asdf_output_translations__directive);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1506]))->cfun.entry(1, T0) /*  LOCATION-DESIGNATOR-P */;
 if (value0!=ECL_NIL) {
  goto L42;
 }
 T0 = ecl_cadr(v1asdf_output_translations__directive);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1519]))->cfun.entry(1, T0) /*  LOCATION-FUNCTION-P */;
 goto L23;
L42:;
 goto L23;
L39:;
 value0 = ECL_NIL;
 goto L23;
L28:;
 goto L23;
L25:;
 value0 = ECL_NIL;
 goto L23;
L23:;
 if (value0!=ECL_NIL) {
  goto L22;
 }
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[253]))->cfun.entry(2, v1asdf_output_translations__directive, ecl_make_int8_t(1)) /*  LENGTH=N-P */)){
  goto L45;
 }
 T0 = ecl_car(v1asdf_output_translations__directive);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1506]))->cfun.entry(1, T0) /*  LOCATION-DESIGNATOR-P */;
 return value0;
L45:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L22:;
 cl_env_copy->nvalues = 1;
 return value0;
L19:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5117validate_output_translations_directive_va(cl_narg narg, cl_object v2asdf_output_translations__directive, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2190]);
 {
  return L5117validate_output_translations_directive(v2asdf_output_translations__directive);
 }
}
/* function definition for VALIDATE-OUTPUT-TRANSLATIONS-FORM                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5118validate_output_translations_form(cl_narg narg, cl_object v1asdf_output_translations__form, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2196]);
 {
  cl_object v2asdf_output_translations__location;
  ecl_va_list args; ecl_va_start(args,v1asdf_output_translations__form,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5118validate_output_translations_formkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2asdf_output_translations__location = keyvars[0];
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1464]))->cfun.entry(7, v1asdf_output_translations__form, VV[2197], VV[2190], ECL_SYM("LOCATION",1003), v2asdf_output_translations__location, VV[2198], VV[2174]) /*  VALIDATE-CONFIGURATION-FORM */;
  return value0;
 }
}
/* function definition for VALIDATE-OUTPUT-TRANSLATIONS-FILE                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5119validate_output_translations_file(cl_object v1asdf_output_translations__file)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1470]))->cfun.entry(4, v1asdf_output_translations__file, VV[2196], ECL_SYM("DESCRIPTION",992), VV[2201]) /*  VALIDATE-CONFIGURATION-FILE */;
 return value0;
}
static cl_object L5119validate_output_translations_file_va(cl_narg narg, cl_object v2asdf_output_translations__file, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2200]);
 {
  return L5119validate_output_translations_file(v2asdf_output_translations__file);
 }
}
/* function definition for VALIDATE-OUTPUT-TRANSLATIONS-DIRECTORY             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5120validate_output_translations_directory(cl_object v1directory)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1473]))->cfun.entry(5, v1directory, VV[2197], VV[2190], VV[2198], VV[2174]) /*  VALIDATE-CONFIGURATION-DIRECTORY */;
 return value0;
}
static cl_object L5120validate_output_translations_directory_va(cl_narg narg, cl_object v2directory, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2203]);
 {
  return L5120validate_output_translations_directory(v2directory);
 }
}
/* function definition for PARSE-OUTPUT-TRANSLATIONS-STRING                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5121parse_output_translations_string(cl_narg narg, cl_object v1string, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2205]);
 {
  cl_object v2asdf_output_translations__location;
  ecl_va_list args; ecl_va_start(args,v1string,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5121parse_output_translations_stringkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2asdf_output_translations__location = keyvars[0];
  }
  if (v1string==ECL_NIL) {
   goto L3;
  }
  if (!(ecl_equal(v1string,VV[96]))){
   goto L1;
  }
  goto L2;
L3:;
L2:;
  value0 = VV[2206];
  cl_env_copy->nvalues = 1;
  return value0;
L1:;
  if (ECL_STRINGP(v1string)) {
   goto L5;
  }
  value0 = cl_error(2, VV[2207], v1string);
  return value0;
L5:;
  {
   ecl_character v3;
   v3 = ecl_char(v1string,(cl_fixnum)(0));
   if (!((v3)==((ecl_character)(34)))){
    goto L7;
   }
  }
  T0 = cl_read_from_string(1, v1string);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2205]))->cfun.entry(3, T0, ECL_SYM("LOCATION",1003), v2asdf_output_translations__location) /*  PARSE-OUTPUT-TRANSLATIONS-STRING */;
  return value0;
L7:;
  {
   ecl_character v3;
   v3 = ecl_char(v1string,(cl_fixnum)(0));
   if (!((v3)==((ecl_character)(40)))){
    goto L9;
   }
  }
  T0 = cl_read_from_string(1, v1string);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2196]))->cfun.entry(3, T0, ECL_SYM("LOCATION",1003), v2asdf_output_translations__location) /*  VALIDATE-OUTPUT-TRANSLATIONS-FORM */;
  return value0;
L9:;
  {
   cl_object v3asdf_output_translations__inherit;
   v3asdf_output_translations__inherit = ECL_NIL;
   {
    cl_object v4asdf_output_translations__directives;
    v4asdf_output_translations__directives = ECL_NIL;
    {
     cl_object v5asdf_output_translations__start;
     v5asdf_output_translations__start = ecl_make_int8_t(0);
     {
      cl_object v6asdf_output_translations__end;
      v6asdf_output_translations__end = ecl_make_fixnum(ecl_length(v1string));
      {
       cl_object v7asdf_output_translations__source;
       v7asdf_output_translations__source = ECL_NIL;
       {
        cl_object v8asdf_output_translations__separator;
        v8asdf_output_translations__separator = (cl_env_copy->function=ecl_fdefinition(VV[760]))->cfun.entry(0) /*  INTER-DIRECTORY-SEPARATOR */;
        {
         cl_object v9asdf_output_translations__i;
         v9asdf_output_translations__i = ECL_NIL;
L18:;
         value0 = cl_position(4, v8asdf_output_translations__separator, v1string, ECL_SYM("START",1347), v5asdf_output_translations__start);
         if (value0!=ECL_NIL) {
          goto L22;
         }
         v9asdf_output_translations__i = v6asdf_output_translations__end;
         goto L20;
L22:;
         v9asdf_output_translations__i = value0;
         goto L20;
L20:;
         {
          cl_object v10asdf_output_translations__s;
          v10asdf_output_translations__s = cl_subseq(3, v1string, v5asdf_output_translations__start, v9asdf_output_translations__i);
          if (Null(v7asdf_output_translations__source)){
          goto L27;
          }
          if (!(ecl_equal(VV[96],v10asdf_output_translations__s))){
          goto L32;
          }
          T0 = ECL_NIL;
          goto L31;
L32:;
          T0 = v10asdf_output_translations__s;
L31:;
          T1 = cl_list(2, v7asdf_output_translations__source, T0);
          v4asdf_output_translations__directives = CONS(T1,v4asdf_output_translations__directives);
          v7asdf_output_translations__source = ECL_NIL;
          goto L26;
L27:;
          if (!(ecl_equal(VV[96],v10asdf_output_translations__s))){
          goto L35;
          }
          if (Null(v3asdf_output_translations__inherit)){
          goto L37;
          }
          cl_error(2, VV[2208], v1string);
L37:;
          v3asdf_output_translations__inherit = ECL_T;
          v4asdf_output_translations__directives = CONS(VV[2209],v4asdf_output_translations__directives);
          goto L26;
L35:;
          v7asdf_output_translations__source = v10asdf_output_translations__s;
L26:;
          v5asdf_output_translations__start = ecl_one_plus(v9asdf_output_translations__i);
          if (!(ecl_greater(v5asdf_output_translations__start,v6asdf_output_translations__end))){
          goto L24;
          }
          if (Null(v7asdf_output_translations__source)){
          goto L46;
          }
          cl_error(2, VV[2210], v1string);
L46:;
          if (v3asdf_output_translations__inherit!=ECL_NIL) {
          goto L48;
          }
          v4asdf_output_translations__directives = CONS(VV[2211],v4asdf_output_translations__directives);
L48:;
          T0 = cl_nreverse(v4asdf_output_translations__directives);
          value0 = CONS(VV[2197],T0);
          cl_env_copy->nvalues = 1;
          return value0;
         }
L24:;
         goto L18;
        }
       }
      }
     }
    }
   }
  }
 }
}
/* function definition for %COMPUTE-DEFAULT-OUTPUT-TRANSLATIONS-VALUE         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5122_compute_default_output_translations_value()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = VV[2214];
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5122_compute_default_output_translations_value_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2213]);
 {
  return L5122_compute_default_output_translations_value();
 }
}
/* function definition for WRAPPING-OUTPUT-TRANSLATIONS                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5123wrapping_output_translations()
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1asdf_output_translations__h;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[775]))->cfun.entry(0) /*  LISP-IMPLEMENTATION-DIRECTORY */;
  v1asdf_output_translations__h = (cl_env_copy->function=ecl_fdefinition(VV[716]))->cfun.entry(1, T1) /*  RESOLVE-SYMLINKS* */;
  if (Null(v1asdf_output_translations__h)){
   goto L4;
  }
  T1 = cl_list(2, v1asdf_output_translations__h, ecl_cmp_symbol_value(cl_env_copy,VV[639]));
  T2 = cl_list(2, T1, ECL_NIL);
  T0 = ecl_list1(T2);
  goto L2;
L4:;
  T0 = ECL_NIL;
 }
L2:;
 T1 = ecl_append(T0,VV[2218]);
 value0 = CONS(VV[2197],T1);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5123wrapping_output_translations_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2217]);
 {
  return L5123wrapping_output_translations();
 }
}
/* function definition for USER-OUTPUT-TRANSLATIONS-PATHNAME                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5124user_output_translations_pathname(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1asdf_output_translations__direction;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5124user_output_translations_pathnamekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v1asdf_output_translations__direction = ECL_SYM("INPUT",1289);
   } else {
    v1asdf_output_translations__direction = keyvars[0];
   }
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1581]))->cfun.entry(2, ecl_cmp_symbol_value(cl_env_copy,VV[2220]), v1asdf_output_translations__direction) /*  XDG-CONFIG-PATHNAME */;
  return value0;
 }
}
/* function definition for SYSTEM-OUTPUT-TRANSLATIONS-PATHNAME                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5125system_output_translations_pathname(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1asdf_output_translations__direction;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5125system_output_translations_pathnamekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v1asdf_output_translations__direction = ECL_SYM("INPUT",1289);
   } else {
    v1asdf_output_translations__direction = keyvars[0];
   }
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1565]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[2220])) /*  SYSTEM-CONFIG-PATHNAMES */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1574]))->cfun.entry(3, T0, ECL_SYM("DIRECTION",1249), v1asdf_output_translations__direction) /*  FIND-PREFERRED-FILE */;
  return value0;
 }
}
/* function definition for USER-OUTPUT-TRANSLATIONS-DIRECTORY-PATHNAME        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5126user_output_translations_directory_pathname(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1asdf_output_translations__direction;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5126user_output_translations_directory_pathnamekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v1asdf_output_translations__direction = ECL_SYM("INPUT",1289);
   } else {
    v1asdf_output_translations__direction = keyvars[0];
   }
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1581]))->cfun.entry(2, ecl_cmp_symbol_value(cl_env_copy,VV[2221]), v1asdf_output_translations__direction) /*  XDG-CONFIG-PATHNAME */;
  return value0;
 }
}
/* function definition for SYSTEM-OUTPUT-TRANSLATIONS-DIRECTORY-PATHNAME      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5127system_output_translations_directory_pathname(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1asdf_output_translations__direction;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5127system_output_translations_directory_pathnamekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v1asdf_output_translations__direction = ECL_SYM("INPUT",1289);
   } else {
    v1asdf_output_translations__direction = keyvars[0];
   }
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1565]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[2221])) /*  SYSTEM-CONFIG-PATHNAMES */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1574]))->cfun.entry(3, T0, ECL_SYM("DIRECTION",1249), v1asdf_output_translations__direction) /*  FIND-PREFERRED-FILE */;
  return value0;
 }
}
/* function definition for ENVIRONMENT-OUTPUT-TRANSLATIONS                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5128environment_output_translations()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[452]))->cfun.entry(1, VV[2231]) /*  GETENV */;
 return value0;
}
static cl_object L5128environment_output_translations_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2230]);
 {
  return L5128environment_output_translations();
 }
}
/* function definition for INHERIT-OUTPUT-TRANSLATIONS                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5129inherit_output_translations(cl_narg narg, cl_object v1asdf_output_translations__inherit, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2234]);
 {
  cl_object v2asdf_output_translations__collect;
  ecl_va_list args; ecl_va_start(args,v1asdf_output_translations__inherit,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5129inherit_output_translationskeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2asdf_output_translations__collect = keyvars[0];
  }
  if (Null(v1asdf_output_translations__inherit)){
   goto L1;
  }
  T0 = ecl_car(v1asdf_output_translations__inherit);
  T1 = ecl_cdr(v1asdf_output_translations__inherit);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2233]))->cfun.entry(5, T0, VV[2235], v2asdf_output_translations__collect, VV[2236], T1) /*  PROCESS-OUTPUT-TRANSLATIONS */;
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for PROCESS-OUTPUT-TRANSLATIONS-DIRECTIVE              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5130process_output_translations_directive(cl_narg narg, cl_object v1asdf_output_translations__directive, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2238]);
 {
  cl_object v2asdf_output_translations__inherit;
  cl_object v3asdf_output_translations__collect;
  ecl_va_list args; ecl_va_start(args,v1asdf_output_translations__directive,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L5130process_output_translations_directivekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2asdf_output_translations__inherit = keyvars[0];
   v3asdf_output_translations__collect = keyvars[1];
  }
  if (!(ECL_ATOM(v1asdf_output_translations__directive))){
   goto L1;
  }
  if (!((v1asdf_output_translations__directive)==(VV[2192]))){
   goto L3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2238]))->cfun.entry(3, VV[2240], VV[2235], v3asdf_output_translations__collect) /*  PROCESS-OUTPUT-TRANSLATIONS-DIRECTIVE */;
  return value0;
L3:;
  if (!((v1asdf_output_translations__directive)==(VV[2193]))){
   goto L6;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2238]))->cfun.entry(3, VV[1137], VV[2235], v3asdf_output_translations__collect) /*  PROCESS-OUTPUT-TRANSLATIONS-DIRECTIVE */;
  return value0;
L6:;
  if (!((v1asdf_output_translations__directive)==(VV[2209]))){
   goto L9;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2234]))->cfun.entry(3, v2asdf_output_translations__inherit, VV[2235], v3asdf_output_translations__collect) /*  INHERIT-OUTPUT-TRANSLATIONS */;
  return value0;
L9:;
  if (!((v1asdf_output_translations__directive)==(VV[2211]))){
   goto L17;
  }
  goto L14;
L17:;
  goto L15;
L15:;
  if (!((v1asdf_output_translations__directive)==(VV[1465]))){
   goto L21;
  }
  goto L14;
L21:;
  goto L19;
L19:;
  if (!((v1asdf_output_translations__directive)==(ECL_NIL))){
   goto L12;
  }
  goto L13;
L14:;
L13:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L12:;
  value0 = si_ecase_error(v1asdf_output_translations__directive, VV[2244]);
  return value0;
L1:;
  {
   cl_object v4;
   cl_object v5;
   v4 = ecl_car(v1asdf_output_translations__directive);
   v5 = ecl_cadr(v1asdf_output_translations__directive);
   if (!((v4)==(ECL_SYM("INCLUDE",1284)))){
    goto L26;
   }
   if (Null(v5)){
    goto L28;
   }
   T0 = cl_pathname(v5);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[2233]))->cfun.entry(5, T0, VV[2236], ECL_NIL, VV[2235], v3asdf_output_translations__collect) /*  PROCESS-OUTPUT-TRANSLATIONS */;
   return value0;
L28:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L26:;
   if (Null(v4)){
    goto L30;
   }
   {
    cl_object v6asdf_output_translations__trusrc;
    value0 = ecl_make_bool((v4)==(ECL_T));
    if (value0!=ECL_NIL) {
     goto L34;
    }
    {
     cl_object v7asdf_output_translations__loc;
     v7asdf_output_translations__loc = (cl_env_copy->function=ecl_fdefinition(VV[1504]))->cfun.entry(5, v4, VV[595], ECL_T, VV[1480], ECL_T) /*  RESOLVE-LOCATION */;
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v7asdf_output_translations__loc) /*  ABSOLUTE-PATHNAME-P */)){
      goto L37;
     }
     v6asdf_output_translations__trusrc = (cl_env_copy->function=ecl_fdefinition(VV[716]))->cfun.entry(1, v7asdf_output_translations__loc) /*  RESOLVE-SYMLINKS* */;
     goto L32;
L37:;
     v6asdf_output_translations__trusrc = v7asdf_output_translations__loc;
     goto L32;
    }
L34:;
    v6asdf_output_translations__trusrc = value0;
    goto L32;
L32:;
    if (Null((cl_env_copy->function=ecl_fdefinition(VV[1519]))->cfun.entry(1, v5) /*  LOCATION-FUNCTION-P */)){
     goto L39;
    }
    T0 = ecl_cadr(v5);
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[344]))->cfun.entry(1, T0) /*  ENSURE-FUNCTION */;
    T2 = cl_list(2, v6asdf_output_translations__trusrc, T1);
    value0 = ecl_function_dispatch(cl_env_copy,v3asdf_output_translations__collect)(1, T2);
    return value0;
L39:;
    if (!((v5)==(ECL_NIL))){
     goto L46;
    }
    goto L43;
L46:;
    goto L44;
L44:;
    if (!((v5)==(ECL_T))){
     goto L41;
    }
    goto L42;
L43:;
L42:;
    T0 = cl_list(2, v6asdf_output_translations__trusrc, ECL_T);
    value0 = ecl_function_dispatch(cl_env_copy,v3asdf_output_translations__collect)(1, T0);
    return value0;
L41:;
    {
     cl_object v7asdf_output_translations__trudst;
     v7asdf_output_translations__trudst = (cl_env_copy->function=ecl_fdefinition(VV[1504]))->cfun.entry(5, v5, VV[595], ECL_T, VV[1480], ECL_T) /*  RESOLVE-LOCATION */;
     T0 = cl_list(2, v7asdf_output_translations__trudst, ECL_T);
     ecl_function_dispatch(cl_env_copy,v3asdf_output_translations__collect)(1, T0);
     T0 = cl_list(2, v6asdf_output_translations__trusrc, v7asdf_output_translations__trudst);
     value0 = ecl_function_dispatch(cl_env_copy,v3asdf_output_translations__collect)(1, T0);
     return value0;
    }
   }
L30:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function PROCESS-OUTPUT-TRANSLATIONS                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5131process_output_translations(cl_narg narg, cl_object v1asdf_output_translations__x, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2233]);
 {
  cl_object v2asdf_output_translations__inherit;
  cl_object v3asdf_output_translations__collect;
  ecl_va_list args; ecl_va_start(args,v1asdf_output_translations__x,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,LC5131process_output_translationskeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   if (Null(keyvars[2])) {
    v2asdf_output_translations__inherit = ecl_cmp_symbol_value(cl_env_copy,VV[2216]);
   } else {
    v2asdf_output_translations__inherit = keyvars[0];
   }
   v3asdf_output_translations__collect = keyvars[1];
  }
  T0 = ecl_function_dispatch(cl_env_copy,v1asdf_output_translations__x)(0);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2233]))->cfun.entry(5, T0, VV[2236], v2asdf_output_translations__inherit, VV[2235], v3asdf_output_translations__collect) /*  PROCESS-OUTPUT-TRANSLATIONS */;
  return value0;
 }
}
/* local function PROCESS-OUTPUT-TRANSLATIONS                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5132process_output_translations(cl_narg narg, cl_object v1pathname, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2233]);
 {
  cl_object v2asdf_output_translations__inherit;
  cl_object v3asdf_output_translations__collect;
  ecl_va_list args; ecl_va_start(args,v1pathname,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,LC5132process_output_translationskeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2asdf_output_translations__inherit = keyvars[0];
   v3asdf_output_translations__collect = keyvars[1];
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, v1pathname) /*  DIRECTORY-PATHNAME-P */)){
   goto L1;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2203]))->cfun.entry(1, v1pathname) /*  VALIDATE-OUTPUT-TRANSLATIONS-DIRECTORY */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2233]))->cfun.entry(5, T0, VV[2236], v2asdf_output_translations__inherit, VV[2235], v3asdf_output_translations__collect) /*  PROCESS-OUTPUT-TRANSLATIONS */;
  return value0;
L1:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[669]))->cfun.entry(3, v1pathname, VV[681], ecl_cmp_symbol_value(cl_env_copy,VV[715])) /*  PROBE-FILE* */)){
   goto L3;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2200]))->cfun.entry(1, v1pathname) /*  VALIDATE-OUTPUT-TRANSLATIONS-FILE */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2233]))->cfun.entry(5, T0, VV[2236], v2asdf_output_translations__inherit, VV[2235], v3asdf_output_translations__collect) /*  PROCESS-OUTPUT-TRANSLATIONS */;
  return value0;
L3:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2234]))->cfun.entry(3, v2asdf_output_translations__inherit, VV[2235], v3asdf_output_translations__collect) /*  INHERIT-OUTPUT-TRANSLATIONS */;
  return value0;
 }
}
/* local function PROCESS-OUTPUT-TRANSLATIONS                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5133process_output_translations(cl_narg narg, cl_object v1string, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2233]);
 {
  cl_object v2asdf_output_translations__inherit;
  cl_object v3asdf_output_translations__collect;
  ecl_va_list args; ecl_va_start(args,v1string,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,LC5133process_output_translationskeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2asdf_output_translations__inherit = keyvars[0];
   v3asdf_output_translations__collect = keyvars[1];
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2205]))->cfun.entry(1, v1string) /*  PARSE-OUTPUT-TRANSLATIONS-STRING */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2233]))->cfun.entry(5, T0, VV[2236], v2asdf_output_translations__inherit, VV[2235], v3asdf_output_translations__collect) /*  PROCESS-OUTPUT-TRANSLATIONS */;
  return value0;
 }
}
/* local function PROCESS-OUTPUT-TRANSLATIONS                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5134process_output_translations(cl_narg narg, cl_object v1asdf_output_translations__x, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2233]);
 {
  cl_object v2asdf_output_translations__inherit;
  cl_object v3asdf_output_translations__collect;
  ecl_va_list args; ecl_va_start(args,v1asdf_output_translations__x,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,LC5134process_output_translationskeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2asdf_output_translations__inherit = keyvars[0];
   v3asdf_output_translations__collect = keyvars[1];
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2234]))->cfun.entry(3, v2asdf_output_translations__inherit, VV[2235], v3asdf_output_translations__collect) /*  INHERIT-OUTPUT-TRANSLATIONS */;
  return value0;
 }
}
/* local function PROCESS-OUTPUT-TRANSLATIONS                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5135process_output_translations(cl_narg narg, cl_object v1asdf_output_translations__form, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2233]);
 {
  cl_object v2asdf_output_translations__inherit;
  cl_object v3asdf_output_translations__collect;
  ecl_va_list args; ecl_va_start(args,v1asdf_output_translations__form,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,LC5135process_output_translationskeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2asdf_output_translations__inherit = keyvars[0];
   v3asdf_output_translations__collect = keyvars[1];
  }
  {
   cl_object v4;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[2196]))->cfun.entry(1, v1asdf_output_translations__form) /*  VALIDATE-OUTPUT-TRANSLATIONS-FORM */;
   v4 = ecl_cdr(T0);
   goto L4;
L3:;
   {
    cl_object v5asdf_output_translations__directive;
    v5asdf_output_translations__directive = ecl_car(v4);
    (cl_env_copy->function=ecl_fdefinition(VV[2238]))->cfun.entry(5, v5asdf_output_translations__directive, VV[2236], v2asdf_output_translations__inherit, VV[2235], v3asdf_output_translations__collect) /*  PROCESS-OUTPUT-TRANSLATIONS-DIRECTIVE */;
   }
   v4 = ecl_cdr(v4);
L4:;
   if (Null(v4)){
    goto L11;
   }
   goto L3;
L11:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for COMPUTE-OUTPUT-TRANSLATIONS                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5137compute_output_translations(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[2246]);
 {
  cl_object v1asdf_output_translations__parameter;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1asdf_output_translations__parameter = ECL_NIL;
   } else {
    i++;
    v1asdf_output_translations__parameter = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object env1 = env0;
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(ECL_NIL,env1);
   {
    cl_object v2;
    v2 = ecl_make_cclosure_va((cl_objectfn)LC5136c,env1,Cblock,1);
    T1 = cl_listX(3, VV[2217], v1asdf_output_translations__parameter, ecl_cmp_symbol_value(cl_env_copy,VV[2216]));
    (cl_env_copy->function=ecl_fdefinition(VV[2234]))->cfun.entry(3, T1, VV[2235], v2) /*  INHERIT-OUTPUT-TRANSLATIONS */;
    T0 = cl_reverse(ECL_CONS_CAR(CLV0));
   }
  }
  value0 = cl_remove_duplicates(5, T0, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337), VV[91], ECL_T);
  return value0;
 }
}
/* function definition for INITIALIZE-OUTPUT-TRANSLATIONS                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5138initialize_output_translations(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[2250]);
 {
  cl_object v1asdf_output_translations__parameter;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1asdf_output_translations__parameter = ecl_cmp_symbol_value(cl_env_copy,VV[2249]);
   } else {
    i++;
    v1asdf_output_translations__parameter = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = v1asdf_output_translations__parameter;
  ecl_cmp_setq(cl_env_copy,VV[2249],T0);
  {
   cl_object v2;
   v2 = (cl_env_copy->function=ecl_fdefinition(VV[2246]))->cfun.entry(1, v1asdf_output_translations__parameter) /*  COMPUTE-OUTPUT-TRANSLATIONS */;
   value0 = L5114_setf_output_translations_(v2);
   return value0;
  }
 }
}
/* function definition for DISABLE-OUTPUT-TRANSLATIONS                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5139disable_output_translations()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2250]))->cfun.entry(1, VV[2253]) /*  INITIALIZE-OUTPUT-TRANSLATIONS */;
 return value0;
}
static cl_object L5139disable_output_translations_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2252]);
 {
  return L5139disable_output_translations();
 }
}
/* function definition for ENSURE-OUTPUT-TRANSLATIONS                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5140ensure_output_translations()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[2186]))->cfun.entry(0) /*  OUTPUT-TRANSLATIONS-INITIALIZED-P */)){
  goto L2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2178]))->cfun.entry(0) /*  OUTPUT-TRANSLATIONS */;
 return value0;
L2:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2250]))->cfun.entry(0) /*  INITIALIZE-OUTPUT-TRANSLATIONS */;
 return value0;
}
static cl_object L5140ensure_output_translations_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2255]);
 {
  return L5140ensure_output_translations();
 }
}
/* function definition for APPLY-OUTPUT-TRANSLATIONS                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5141apply_output_translations(cl_object v1asdf_output_translations__path)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_logical_pathname_p(v1asdf_output_translations__path))){
  goto L2;
 }
 value0 = v1asdf_output_translations__path;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (cl_pathnamep(v1asdf_output_translations__path)!=ECL_NIL) {
  goto L6;
 }
 if (!(ECL_STRINGP(v1asdf_output_translations__path))){
  goto L4;
 }
 goto L5;
L6:;
L5:;
 (cl_env_copy->function=ecl_fdefinition(VV[2255]))->cfun.entry(0) /*  ENSURE-OUTPUT-TRANSLATIONS */;
 {
  cl_object v2asdf_output_translations__p;
  v2asdf_output_translations__p = (cl_env_copy->function=ecl_fdefinition(VV[716]))->cfun.entry(1, v1asdf_output_translations__path) /*  RESOLVE-SYMLINKS* */;
  {
   cl_object v3;
   cl_object v4asdf_output_translations__source;
   cl_object v5asdf_output_translations__destination;
   cl_object v6;
   {
    cl_object v7;
    v7 = ecl_car(ecl_cmp_symbol_value(cl_env_copy,VV[2177]));
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v7;
   }
   v4asdf_output_translations__source = ECL_NIL;
   v5asdf_output_translations__destination = ECL_NIL;
   v6 = v3;
   {
    cl_object v7asdf_output_translations__root;
    v7asdf_output_translations__root = ECL_NIL;
    {
     cl_object v8asdf_output_translations__absolute_source;
     v8asdf_output_translations__absolute_source = ECL_NIL;
L18:;
     if (!(ecl_endp(v6))){
      goto L20;
     }
     goto L19;
L20:;
     {
      cl_object v9;
      v9 = ECL_CONS_CAR(v6);
      v4asdf_output_translations__source = ecl_car(v9);
      v9 = ecl_cdr(v9);
      v5asdf_output_translations__destination = ecl_car(v9);
     }
     {
      cl_object v9;
      v9 = ECL_CONS_CDR(v6);
      if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v6 = v9;
     }
     if ((v4asdf_output_translations__source)==(ECL_T)) {
      goto L37;
     }
     if (Null(cl_pathnamep(v4asdf_output_translations__source))){
      goto L35;
     }
     if ((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v4asdf_output_translations__source) /*  ABSOLUTE-PATHNAME-P */!=ECL_NIL) {
      goto L35;
     }
     goto L36;
L37:;
L36:;
     v7asdf_output_translations__root = (cl_env_copy->function=ecl_fdefinition(VV[613]))->cfun.entry(1, v2asdf_output_translations__p) /*  PATHNAME-ROOT */;
     goto L34;
L35:;
     v7asdf_output_translations__root = ECL_NIL;
L34:;
     if (!((v4asdf_output_translations__source)==(ECL_T))){
      goto L42;
     }
     v8asdf_output_translations__absolute_source = (cl_env_copy->function=ecl_fdefinition(VV[640]))->cfun.entry(1, v7asdf_output_translations__root) /*  WILDEN */;
     goto L41;
L42:;
     if (Null(v7asdf_output_translations__root)){
      goto L44;
     }
     v8asdf_output_translations__absolute_source = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, v4asdf_output_translations__source, v7asdf_output_translations__root) /*  MERGE-PATHNAMES* */;
     goto L41;
L44:;
     v8asdf_output_translations__absolute_source = v4asdf_output_translations__source;
L41:;
     if ((v4asdf_output_translations__source)==(ECL_T)) {
      goto L48;
     }
     if (Null(cl_pathname_match_p(v2asdf_output_translations__p, v8asdf_output_translations__absolute_source))){
      goto L46;
     }
     goto L47;
L48:;
L47:;
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[652]))->cfun.entry(5, v2asdf_output_translations__p, v8asdf_output_translations__absolute_source, v5asdf_output_translations__destination, v7asdf_output_translations__root, v4asdf_output_translations__source) /*  TRANSLATE-PATHNAME* */;
     return value0;
L46:;
     goto L18;
L19:;
     value0 = v2asdf_output_translations__p;
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
L4:;
 value0 = si_etypecase_error(v1asdf_output_translations__path, VV[2258]);
 return value0;
}
static cl_object L5141apply_output_translations_va(cl_narg narg, cl_object v9asdf_output_translations__path, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2257]);
 {
  return L5141apply_output_translations(v9asdf_output_translations__path);
 }
}
/* local function LAMBDA6865                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5142__lambda6865()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = VV[2262];
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5142__lambda6865_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2261]);
 {
  return LC5142__lambda6865();
 }
}
/* function definition for SOURCE-REGISTRY-INITIALIZED-P                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5143source_registry_initialized_p()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_hash_table_p(ecl_cmp_symbol_value(cl_env_copy,VV[2265]));
 return value0;
}
static cl_object L5143source_registry_initialized_p_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2267]);
 {
  return L5143source_registry_initialized_p();
 }
}
/* function definition for CLEAR-SOURCE-REGISTRY                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5144clear_source_registry()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ECL_NIL;
 ecl_cmp_setq(cl_env_copy,VV[2265],T0);
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 0;
 return value0;
}
static cl_object L5144clear_source_registry_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2269]);
 {
  return L5144clear_source_registry();
 }
}
/* function definition for DIRECTORY-ASD-FILES                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5145directory_asd_files(cl_object v1directory)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[691]))->cfun.entry(2, v1directory, ecl_cmp_symbol_value(cl_env_copy,VV[2271])) /*  DIRECTORY-FILES */;
 return value0;
}
static cl_object L5145directory_asd_files_va(cl_narg narg, cl_object v2directory, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2272]);
 {
  return L5145directory_asd_files(v2directory);
 }
}
/* function definition for COLLECT-ASDS-IN-DIRECTORY                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5146collect_asds_in_directory(cl_object v1directory, cl_object v2asdf_source_registry__collect)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_source_registry__asds;
  v3asdf_source_registry__asds = (cl_env_copy->function=ecl_fdefinition(VV[2272]))->cfun.entry(1, v1directory) /*  DIRECTORY-ASD-FILES */;
  cl_map(3, ECL_NIL, v2asdf_source_registry__collect, v3asdf_source_registry__asds);
  value0 = v3asdf_source_registry__asds;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L5146collect_asds_in_directory_va(cl_narg narg, cl_object v4directory, cl_object v5asdf_source_registry__collect, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2274]);
 {
  return L5146collect_asds_in_directory(v4directory, v5asdf_source_registry__collect);
 }
}
/* function definition for PROCESS-SOURCE-REGISTRY-CACHE                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5148process_source_registry_cache(cl_object volatile v1directory, cl_object volatile v2asdf_source_registry__collect)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v3asdf_source_registry__cache;
  {
   volatile cl_object env1 = env0;
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(ECL_NIL,env1);
   {
    volatile cl_object env2 = env1;
    CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY       */
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
     if (__ecl_frs_push_result!=0) {
     if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
      goto L3;
     }
     ecl_internal_error("GO found an inexistent tag");
     } else {
     {
      cl_object v4;
      v4 = ecl_make_cclosure_va((cl_objectfn)LC5147__lambda6886,env2,Cblock,1);
      T0 = v4;
     }
     T1 = CONS(ECL_SYM("ERROR",339),T0);
     T2 = ecl_list1(T1);
     T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
     ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(2, v1directory, VV[2280]) /*  SUBPATHNAME */;
     v3asdf_source_registry__cache = (cl_env_copy->function=ecl_fdefinition(VV[922]))->cfun.entry(1, T0) /*  SAFE-READ-FILE-FORM */;
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     goto L2;
L3:;
     {
      cl_object v4condition;
      v4condition = ECL_CONS_CAR(CLV0);
      cl_env_copy->nvalues = 2;
      cl_env_copy->values[1] = v4condition;
      cl_env_copy->values[0] = ECL_NIL;
      v3asdf_source_registry__cache = cl_env_copy->values[0];
      ecl_frs_pop_n(cl_env_copy, 1);
      goto L2;
     }
     }
    }
   }
  }
L2:;
  if (!(ECL_LISTP(v3asdf_source_registry__cache))){
   goto L8;
  }
  T0 = ecl_car(v3asdf_source_registry__cache);
  if (!((VV[2281])==(T0))){
   goto L8;
  }
  {
   cl_object v4;
   cl_object v5asdf_source_registry__s;
   cl_object v6;
   {
    cl_object v7;
    v7 = ecl_cdr(v3asdf_source_registry__cache);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   v5asdf_source_registry__s = ECL_NIL;
   v6 = v4;
L17:;
   if (!(ecl_endp(v6))){
    goto L19;
   }
   goto L18;
L19:;
   v5asdf_source_registry__s = ECL_CONS_CAR(v6);
   {
    cl_object v7;
    v7 = ECL_CONS_CDR(v6);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v6 = v7;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(2, v1directory, v5asdf_source_registry__s) /*  SUBPATHNAME */;
   ecl_function_dispatch(cl_env_copy,v2asdf_source_registry__collect)(1, T0);
   goto L17;
L18:;
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L8:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L5148process_source_registry_cache_va(cl_narg narg, cl_object v4directory, cl_object v5asdf_source_registry__collect, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2277]);
 {
  return L5148process_source_registry_cache(v4directory, v5asdf_source_registry__collect);
 }
}
/* function definition for COLLECT-SUB*DIRECTORIES-ASD-FILES                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5152collect_sub_directories_asd_files(cl_narg narg, cl_object v1directory, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2283]);
 {
  ecl_va_list args; ecl_va_start(args,v1directory,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1directory,env0);           /*  DIRECTORY               */
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L5152collect_sub_directories_asd_fileskeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[4])) {
    CLV1 = env0 = CONS(ecl_cmp_symbol_value(cl_env_copy,VV[2263]),env0); /*  EXCLUDE */
   } else {
    CLV1 = env0 = CONS(keyvars[0],env0);          /*  EXCLUDE                 */
   }
   CLV2 = env0 = CONS(keyvars[1],env0);           /*  COLLECT                 */
   if (Null(keyvars[6])) {
    CLV3 = env0 = CONS(ecl_cmp_symbol_value(cl_env_copy,VV[2276]),env0); /*  RECURSE-BEYOND-ASDS */
   } else {
    CLV3 = env0 = CONS(keyvars[2],env0);          /*  RECURSE-BEYOND-ASDS     */
   }
   CLV4 = env0 = CONS(keyvars[3],env0);           /*  IGNORE-CACHE            */
  }
  {
   cl_object env1 = env0;
   T0 = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUALP",338));
   CLV5 = env1 = CONS(T0,env1);                   /*  VISITED                 */
   {
    cl_object v2;
    cl_object v3;
    v2 = ecl_make_cclosure_va((cl_objectfn)LC5151recursep,env1,Cblock,1);
    v3 = ecl_make_cclosure_va((cl_objectfn)LC5149collectp,env1,Cblock,1);
    T0 = cl_constantly(ECL_NIL);
    value0 = (cl_env_copy->function=ecl_fdefinition(VV[704]))->cfun.entry(4, ECL_CONS_CAR(CLV0), v3, v2, T0) /*  COLLECT-SUB*DIRECTORIES */;
    return value0;
   }
  }
 }
}
/* function definition for VALIDATE-SOURCE-REGISTRY-DIRECTIVE                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5153validate_source_registry_directive(cl_object v1asdf_source_registry__directive)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!((v1asdf_source_registry__directive)==(VV[2290]))){
  goto L6;
 }
 value0 = VV[2289];
 goto L4;
L6:;
 value0 = ECL_NIL;
 goto L4;
L4:;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 if (!(ECL_CONSP(v1asdf_source_registry__directive))){
  goto L9;
 }
 {
  cl_object v2rest;
  v2rest = ecl_cdr(v1asdf_source_registry__directive);
  {
   cl_object v3;
   v3 = ecl_car(v1asdf_source_registry__directive);
   if (!((v3)==(ECL_SYM("INCLUDE",1284)))){
    goto L18;
   }
   goto L15;
L18:;
   goto L16;
L16:;
   if (!((v3)==(ECL_SYM("DIRECTORY",1250)))){
    goto L22;
   }
   goto L15;
L22:;
   goto L20;
L20:;
   if (!((v3)==(VV[2293]))){
    goto L13;
   }
   goto L14;
L15:;
L14:;
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[253]))->cfun.entry(2, v2rest, ecl_make_int8_t(1)) /*  LENGTH=N-P */)){
    goto L26;
   }
   T0 = ecl_car(v2rest);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1506]))->cfun.entry(1, T0) /*  LOCATION-DESIGNATOR-P */;
   return value0;
L26:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   if (!((v3)==(VV[2296]))){
    goto L33;
   }
   goto L30;
L33:;
   goto L31;
L31:;
   if (!((v3)==(VV[2297]))){
    goto L28;
   }
   goto L29;
L30:;
L29:;
   T0 = (ECL_SYM("STRINGP",828)->symbol.gfdef);
   value0 = cl_every(2, T0, v2rest);
   return value0;
L28:;
   if (!((v3)==(VV[2290]))){
    goto L37;
   }
   value0 = ecl_make_bool(v2rest==ECL_NIL);
   cl_env_copy->nvalues = 1;
   return value0;
L37:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
L9:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5153validate_source_registry_directive_va(cl_narg narg, cl_object v4asdf_source_registry__directive, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2288]);
 {
  return L5153validate_source_registry_directive(v4asdf_source_registry__directive);
 }
}
/* function definition for VALIDATE-SOURCE-REGISTRY-FORM                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5154validate_source_registry_form(cl_narg narg, cl_object v1asdf_source_registry__form, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2300]);
 {
  cl_object v2asdf_source_registry__location;
  ecl_va_list args; ecl_va_start(args,v1asdf_source_registry__form,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5154validate_source_registry_formkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2asdf_source_registry__location = keyvars[0];
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1464]))->cfun.entry(7, v1asdf_source_registry__form, VV[2301], VV[2288], ECL_SYM("LOCATION",1003), v2asdf_source_registry__location, VV[2198], VV[2260]) /*  VALIDATE-CONFIGURATION-FORM */;
  return value0;
 }
}
/* function definition for VALIDATE-SOURCE-REGISTRY-FILE                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5155validate_source_registry_file(cl_object v1asdf_source_registry__file)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1470]))->cfun.entry(4, v1asdf_source_registry__file, VV[2300], ECL_SYM("DESCRIPTION",992), VV[2304]) /*  VALIDATE-CONFIGURATION-FILE */;
 return value0;
}
static cl_object L5155validate_source_registry_file_va(cl_narg narg, cl_object v2asdf_source_registry__file, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2303]);
 {
  return L5155validate_source_registry_file(v2asdf_source_registry__file);
 }
}
/* function definition for VALIDATE-SOURCE-REGISTRY-DIRECTORY                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5156validate_source_registry_directory(cl_object v1directory)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1473]))->cfun.entry(5, v1directory, VV[2301], VV[2288], VV[2198], VV[2260]) /*  VALIDATE-CONFIGURATION-DIRECTORY */;
 return value0;
}
static cl_object L5156validate_source_registry_directory_va(cl_narg narg, cl_object v2directory, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2306]);
 {
  return L5156validate_source_registry_directory(v2directory);
 }
}
/* function definition for PARSE-SOURCE-REGISTRY-STRING                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5158parse_source_registry_string(cl_narg narg, cl_object v1string, ...)
{
 cl_object T0, T1, T2;
 volatile cl_object lex0[1];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2308]);
 {
  cl_object v2asdf_source_registry__location;
  ecl_va_list args; ecl_va_start(args,v1string,narg,1);
  lex0[0] = v1string;                             /*  STRING                  */
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5158parse_source_registry_stringkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2asdf_source_registry__location = keyvars[0];
  }
  if (lex0[0]==ECL_NIL) {
   goto L3;
  }
  if (!(ecl_equal(lex0[0],VV[96]))){
   goto L1;
  }
  goto L2;
L3:;
L2:;
  value0 = VV[2309];
  cl_env_copy->nvalues = 1;
  return value0;
L1:;
  if (ECL_STRINGP(lex0[0])) {
   goto L5;
  }
  value0 = cl_error(2, VV[2207], lex0[0]);
  return value0;
L5:;
  {
   cl_object v3;
   v3 = ECL_CODE_CHAR(ecl_char(lex0[0],(cl_fixnum)(0)));
   {
    cl_object v4;
    v4 = si_make_seq_iterator(2, VV[2310], ecl_make_int8_t(0));
L11:;
    if (v4!=ECL_NIL) {
     goto L13;
    }
    goto L7;
L13:;
    {
     cl_object v5;
     v5 = si_seq_iterator_ref(VV[2310], v4);
     if (!((ECL_CODE_CHAR(ECL_CHAR_CODE(v3))==(v5)))){
      goto L15;
     }
     if (Null(v5)){
      goto L7;
     }
     goto L8;
    }
L15:;
    v4 = si_seq_iterator_next(VV[2310], v4);
    goto L11;
   }
  }
L8:;
  T0 = cl_read_from_string(1, lex0[0]);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2300]))->cfun.entry(3, T0, ECL_SYM("LOCATION",1003), v2asdf_source_registry__location) /*  VALIDATE-SOURCE-REGISTRY-FORM */;
  return value0;
L7:;
  {
   cl_object v3asdf_source_registry__inherit;
   v3asdf_source_registry__inherit = ECL_NIL;
   {
    cl_object v4asdf_source_registry__directives;
    v4asdf_source_registry__directives = ECL_NIL;
    {
     cl_object v5asdf_source_registry__start;
     v5asdf_source_registry__start = ecl_make_int8_t(0);
     {
      cl_object v6asdf_source_registry__end;
      v6asdf_source_registry__end = ecl_make_fixnum(ecl_length(lex0[0]));
      {
       cl_object v7asdf_source_registry__separator;
       v7asdf_source_registry__separator = (cl_env_copy->function=ecl_fdefinition(VV[760]))->cfun.entry(0) /*  INTER-DIRECTORY-SEPARATOR */;
       {
        cl_object v8asdf_source_registry__pos;
        v8asdf_source_registry__pos = ECL_NIL;
L26:;
        v8asdf_source_registry__pos = cl_position(4, v7asdf_source_registry__separator, lex0[0], ECL_SYM("START",1347), v5asdf_source_registry__start);
        {
         cl_object v9asdf_source_registry__s;
         value0 = v8asdf_source_registry__pos;
         if (value0!=ECL_NIL) {
          goto L33;
         }
         T0 = v6asdf_source_registry__end;
         goto L31;
L33:;
         T0 = value0;
         goto L31;
L31:;
         v9asdf_source_registry__s = cl_subseq(3, lex0[0], v5asdf_source_registry__start, T0);
         if (!(ecl_equal(VV[96],v9asdf_source_registry__s))){
          goto L36;
         }
         if (Null(v3asdf_source_registry__inherit)){
          goto L38;
         }
         cl_error(2, VV[2208], lex0[0]);
L38:;
         v3asdf_source_registry__inherit = ECL_T;
         v4asdf_source_registry__directives = CONS(VV[2209],v4asdf_source_registry__directives);
         goto L35;
L36:;
         if (Null((cl_env_copy->function=ecl_fdefinition(VV[300]))->cfun.entry(2, v9asdf_source_registry__s, VV[2313]) /*  STRING-SUFFIX-P */)){
          goto L43;
         }
         {
          cl_fixnum v10;
          v10 = ecl_length(v9asdf_source_registry__s);
          T1 = ecl_minus(ecl_make_fixnum(v10),ecl_make_int8_t(2));
          T2 = cl_subseq(3, v9asdf_source_registry__s, ecl_make_int8_t(0), T1);
          T0 = LC5157check(lex0, T2);
         }
         T1 = cl_list(2, VV[2293], T0);
         v4asdf_source_registry__directives = CONS(T1,v4asdf_source_registry__directives);
         goto L35;
L43:;
         T0 = LC5157check(lex0, v9asdf_source_registry__s);
         T1 = cl_list(2, ECL_SYM("DIRECTORY",1250), T0);
         v4asdf_source_registry__directives = CONS(T1,v4asdf_source_registry__directives);
L35:;
         if (Null(v8asdf_source_registry__pos)){
          goto L49;
         }
         v5asdf_source_registry__start = ecl_one_plus(v8asdf_source_registry__pos);
         goto L29;
L49:;
         if (v3asdf_source_registry__inherit!=ECL_NIL) {
          goto L52;
         }
         v4asdf_source_registry__directives = CONS(VV[2314],v4asdf_source_registry__directives);
L52:;
         T0 = cl_nreverse(v4asdf_source_registry__directives);
         value0 = CONS(VV[2301],T0);
         cl_env_copy->nvalues = 1;
         return value0;
        }
L29:;
        goto L26;
       }
      }
     }
    }
   }
  }
 }
}
/* function definition for REGISTER-ASD-DIRECTORY                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5159register_asd_directory(cl_narg narg, cl_object v1directory, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2316]);
 {
  cl_object v2asdf_source_registry__recurse;
  cl_object v3asdf_source_registry__exclude;
  cl_object v4asdf_source_registry__collect;
  ecl_va_list args; ecl_va_start(args,v1directory,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L5159register_asd_directorykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2asdf_source_registry__recurse = keyvars[0];
   v3asdf_source_registry__exclude = keyvars[1];
   v4asdf_source_registry__collect = keyvars[2];
  }
  if (v2asdf_source_registry__recurse!=ECL_NIL) {
   goto L1;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2274]))->cfun.entry(2, v1directory, v4asdf_source_registry__collect) /*  COLLECT-ASDS-IN-DIRECTORY */;
  return value0;
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2283]))->cfun.entry(5, v1directory, VV[2296], v3asdf_source_registry__exclude, VV[2235], v4asdf_source_registry__collect) /*  COLLECT-SUB*DIRECTORIES-ASD-FILES */;
  return value0;
 }
}
/* function definition for %COMPUTE-DEFAULT-SOURCE-REGISTRIES-VALUE           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5160_compute_default_source_registries_value()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = VV[2319];
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5160_compute_default_source_registries_value_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2318]);
 {
  return L5160_compute_default_source_registries_value();
 }
}
/* function definition for WRAPPING-SOURCE-REGISTRY                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5161wrapping_source_registry()
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[775]))->cfun.entry(0) /*  LISP-IMPLEMENTATION-DIRECTORY */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[716]))->cfun.entry(1, T0) /*  RESOLVE-SYMLINKS* */;
 T2 = cl_list(2, VV[2293], T1);
 value0 = cl_list(3, VV[2301], T2, VV[2209]);
 return value0;
}
static cl_object L5161wrapping_source_registry_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2324]);
 {
  return L5161wrapping_source_registry();
 }
}
/* function definition for DEFAULT-USER-SOURCE-REGISTRY                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5162default_user_source_registry()
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1540]))->cfun.entry(1, VV[2328]) /*  XDG-DATA-HOME */;
 T1 = cl_list(2, ECL_SYM("DIRECTORY",1250), T0);
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[1540]))->cfun.entry(1, VV[2329]) /*  XDG-DATA-HOME */;
 T3 = cl_list(2, VV[2293], T2);
 value0 = cl_list(5, VV[2301], VV[2327], T1, T3, VV[2209]);
 return value0;
}
static cl_object L5162default_user_source_registry_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2326]);
 {
  return L5162default_user_source_registry();
 }
}
/* function definition for DEFAULT-SYSTEM-SOURCE-REGISTRY                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5163default_system_source_registry()
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  cl_object v2asdf_source_registry__dir;
  cl_object v3;
  {
   cl_object v4;
   v4 = (cl_env_copy->function=ecl_fdefinition(VV[1548]))->cfun.entry(1, VV[2332]) /*  XDG-DATA-DIRS */;
   if (ecl_unlikely(!ECL_LISTP(v4))) FEtype_error_list(v4);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v1 = v4;
  }
  v2asdf_source_registry__dir = ECL_NIL;
  v3 = v1;
  {
   cl_object v4;
   cl_object v5;
   v4 = ecl_list1(ECL_NIL);
   v5 = v4;
L10:;
   if (!(ecl_endp(v3))){
    goto L12;
   }
   goto L11;
L12:;
   v2asdf_source_registry__dir = ECL_CONS_CAR(v3);
   {
    cl_object v6;
    v6 = ECL_CONS_CDR(v3);
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v6;
   }
   {
    cl_object v6;
    v6 = v5;
    if (ecl_unlikely(ECL_ATOM(v6))) FEtype_error_cons(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T1 = v6;
   }
   T2 = cl_list(2, v2asdf_source_registry__dir, VV[2333]);
   T3 = cl_list(2, ECL_SYM("DIRECTORY",1250), T2);
   v5 = ecl_list1(T3);
   (ECL_CONS_CDR(T1)=v5,T1);
   {
    cl_object v6;
    v6 = v5;
    if (ecl_unlikely(ECL_ATOM(v6))) FEtype_error_cons(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T1 = v6;
   }
   T2 = cl_list(2, v2asdf_source_registry__dir, VV[2334]);
   T3 = cl_list(2, VV[2293], T2);
   v5 = ecl_list1(T3);
   (ECL_CONS_CDR(T1)=v5,T1);
   goto L10;
L11:;
   T0 = ecl_cdr(v4);
   goto L2;
  }
 }
L2:;
 T1 = ecl_append(T0,VV[1477]);
 value0 = CONS(VV[2301],T1);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5163default_system_source_registry_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2331]);
 {
  return L5163default_system_source_registry();
 }
}
/* function definition for USER-SOURCE-REGISTRY                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5164user_source_registry(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1asdf_source_registry__direction;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5164user_source_registrykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v1asdf_source_registry__direction = ECL_SYM("INPUT",1289);
   } else {
    v1asdf_source_registry__direction = keyvars[0];
   }
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1581]))->cfun.entry(2, ecl_cmp_symbol_value(cl_env_copy,VV[2322]), v1asdf_source_registry__direction) /*  XDG-CONFIG-PATHNAME */;
  return value0;
 }
}
/* function definition for SYSTEM-SOURCE-REGISTRY                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5165system_source_registry(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1asdf_source_registry__direction;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5165system_source_registrykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v1asdf_source_registry__direction = ECL_SYM("INPUT",1289);
   } else {
    v1asdf_source_registry__direction = keyvars[0];
   }
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1565]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[2322])) /*  SYSTEM-CONFIG-PATHNAMES */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1574]))->cfun.entry(3, T0, ECL_SYM("DIRECTION",1249), v1asdf_source_registry__direction) /*  FIND-PREFERRED-FILE */;
  return value0;
 }
}
/* function definition for USER-SOURCE-REGISTRY-DIRECTORY                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5166user_source_registry_directory(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1asdf_source_registry__direction;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5166user_source_registry_directorykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v1asdf_source_registry__direction = ECL_SYM("INPUT",1289);
   } else {
    v1asdf_source_registry__direction = keyvars[0];
   }
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1581]))->cfun.entry(2, ecl_cmp_symbol_value(cl_env_copy,VV[2323]), v1asdf_source_registry__direction) /*  XDG-CONFIG-PATHNAME */;
  return value0;
 }
}
/* function definition for SYSTEM-SOURCE-REGISTRY-DIRECTORY                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5167system_source_registry_directory(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1asdf_source_registry__direction;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5167system_source_registry_directorykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   if (Null(keyvars[1])) {
    v1asdf_source_registry__direction = ECL_SYM("INPUT",1289);
   } else {
    v1asdf_source_registry__direction = keyvars[0];
   }
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1565]))->cfun.entry(1, ecl_cmp_symbol_value(cl_env_copy,VV[2323])) /*  SYSTEM-CONFIG-PATHNAMES */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1574]))->cfun.entry(3, T0, ECL_SYM("DIRECTION",1249), v1asdf_source_registry__direction) /*  FIND-PREFERRED-FILE */;
  return value0;
 }
}
/* function definition for ENVIRONMENT-SOURCE-REGISTRY                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5168environment_source_registry()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[452]))->cfun.entry(1, VV[2345]) /*  GETENV */;
 return value0;
}
static cl_object L5168environment_source_registry_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2344]);
 {
  return L5168environment_source_registry();
 }
}
/* function definition for INHERIT-SOURCE-REGISTRY                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5169inherit_source_registry(cl_narg narg, cl_object v1asdf_source_registry__inherit, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2348]);
 {
  cl_object v2asdf_source_registry__register;
  ecl_va_list args; ecl_va_start(args,v1asdf_source_registry__inherit,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5169inherit_source_registrykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2asdf_source_registry__register = keyvars[0];
  }
  if (Null(v1asdf_source_registry__inherit)){
   goto L1;
  }
  T0 = ecl_car(v1asdf_source_registry__inherit);
  T1 = ecl_cdr(v1asdf_source_registry__inherit);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2347]))->cfun.entry(5, T0, VV[2349], v2asdf_source_registry__register, VV[2236], T1) /*  PROCESS-SOURCE-REGISTRY */;
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for PROCESS-SOURCE-REGISTRY-DIRECTIVE                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5170process_source_registry_directive(cl_narg narg, cl_object v1asdf_source_registry__directive, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2351]);
 {
  cl_object v2asdf_source_registry__inherit;
  cl_object v3asdf_source_registry__register;
  ecl_va_list args; ecl_va_start(args,v1asdf_source_registry__directive,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L5170process_source_registry_directivekeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2asdf_source_registry__inherit = keyvars[0];
   v3asdf_source_registry__register = keyvars[1];
  }
  {
   cl_object v4;
   cl_object v5;
   cl_object v6asdf_source_registry__kw;
   if (!(ECL_CONSP(v1asdf_source_registry__directive))){
    goto L3;
   }
   v4 = v1asdf_source_registry__directive;
   goto L2;
L3:;
   v4 = ecl_list1(v1asdf_source_registry__directive);
L2:;
   v5 = v4;
   if (!(v5==ECL_NIL)){
    goto L7;
   }
   si_dm_too_few_arguments(v4);
L7:;
   {
    cl_object v7;
    v7 = ecl_car(v5);
    v5 = ecl_cdr(v5);
    v6asdf_source_registry__kw = v7;
   }
   if (!((v6asdf_source_registry__kw)==(ECL_SYM("INCLUDE",1284)))){
    goto L12;
   }
   {
    cl_object v7;
    cl_object v8pathname;
    v7 = v5;
    if (!(v7==ECL_NIL)){
     goto L17;
    }
    si_dm_too_few_arguments(v5);
L17:;
    {
     cl_object v9;
     v9 = ecl_car(v7);
     v7 = ecl_cdr(v7);
     v8pathname = v9;
    }
    if (Null(v7)){
     goto L22;
    }
    si_dm_too_many_arguments(v5);
L22:;
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[1504]))->cfun.entry(1, v8pathname) /*  RESOLVE-LOCATION */;
    (cl_env_copy->function=ecl_fdefinition(VV[2347]))->cfun.entry(5, T0, VV[2236], ECL_NIL, VV[2349], v3asdf_source_registry__register) /*  PROCESS-SOURCE-REGISTRY */;
    goto L1;
   }
L12:;
   if (!((v6asdf_source_registry__kw)==(ECL_SYM("DIRECTORY",1250)))){
    goto L24;
   }
   {
    cl_object v9;
    cl_object v10pathname;
    v9 = v5;
    if (!(v9==ECL_NIL)){
     goto L29;
    }
    si_dm_too_few_arguments(v5);
L29:;
    {
     cl_object v11;
     v11 = ecl_car(v9);
     v9 = ecl_cdr(v9);
     v10pathname = v11;
    }
    if (Null(v9)){
     goto L34;
    }
    si_dm_too_many_arguments(v5);
L34:;
    if (Null(v10pathname)){
     goto L1;
    }
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[1504]))->cfun.entry(3, v10pathname, VV[595], ECL_T) /*  RESOLVE-LOCATION */;
    ecl_function_dispatch(cl_env_copy,v3asdf_source_registry__register)(1, T0);
    goto L1;
   }
L24:;
   if (!((v6asdf_source_registry__kw)==(VV[2293]))){
    goto L37;
   }
   {
    cl_object v11;
    cl_object v12pathname;
    v11 = v5;
    if (!(v11==ECL_NIL)){
     goto L42;
    }
    si_dm_too_few_arguments(v5);
L42:;
    {
     cl_object v13;
     v13 = ecl_car(v11);
     v11 = ecl_cdr(v11);
     v12pathname = v13;
    }
    if (Null(v11)){
     goto L47;
    }
    si_dm_too_many_arguments(v5);
L47:;
    if (Null(v12pathname)){
     goto L1;
    }
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[1504]))->cfun.entry(3, v12pathname, VV[595], ECL_T) /*  RESOLVE-LOCATION */;
    ecl_function_dispatch(cl_env_copy,v3asdf_source_registry__register)(5, T0, VV[2354], ECL_T, VV[2296], ecl_cmp_symbol_value(cl_env_copy,VV[2264]));
    goto L1;
   }
L37:;
   if (!((v6asdf_source_registry__kw)==(VV[2296]))){
    goto L50;
   }
   T0 = v5;
   ecl_cmp_setq(cl_env_copy,VV[2264],T0);
   goto L1;
L50:;
   if (!((v6asdf_source_registry__kw)==(VV[2297]))){
    goto L54;
   }
   T0 = ecl_append(ecl_cmp_symbol_value(cl_env_copy,VV[2264]),v5);
   ecl_cmp_setq(cl_env_copy,VV[2264],T0);
   goto L1;
L54:;
   if (!((v6asdf_source_registry__kw)==(VV[2290]))){
    goto L58;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[2348]))->cfun.entry(3, VV[2356], VV[2349], v3asdf_source_registry__register) /*  INHERIT-SOURCE-REGISTRY */;
   goto L1;
L58:;
   if (!((v6asdf_source_registry__kw)==(VV[2209]))){
    goto L61;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[2348]))->cfun.entry(3, v2asdf_source_registry__inherit, VV[2349], v3asdf_source_registry__register) /*  INHERIT-SOURCE-REGISTRY */;
   goto L1;
L61:;
   if (!((v6asdf_source_registry__kw)==(VV[2211]))){
    goto L66;
   }
   goto L1;
L66:;
   goto L64;
L64:;
   si_ecase_error(v6asdf_source_registry__kw, VV[2357]);
  }
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function PROCESS-SOURCE-REGISTRY                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5171process_source_registry(cl_narg narg, cl_object v1asdf_source_registry__x, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2347]);
 {
  cl_object v2asdf_source_registry__inherit;
  cl_object v3asdf_source_registry__register;
  ecl_va_list args; ecl_va_start(args,v1asdf_source_registry__x,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,LC5171process_source_registrykeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2asdf_source_registry__inherit = keyvars[0];
   v3asdf_source_registry__register = keyvars[1];
  }
  T0 = ecl_function_dispatch(cl_env_copy,v1asdf_source_registry__x)(0);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2347]))->cfun.entry(5, T0, VV[2236], v2asdf_source_registry__inherit, VV[2349], v3asdf_source_registry__register) /*  PROCESS-SOURCE-REGISTRY */;
  return value0;
 }
}
/* local function PROCESS-SOURCE-REGISTRY                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5172process_source_registry(cl_narg narg, cl_object v1pathname, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2347]);
 {
  cl_object v2asdf_source_registry__inherit;
  cl_object v3asdf_source_registry__register;
  ecl_va_list args; ecl_va_start(args,v1pathname,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,LC5172process_source_registrykeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2asdf_source_registry__inherit = keyvars[0];
   v3asdf_source_registry__register = keyvars[1];
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, v1pathname) /*  DIRECTORY-PATHNAME-P */)){
   goto L1;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[716]))->cfun.entry(1, v1pathname) /*  RESOLVE-SYMLINKS* */;
  ecl_bds_bind(cl_env_copy,VV[1495],T0);          /*  *HERE-DIRECTORY*        */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2306]))->cfun.entry(1, v1pathname) /*  VALIDATE-SOURCE-REGISTRY-DIRECTORY */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2347]))->cfun.entry(5, T0, VV[2236], v2asdf_source_registry__inherit, VV[2349], v3asdf_source_registry__register) /*  PROCESS-SOURCE-REGISTRY */;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L1:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[669]))->cfun.entry(3, v1pathname, VV[681], ecl_cmp_symbol_value(cl_env_copy,VV[715])) /*  PROBE-FILE* */)){
   goto L3;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[555]))->cfun.entry(1, v1pathname) /*  PATHNAME-DIRECTORY-PATHNAME */;
  ecl_bds_bind(cl_env_copy,VV[1495],T0);          /*  *HERE-DIRECTORY*        */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2303]))->cfun.entry(1, v1pathname) /*  VALIDATE-SOURCE-REGISTRY-FILE */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2347]))->cfun.entry(5, T0, VV[2236], v2asdf_source_registry__inherit, VV[2349], v3asdf_source_registry__register) /*  PROCESS-SOURCE-REGISTRY */;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
L3:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2348]))->cfun.entry(3, v2asdf_source_registry__inherit, VV[2349], v3asdf_source_registry__register) /*  INHERIT-SOURCE-REGISTRY */;
  return value0;
 }
}
/* local function PROCESS-SOURCE-REGISTRY                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5173process_source_registry(cl_narg narg, cl_object v1string, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2347]);
 {
  cl_object v2asdf_source_registry__inherit;
  cl_object v3asdf_source_registry__register;
  ecl_va_list args; ecl_va_start(args,v1string,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,LC5173process_source_registrykeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2asdf_source_registry__inherit = keyvars[0];
   v3asdf_source_registry__register = keyvars[1];
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2308]))->cfun.entry(1, v1string) /*  PARSE-SOURCE-REGISTRY-STRING */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2347]))->cfun.entry(5, T0, VV[2236], v2asdf_source_registry__inherit, VV[2349], v3asdf_source_registry__register) /*  PROCESS-SOURCE-REGISTRY */;
  return value0;
 }
}
/* local function PROCESS-SOURCE-REGISTRY                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5174process_source_registry(cl_narg narg, cl_object v1asdf_source_registry__x, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2347]);
 {
  cl_object v2asdf_source_registry__inherit;
  cl_object v3asdf_source_registry__register;
  ecl_va_list args; ecl_va_start(args,v1asdf_source_registry__x,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,LC5174process_source_registrykeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2asdf_source_registry__inherit = keyvars[0];
   v3asdf_source_registry__register = keyvars[1];
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2348]))->cfun.entry(3, v2asdf_source_registry__inherit, VV[2349], v3asdf_source_registry__register) /*  INHERIT-SOURCE-REGISTRY */;
  return value0;
 }
}
/* local function PROCESS-SOURCE-REGISTRY                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5175process_source_registry(cl_narg narg, cl_object v1asdf_source_registry__form, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2347]);
 {
  cl_object v2asdf_source_registry__inherit;
  cl_object v3asdf_source_registry__register;
  ecl_va_list args; ecl_va_start(args,v1asdf_source_registry__form,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,LC5175process_source_registrykeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2asdf_source_registry__inherit = keyvars[0];
   v3asdf_source_registry__register = keyvars[1];
  }
  ecl_bds_bind(cl_env_copy,VV[2264],ecl_cmp_symbol_value(cl_env_copy,VV[2263])); /*  *SOURCE-REGISTRY-EXCLUSIONS* */
  {
   cl_object v4;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[2300]))->cfun.entry(1, v1asdf_source_registry__form) /*  VALIDATE-SOURCE-REGISTRY-FORM */;
   v4 = ecl_cdr(T0);
   goto L4;
L3:;
   {
    cl_object v5asdf_source_registry__directive;
    v5asdf_source_registry__directive = ecl_car(v4);
    (cl_env_copy->function=ecl_fdefinition(VV[2351]))->cfun.entry(5, v5asdf_source_registry__directive, VV[2236], v2asdf_source_registry__inherit, VV[2349], v3asdf_source_registry__register) /*  PROCESS-SOURCE-REGISTRY-DIRECTIVE */;
   }
   v4 = ecl_cdr(v4);
L4:;
   if (Null(v4)){
    goto L11;
   }
   goto L3;
L11:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   ecl_bds_unwind1(cl_env_copy);
   return value0;
  }
 }
}
/* function definition for FLATTEN-SOURCE-REGISTRY                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5178flatten_source_registry(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[2359]);
 {
  cl_object v1asdf_source_registry__parameter;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1asdf_source_registry__parameter = ecl_cmp_symbol_value(cl_env_copy,VV[2266]);
   } else {
    i++;
    v1asdf_source_registry__parameter = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object env1 = env0;
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(ECL_NIL,env1);
   ecl_bds_bind(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34),ecl_cmp_symbol_value(cl_env_copy,VV[533])); /*  *DEFAULT-PATHNAME-DEFAULTS* */
   T1 = cl_listX(3, VV[2324], v1asdf_source_registry__parameter, ecl_cmp_symbol_value(cl_env_copy,VV[2321]));
   {
    cl_object v2;
    v2 = ecl_make_cclosure_va((cl_objectfn)LC5177__lambda7170,env1,Cblock,1);
    T2 = v2;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[2348]))->cfun.entry(3, T1, VV[2349], T2) /*  INHERIT-SOURCE-REGISTRY */;
   ecl_bds_unwind1(cl_env_copy);
   T0 = cl_reverse(ECL_CONS_CAR(CLV0));
  }
  value0 = cl_remove_duplicates(5, T0, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337), VV[91], ECL_T);
  return value0;
 }
}
/* function definition for COMPUTE-SOURCE-REGISTRY                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5180compute_source_registry(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[2363]);
 {
  cl_object v1asdf_source_registry__parameter;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1asdf_source_registry__parameter = ecl_cmp_symbol_value(cl_env_copy,VV[2266]);
   } else {
    i++;
    v1asdf_source_registry__parameter = va_arg(args,cl_object);
   }
   if (i >= narg) {
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(ecl_cmp_symbol_value(cl_env_copy,VV[2265]),env0); /*  REGISTRY */
   } else {
    i++;
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(va_arg(args,cl_object),env0); /*  REGISTRY             */
   }
  }
  va_end(args);
  {
   cl_object v2;
   v2 = (cl_env_copy->function=ecl_fdefinition(VV[2359]))->cfun.entry(1, v1asdf_source_registry__parameter) /*  FLATTEN-SOURCE-REGISTRY */;
   goto L6;
L5:;
   {
    cl_object v3asdf_source_registry__entry;
    v3asdf_source_registry__entry = ecl_car(v2);
    {
     cl_object v4;
     cl_object v5;
     cl_object v6;
     cl_object v7asdf_source_registry__exclude;
     cl_object env1 = env0;
     v4 = v3asdf_source_registry__entry;
     if (!(v4==ECL_NIL)){
      goto L12;
     }
     si_dm_too_few_arguments(v3asdf_source_registry__entry);
L12:;
     {
      cl_object v8;
      v8 = ecl_car(v4);
      v4 = ecl_cdr(v4);
      T0 = v8;
     }
     CLV1 = env1 = CONS(T0,env1);                 /*  DIRECTORY               */
     v5 = si_search_keyword(v4, VV[2354]);
     if (!((v5)==(ECL_SYM("MISSING-KEYWORD",2044)))){
      goto L20;
     }
     T0 = ECL_NIL;
     goto L19;
L20:;
     T0 = v5;
L19:;
     CLV2 = env1 = CONS(T0,env1);                 /*  RECURSE                 */
     v6 = si_search_keyword(v4, VV[2296]);
     if (!((v6)==(ECL_SYM("MISSING-KEYWORD",2044)))){
      goto L24;
     }
     v7asdf_source_registry__exclude = ECL_NIL;
     goto L23;
L24:;
     v7asdf_source_registry__exclude = v6;
L23:;
     si_check_keyword(2, v4, VV[2364]);
     {
      cl_object env2 = env1;
      T0 = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
      CLV3 = env2 = CONS(T0,env2);                /*  H                       */
      {
       cl_object v8;
       v8 = ecl_make_cclosure_va((cl_objectfn)LC5179__lambda7221,env2,Cblock,1);
       T0 = v8;
      }
      (cl_env_copy->function=ecl_fdefinition(VV[2316]))->cfun.entry(7, ECL_CONS_CAR(CLV1), VV[2354], ECL_CONS_CAR(CLV2), VV[2296], v7asdf_source_registry__exclude, VV[2235], T0) /*  REGISTER-ASD-DIRECTORY */;
     }
    }
   }
   v2 = ecl_cdr(v2);
L6:;
   if (Null(v2)){
    goto L31;
   }
   goto L5;
L31:;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
}
/* function definition for INITIALIZE-SOURCE-REGISTRY                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5181initialize_source_registry(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[2368]);
 {
  cl_object v1asdf_source_registry__parameter;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1asdf_source_registry__parameter = ecl_cmp_symbol_value(cl_env_copy,VV[2266]);
   } else {
    i++;
    v1asdf_source_registry__parameter = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = v1asdf_source_registry__parameter;
  ecl_cmp_setq(cl_env_copy,VV[2266],T0);
  T0 = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
  ecl_cmp_setq(cl_env_copy,VV[2265],T0);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2363]))->cfun.entry(1, v1asdf_source_registry__parameter) /*  COMPUTE-SOURCE-REGISTRY */;
  return value0;
 }
}
/* function definition for ENSURE-SOURCE-REGISTRY                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5182ensure_source_registry(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[2370]);
 {
  cl_object v1asdf_source_registry__parameter;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1asdf_source_registry__parameter = ECL_NIL;
   } else {
    i++;
    v1asdf_source_registry__parameter = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if ((cl_env_copy->function=ecl_fdefinition(VV[2267]))->cfun.entry(0) /*  SOURCE-REGISTRY-INITIALIZED-P */!=ECL_NIL) {
   goto L2;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[2368]))->cfun.entry(1, v1asdf_source_registry__parameter) /*  INITIALIZE-SOURCE-REGISTRY */;
L2:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
}
/* function definition for SYSDEF-SOURCE-REGISTRY-SEARCH                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5183sysdef_source_registry_search(cl_object v1asdf_source_registry__system)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[2370]))->cfun.entry(0) /*  ENSURE-SOURCE-REGISTRY */;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1756]))->cfun.entry(1, v1asdf_source_registry__system) /*  PRIMARY-SYSTEM-NAME */;
 value0 = ecl_gethash_safe(T0,ecl_cmp_symbol_value(cl_env_copy,VV[2265]),ECL_NIL);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5183sysdef_source_registry_search_va(cl_narg narg, cl_object v2asdf_source_registry__system, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2372]);
 {
  return L5183sysdef_source_registry_search(v2asdf_source_registry__system);
 }
}
/* function definition for DETERMINE-SYSTEM-DIRECTORY                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5185determine_system_directory(cl_object v1pathname)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = v1pathname;
  if (v2==ECL_NIL) {
   goto L4;
  }
  if (ECL_STRINGP(v2)) {
   goto L4;
  }
  if (cl_pathnamep(v2)!=ECL_NIL) {
   goto L4;
  }
  v1pathname = si_do_check_type(v2, VV[2375], ECL_NIL, ECL_SYM("PATHNAME",632));
L4:;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(3, v1pathname, ECL_SYM("TYPE",1356), ECL_SYM("DIRECTORY",1250)) /*  PARSE-UNIX-NAMESTRING */;
 {
  cl_object v2;
  v2 = ecl_make_cfun_va((cl_objectfn)LC5184__lambda7246_va,ECL_NIL,Cblock,0);
  T1 = v2;
 }
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[617]))->cfun.entry(3, T0, T1, ECL_NIL) /*  ENSURE-ABSOLUTE-PATHNAME */;
 T3 = (cl_env_copy->function=ecl_fdefinition(VV[716]))->cfun.entry(1, T2) /*  RESOLVE-SYMLINKS* */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[555]))->cfun.entry(1, T3) /*  PATHNAME-DIRECTORY-PATHNAME */;
 return value0;
}
static cl_object L5185determine_system_directory_va(cl_narg narg, cl_object v2pathname, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2374]);
 {
  return L5185determine_system_directory(v2pathname);
 }
}
/* function definition for CLASS-FOR-TYPE                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5186class_for_type(cl_object v1asdf_component_parent, cl_object v2type)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[361]))->cfun.entry(7, v2type, ECL_SYM("PACKAGE",1321), VV[1899], VV[1900], VV[1652], ECL_SYM("ERROR",1260), ECL_NIL) /*  COERCE-CLASS */;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 if (!((v2type)==(ECL_SYM("FILE",1269)))){
  goto L7;
 }
 {
  cl_object v3asdf_parse_defsystem__p;
  v3asdf_parse_defsystem__p = ECL_NIL;
  {
   cl_object v4;
   v4 = ECL_NIL;
   v3asdf_parse_defsystem__p = v1asdf_component_parent;
L15:;
   if (v3asdf_parse_defsystem__p!=ECL_NIL) {
    goto L19;
   }
   goto L16;
L19:;
   v4 = (cl_env_copy->function=ecl_fdefinition(VV[2380]))->cfun.entry(1, v3asdf_parse_defsystem__p) /*  MODULE-DEFAULT-COMPONENT-CLASS */;
   if (Null(v4)){
    goto L21;
   }
   value0 = v4;
   goto L12;
L21:;
   v3asdf_parse_defsystem__p = (cl_env_copy->function=ecl_fdefinition(VV[1644]))->cfun.entry(1, v3asdf_parse_defsystem__p) /*  COMPONENT-PARENT */;
   goto L15;
L16:;
   value0 = ECL_NIL;
  }
 }
L12:;
 if (value0!=ECL_NIL) {
  goto L11;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,VV[2378]);
 goto L9;
L11:;
 T0 = value0;
 goto L9;
L9:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[361]))->cfun.entry(7, T0, ECL_SYM("PACKAGE",1321), VV[1899], VV[1900], VV[1652], ECL_SYM("ERROR",1260), ECL_NIL) /*  COERCE-CLASS */;
 goto L5;
L7:;
 value0 = ECL_NIL;
 goto L5;
L5:;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1751]))->cfun.entry(2, VV[2381], v2type) /*  SYSDEF-ERROR */;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5186class_for_type_va(cl_narg narg, cl_object v3asdf_component_parent, cl_object v4type, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2379]);
 {
  return L5186class_for_type(v3asdf_component_parent, v4type);
 }
}
/* local function LAMBDA7252                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5188__lambda7252()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC5187__lambda7254_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC5188__lambda7252_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2384]);
 {
  return LC5188__lambda7252();
 }
}
/* local function LAMBDA7256                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5190__lambda7256()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC5189__lambda7258_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC5190__lambda7256_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2390]);
 {
  return LC5190__lambda7256();
 }
}
/* function definition for SYSDEF-ERROR-COMPONENT                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5191sysdef_error_component(cl_object v1asdf_parse_defsystem__msg, cl_object v2type, cl_object v3asdf_component_name, cl_object v4asdf_parse_defsystem__value)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[283]))->cfun.entry(2, v1asdf_parse_defsystem__msg, VV[2396]) /*  STRCAT */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1751]))->cfun.entry(4, T0, v2type, v3asdf_component_name, v4asdf_parse_defsystem__value) /*  SYSDEF-ERROR */;
 return value0;
}
static cl_object L5191sysdef_error_component_va(cl_narg narg, cl_object v5asdf_parse_defsystem__msg, cl_object v6type, cl_object v7asdf_component_name, cl_object v8asdf_parse_defsystem__value, ...)
{
 if (ecl_unlikely(narg!=4)) FEwrong_num_arguments(VV[2395]);
 {
  return L5191sysdef_error_component(v5asdf_parse_defsystem__msg, v6type, v7asdf_component_name, v8asdf_parse_defsystem__value);
 }
}
/* function definition for CHECK-COMPONENT-INPUT                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5192check_component_input(cl_object v1type, cl_object v2asdf_component_name, cl_object v3asdf_system__weakly_depends_on, cl_object v4asdf_system__depends_on, cl_object v5asdf_component_components)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (ECL_LISTP(v4asdf_system__depends_on)) {
  goto L2;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[2395]))->cfun.entry(4, VV[2399], v1type, v2asdf_component_name, v4asdf_system__depends_on) /*  SYSDEF-ERROR-COMPONENT */;
L2:;
 if (ECL_LISTP(v3asdf_system__weakly_depends_on)) {
  goto L4;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[2395]))->cfun.entry(4, VV[2400], v1type, v2asdf_component_name, v3asdf_system__weakly_depends_on) /*  SYSDEF-ERROR-COMPONENT */;
L4:;
 if (ECL_LISTP(v5asdf_component_components)) {
  goto L6;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2395]))->cfun.entry(4, VV[2401], v1type, v2asdf_component_name, v5asdf_component_components) /*  SYSDEF-ERROR-COMPONENT */;
 return value0;
L6:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5192check_component_input_va(cl_narg narg, cl_object v6type, cl_object v7asdf_component_name, cl_object v8asdf_system__weakly_depends_on, cl_object v9asdf_system__depends_on, cl_object v10asdf_component_components, ...)
{
 if (ecl_unlikely(narg!=5)) FEwrong_num_arguments(VV[2398]);
 {
  return L5192check_component_input(v6type, v7asdf_component_name, v8asdf_system__weakly_depends_on, v9asdf_system__depends_on, v10asdf_component_components);
 }
}
/* function definition for NORMALIZE-VERSION                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5195normalize_version(cl_narg narg, cl_object v1asdf_parse_defsystem__form, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2403]);
 {
  ecl_va_list args; ecl_va_start(args,v1asdf_parse_defsystem__form,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1asdf_parse_defsystem__form,env0); /*  FORM             */
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L5195normalize_versionkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   CLV1 = env0 = CONS(keyvars[0],env0);           /*  PATHNAME                */
   CLV2 = env0 = CONS(keyvars[1],env0);           /*  COMPONENT               */
   CLV3 = env0 = CONS(keyvars[2],env0);           /*  PARENT                  */
  }
  {
   cl_object v2;
   v2 = ecl_make_cclosure_va((cl_objectfn)LC5194invalid_parse,env0,Cblock,1);
   {
    cl_object v3asdf_parse_defsystem__v;
    if (ECL_STRINGP(ECL_CONS_CAR(CLV0))) {
     goto L4;
    }
    if (!(ECL_CONS_CAR(CLV0)==ECL_NIL)){
     goto L2;
    }
    goto L3;
L4:;
L3:;
    v3asdf_parse_defsystem__v = ECL_CONS_CAR(CLV0);
    goto L1;
L2:;
    if (Null(cl_realp(ECL_CONS_CAR(CLV0)))){
     goto L6;
    }
    (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC5193invalid(1, VV[2408]));
    v3asdf_parse_defsystem__v = cl_format(3, ECL_NIL, VV[2409], ECL_CONS_CAR(CLV0));
    goto L1;
L6:;
    if (!(ECL_CONSP(ECL_CONS_CAR(CLV0)))){
     goto L9;
    }
    {
     cl_object v4;
     v4 = ecl_car(ECL_CONS_CAR(CLV0));
     if (!((v4)==(VV[2411]))){
      goto L12;
     }
     {
      cl_object v5;
      cl_object v6;
      cl_object v7asdf_parse_defsystem__subpath;
      cl_object v8;
      cl_object v9asdf_parse_defsystem__at;
      v5 = ecl_cdr(ECL_CONS_CAR(CLV0));
      v6 = v5;
      if (!(v6==ECL_NIL)){
       goto L18;
      }
      si_dm_too_few_arguments(v5);
L18:;
      {
       cl_object v10;
       v10 = ecl_car(v6);
       v6 = ecl_cdr(v6);
       v7asdf_parse_defsystem__subpath = v10;
      }
      v8 = si_search_keyword(v6, VV[911]);
      if (!((v8)==(ECL_SYM("MISSING-KEYWORD",2044)))){
       goto L25;
      }
      v9asdf_parse_defsystem__at = ecl_make_int8_t(0);
      goto L24;
L25:;
      v9asdf_parse_defsystem__at = v8;
L24:;
      si_check_keyword(2, v6, VV[2412]);
      T0 = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(2, ECL_CONS_CAR(CLV1), v7asdf_parse_defsystem__subpath) /*  SUBPATHNAME */;
      v3asdf_parse_defsystem__v = (cl_env_copy->function=ecl_fdefinition(VV[922]))->cfun.entry(5, T0, VV[911], v9asdf_parse_defsystem__at, ECL_SYM("PACKAGE",1321), VV[1842]) /*  SAFE-READ-FILE-FORM */;
      goto L1;
     }
L12:;
     if (!((v4)==(VV[2414]))){
      goto L28;
     }
     {
      cl_object v10;
      cl_object v11;
      cl_object v12asdf_parse_defsystem__subpath;
      cl_object v13;
      cl_object v14asdf_parse_defsystem__at;
      v10 = ecl_cdr(ECL_CONS_CAR(CLV0));
      v11 = v10;
      if (!(v11==ECL_NIL)){
       goto L34;
      }
      si_dm_too_few_arguments(v10);
L34:;
      {
       cl_object v15;
       v15 = ecl_car(v11);
       v11 = ecl_cdr(v11);
       v12asdf_parse_defsystem__subpath = v15;
      }
      v13 = si_search_keyword(v11, VV[911]);
      if (!((v13)==(ECL_SYM("MISSING-KEYWORD",2044)))){
       goto L41;
      }
      v14asdf_parse_defsystem__at = ecl_make_int8_t(0);
      goto L40;
L41:;
      v14asdf_parse_defsystem__at = v13;
L40:;
      si_check_keyword(2, v11, VV[2412]);
      T0 = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(2, ECL_CONS_CAR(CLV1), v12asdf_parse_defsystem__subpath) /*  SUBPATHNAME */;
      v3asdf_parse_defsystem__v = (cl_env_copy->function=ecl_fdefinition(VV[919]))->cfun.entry(3, T0, VV[911], v14asdf_parse_defsystem__at) /*  SAFE-READ-FILE-LINE */;
      goto L1;
     }
L28:;
     v3asdf_parse_defsystem__v = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC5193invalid(0));
     goto L1;
    }
L9:;
    v3asdf_parse_defsystem__v = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC5193invalid(0));
L1:;
    if (Null(v3asdf_parse_defsystem__v)){
     goto L44;
    }
    {
     cl_object v4asdf_parse_defsystem__pv;
     v4asdf_parse_defsystem__pv = (cl_env_copy->function=ecl_fdefinition(VV[374]))->cfun.entry(2, v3asdf_parse_defsystem__v, v2) /*  PARSE-VERSION */;
     if (Null(v4asdf_parse_defsystem__pv)){
      goto L47;
     }
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[371]))->cfun.entry(1, v4asdf_parse_defsystem__pv) /*  UNPARSE-VERSION */;
     return value0;
L47:;
     value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC5193invalid(0));
     return value0;
    }
L44:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for %COMPUTE-+ASDF-METHODS+-VALUE                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5196_compute__asdf_methods__value()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = VV[2417];
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5196_compute__asdf_methods__value_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2416]);
 {
  return L5196_compute__asdf_methods__value();
 }
}
/* function definition for %REMOVE-COMPONENT-INLINE-METHODS                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5198_remove_component_inline_methods(cl_object v1asdf_component_component)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = ecl_cmp_symbol_value(cl_env_copy,VV[2419]);
  goto L6;
L5:;
  {
   cl_object env1 = env0;
   T0 = ecl_car(v2);
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(T0,env1);                   /*  NAME                    */
   {
    cl_object v3;
    v3 = ecl_make_cclosure_va((cl_objectfn)LC5197__lambda7317,env1,Cblock,1);
    T0 = v3;
   }
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[2422]))->cfun.entry(1, v1asdf_component_component) /*  COMPONENT-INLINE-METHODS */;
   cl_map(3, ECL_NIL, T0, T1);
  }
  v2 = ecl_cdr(v2);
L6:;
  if (Null(v2)){
   goto L13;
  }
  goto L5;
L13:;
 }
 (cl_env_copy->function=ecl_fdefinition(VV[2422]))->cfun.entry(1, v1asdf_component_component) /*  COMPONENT-INLINE-METHODS */;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5198_remove_component_inline_methods_va(cl_narg narg, cl_object v2asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2420]);
 {
  return L5198_remove_component_inline_methods(v2asdf_component_component);
 }
}
/* function definition for %DEFINE-COMPONENT-INLINE-METHODS                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5199_define_component_inline_methods(cl_object v1asdf_parse_defsystem__ret, cl_object v2rest)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4asdf_parse_defsystem__key;
  cl_object v5asdf_parse_defsystem__value;
  v3 = v2rest;
  v4asdf_parse_defsystem__key = ECL_NIL;
  v5asdf_parse_defsystem__value = ECL_NIL;
  {
   cl_object v6asdf_component_name;
   v6asdf_component_name = ECL_NIL;
L6:;
   if (!(ECL_ATOM(v3))){
    goto L8;
   }
   goto L7;
L8:;
   {
    cl_object v7;
    v7 = v3;
    v4asdf_parse_defsystem__key = ecl_car(v7);
    v7 = ecl_cdr(v7);
    v5asdf_parse_defsystem__value = ecl_car(v7);
   }
   v3 = ecl_cddr(v3);
   if (Null(cl_keywordp(v4asdf_parse_defsystem__key))){
    goto L22;
   }
   {
    cl_object v7;
    v7 = ecl_cmp_symbol_value(cl_env_copy,VV[2419]);
    {
     cl_object v8;
     v8 = si_make_seq_iterator(2, v7, ecl_make_int8_t(0));
L26:;
     if (v8!=ECL_NIL) {
      goto L28;
     }
     v6asdf_component_name = ECL_NIL;
     goto L20;
L28:;
     {
      cl_object v9;
      v9 = si_seq_iterator_ref(v7, v8);
      if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("STRING=",825))(2, v4asdf_parse_defsystem__key, v9))){
       goto L30;
      }
      v6asdf_component_name = v9;
      goto L20;
     }
L30:;
     v8 = si_seq_iterator_next(v7, v8);
     goto L26;
    }
   }
L22:;
   v6asdf_component_name = ECL_NIL;
   goto L20;
L20:;
   if (Null(v6asdf_component_name)){
    goto L35;
   }
   {
    cl_object v7;
    cl_object v8asdf_parse_defsystem__op;
    cl_object v9asdf_parse_defsystem__body;
    v7 = v5asdf_parse_defsystem__value;
    if (!(v7==ECL_NIL)){
     goto L39;
    }
    si_dm_too_few_arguments(v5asdf_parse_defsystem__value);
L39:;
    {
     cl_object v10;
     v10 = ecl_car(v7);
     v7 = ecl_cdr(v7);
     v8asdf_parse_defsystem__op = v10;
    }
    v9asdf_parse_defsystem__body = v7;
    {
     cl_object v10asdf_parse_defsystem__arg;
     v10asdf_parse_defsystem__arg = ECL_NIL;
     {
      cl_object v11;
      cl_object v12;
      cl_object v13asdf_parse_defsystem__qualifiers;
      v11 = ecl_list1(ECL_NIL);
      v12 = v11;
      v13asdf_parse_defsystem__qualifiers = ECL_NIL;
L49:;
      {
       cl_object v14;
       v14 = v9asdf_parse_defsystem__body;
       {
        cl_object v15;
        v15 = v14;
        {
         bool v16;
         v16 = ECL_LISTP(v15);
         if (ecl_unlikely(!(v16)))
         FEwrong_type_argument(VV[508],v15);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
        }
       }
       if (Null(v14)){
        goto L57;
       }
       {
        cl_object v15;
        v15 = ECL_CONS_CDR(v14);
        v9asdf_parse_defsystem__body = v15;
        v14 = ECL_CONS_CAR(v14);
       }
L57:;
       v10asdf_parse_defsystem__arg = v14;
      }
      if (ECL_ATOM(v10asdf_parse_defsystem__arg)) {
       goto L63;
      }
      goto L50;
L63:;
      {
       cl_object v14;
       v14 = v12;
       if (ecl_unlikely(ECL_ATOM(v14))) FEtype_error_cons(v14);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T0 = v14;
      }
      v12 = ecl_list1(v10asdf_parse_defsystem__arg);
      (ECL_CONS_CDR(T0)=v12,T0);
      v13asdf_parse_defsystem__qualifiers = ecl_cdr(v11);
      goto L49;
L50:;
      {
       cl_object v14;
       cl_object v15asdf_parse_defsystem__o;
       cl_object v16asdf_parse_defsystem__c;
       v14 = v10asdf_parse_defsystem__arg;
       if (!(v14==ECL_NIL)){
        goto L76;
       }
       si_dm_too_few_arguments(v10asdf_parse_defsystem__arg);
L76:;
       {
        cl_object v17;
        v17 = ecl_car(v14);
        v14 = ecl_cdr(v14);
        v15asdf_parse_defsystem__o = v17;
       }
       if (!(v14==ECL_NIL)){
        goto L82;
       }
       si_dm_too_few_arguments(v10asdf_parse_defsystem__arg);
L82:;
       {
        cl_object v17;
        v17 = ecl_car(v14);
        v14 = ecl_cdr(v14);
        v16asdf_parse_defsystem__c = v17;
       }
       if (Null(v14)){
        goto L87;
       }
       si_dm_too_many_arguments(v10asdf_parse_defsystem__arg);
L87:;
       {
        cl_object v17;
        cl_object v18;
        T0 = cl_list(2, v15asdf_parse_defsystem__o, v8asdf_parse_defsystem__op);
        T1 = cl_list(2, ECL_SYM("EQL",336), v1asdf_parse_defsystem__ret);
        T2 = cl_list(2, v16asdf_parse_defsystem__c, T1);
        T3 = cl_list(2, T0, T2);
        T4 = CONS(T3,v9asdf_parse_defsystem__body);
        T5 = ecl_append(v13asdf_parse_defsystem__qualifiers,T4);
        T6 = cl_listX(3, ECL_SYM("DEFMETHOD",944), v6asdf_component_name, T5);
        v17 = cl_eval(T6);
        T0 = (cl_env_copy->function=ecl_fdefinition(VV[2422]))->cfun.entry(1, v1asdf_parse_defsystem__ret) /*  COMPONENT-INLINE-METHODS */;
        v18 = cl_adjoin(2, v17, T0);
        (cl_env_copy->function=ecl_fdefinition(VV[2425]))->cfun.entry(2, v18, v1asdf_parse_defsystem__ret) /*  (SETF COMPONENT-INLINE-METHODS) */;
       }
      }
     }
    }
   }
L35:;
   goto L6;
L7:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L5199_define_component_inline_methods_va(cl_narg narg, cl_object v7asdf_parse_defsystem__ret, cl_object v8rest, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2424]);
 {
  return L5199_define_component_inline_methods(v7asdf_parse_defsystem__ret, v8rest);
 }
}
/* function definition for %REFRESH-COMPONENT-INLINE-METHODS                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5200_refresh_component_inline_methods(cl_object v1asdf_component_component, cl_object v2rest)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 (cl_env_copy->function=ecl_fdefinition(VV[2420]))->cfun.entry(1, v1asdf_component_component) /*  %REMOVE-COMPONENT-INLINE-METHODS */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2424]))->cfun.entry(2, v1asdf_component_component, v2rest) /*  %DEFINE-COMPONENT-INLINE-METHODS */;
 return value0;
}
static cl_object L5200_refresh_component_inline_methods_va(cl_narg narg, cl_object v3asdf_component_component, cl_object v4rest, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2427]);
 {
  return L5200_refresh_component_inline_methods(v3asdf_component_component, v4rest);
 }
}
/* function definition for PARSE-DEPENDENCY-DEF                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5201parse_dependency_def(cl_object v1asdf_parse_defsystem__dd)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(v1asdf_parse_defsystem__dd))){
  goto L2;
 }
 {
  cl_object v2;
  v2 = ecl_car(v1asdf_parse_defsystem__dd);
  if (!((v2)==(VV[1888]))){
   goto L5;
  }
  {
   cl_fixnum v3;
   v3 = ecl_length(v1asdf_parse_defsystem__dd);
   if ((v3)==((cl_fixnum)(3))) {
    goto L7;
   }
  }
  (cl_env_copy->function=ecl_fdefinition(VV[1751]))->cfun.entry(2, VV[2430], v1asdf_parse_defsystem__dd) /*  SYSDEF-ERROR */;
L7:;
  {
   cl_object v3asdf_parse_defsystem__embedded;
   T0 = ecl_caddr(v1asdf_parse_defsystem__dd);
   v3asdf_parse_defsystem__embedded = (cl_env_copy->function=ecl_fdefinition(VV[2429]))->cfun.entry(1, T0) /*  PARSE-DEPENDENCY-DEF */;
   T0 = ecl_cadr(v1asdf_parse_defsystem__dd);
   value0 = cl_list(3, VV[1888], T0, v3asdf_parse_defsystem__embedded);
   return value0;
  }
L5:;
  if (!((v2)==(VV[2431]))){
   goto L10;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1751]))->cfun.entry(2, VV[2432], v1asdf_parse_defsystem__dd) /*  SYSDEF-ERROR */;
  return value0;
L10:;
  if (!((v2)==(VV[2163]))){
   goto L12;
  }
  {
   cl_fixnum v4;
   v4 = ecl_length(v1asdf_parse_defsystem__dd);
   if ((v4)==((cl_fixnum)(2))) {
    goto L14;
   }
  }
  (cl_env_copy->function=ecl_fdefinition(VV[1751]))->cfun.entry(2, VV[2433], v1asdf_parse_defsystem__dd) /*  SYSDEF-ERROR */;
L14:;
  value0 = v1asdf_parse_defsystem__dd;
  cl_env_copy->nvalues = 1;
  return value0;
L12:;
  if (!((v2)==(ECL_SYM("VERSION",1364)))){
   goto L16;
  }
  {
   cl_fixnum v4;
   v4 = ecl_length(v1asdf_parse_defsystem__dd);
   if ((v4)==((cl_fixnum)(3))) {
    goto L18;
   }
  }
  (cl_env_copy->function=ecl_fdefinition(VV[1751]))->cfun.entry(2, VV[2434], v1asdf_parse_defsystem__dd) /*  SYSDEF-ERROR */;
L18:;
  T0 = ecl_cadr(v1asdf_parse_defsystem__dd);
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, T0) /*  COERCE-NAME */;
  T2 = ecl_caddr(v1asdf_parse_defsystem__dd);
  value0 = cl_list(3, ECL_SYM("VERSION",1364), T1, T2);
  return value0;
L16:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1751]))->cfun.entry(2, VV[2435], v1asdf_parse_defsystem__dd) /*  SYSDEF-ERROR */;
  return value0;
 }
L2:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_parse_defsystem__dd) /*  COERCE-NAME */;
 return value0;
}
static cl_object L5201parse_dependency_def_va(cl_narg narg, cl_object v4asdf_parse_defsystem__dd, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2429]);
 {
  return L5201parse_dependency_def(v4asdf_parse_defsystem__dd);
 }
}
/* function definition for PARSE-DEPENDENCY-DEFS                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5202parse_dependency_defs(cl_object v1asdf_parse_defsystem__dd_list)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  {
   cl_object v5;
   v5 = v1asdf_parse_defsystem__dd_list;
   if (ecl_unlikely(!ECL_LISTP(v5))) FEtype_error_list(v5);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v2 = v5;
  }
  v3 = ECL_NIL;
  v4 = v2;
  {
   cl_object v5;
   cl_object v6;
   v5 = ecl_list1(ECL_NIL);
   v6 = v5;
L9:;
   if (!(ecl_endp(v4))){
    goto L11;
   }
   goto L10;
L11:;
   v3 = ECL_CONS_CAR(v4);
   {
    cl_object v7;
    v7 = ECL_CONS_CDR(v4);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   {
    cl_object v7;
    v7 = v6;
    if (ecl_unlikely(ECL_ATOM(v7))) FEtype_error_cons(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T0 = v7;
   }
   T1 = ecl_function_dispatch(cl_env_copy,VV[2429])(1, v3);
   v6 = ecl_list1(T1);
   (ECL_CONS_CDR(T0)=v6,T0);
   goto L9;
L10:;
   value0 = ecl_cdr(v5);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L5202parse_dependency_defs_va(cl_narg narg, cl_object v7asdf_parse_defsystem__dd_list, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2437]);
 {
  return L5202parse_dependency_defs(v7asdf_parse_defsystem__dd_list);
 }
}
/* function definition for PARSE-COMPONENT-FORM                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5204parse_component_form(cl_narg narg, cl_object v1asdf_component_parent, cl_object v2asdf_parse_defsystem__options, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2439]);
 {
  cl_object v3asdf_parse_defsystem__previous_serial_component;
  ecl_va_list args; ecl_va_start(args,v2asdf_parse_defsystem__options,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,L5204parse_component_formkeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v3asdf_parse_defsystem__previous_serial_component = keyvars[0];
  }
  {
   cl_object v4;
   cl_object v5type;
   cl_object v6asdf_component_name;
   cl_object v7;
   cl_object v8asdf_system_builtin_system_p;
   cl_object v9asdf_parse_defsystem__bspp;
   cl_object v10;
   cl_object v11asdf_component_components;
   cl_object v12;
   cl_object v13pathname;
   cl_object v14;
   cl_object v15asdf_action_perform;
   cl_object v16;
   cl_object v17asdf_action_explain;
   cl_object v18;
   cl_object v19asdf_action_output_files;
   cl_object v20;
   cl_object v21asdf_action_operation_done_p;
   cl_object v22;
   cl_object v23asdf_system__weakly_depends_on;
   cl_object v24;
   cl_object v25asdf_system__depends_on;
   cl_object v26;
   cl_object v27asdf_parse_defsystem__serial;
   cl_object v28;
   cl_object v29asdf_parse_defsystem__do_first;
   cl_object v30;
   cl_object v31asdf_parse_defsystem__if_component_dep_fails;
   cl_object v32;
   cl_object v33asdf_component_version;
   v4 = v2asdf_parse_defsystem__options;
   if (!(v4==ECL_NIL)){
    goto L3;
   }
   si_dm_too_few_arguments(v2asdf_parse_defsystem__options);
L3:;
   {
    cl_object v34;
    v34 = ecl_car(v4);
    v4 = ecl_cdr(v4);
    v5type = v34;
   }
   if (!(v4==ECL_NIL)){
    goto L9;
   }
   si_dm_too_few_arguments(v2asdf_parse_defsystem__options);
L9:;
   {
    cl_object v34;
    v34 = ecl_car(v4);
    v4 = ecl_cdr(v4);
    v6asdf_component_name = v34;
   }
   v7 = si_search_keyword(v4, VV[2440]);
   if (!((v7)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L16;
   }
   v8asdf_system_builtin_system_p = ECL_NIL;
   goto L15;
L16:;
   v8asdf_system_builtin_system_p = v7;
L15:;
   {
    bool v34;
    v34 = (v7)==(ECL_SYM("MISSING-KEYWORD",2044));
    v9asdf_parse_defsystem__bspp = (v34)?ECL_NIL:ECL_T;
   }
   v10 = si_search_keyword(v4, VV[2441]);
   if (!((v10)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L21;
   }
   v11asdf_component_components = ECL_NIL;
   goto L20;
L21:;
   v11asdf_component_components = v10;
L20:;
   v12 = si_search_keyword(v4, ECL_SYM("PATHNAME",1322));
   if (!((v12)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L25;
   }
   v13pathname = ECL_NIL;
   goto L24;
L25:;
   v13pathname = v12;
L24:;
   v14 = si_search_keyword(v4, VV[2442]);
   if (!((v14)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L29;
   }
   v15asdf_action_perform = ECL_NIL;
   goto L28;
L29:;
   v15asdf_action_perform = v14;
L28:;
   v16 = si_search_keyword(v4, VV[2443]);
   if (!((v16)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L33;
   }
   v17asdf_action_explain = ECL_NIL;
   goto L32;
L33:;
   v17asdf_action_explain = v16;
L32:;
   v18 = si_search_keyword(v4, VV[2444]);
   if (!((v18)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L37;
   }
   v19asdf_action_output_files = ECL_NIL;
   goto L36;
L37:;
   v19asdf_action_output_files = v18;
L36:;
   v20 = si_search_keyword(v4, VV[2445]);
   if (!((v20)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L41;
   }
   v21asdf_action_operation_done_p = ECL_NIL;
   goto L40;
L41:;
   v21asdf_action_operation_done_p = v20;
L40:;
   v22 = si_search_keyword(v4, VV[2446]);
   if (!((v22)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L45;
   }
   v23asdf_system__weakly_depends_on = ECL_NIL;
   goto L44;
L45:;
   v23asdf_system__weakly_depends_on = v22;
L44:;
   v24 = si_search_keyword(v4, VV[2447]);
   if (!((v24)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L49;
   }
   v25asdf_system__depends_on = ECL_NIL;
   goto L48;
L49:;
   v25asdf_system__depends_on = v24;
L48:;
   v26 = si_search_keyword(v4, VV[2448]);
   if (!((v26)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L53;
   }
   v27asdf_parse_defsystem__serial = ECL_NIL;
   goto L52;
L53:;
   v27asdf_parse_defsystem__serial = v26;
L52:;
   v28 = si_search_keyword(v4, VV[2449]);
   if (!((v28)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L57;
   }
   v29asdf_parse_defsystem__do_first = ECL_NIL;
   goto L56;
L57:;
   v29asdf_parse_defsystem__do_first = v28;
L56:;
   v30 = si_search_keyword(v4, VV[2450]);
   if (!((v30)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L61;
   }
   v31asdf_parse_defsystem__if_component_dep_fails = ECL_NIL;
   goto L60;
L61:;
   v31asdf_parse_defsystem__if_component_dep_fails = v30;
L60:;
   v32 = si_search_keyword(v4, ECL_SYM("VERSION",1364));
   if (!((v32)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L65;
   }
   v33asdf_component_version = ECL_NIL;
   goto L64;
L65:;
   v33asdf_component_version = v32;
L64:;
   si_check_keyword(3, v4, VV[2451], ECL_T);
   (cl_env_copy->function=ecl_fdefinition(VV[2398]))->cfun.entry(5, v5type, v6asdf_component_name, v23asdf_system__weakly_depends_on, v25asdf_system__depends_on, v11asdf_component_components) /*  CHECK-COMPONENT-INPUT */;
   if (Null(v1asdf_component_parent)){
    goto L69;
   }
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, v1asdf_component_parent, v6asdf_component_name) /*  FIND-COMPONENT */)){
    goto L69;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, v1asdf_component_parent, v6asdf_component_name) /*  FIND-COMPONENT */;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[2379]))->cfun.entry(2, v1asdf_component_parent, v5type) /*  CLASS-FOR-TYPE */;
   if (cl_typep(2, T0, T1)!=ECL_NIL) {
    goto L69;
   }
   cl_error(3, VV[1647], ECL_SYM("NAME",1309), v6asdf_component_name);
L69:;
   if (Null(v29asdf_parse_defsystem__do_first)){
    goto L73;
   }
   cl_error(1, VV[2452]);
L73:;
   {
    cl_object v34asdf_component_name;
    cl_object v35asdf_parse_defsystem__args;
    cl_object v36asdf_component_component;
    cl_object v37class;
    v34asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v6asdf_component_name) /*  COERCE-NAME */;
    if (Null(v1asdf_component_parent)){
     goto L78;
    }
    T0 = cl_list(2, VV[2453], v1asdf_component_parent);
    goto L77;
L78:;
    T0 = ECL_NIL;
L77:;
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[261]))->cfun.entry(2, VV[2454], v4) /*  REMOVE-PLIST-KEYS */;
    T2 = ecl_append(T0,T1);
    v35asdf_parse_defsystem__args = cl_listX(5, ECL_SYM("NAME",1309), v34asdf_component_name, ECL_SYM("PATHNAME",1322), v13pathname, T2);
    v36asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, v1asdf_component_parent, v34asdf_component_name) /*  FIND-COMPONENT */;
    v37class = (cl_env_copy->function=ecl_fdefinition(VV[2379]))->cfun.entry(2, v1asdf_component_parent, v5type) /*  CLASS-FOR-TYPE */;
    if (Null(v1asdf_component_parent)){
     goto L82;
    }
    if (Null(cl_subtypep(2, v37class, VV[1695]))){
     goto L82;
    }
    cl_error(5, VV[2389], VV[2453], v1asdf_component_parent, ECL_SYM("NAME",1309), v34asdf_component_name);
L82:;
    if (Null(v36asdf_component_component)){
     goto L86;
    }
    cl_apply(3, ECL_SYM("REINITIALIZE-INSTANCE",967), v36asdf_component_component, v35asdf_parse_defsystem__args);
    goto L85;
L86:;
    v36asdf_component_component = cl_apply(3, ECL_SYM("MAKE-INSTANCE",953), v37class, v35asdf_parse_defsystem__args);
L85:;
    (cl_env_copy->function=ecl_fdefinition(VV[1638]))->cfun.entry(1, v36asdf_component_component) /*  COMPONENT-PATHNAME */;
    if (Null(si_of_class_p(2, v36asdf_component_component, VV[1695]))){
     goto L90;
    }
    {
     cl_object v38;
     v38 = (cl_env_copy->function=ecl_fdefinition(VV[2437]))->cfun.entry(1, v25asdf_system__depends_on) /*  PARSE-DEPENDENCY-DEFS */;
     (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v38, v36asdf_component_component, VV[2455]) /*  (SETF SLOT-VALUE) */;
    }
    {
     cl_object v38;
     {
      cl_object v39;
      cl_object v40;
      cl_object v41;
      {
       cl_object v42;
       v42 = v23asdf_system__weakly_depends_on;
       if (ecl_unlikely(!ECL_LISTP(v42))) FEtype_error_list(v42);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v39 = v42;
      }
      v40 = ECL_NIL;
      v41 = v39;
      {
       cl_object v42;
       cl_object v43;
       v42 = ecl_list1(ECL_NIL);
       v43 = v42;
L102:;
       if (!(ecl_endp(v41))){
        goto L104;
       }
       goto L103;
L104:;
       v40 = ECL_CONS_CAR(v41);
       {
        cl_object v44;
        v44 = ECL_CONS_CDR(v41);
        if (ecl_unlikely(!ECL_LISTP(v44))) FEtype_error_list(v44);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v41 = v44;
       }
       {
        cl_object v44;
        v44 = v43;
        if (ecl_unlikely(ECL_ATOM(v44))) FEtype_error_cons(v44);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T0 = v44;
       }
       T1 = ecl_function_dispatch(cl_env_copy,VV[1753])(1, v40);
       v43 = ecl_list1(T1);
       (ECL_CONS_CDR(T0)=v43,T0);
       goto L102;
L103:;
       v38 = ecl_cdr(v42);
       goto L94;
      }
     }
L94:;
     (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v38, v36asdf_component_component, VV[2456]) /*  (SETF SLOT-VALUE) */;
    }
L90:;
    {
     cl_object v38asdf_parse_defsystem__sysfile;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[1637]))->cfun.entry(1, v36asdf_component_component) /*  COMPONENT-SYSTEM */;
     v38asdf_parse_defsystem__sysfile = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, T0) /*  SYSTEM-SOURCE-FILE */;
     if (Null(si_of_class_p(2, v36asdf_component_component, VV[1695]))){
      goto L122;
     }
     if (v9asdf_parse_defsystem__bspp!=ECL_NIL) {
      goto L122;
     }
     {
      cl_object v39;
      v39 = (cl_env_copy->function=ecl_fdefinition(VV[778]))->cfun.entry(1, v38asdf_parse_defsystem__sysfile) /*  LISP-IMPLEMENTATION-PATHNAME-P */;
      (cl_env_copy->function=ecl_fdefinition(VV[2457]))->cfun.entry(2, v39, v36asdf_component_component) /*  (SETF BUILTIN-SYSTEM-P) */;
     }
L122:;
     v33asdf_component_version = (cl_env_copy->function=ecl_fdefinition(VV[2403]))->cfun.entry(7, v33asdf_component_version, VV[2458], v34asdf_component_name, VV[2453], v1asdf_component_parent, ECL_SYM("PATHNAME",1322), v38asdf_parse_defsystem__sysfile) /*  NORMALIZE-VERSION */;
    }
    (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v33asdf_component_version, v36asdf_component_component, VV[1683]) /*  (SETF SLOT-VALUE) */;
    if (Null(si_of_class_p(2, v36asdf_component_component, VV[1667]))){
     goto L128;
    }
    {
     cl_object v38;
     {
      cl_object v39asdf_parse_defsystem__previous_component;
      v39asdf_parse_defsystem__previous_component = ECL_NIL;
      {
       cl_object v40;
       cl_object v41asdf_parse_defsystem__c_form;
       cl_object v42;
       {
        cl_object v43;
        v43 = v11asdf_component_components;
        if (ecl_unlikely(!ECL_LISTP(v43))) FEtype_error_list(v43);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v40 = v43;
       }
       v41asdf_parse_defsystem__c_form = ECL_NIL;
       v42 = v40;
       {
        cl_object v43asdf_parse_defsystem__c;
        v43asdf_parse_defsystem__c = ECL_NIL;
        {
         cl_object v44asdf_component_name;
         v44asdf_component_name = ECL_NIL;
         {
          cl_object v45;
          cl_object v46;
          v45 = ecl_list1(ECL_NIL);
          v46 = v45;
L142:;
          if (!(ecl_endp(v42))){
          goto L144;
          }
          goto L143;
L144:;
          v41asdf_parse_defsystem__c_form = ECL_CONS_CAR(v42);
          {
          cl_object v47;
          v47 = ECL_CONS_CDR(v42);
          if (ecl_unlikely(!ECL_LISTP(v47))) FEtype_error_list(v47);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          v42 = v47;
          }
          v43asdf_parse_defsystem__c = (cl_env_copy->function=ecl_fdefinition(VV[2439]))->cfun.entry(4, v36asdf_component_component, v41asdf_parse_defsystem__c_form, VV[2459], v39asdf_parse_defsystem__previous_component) /*  PARSE-COMPONENT-FORM */;
          v44asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1636]))->cfun.entry(1, v43asdf_parse_defsystem__c) /*  COMPONENT-NAME */;
          {
          cl_object v47;
          v47 = v46;
          if (ecl_unlikely(ECL_ATOM(v47))) FEtype_error_cons(v47);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T0 = v47;
          }
          v46 = ecl_list1(v43asdf_parse_defsystem__c);
          (ECL_CONS_CDR(T0)=v46,T0);
          if (Null(v27asdf_parse_defsystem__serial)){
          goto L161;
          }
          v39asdf_parse_defsystem__previous_component = v44asdf_component_name;
L161:;
          goto L142;
L143:;
          v38 = ecl_cdr(v45);
          goto L131;
         }
        }
       }
      }
     }
L131:;
     (cl_env_copy->function=ecl_fdefinition(VV[2460]))->cfun.entry(2, v38, v36asdf_component_component) /*  (SETF COMPONENT-CHILDREN) */;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[1668]))->cfun.entry(1, v36asdf_component_component) /*  COMPUTE-CHILDREN-BY-NAME */;
L128:;
    if (Null(v3asdf_parse_defsystem__previous_serial_component)){
     goto L166;
    }
    v25asdf_system__depends_on = CONS(v3asdf_parse_defsystem__previous_serial_component,v25asdf_system__depends_on);
L166:;
    if (Null(v23asdf_system__weakly_depends_on)){
     goto L169;
    }
    {
     cl_object v38;
     {
      cl_object v39;
      v39 = ecl_make_cfun_va((cl_objectfn)LC5203__lambda7563_va,ECL_NIL,Cblock,1);
      T0 = v39;
     }
     T1 = cl_complement(T0);
     v38 = cl_remove_if(2, T1, v23asdf_system__weakly_depends_on);
     v25asdf_system__depends_on = ecl_append(v25asdf_system__depends_on,v38);
    }
L169:;
    (cl_env_copy->function=ecl_fdefinition(VV[2462]))->cfun.entry(2, v25asdf_system__depends_on, v36asdf_component_component) /*  (SETF COMPONENT-SIDEWAY-DEPENDENCIES) */;
    (cl_env_copy->function=ecl_fdefinition(VV[2427]))->cfun.entry(2, v36asdf_component_component, v4) /*  %REFRESH-COMPONENT-INLINE-METHODS */;
    if (Null(v31asdf_parse_defsystem__if_component_dep_fails)){
     goto L176;
    }
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[1637]))->cfun.entry(1, v36asdf_component_component) /*  COMPONENT-SYSTEM */;
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, T0) /*  COERCE-NAME */;
    cl_error(2, VV[2463], T1);
L176:;
    value0 = v36asdf_component_component;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for REGISTER-SYSTEM-DEFINITION                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5206register_system_definition(cl_narg narg, cl_object v1asdf_component_name, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2465]);
 {
  cl_object v2asdf_parse_defsystem__options;
  ecl_va_list args; ecl_va_start(args,v1asdf_component_name,narg,1);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1asdf_component_name,env0); /*  NAME                    */
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L5206register_system_definitionkeys,keyvars,(cl_object*)&v2asdf_parse_defsystem__options,TRUE);
   CLV1 = env0 = CONS(v2asdf_parse_defsystem__options,env0); /*  OPTIONS      */
   ecl_va_end(args);
   CLV2 = env0 = CONS(keyvars[0],env0);           /*  PATHNAME                */
   if (Null(keyvars[5])) {
    CLV3 = env0 = CONS(VV[1695],env0);            /*  CLASS                   */
   } else {
    CLV3 = env0 = CONS(keyvars[1],env0);          /*  CLASS                   */
   }
   CLV4 = env0 = CONS(keyvars[2],env0);           /*  SOURCE-FILE             */
   CLV5 = env0 = CONS(keyvars[6],env0);           /*  SFP                     */
   CLV6 = env0 = CONS(keyvars[3],env0);           /*  DEFSYSTEM-DEPENDS-ON    */
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC5205__lambda7576,env0,Cblock,0);
   T0 = v3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1712]))->cfun.entry(5, T0, VV[1401], ECL_NIL, ECL_SYM("KEY",1297), ECL_NIL) /*  CALL-WITH-ASDF-CACHE */;
  return value0;
 }
}
/* local function DEFSYSTEM                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5207defsystem(cl_object v1, cl_object v2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4asdf_component_name;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4asdf_component_name = v5;
  }
  T0 = cl_list(2, ECL_SYM("QUOTE",682), v4asdf_component_name);
  T1 = cl_list(2, ECL_SYM("QUOTE",682), v3);
  value0 = cl_list(4, ECL_SYM("APPLY",91), VV[2473], T0, T1);
  return value0;
 }
}
static cl_object LC5207defsystem_va(cl_narg narg, cl_object v5, cl_object v6, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2472]);
 {
  return LC5207defsystem(v5, v6);
 }
}
/* local function PROLOGUE-CODE                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5208prologue_code(cl_object v1asdf_bundle__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5208prologue_code_va(cl_narg narg, cl_object v2asdf_bundle__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2479]);
 {
  return LC5208prologue_code(v2asdf_bundle__x);
 }
}
/* local function EPILOGUE-CODE                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5209epilogue_code(cl_object v1asdf_bundle__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5209epilogue_code_va(cl_narg narg, cl_object v2asdf_bundle__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2480]);
 {
  return LC5209epilogue_code(v2asdf_bundle__x);
 }
}
/* local function NO-UIOP                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5210no_uiop(cl_object v1asdf_bundle__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5210no_uiop_va(cl_narg narg, cl_object v2asdf_bundle__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2481]);
 {
  return LC5210no_uiop(v2asdf_bundle__x);
 }
}
/* local function PREFIX-LISP-OBJECT-FILES                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5211prefix_lisp_object_files(cl_object v1asdf_bundle__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5211prefix_lisp_object_files_va(cl_narg narg, cl_object v2asdf_bundle__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2482]);
 {
  return LC5211prefix_lisp_object_files(v2asdf_bundle__x);
 }
}
/* local function POSTFIX-LISP-OBJECT-FILES                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5212postfix_lisp_object_files(cl_object v1asdf_bundle__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5212postfix_lisp_object_files_va(cl_narg narg, cl_object v2asdf_bundle__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2483]);
 {
  return LC5212postfix_lisp_object_files(v2asdf_bundle__x);
 }
}
/* local function EXTRA-OBJECT-FILES                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5213extra_object_files(cl_object v1asdf_bundle__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5213extra_object_files_va(cl_narg narg, cl_object v2asdf_bundle__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2484]);
 {
  return LC5213extra_object_files(v2asdf_bundle__x);
 }
}
/* local function EXTRA-BUILD-ARGS                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5214extra_build_args(cl_object v1asdf_bundle__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5214extra_build_args_va(cl_narg narg, cl_object v2asdf_bundle__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2485]);
 {
  return LC5214extra_build_args(v2asdf_bundle__x);
 }
}
/* function definition for OPERATION-MONOLITHIC-P                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5215operation_monolithic_p(cl_object v1asdf_bundle__op)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = si_of_class_p(2, v1asdf_bundle__op, VV[2476]);
 return value0;
}
static cl_object L5215operation_monolithic_p_va(cl_narg narg, cl_object v2asdf_bundle__op, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2488]);
 {
  return L5215operation_monolithic_p(v2asdf_bundle__op);
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5218component_depends_on(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__s)
{
 cl_object T0, T1;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 {
  cl_object v3asdf_bundle__mono;
  cl_object v4go;
  cl_object v5asdf_bundle__bundle_p;
  cl_object v6asdf_bundle__component_type;
  cl_object v7asdf_bundle__keep_component;
  cl_object v8asdf_bundle__deps;
  v3asdf_bundle__mono = (cl_env_copy->function=ecl_fdefinition(VV[2488]))->cfun.entry(1, v1asdf_bundle__o) /*  OPERATION-MONOLITHIC-P */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2487]))->cfun.entry(1, v1asdf_bundle__o) /*  GATHER-OP */;
  if (value0!=ECL_NIL) {
   goto L10;
  }
  T0 = VV[2000];
  goto L8;
L10:;
  T0 = value0;
  goto L8;
L8:;
  v4go = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, T0) /*  MAKE-OPERATION */;
  v5asdf_bundle__bundle_p = si_of_class_p(2, v4go, VV[2475]);
  if (Null(v3asdf_bundle__mono)){
   goto L14;
  }
  if (Null(v5asdf_bundle__bundle_p)){
   goto L16;
  }
  v6asdf_bundle__component_type = VV[1695];
  goto L13;
L16:;
  v6asdf_bundle__component_type = ECL_T;
  goto L13;
L14:;
  v6asdf_bundle__component_type = VV[2490];
L13:;
  if (Null(v5asdf_bundle__bundle_p)){
   goto L19;
  }
  v7asdf_bundle__keep_component = VV[1695];
  goto L18;
L19:;
  v7asdf_bundle__keep_component = VV[2490];
L18:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1902]))->cfun.entry(2, v1asdf_bundle__o, VV[1999]) /*  FIND-OPERATION */;
  v8asdf_bundle__deps = (cl_env_copy->function=ecl_fdefinition(VV[1911]))->cfun.entry(11, v2asdf_bundle__s, VV[2491], v3asdf_bundle__mono, VV[2492], v6asdf_bundle__component_type, VV[2493], v7asdf_bundle__keep_component, VV[2130], T0, VV[2494], VV[1997]) /*  REQUIRED-COMPONENTS */;
  T0 = CONS(v4go,v8asdf_bundle__deps);
  T1 = LC5216call_next_method(0, lex0);
  value0 = CONS(T0,T1);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC5218component_depends_on_va(cl_narg narg, cl_object v9asdf_bundle__o, cl_object v10asdf_bundle__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC5218component_depends_on(v9asdf_bundle__o, v10asdf_bundle__s);
 }
}
/* function definition for BUNDLE-PATHNAME-TYPE                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5219bundle_pathname_type(cl_object v1bundle_type)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (v1bundle_type==ECL_NIL) {
  goto L4;
 }
 if (!(ECL_STRINGP(v1bundle_type))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = v1bundle_type;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (Null(cl_typep(2, v1bundle_type, VV[2510]))){
  goto L6;
 }
 value0 = cl_error(1, VV[2511]);
 return value0;
L6:;
 if (Null(cl_typep(2, v1bundle_type, VV[2512]))){
  goto L8;
 }
 value0 = VV[2513];
 cl_env_copy->nvalues = 1;
 return value0;
L8:;
 if (!((v1bundle_type)==(VV[1066]))){
  goto L10;
 }
 value0 = VV[2514];
 cl_env_copy->nvalues = 1;
 return value0;
L10:;
 if (Null(cl_typep(2, v1bundle_type, VV[2515]))){
  goto L13;
 }
 value0 = VV[2516];
 cl_env_copy->nvalues = 1;
 return value0;
L13:;
 if (!((v1bundle_type)==(VV[2518]))){
  goto L20;
 }
 goto L17;
L20:;
 goto L18;
L18:;
 if (!((v1bundle_type)==(VV[2519]))){
  goto L15;
 }
 goto L16;
L17:;
L16:;
 value0 = VV[2521];
 cl_env_copy->nvalues = 1;
 return value0;
L15:;
 if (!((v1bundle_type)==(VV[2523]))){
  goto L28;
 }
 goto L25;
L28:;
 goto L26;
L26:;
 if (!((v1bundle_type)==(VV[2524]))){
  goto L23;
 }
 goto L24;
L25:;
L24:;
 value0 = VV[2526];
 cl_env_copy->nvalues = 1;
 return value0;
L23:;
 if (Null(cl_typep(2, v1bundle_type, VV[2527]))){
  goto L31;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L31:;
 value0 = si_etypecase_error(v1bundle_type, VV[2528]);
 return value0;
}
static cl_object L5219bundle_pathname_type_va(cl_narg narg, cl_object v2bundle_type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2509]);
 {
  return L5219bundle_pathname_type(v2bundle_type);
 }
}
/* function definition for BUNDLE-OUTPUT-FILES                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5220bundle_output_files(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3bundle_type;
  v3bundle_type = (cl_env_copy->function=ecl_fdefinition(VV[2531]))->cfun.entry(1, v1asdf_bundle__o) /*  BUNDLE-TYPE */;
  if ((v3bundle_type)==(VV[2532])) {
   goto L3;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, v1asdf_bundle__o, v2asdf_bundle__c) /*  INPUT-FILES */;
  if (!(T0==ECL_NIL)){
   goto L7;
  }
  if (!((v3bundle_type)==(VV[1066]))){
   goto L12;
  }
  goto L9;
L12:;
  goto L10;
L10:;
  if (!((v3bundle_type)==(VV[1067]))){
   goto L3;
  }
  goto L4;
L9:;
  goto L4;
L7:;
  goto L4;
L4:;
  {
   cl_object v4;
   cl_object v5;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1692]))->cfun.entry(1, v2asdf_bundle__c) /*  COMPONENT-BUILD-PATHNAME */;
   if (value0!=ECL_NIL) {
    goto L17;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1636]))->cfun.entry(1, v2asdf_bundle__c) /*  COMPONENT-NAME */;
   T1 = cl_slot_value(v1asdf_bundle__o, VV[2535]);
   v4 = cl_format(4, ECL_NIL, VV[2534], T0, T1);
   goto L15;
L17:;
   v4 = value0;
   goto L15;
L15:;
   v5 = (cl_env_copy->function=ecl_fdefinition(VV[2509]))->cfun.entry(1, v3bundle_type) /*  BUNDLE-PATHNAME-TYPE */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1638]))->cfun.entry(1, v2asdf_bundle__c) /*  COMPONENT-PATHNAME */;
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(4, T0, v4, ECL_SYM("TYPE",1356), v5) /*  SUBPATHNAME */;
   T2 = ecl_list1(T1);
   T3 = cl_class_of(v1asdf_bundle__o);
   T4 = (cl_env_copy->function=ecl_fdefinition(VV[2140]))->cfun.entry(1, v2asdf_bundle__c) /*  COMPONENT-BUILD-OPERATION */;
   T5 = (cl_env_copy->function=ecl_fdefinition(VV[361]))->cfun.entry(7, T4, ECL_SYM("PACKAGE",1321), VV[1899], VV[1900], VV[1889], ECL_SYM("ERROR",1260), ECL_NIL) /*  COERCE-CLASS */;
   {
    bool v6;
    v6 = (T3)==(T5);
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = ecl_make_bool(v6);
    cl_env_copy->values[0] = T2;
    return cl_env_copy->values[0];
   }
  }
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L5220bundle_output_files_va(cl_narg narg, cl_object v6asdf_bundle__o, cl_object v7asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2530]);
 {
  return L5220bundle_output_files(v6asdf_bundle__o, v7asdf_bundle__c);
 }
}
/* local function OUTPUT-FILES                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5221output_files(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2530]))->cfun.entry(2, v1asdf_bundle__o, v2asdf_bundle__c) /*  BUNDLE-OUTPUT-FILES */;
 return value0;
}
static cl_object LC5221output_files_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1962]);
 {
  return LC5221output_files(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function INITIALIZE-INSTANCE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5222initialize_instance(cl_narg narg, cl_object v1asdf_bundle__instance, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("INITIALIZE-INSTANCE",951));
 {
  cl_object v2name_suffix;
  cl_object v3asdf_bundle__name_suffix_p;
  ecl_va_list args; ecl_va_start(args,v1asdf_bundle__instance,narg,1);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC5222initialize_instancekeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   v2name_suffix = keyvars[0];
   v3asdf_bundle__name_suffix_p = keyvars[1];
  }
  if (v3asdf_bundle__name_suffix_p!=ECL_NIL) {
   goto L1;
  }
  {
   cl_object v4;
   if (si_of_class_p(2, v1asdf_bundle__instance, VV[2508])!=ECL_NIL) {
    goto L4;
   }
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[2488]))->cfun.entry(1, v1asdf_bundle__instance) /*  OPERATION-MONOLITHIC-P */)){
    goto L6;
   }
   v4 = VV[2540];
   goto L3;
L6:;
   v4 = ECL_NIL;
   goto L3;
L4:;
   v4 = ECL_NIL;
L3:;
   (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v4, v1asdf_bundle__instance, VV[2535]) /*  (SETF SLOT-VALUE) */;
  }
L1:;
  if (Null(si_of_class_p(2, v1asdf_bundle__instance, VV[2477]))){
   goto L8;
  }
  {
   cl_object v4;
   cl_object v5;
   cl_object v6asdf_bundle__lisp_files;
   cl_object v7;
   cl_object v8prologue_code;
   cl_object v9;
   cl_object v10epilogue_code;
   v4 = (cl_env_copy->function=ecl_fdefinition(VV[1891]))->cfun.entry(1, v1asdf_bundle__instance) /*  OPERATION-ORIGINAL-INITARGS */;
   v5 = si_search_keyword(v4, VV[1075]);
   if (!((v5)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L13;
   }
   v6asdf_bundle__lisp_files = ECL_NIL;
   goto L12;
L13:;
   v6asdf_bundle__lisp_files = v5;
L12:;
   v7 = si_search_keyword(v4, VV[1077]);
   if (!((v7)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L17;
   }
   v8prologue_code = ECL_NIL;
   goto L16;
L17:;
   v8prologue_code = v7;
L16:;
   v9 = si_search_keyword(v4, VV[1078]);
   if (!((v9)==(ECL_SYM("MISSING-KEYWORD",2044)))){
    goto L21;
   }
   v10epilogue_code = ECL_NIL;
   goto L20;
L21:;
   v10epilogue_code = v9;
L20:;
   si_check_keyword(3, v4, VV[2541], ECL_T);
   (cl_env_copy->function=ecl_fdefinition(VV[2542]))->cfun.entry(2, v8prologue_code, v1asdf_bundle__instance) /*  (SETF PROLOGUE-CODE) */;
   (cl_env_copy->function=ecl_fdefinition(VV[2543]))->cfun.entry(2, v10epilogue_code, v1asdf_bundle__instance) /*  (SETF EPILOGUE-CODE) */;
   (cl_env_copy->function=ecl_fdefinition(VV[2544]))->cfun.entry(2, v6asdf_bundle__lisp_files, v1asdf_bundle__instance) /*  (SETF EXTRA-OBJECT-FILES) */;
  }
L8:;
  {
   cl_object v4;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1891]))->cfun.entry(1, v1asdf_bundle__instance) /*  OPERATION-ORIGINAL-INITARGS */;
   v4 = (cl_env_copy->function=ecl_fdefinition(VV[261]))->cfun.entry(2, VV[2545], T0) /*  REMOVE-PLIST-KEYS */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[2546]))->cfun.entry(2, v4, v1asdf_bundle__instance) /*  (SETF EXTRA-BUILD-ARGS) */;
   return value0;
  }
 }
}
/* function definition for USER-SYSTEM-P                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5223user_system_p(cl_object v1asdf_bundle__s)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_of_class_p(2, v1asdf_bundle__s, VV[1695]))){
  goto L3;
 }
 if ((cl_env_copy->function=ecl_fdefinition(VV[2024]))->cfun.entry(1, v1asdf_bundle__s) /*  BUILTIN-SYSTEM-P */!=ECL_NIL) {
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2547]))->cfun.entry(1, v1asdf_bundle__s) /*  TRIVIAL-SYSTEM-P */;
 value0 = Null(T0)?ECL_T:ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5223user_system_p_va(cl_narg narg, cl_object v2asdf_bundle__s, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2548]);
 {
  return L5223user_system_p(v2asdf_bundle__s);
 }
}
/* function definition for DIRECT-DEPENDENCY-FILES                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5226direct_dependency_files(cl_narg narg, cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2551]);
 {
  ecl_va_list args; ecl_va_start(args,v2asdf_bundle__c,narg,2);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,L5226direct_dependency_fileskeys,keyvars,NULL,TRUE);
   ecl_va_end(args);
   if (Null(keyvars[2])) {
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(ECL_SYM("IDENTITY",428),env0); /*  TEST                */
   } else {
    env0 = ECL_NIL;
    CLV0 = env0 = CONS(keyvars[0],env0);          /*  TEST                    */
   }
   if (Null(keyvars[3])) {
    CLV1 = env0 = CONS(VV[1962],env0);            /*  KEY                     */
   } else {
    CLV1 = env0 = CONS(keyvars[1],env0);          /*  KEY                     */
   }
  }
  {
   cl_object env1 = env0;
   CLV2 = env1 = CONS(ECL_NIL,env1);
   {
    cl_object v3;
    v3 = ecl_make_cclosure_va((cl_objectfn)LC5225__lambda7749,env1,Cblock,2);
    T0 = v3;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[2080]))->cfun.entry(4, ECL_T, v1asdf_bundle__o, v2asdf_bundle__c, T0) /*  MAP-DIRECT-DEPENDENCIES */;
   value0 = cl_reverse(ECL_CONS_CAR(CLV2));
   return value0;
  }
 }
}
/* function definition for PATHNAME-TYPE-EQUAL-FUNCTION                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5228pathname_type_equal_function(cl_object v1type)
{
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1type,env0);                 /*  TYPE                    */
 {
  cl_object v2;
  v2 = ecl_make_cclosure_va((cl_objectfn)LC5227__lambda7755,env0,Cblock,1);
  value0 = v2;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L5228pathname_type_equal_function_va(cl_narg narg, cl_object v3type, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2555]);
 {
  return L5228pathname_type_equal_function(v3type);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5229input_files(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2531]))->cfun.entry(1, v1asdf_bundle__o) /*  BUNDLE-TYPE */;
 if ((T0)==(VV[2532])) {
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2558]))->cfun.entry(1, v1asdf_bundle__o) /*  GATHER-TYPE */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[2509]))->cfun.entry(1, T0) /*  BUNDLE-PATHNAME-TYPE */;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[2555]))->cfun.entry(1, T1) /*  PATHNAME-TYPE-EQUAL-FUNCTION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2551]))->cfun.entry(6, v1asdf_bundle__o, v2asdf_bundle__c, ECL_SYM("KEY",1297), VV[1962], ECL_SYM("TEST",1353), T2) /*  DIRECT-DEPENDENCY-FILES */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5229input_files_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC5229input_files(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* function definition for SELECT-BUNDLE-OPERATION                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5230select_bundle_operation(cl_narg narg, cl_object v1type, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2559]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[2559]);
 {
  cl_object v2asdf_bundle__monolithic;
  va_list args; va_start(args,v1type);
  {
   int i = 1;
   if (i >= narg) {
    v2asdf_bundle__monolithic = ECL_NIL;
   } else {
    i++;
    v2asdf_bundle__monolithic = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (!((v1type)==(VV[2523]))){
   goto L7;
  }
  goto L4;
L7:;
  goto L5;
L5:;
  if (!((v1type)==(VV[2524]))){
   goto L2;
  }
  goto L3;
L4:;
L3:;
  if (Null(v2asdf_bundle__monolithic)){
   goto L10;
  }
  value0 = VV[2506];
  cl_env_copy->nvalues = 1;
  return value0;
L10:;
  value0 = VV[2500];
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  if (!((v1type)==(VV[2518]))){
   goto L17;
  }
  goto L14;
L17:;
  goto L15;
L15:;
  if (!((v1type)==(VV[2519]))){
   goto L12;
  }
  goto L13;
L14:;
L13:;
  if (Null(v2asdf_bundle__monolithic)){
   goto L20;
  }
  value0 = VV[2505];
  cl_env_copy->nvalues = 1;
  return value0;
L20:;
  value0 = VV[2497];
  cl_env_copy->nvalues = 1;
  return value0;
L12:;
  if (!((v1type)==(VV[2023]))){
   goto L22;
  }
  if (Null(v2asdf_bundle__monolithic)){
   goto L25;
  }
  value0 = VV[2503];
  cl_env_copy->nvalues = 1;
  return value0;
L25:;
  value0 = VV[2498];
  cl_env_copy->nvalues = 1;
  return value0;
L22:;
  if (!((v1type)==(VV[1066]))){
   goto L27;
  }
  value0 = VV[2507];
  cl_env_copy->nvalues = 1;
  return value0;
L27:;
  if (!((v1type)==(VV[1067]))){
   goto L30;
  }
  value0 = VV[2508];
  cl_env_copy->nvalues = 1;
  return value0;
L30:;
  value0 = si_ecase_error(v1type, VV[2561]);
  return value0;
 }
}
/* function definition for MAKE-BUILD                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5232make_build(volatile cl_narg narg, cl_object volatile v1asdf_system_system, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2563]);
 {
  cl_object volatile v2asdf_bundle__args;
  cl_object volatile v3asdf_bundle__monolithic;
  cl_object volatile v4type;
  cl_object volatile v5asdf_bundle__move_here;
  cl_object volatile v6asdf_bundle__move_here_p;
  cl_object volatile v7asdf_bundle__init_name;
  ecl_va_list args; ecl_va_start(args,v1asdf_system_system,narg,1);
  {
   cl_object keyvars[8];
   cl_parse_key(args,4,L5232make_buildkeys,keyvars,(cl_object*)&v2asdf_bundle__args,TRUE);
   ecl_va_end(args);
   v3asdf_bundle__monolithic = keyvars[0];
   if (Null(keyvars[5])) {
    v4type = VV[2023];
   } else {
    v4type = keyvars[1];
   }
   v5asdf_bundle__move_here = keyvars[2];
   v6asdf_bundle__move_here_p = keyvars[6];
   v7asdf_bundle__init_name = keyvars[3];
  }
  {
   volatile cl_object v8asdf_bundle__operation_name;
   volatile cl_object v9asdf_bundle__move_here_path;
   volatile cl_object v10asdf_operation_operation;
   volatile cl_object v11asdf_system_system;
   volatile cl_object v12asdf_bundle__files;
   v8asdf_bundle__operation_name = (cl_env_copy->function=ecl_fdefinition(VV[2559]))->cfun.entry(2, v4type, v3asdf_bundle__monolithic) /*  SELECT-BUNDLE-OPERATION */;
   if (Null(v5asdf_bundle__move_here)){
    goto L4;
   }
   if (cl_pathnamep(v5asdf_bundle__move_here)!=ECL_NIL) {
    goto L7;
   }
   if (!(ECL_STRINGP(v5asdf_bundle__move_here))){
    goto L4;
   }
   goto L5;
L7:;
L5:;
   v9asdf_bundle__move_here_path = (cl_env_copy->function=ecl_fdefinition(VV[596]))->cfun.entry(5, v5asdf_bundle__move_here, VV[672], VV[673], VV[595], ECL_T) /*  ENSURE-PATHNAME */;
   goto L3;
L4:;
   v9asdf_bundle__move_here_path = (cl_env_copy->function=ecl_fdefinition(VV[1700]))->cfun.entry(2, v1asdf_system_system, VV[2564]) /*  SYSTEM-RELATIVE-PATHNAME */;
L3:;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[261]))->cfun.entry(2, VV[2565], v2asdf_bundle__args) /*  REMOVE-PLIST-KEYS */;
   v10asdf_operation_operation = cl_apply(4, VV[2131], v8asdf_bundle__operation_name, v1asdf_system_system, T0);
   v11asdf_system_system = (cl_env_copy->function=ecl_fdefinition(VV[1690]))->cfun.entry(1, v1asdf_system_system) /*  FIND-SYSTEM */;
   if (Null(v11asdf_system_system)){
    goto L13;
   }
   v12asdf_bundle__files = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, v10asdf_operation_operation, v11asdf_system_system) /*  OUTPUT-FILES */;
   goto L11;
L13:;
   v12asdf_bundle__files = ECL_NIL;
   goto L11;
L11:;
   if (v5asdf_bundle__move_here!=ECL_NIL) {
    goto L17;
   }
   if (!(v6asdf_bundle__move_here_p==ECL_NIL)){
    goto L15;
   }
   if (!((v8asdf_bundle__operation_name)==(VV[1067]))){
    goto L23;
   }
   goto L20;
L23:;
   goto L21;
L21:;
   if (!((v8asdf_bundle__operation_name)==(VV[1066]))){
    goto L15;
   }
   goto L16;
L20:;
   goto L16;
L17:;
L16:;
   {
    volatile cl_object v13asdf_bundle__dest_path;
    T0 = cl_ensure_directories_exist(1, v9asdf_bundle__move_here_path);
    v13asdf_bundle__dest_path = (cl_env_copy->function=ecl_fdefinition(VV[716]))->cfun.entry(1, T0) /*  RESOLVE-SYMLINKS* */;
    {
     volatile cl_object v14;
     volatile cl_object v15asdf_bundle__f;
     volatile cl_object v16;
     {
      cl_object v17;
      v17 = v12asdf_bundle__files;
      if (ecl_unlikely(!ECL_LISTP(v17))) FEtype_error_list(v17);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v14 = v17;
     }
     v15asdf_bundle__f = ECL_NIL;
     v16 = v14;
     {
      volatile cl_object v17asdf_bundle__new_f;
      v17asdf_bundle__new_f = ECL_NIL;
      {
       volatile cl_object v18;
       volatile cl_object v19;
       v18 = ecl_list1(ECL_NIL);
       v19 = v18;
L35:;
       if (!(ecl_endp(v16))){
        goto L37;
       }
       goto L36;
L37:;
       v15asdf_bundle__f = ECL_CONS_CAR(v16);
       {
        cl_object v20;
        v20 = ECL_CONS_CDR(v16);
        if (ecl_unlikely(!ECL_LISTP(v20))) FEtype_error_list(v20);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v16 = v20;
       }
       T0 = cl_pathname_name(1, v15asdf_bundle__f);
       T1 = cl_pathname_type(1, v15asdf_bundle__f);
       v17asdf_bundle__new_f = cl_make_pathname(6, ECL_SYM("NAME",1309), T0, ECL_SYM("TYPE",1356), T1, ECL_SYM("DEFAULTS",1247), v13asdf_bundle__dest_path);
       {
        volatile cl_object env1 = env0;
        env1 = ECL_NIL;
        CLV0 = env1 = CONS(ECL_NIL,env1);
        {
         volatile cl_object env2 = env1;
         CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY  */
         {
          ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
          if (__ecl_frs_push_result!=0) {
          if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
          goto L48;
          }
          ecl_internal_error("GO found an inexistent tag");
          } else {
          {
          cl_object v20;
          v20 = ecl_make_cclosure_va((cl_objectfn)LC5231__lambda7845,env2,Cblock,1);
          T0 = v20;
          }
          T1 = CONS(ECL_SYM("FILE-ERROR",355),T0);
          T2 = ecl_list1(T1);
          T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
          ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
          (cl_env_copy->function=ecl_fdefinition(VV[786]))->cfun.entry(2, v15asdf_bundle__f, v17asdf_bundle__new_f) /*  RENAME-FILE-OVERWRITING-TARGET */;
          ecl_frs_pop_n(cl_env_copy, 1);
          ecl_bds_unwind1(cl_env_copy);
          goto L47;
L48:;
          (cl_env_copy->function=ecl_fdefinition(VV[892]))->cfun.entry(2, v15asdf_bundle__f, v17asdf_bundle__new_f) /*  COPY-FILE */;
          (cl_env_copy->function=ecl_fdefinition(VV[782]))->cfun.entry(1, v15asdf_bundle__f) /*  DELETE-FILE-IF-EXISTS */;
          ecl_frs_pop_n(cl_env_copy, 1);
          goto L47;
          }
         }
        }
       }
L47:;
       {
        cl_object v20;
        v20 = v19;
        if (ecl_unlikely(ECL_ATOM(v20))) FEtype_error_cons(v20);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T0 = v20;
       }
       v19 = ecl_list1(v17asdf_bundle__new_f);
       (ECL_CONS_CDR(T0)=v19,T0);
       goto L35;
L36:;
       value0 = ecl_cdr(v18);
       cl_env_copy->nvalues = 1;
       return value0;
      }
     }
    }
   }
L15:;
   value0 = v12asdf_bundle__files;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for BUNDLE-SYSTEM                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5233bundle_system(cl_narg narg, cl_object v1asdf_system_system, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2570]);
 {
  cl_object v2asdf_bundle__args;
  cl_object v3asdf_bundle__force;
  cl_object v4asdf_bundle__verbose;
  cl_object v5asdf_component_version;
  ecl_va_list args; ecl_va_start(args,v1asdf_system_system,narg,1);
  {
   cl_object keyvars[6];
   cl_parse_key(args,3,L5233bundle_systemkeys,keyvars,(cl_object*)&v2asdf_bundle__args,TRUE);
   ecl_va_end(args);
   v3asdf_bundle__force = keyvars[0];
   if (Null(keyvars[4])) {
    v4asdf_bundle__verbose = ECL_T;
   } else {
    v4asdf_bundle__verbose = keyvars[1];
   }
   v5asdf_component_version = keyvars[2];
  }
  value0 = cl_apply(4, VV[2131], VV[2501], v1asdf_system_system, v2asdf_bundle__args);
  return value0;
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5236component_depends_on(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object T0, T1, T2, T3, T4;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1951]))->cfun.entry(1, v2asdf_bundle__c) /*  COMPONENT-SIDEWAY-DEPENDENCIES */;
 T1 = CONS(v1asdf_bundle__o,T0);
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[2548]))->cfun.entry(1, v2asdf_bundle__c) /*  USER-SYSTEM-P */)){
  goto L7;
 }
 T2 = VV[2498];
 goto L6;
L7:;
 T2 = VV[1999];
L6:;
 T3 = cl_list(2, T2, v2asdf_bundle__c);
 T4 = LC5234call_next_method(0, lex0);
 value0 = cl_listX(3, T1, T3, T4);
 return value0;
}
static cl_object LC5236component_depends_on_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC5236component_depends_on(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5237input_files(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[2548]))->cfun.entry(1, v2asdf_bundle__c) /*  USER-SYSTEM-P */)){
  goto L2;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1902]))->cfun.entry(2, v1asdf_bundle__o, VV[2498]) /*  FIND-OPERATION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, T0, v2asdf_bundle__c) /*  OUTPUT-FILES */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5237input_files_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC5237input_files(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5238perform(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, v1asdf_bundle__o, v2asdf_bundle__c) /*  INPUT-FILES */)){
  goto L2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2034]))->cfun.entry(2, v1asdf_bundle__o, v2asdf_bundle__c) /*  PERFORM-LISP-LOAD-FASL */;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5238perform_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5238perform(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function MARK-OPERATION-DONE                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5239mark_operation_done(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1902]))->cfun.entry(2, v1asdf_bundle__o, VV[1999]) /*  FIND-OPERATION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1972]))->cfun.entry(2, T0, v2asdf_bundle__c) /*  MARK-OPERATION-DONE */;
 return value0;
}
static cl_object LC5239mark_operation_done_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1972]);
 {
  return LC5239mark_operation_done(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function TRIVIAL-SYSTEM-P                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5241trivial_system_p(cl_object v1asdf_bundle__s)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = ecl_make_cfun_va((cl_objectfn)LC5240__lambda7855_va,ECL_NIL,Cblock,1);
  T0 = v2;
 }
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1672]))->cfun.entry(1, v1asdf_bundle__s) /*  COMPONENT-CHILDREN */;
 value0 = cl_every(2, T0, T1);
 return value0;
}
static cl_object LC5241trivial_system_p_va(cl_narg narg, cl_object v2asdf_bundle__s, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2547]);
 {
  return LC5241trivial_system_p(v2asdf_bundle__s);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5242input_files(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1638]))->cfun.entry(1, v2asdf_bundle__c) /*  COMPONENT-PATHNAME */;
 value0 = ecl_list1(T0);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5242input_files_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC5242input_files(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5243perform(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2034]))->cfun.entry(2, v1asdf_bundle__o, v2asdf_bundle__c) /*  PERFORM-LISP-LOAD-FASL */;
 return value0;
}
static cl_object LC5243perform_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5243perform(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5244perform(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1902]))->cfun.entry(2, v1asdf_bundle__o, VV[1999]) /*  FIND-OPERATION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1982]))->cfun.entry(2, T0, v2asdf_bundle__c) /*  PERFORM */;
 return value0;
}
static cl_object LC5244perform_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5244perform(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5245perform(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5245perform_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5245perform(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function TRIVIAL-SYSTEM-P                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5246trivial_system_p(cl_object v1asdf_bundle__s)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5246trivial_system_p_va(cl_narg narg, cl_object v2asdf_bundle__s, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2547]);
 {
  return LC5246trivial_system_p(v2asdf_bundle__s);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5247perform(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5247perform_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5247perform(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5248perform(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5248perform_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5248perform(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5249perform(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5249perform_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5249perform(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5250perform(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5250perform_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5250perform(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5251component_depends_on(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5251component_depends_on_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC5251component_depends_on(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function OUTPUT-FILES                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5252output_files(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2573]))->cfun.entry(1, v2asdf_bundle__c) /*  PREBUILT-SYSTEM-STATIC-LIBRARY */;
 T1 = ecl_list1(T0);
 cl_env_copy->nvalues = 2;
 cl_env_copy->values[1] = ECL_T;
 cl_env_copy->values[0] = T1;
 return cl_env_copy->values[0];
}
static cl_object LC5252output_files_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1962]);
 {
  return LC5252output_files(v3asdf_bundle__o, v4asdf_bundle__c);
 }
}
/* local function OUTPUT-FILES                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5253output_files(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__s)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1636]))->cfun.entry(1, v2asdf_bundle__s) /*  COMPONENT-NAME */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1638]))->cfun.entry(1, v2asdf_bundle__s) /*  COMPONENT-PATHNAME */;
 T2 = cl_make_pathname(6, ECL_SYM("NAME",1309), T0, ECL_SYM("TYPE",1356), VV[1821], ECL_SYM("DEFAULTS",1247), T1);
 value0 = ecl_list1(T2);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5253output_files_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1962]);
 {
  return LC5253output_files(v3asdf_bundle__o, v4asdf_bundle__s);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5256perform(cl_object volatile v1asdf_bundle__o, cl_object volatile v2asdf_bundle__s)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  volatile cl_object v3asdf_bundle__inputs;
  volatile cl_object v4asdf_bundle__fasl;
  volatile cl_object v5asdf_bundle__library;
  volatile cl_object v6asdf_bundle__asd;
  volatile cl_object v7asdf_component_name;
  volatile cl_object v8asdf_component_version;
  volatile cl_object v9asdf_bundle__dependencies;
  volatile cl_object v10asdf_bundle__depends_on;
  v3asdf_bundle__inputs = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, v1asdf_bundle__o, v2asdf_bundle__s) /*  INPUT-FILES */;
  v4asdf_bundle__fasl = ecl_car(v3asdf_bundle__inputs);
  v5asdf_bundle__library = ecl_cadr(v3asdf_bundle__inputs);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, v1asdf_bundle__o, v2asdf_bundle__s) /*  OUTPUT-FILES */;
  v6asdf_bundle__asd = ecl_car(T0);
  if (Null(v4asdf_bundle__fasl)){
   goto L7;
  }
  if (Null(v6asdf_bundle__asd)){
   goto L7;
  }
  v7asdf_component_name = cl_pathname_name(1, v6asdf_bundle__asd);
  goto L6;
L7:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  v8asdf_component_version = (cl_env_copy->function=ecl_fdefinition(VV[1643]))->cfun.entry(1, v2asdf_bundle__s) /*  COMPONENT-VERSION */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[2488]))->cfun.entry(1, v1asdf_bundle__o) /*  OPERATION-MONOLITHIC-P */)){
   goto L12;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1911]))->cfun.entry(5, v2asdf_bundle__s, VV[2492], VV[1695], VV[2494], VV[1996]) /*  REQUIRED-COMPONENTS */;
  v9asdf_bundle__dependencies = cl_remove_if_not(2, VV[2024], T0);
  goto L11;
L12:;
  {
   cl_object env1 = env0;
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(ECL_NIL,env1);
   {
    cl_object v11;
    v11 = ecl_make_cclosure_va((cl_objectfn)LC5255__lambda7879,env1,Cblock,2);
    T0 = v11;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[2080]))->cfun.entry(4, ECL_T, VV[1999], v2asdf_bundle__s, T0) /*  MAP-DIRECT-DEPENDENCIES */;
   v9asdf_bundle__dependencies = cl_reverse(ECL_CONS_CAR(CLV0));
  }
L11:;
  {
   cl_object v11;
   cl_object v12;
   cl_object v13;
   {
    cl_object v14;
    v14 = v9asdf_bundle__dependencies;
    if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v11 = v14;
   }
   v12 = ECL_NIL;
   v13 = v11;
   {
    cl_object v14;
    cl_object v15;
    v14 = ecl_list1(ECL_NIL);
    v15 = v14;
L24:;
    if (!(ecl_endp(v13))){
     goto L26;
    }
    goto L25;
L26:;
    v12 = ECL_CONS_CAR(v13);
    {
     cl_object v16;
     v16 = ECL_CONS_CDR(v13);
     if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v13 = v16;
    }
    {
     cl_object v16;
     v16 = v15;
     if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T0 = v16;
    }
    T1 = ecl_function_dispatch(cl_env_copy,VV[1753])(1, v12);
    v15 = ecl_list1(T1);
    (ECL_CONS_CDR(T0)=v15,T0);
    goto L24;
L25:;
    v10asdf_bundle__depends_on = ecl_cdr(v14);
    goto L16;
   }
  }
L16:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, v2asdf_bundle__s) /*  SYSTEM-SOURCE-FILE */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[536]))->cfun.entry(2, v6asdf_bundle__asd, T0) /*  PATHNAME-EQUAL */)){
   goto L42;
  }
  T0 = CONS(v1asdf_bundle__o,v2asdf_bundle__s);
  cl_cerror(4, VV[2576], VV[2577], T0, v6asdf_bundle__asd);
L42:;
  {
   volatile cl_object v11asdf_bundle__s;
   v11asdf_bundle__s = cl_open(7, v6asdf_bundle__asd, ECL_SYM("DIRECTION",1249), ECL_SYM("OUTPUT",1319), ECL_SYM("IF-EXISTS",1279), ECL_SYM("SUPERSEDE",1351), ECL_SYM("IF-DOES-NOT-EXIST",1277), ECL_SYM("CREATE",1244));
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    volatile bool unwinding = FALSE;
    ecl_frame_ptr next_fr;
    {
     ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
     if (__ecl_frs_push_result!=0) {
       unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
     } else {
     {
      struct ecl_stack_frame _ecl_inner_frame_aux;
      volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
      T0 = (cl_env_copy->function=ecl_fdefinition(VV[2488]))->cfun.entry(1, v1asdf_bundle__o) /*  OPERATION-MONOLITHIC-P */;
      cl_format(4, v11asdf_bundle__s, VV[2578], T0, v7asdf_component_name);
      T0 = cl_lisp_implementation_type();
      T1 = cl_lisp_implementation_version();
      T2 = cl_software_type();
      T3 = cl_machine_type();
      T4 = cl_software_version();
      cl_format(7, v11asdf_bundle__s, VV[2579], T0, T1, T2, T3, T4);
      T0 = cl_find_package(VV[1842]);
      ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T0); /*  *PACKAGE*     */
      T0 = cl_pathname_name(1, v4asdf_bundle__fasl);
      T1 = cl_list(2, VV[2580], T0);
      T2 = ecl_list1(T1);
      if (Null(v5asdf_bundle__library)){
       goto L51;
      }
      T4 = cl_file_namestring(v5asdf_bundle__library);
      T3 = cl_list(2, VV[2518], T4);
      goto L50;
L51:;
      T3 = ECL_NIL;
L50:;
      T4 = cl_listX(11, VV[2472], v7asdf_component_name, VV[1779], VV[2539], ECL_SYM("VERSION",1364), v8asdf_component_version, VV[2447], v10asdf_bundle__depends_on, VV[2441], T2, T3);
      cl_pprint(2, T4, v11asdf_bundle__s);
      cl_env_copy->values[0] = (ecl_terpri(v11asdf_bundle__s));
      cl_env_copy->nvalues = 1;
      ecl_bds_unwind1(cl_env_copy);
      ecl_stack_frame_push_values(_ecl_inner_frame);
      if (Null(v11asdf_bundle__s)){
       goto L53;
      }
      cl_close(1, v11asdf_bundle__s);
L53:;
      ecl_stack_frame_pop_values(_ecl_inner_frame);
      ecl_stack_frame_close(_ecl_inner_frame);
     }
     }
    }
    ecl_frs_pop(cl_env_copy);
    ecl_stack_frame_push_values(_ecl_inner_frame);
    if (Null(v11asdf_bundle__s)){
     goto L55;
    }
    cl_close(3, v11asdf_bundle__s, ECL_SYM("ABORT",1225), ECL_T);
L55:;
    ecl_stack_frame_pop_values(_ecl_inner_frame);
    if (unwinding) ecl_unwind(cl_env_copy,next_fr);
    ecl_stack_frame_close(_ecl_inner_frame);
    return cl_env_copy->values[0];
   }
  }
 }
}
static cl_object LC5256perform_va(cl_narg narg, cl_object v12asdf_bundle__o, cl_object v13asdf_bundle__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5256perform(v12asdf_bundle__o, v13asdf_bundle__s);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5257input_files(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__s)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1902]))->cfun.entry(2, v1asdf_bundle__o, VV[2498]) /*  FIND-OPERATION */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2530]))->cfun.entry(2, T0, v2asdf_bundle__s) /*  BUNDLE-OUTPUT-FILES */;
 return value0;
}
static cl_object LC5257input_files_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC5257input_files(v3asdf_bundle__o, v4asdf_bundle__s);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5258perform(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__s)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2034]))->cfun.entry(2, v1asdf_bundle__o, v2asdf_bundle__s) /*  PERFORM-LISP-LOAD-FASL */;
 return value0;
}
static cl_object LC5258perform_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5258perform(v3asdf_bundle__o, v4asdf_bundle__s);
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5261component_depends_on(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__s)
{
 cl_object T0, T1;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 T0 = cl_list(2, VV[1999], v2asdf_bundle__s);
 T1 = LC5259call_next_method(0, lex0);
 value0 = CONS(T0,T1);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5261component_depends_on_va(cl_narg narg, cl_object v3asdf_bundle__o, cl_object v4asdf_bundle__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC5261component_depends_on(v3asdf_bundle__o, v4asdf_bundle__s);
 }
}
/* function definition for SYSTEM-MODULE-PATHNAME                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5262system_module_pathname(cl_object v1asdf_component_module)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_component_name;
  v2asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_component_module) /*  COERCE-NAME */;
  T0 = cl_make_pathname(4, ECL_SYM("NAME",1309), v2asdf_component_name, ECL_SYM("DEFAULTS",1247), VV[2582]);
  T1 = (cl_env_copy->function=(ECL_SYM("COMPILE-FILE-PATHNAME",237)->symbol.gfdef))->cfun.entry(3, T0, ECL_SYM("TYPE",1356), VV[2518]) /*  COMPILE-FILE-PATHNAME */;
  T2 = cl_make_pathname(4, ECL_SYM("NAME",1309), v2asdf_component_name, ECL_SYM("DEFAULTS",1247), VV[2582]);
  T3 = (cl_env_copy->function=(ECL_SYM("COMPILE-FILE-PATHNAME",237)->symbol.gfdef))->cfun.entry(3, T2, ECL_SYM("TYPE",1356), ECL_SYM("OBJECT",1315)) /*  COMPILE-FILE-PATHNAME */;
  T4 = cl_list(2, T1, T3);
  value0 = cl_some(2, VV[683], T4);
  return value0;
 }
}
static cl_object L5262system_module_pathname_va(cl_narg narg, cl_object v3asdf_component_module, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2581]);
 {
  return L5262system_module_pathname(v3asdf_component_module);
 }
}
/* function definition for MAKE-PREBUILT-SYSTEM                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5263make_prebuilt_system(cl_narg narg, cl_object v1asdf_component_name, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2584]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[2584]);
 {
  cl_object v2pathname;
  va_list args; va_start(args,v1asdf_component_name);
  {
   int i = 1;
   if (i >= narg) {
    v2pathname = (cl_env_copy->function=ecl_fdefinition(VV[2581]))->cfun.entry(1, v1asdf_component_name) /*  SYSTEM-MODULE-PATHNAME */;
   } else {
    i++;
    v2pathname = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(v2pathname)){
   goto L2;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_component_name) /*  COERCE-NAME */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[716]))->cfun.entry(1, v2pathname) /*  RESOLVE-SYMLINKS* */;
  value0 = (cl_env_copy->function=(ECL_SYM("MAKE-INSTANCE",953)->symbol.gfdef))->cfun.entry(5, VV[2539], ECL_SYM("NAME",1309), T0, VV[2519], T1) /*  MAKE-INSTANCE */;
  return value0;
L2:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function COMPONENT-DEPENDS-ON                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5267component_depends_on(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object T0, T1, T2;
 volatile cl_object lex0[2];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_LISTP(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547))))){
  goto L3;
 }
 T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547));
 goto L2;
L3:;
 T1 = (ECL_SYM("LIST",483)->symbol.gfdef);
 T0 = cl_apply(2, T1, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM(".COMBINED-METHOD-ARGS.",1547)));
L2:;
 lex0[0] = T0;                                    /*  .CLOSED-COMBINED-METHOD-ARGS. */
 lex0[1] = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*NEXT-METHODS*",1549)); /*  .NEXT-METHODS. */
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  cl_object v7lib_op;
  v3 = LC5264call_next_method(0, lex0);
  v4 = v3;
  if (!(v4==ECL_NIL)){
   goto L9;
  }
  si_dm_too_few_arguments(v3);
L9:;
  {
   cl_object v8;
   v8 = ecl_car(v4);
   v4 = ecl_cdr(v4);
   v5 = v8;
  }
  v6 = v5;
  if (!(v6==ECL_NIL)){
   goto L16;
  }
  si_dm_too_few_arguments(v3);
L16:;
  {
   cl_object v8;
   v8 = ecl_car(v6);
   v6 = ecl_cdr(v6);
   v7lib_op = v8;
  }
  if (Null(v4)){
   goto L21;
  }
  si_dm_too_many_arguments(v3);
L21:;
  {
   cl_object v8;
   v8 = ecl_make_cfun_va((cl_objectfn)LC5266ensure_linkable_system_va,ECL_NIL,Cblock,1);
   {
    cl_object v9;
    cl_object v10;
    cl_object v11;
    {
     cl_object v12;
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[2481]))->cfun.entry(1, v2asdf_bundle__c) /*  NO-UIOP */)){
      goto L26;
     }
     v12 = v6;
     goto L25;
L26:;
     v12 = cl_union(2, v6, VV[2587]);
L25:;
     if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v9 = v12;
    }
    v10 = ECL_NIL;
    v11 = v9;
    {
     cl_object v12;
     cl_object v13;
     v12 = ecl_list1(ECL_NIL);
     v13 = v12;
L33:;
     if (!(ecl_endp(v11))){
      goto L35;
     }
     goto L34;
L35:;
     v10 = ECL_CONS_CAR(v11);
     {
      cl_object v14;
      v14 = ECL_CONS_CDR(v11);
      if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v11 = v14;
     }
     {
      cl_object v14;
      v14 = v13;
      if (ecl_unlikely(ECL_ATOM(v14))) FEtype_error_cons(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T1 = v14;
     }
     T2 = ecl_function_dispatch(cl_env_copy,v8)(1, v10);
     v13 = ecl_list1(T2);
     (ECL_CONS_CDR(T1)=v13,T1);
     goto L33;
L34:;
     T0 = ecl_cdr(v12);
     goto L23;
    }
   }
L23:;
   T1 = CONS(v7lib_op,T0);
   value0 = ecl_list1(T1);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object LC5267component_depends_on_va(cl_narg narg, cl_object v9asdf_bundle__o, cl_object v10asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1941]);
 {
  return LC5267component_depends_on(v9asdf_bundle__o, v10asdf_bundle__c);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5268perform(cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_bundle__object_files;
  cl_object v4asdf_bundle__output;
  cl_object v5asdf_bundle__bundle;
  cl_object v6asdf_bundle__programp;
  cl_object v7asdf_bundle__kind;
  v3asdf_bundle__object_files = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, v1asdf_bundle__o, v2asdf_bundle__c) /*  INPUT-FILES */;
  v4asdf_bundle__output = (cl_env_copy->function=ecl_fdefinition(VV[1962]))->cfun.entry(2, v1asdf_bundle__o, v2asdf_bundle__c) /*  OUTPUT-FILES */;
  v5asdf_bundle__bundle = ecl_car(v4asdf_bundle__output);
  v6asdf_bundle__programp = si_of_class_p(2, v1asdf_bundle__o, VV[2508]);
  v7asdf_bundle__kind = (cl_env_copy->function=ecl_fdefinition(VV[2531]))->cfun.entry(1, v1asdf_bundle__o) /*  BUNDLE-TYPE */;
  if (Null(v4asdf_bundle__output)){
   goto L7;
  }
  if (Null(v6asdf_bundle__programp)){
   goto L10;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2482]))->cfun.entry(1, v2asdf_bundle__c) /*  PREFIX-LISP-OBJECT-FILES */;
  goto L9;
L10:;
  T0 = ECL_NIL;
L9:;
  if (Null(v6asdf_bundle__programp)){
   goto L13;
  }
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[2483]))->cfun.entry(1, v2asdf_bundle__c) /*  POSTFIX-LISP-OBJECT-FILES */;
  goto L12;
L13:;
  T1 = ECL_NIL;
L12:;
  T2 = cl_append(3, T0, v3asdf_bundle__object_files, T1);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2479]))->cfun.entry(1, v1asdf_bundle__o) /*  PROLOGUE-CODE */;
  if (value0!=ECL_NIL) {
   goto L17;
  }
  if (Null(v6asdf_bundle__programp)){
   goto L19;
  }
  T3 = (cl_env_copy->function=ecl_fdefinition(VV[2479]))->cfun.entry(1, v2asdf_bundle__c) /*  PROLOGUE-CODE */;
  goto L15;
L19:;
  T3 = ECL_NIL;
  goto L15;
L17:;
  T3 = value0;
  goto L15;
L15:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2480]))->cfun.entry(1, v1asdf_bundle__o) /*  EPILOGUE-CODE */;
  if (value0!=ECL_NIL) {
   goto L23;
  }
  if (Null(v6asdf_bundle__programp)){
   goto L25;
  }
  T4 = (cl_env_copy->function=ecl_fdefinition(VV[2480]))->cfun.entry(1, v2asdf_bundle__c) /*  EPILOGUE-CODE */;
  goto L21;
L25:;
  T4 = ECL_NIL;
  goto L21;
L23:;
  T4 = value0;
  goto L21;
L21:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2485]))->cfun.entry(1, v1asdf_bundle__o) /*  EXTRA-BUILD-ARGS */;
  if (value0!=ECL_NIL) {
   goto L29;
  }
  if (Null(v6asdf_bundle__programp)){
   goto L31;
  }
  T5 = (cl_env_copy->function=ecl_fdefinition(VV[2485]))->cfun.entry(1, v2asdf_bundle__c) /*  EXTRA-BUILD-ARGS */;
  goto L27;
L31:;
  T5 = ECL_NIL;
  goto L27;
L29:;
  T5 = value0;
  goto L27;
L27:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2484]))->cfun.entry(1, v1asdf_bundle__o) /*  EXTRA-OBJECT-FILES */;
  if (value0!=ECL_NIL) {
   goto L35;
  }
  if (Null(v6asdf_bundle__programp)){
   goto L37;
  }
  T6 = (cl_env_copy->function=ecl_fdefinition(VV[2484]))->cfun.entry(1, v2asdf_bundle__c) /*  EXTRA-OBJECT-FILES */;
  goto L33;
L37:;
  T6 = ECL_NIL;
  goto L33;
L35:;
  T6 = value0;
  goto L33;
L33:;
  T7 = (cl_env_copy->function=ecl_fdefinition(VV[2481]))->cfun.entry(1, v2asdf_bundle__c) /*  NO-UIOP */;
  if (Null(v6asdf_bundle__programp)){
   goto L40;
  }
  T9 = (cl_env_copy->function=ecl_fdefinition(VV[1693]))->cfun.entry(1, v2asdf_bundle__c) /*  COMPONENT-ENTRY-POINT */;
  T8 = cl_list(2, VV[2592], T9);
  goto L39;
L40:;
  T8 = ECL_NIL;
L39:;
  value0 = cl_apply(16, VV[1064], v5asdf_bundle__bundle, T2, VV[2588], v7asdf_bundle__kind, VV[1077], T3, VV[1078], T4, VV[2589], T5, VV[2590], T6, VV[2591], T7, T8);
  return value0;
L7:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC5268perform_va(cl_narg narg, cl_object v8asdf_bundle__o, cl_object v9asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5268perform(v8asdf_bundle__o, v9asdf_bundle__c);
 }
}
/* local function INPUT-FILES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5270input_files(cl_object v1asdf_operation_operation, cl_object v2asdf_concatenate_source__s)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_concatenate_source__encoding;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1641]))->cfun.entry(1, v2asdf_concatenate_source__s) /*  COMPONENT-ENCODING */;
  if (value0!=ECL_NIL) {
   goto L4;
  }
  v3asdf_concatenate_source__encoding = ecl_cmp_symbol_value(cl_env_copy,VV[814]);
  goto L2;
L4:;
  v3asdf_concatenate_source__encoding = value0;
  goto L2;
L2:;
  {
   cl_object v4asdf_concatenate_source__other_encodings;
   v4asdf_concatenate_source__other_encodings = ECL_NIL;
   {
    cl_object v5asdf_component_around_compile;
    v5asdf_component_around_compile = (cl_env_copy->function=ecl_fdefinition(VV[1681]))->cfun.entry(1, v2asdf_concatenate_source__s) /*  AROUND-COMPILE-HOOK */;
    {
     cl_object v6asdf_concatenate_source__other_around_compile;
     v6asdf_concatenate_source__other_around_compile = ECL_NIL;
     {
      cl_object v7;
      cl_object v8asdf_concatenate_source__c;
      cl_object v9;
      {
       cl_object v10;
       T0 = (cl_env_copy->function=ecl_fdefinition(VV[2488]))->cfun.entry(1, v1asdf_operation_operation) /*  OPERATION-MONOLITHIC-P */;
       v10 = (cl_env_copy->function=ecl_fdefinition(VV[1911]))->cfun.entry(7, v2asdf_concatenate_source__s, VV[2130], VV[2000], VV[2494], VV[1997], VV[2491], T0) /*  REQUIRED-COMPONENTS */;
       if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v7 = v10;
      }
      v8asdf_concatenate_source__c = ECL_NIL;
      v9 = v7;
      {
       cl_object v10;
       cl_object v11;
       cl_object v12asdf_concatenate_source__inputs;
       v10 = ecl_list1(ECL_NIL);
       v11 = v10;
       v12asdf_concatenate_source__inputs = ECL_NIL;
L17:;
       if (!(ecl_endp(v9))){
        goto L19;
       }
       goto L18;
L19:;
       v8asdf_concatenate_source__c = ECL_CONS_CAR(v9);
       {
        cl_object v13;
        v13 = ECL_CONS_CDR(v9);
        if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v9 = v13;
       }
       {
        cl_object v13;
        if (Null(si_of_class_p(2, v8asdf_concatenate_source__c, VV[1993]))){
         goto L32;
        }
        {
         cl_object v14asdf_concatenate_source__e;
         v14asdf_concatenate_source__e = (cl_env_copy->function=ecl_fdefinition(VV[1641]))->cfun.entry(1, v8asdf_concatenate_source__c) /*  COMPONENT-ENCODING */;
         if (ecl_equal(v14asdf_concatenate_source__e,v3asdf_concatenate_source__encoding)) {
          goto L34;
         }
         {
          cl_object v15asdf_concatenate_source__a;
          {
          cl_object v16;
          cl_object v17;
          v16 = v14asdf_concatenate_source__e;
          v17 = v4asdf_concatenate_source__other_encodings;
          v15asdf_concatenate_source__a = ecl_assql(v16,v17);
          }
          if (Null(v15asdf_concatenate_source__a)){
          goto L40;
          }
          {
          cl_object v16;
          cl_object v17;
          v16 = (cl_env_copy->function=ecl_fdefinition(VV[1654]))->cfun.entry(1, v8asdf_concatenate_source__c) /*  COMPONENT-FIND-PATH */;
          T1 = ecl_cdr(v15asdf_concatenate_source__a);
          v17 = CONS(v16,T1);
          {
          cl_object v18;
          v18 = v15asdf_concatenate_source__a;
          if (ecl_unlikely(ECL_ATOM(v18))) FEtype_error_cons(v18);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T1 = v18;
          }
          (ECL_CONS_CDR(T1)=v17,T1);
          goto L34;
          }
L40:;
          T1 = (cl_env_copy->function=ecl_fdefinition(VV[1654]))->cfun.entry(1, v8asdf_concatenate_source__c) /*  COMPONENT-FIND-PATH */;
          T2 = cl_list(2, v15asdf_concatenate_source__a, T1);
          v4asdf_concatenate_source__other_encodings = CONS(T2,v4asdf_concatenate_source__other_encodings);
         }
        }
L34:;
        T1 = (cl_env_copy->function=ecl_fdefinition(VV[1681]))->cfun.entry(1, v8asdf_concatenate_source__c) /*  AROUND-COMPILE-HOOK */;
        if (ecl_equal(v5asdf_component_around_compile,T1)) {
         goto L49;
        }
        T1 = (cl_env_copy->function=ecl_fdefinition(VV[1654]))->cfun.entry(1, v8asdf_concatenate_source__c) /*  COMPONENT-FIND-PATH */;
        v6asdf_concatenate_source__other_around_compile = CONS(T1,v6asdf_concatenate_source__other_around_compile);
L49:;
        T1 = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, VV[2000]) /*  MAKE-OPERATION */;
        T0 = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, T1, v8asdf_concatenate_source__c) /*  INPUT-FILES */;
        goto L31;
L32:;
        T0 = ECL_NIL;
L31:;
        v13 = cl_copy_list(T0);
        {
         cl_object v14;
         v14 = v11;
         if (ecl_unlikely(ECL_ATOM(v14))) FEtype_error_cons(v14);
         value0 = ECL_NIL;
         cl_env_copy->nvalues = 0;
         T0 = v14;
        }
        (ECL_CONS_CDR(T0)=v13,T0);
        if (Null(v13)){
         goto L28;
        }
       }
       T0 = ecl_cdr(v11);
       v11 = ecl_last(T0,1);
L28:;
       v12asdf_concatenate_source__inputs = ecl_cdr(v10);
       goto L17;
L18:;
       if (Null(v4asdf_concatenate_source__other_encodings)){
        goto L60;
       }
       {
        cl_object v13;
        {
         cl_object v14;
         v14 = ecl_make_cfun_va((cl_objectfn)LC5269__lambda7997_va,ECL_NIL,Cblock,1);
         v13 = v14;
        }
        {
         cl_object v14;
         cl_object v15;
         cl_object v16;
         {
          cl_object v17;
          v17 = v4asdf_concatenate_source__other_encodings;
          if (ecl_unlikely(!ECL_LISTP(v17))) FEtype_error_list(v17);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          v14 = v17;
         }
         v15 = ECL_NIL;
         v16 = v14;
         {
          cl_object v17;
          cl_object v18;
          v17 = ecl_list1(ECL_NIL);
          v18 = v17;
L71:;
          if (!(ecl_endp(v16))){
          goto L73;
          }
          goto L72;
L73:;
          v15 = ECL_CONS_CAR(v16);
          {
          cl_object v19;
          v19 = ECL_CONS_CDR(v16);
          if (ecl_unlikely(!ECL_LISTP(v19))) FEtype_error_list(v19);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          v16 = v19;
          }
          {
          cl_object v19;
          v19 = v18;
          if (ecl_unlikely(ECL_ATOM(v19))) FEtype_error_cons(v19);
          value0 = ECL_NIL;
          cl_env_copy->nvalues = 0;
          T1 = v19;
          }
          T2 = ecl_function_dispatch(cl_env_copy,v13)(1, v15);
          v18 = ecl_list1(T2);
          (ECL_CONS_CDR(T1)=v18,T1);
          goto L71;
L72:;
          T0 = ecl_cdr(v17);
          goto L62;
         }
        }
       }
L62:;
       (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(4, VV[2605], v1asdf_operation_operation, v3asdf_concatenate_source__encoding, T0) /*  WARN */;
L60:;
       if (Null(v6asdf_concatenate_source__other_around_compile)){
        goto L89;
       }
       (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(4, VV[2607], v1asdf_operation_operation, v5asdf_component_around_compile, v6asdf_concatenate_source__other_around_compile) /*  WARN */;
L89:;
       value0 = v12asdf_concatenate_source__inputs;
       cl_env_copy->nvalues = 1;
       return value0;
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 1;
       return value0;
      }
     }
    }
   }
  }
 }
}
static cl_object LC5270input_files_va(cl_narg narg, cl_object v13asdf_operation_operation, cl_object v14asdf_concatenate_source__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1963]);
 {
  return LC5270input_files(v13asdf_operation_operation, v14asdf_concatenate_source__s);
 }
}
/* local function OUTPUT-FILES                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5271output_files(cl_object v1asdf_concatenate_source__o, cl_object v2asdf_concatenate_source__s)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2022]))->cfun.entry(2, v1asdf_concatenate_source__o, v2asdf_concatenate_source__s) /*  LISP-COMPILATION-OUTPUT-FILES */;
 return value0;
}
static cl_object LC5271output_files_va(cl_narg narg, cl_object v3asdf_concatenate_source__o, cl_object v4asdf_concatenate_source__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1962]);
 {
  return LC5271output_files(v3asdf_concatenate_source__o, v4asdf_concatenate_source__s);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5272perform(cl_object v1asdf_concatenate_source__o, cl_object v2asdf_concatenate_source__s)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_concatenate_source__ins;
  cl_object v4asdf_concatenate_source__out;
  cl_object v5asdf_concatenate_source__tmp;
  v3asdf_concatenate_source__ins = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, v1asdf_concatenate_source__o, v2asdf_concatenate_source__s) /*  INPUT-FILES */;
  v4asdf_concatenate_source__out = (cl_env_copy->function=ecl_fdefinition(VV[1966]))->cfun.entry(2, v1asdf_concatenate_source__o, v2asdf_concatenate_source__s) /*  OUTPUT-FILE */;
  v5asdf_concatenate_source__tmp = (cl_env_copy->function=ecl_fdefinition(VV[979]))->cfun.entry(1, v4asdf_concatenate_source__out) /*  TMPIZE-PATHNAME */;
  (cl_env_copy->function=ecl_fdefinition(VV[890]))->cfun.entry(2, v3asdf_concatenate_source__ins, v5asdf_concatenate_source__tmp) /*  CONCATENATE-FILES */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[786]))->cfun.entry(2, v5asdf_concatenate_source__tmp, v4asdf_concatenate_source__out) /*  RENAME-FILE-OVERWRITING-TARGET */;
  return value0;
 }
}
static cl_object LC5272perform_va(cl_narg narg, cl_object v6asdf_concatenate_source__o, cl_object v7asdf_concatenate_source__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5272perform(v6asdf_concatenate_source__o, v7asdf_concatenate_source__s);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5273perform(cl_object v1asdf_concatenate_source__o, cl_object v2asdf_concatenate_source__s)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2039]))->cfun.entry(2, v1asdf_concatenate_source__o, v2asdf_concatenate_source__s) /*  PERFORM-LISP-LOAD-SOURCE */;
 return value0;
}
static cl_object LC5273perform_va(cl_narg narg, cl_object v3asdf_concatenate_source__o, cl_object v4asdf_concatenate_source__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5273perform(v3asdf_concatenate_source__o, v4asdf_concatenate_source__s);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5274perform(cl_object v1asdf_concatenate_source__o, cl_object v2asdf_concatenate_source__s)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2008]))->cfun.entry(2, v1asdf_concatenate_source__o, v2asdf_concatenate_source__s) /*  PERFORM-LISP-COMPILATION */;
 return value0;
}
static cl_object LC5274perform_va(cl_narg narg, cl_object v3asdf_concatenate_source__o, cl_object v4asdf_concatenate_source__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5274perform(v3asdf_concatenate_source__o, v4asdf_concatenate_source__s);
 }
}
/* local function PERFORM                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5275perform(cl_object v1asdf_concatenate_source__o, cl_object v2asdf_concatenate_source__s)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2034]))->cfun.entry(2, v1asdf_concatenate_source__o, v2asdf_concatenate_source__s) /*  PERFORM-LISP-LOAD-FASL */;
 return value0;
}
static cl_object LC5275perform_va(cl_narg narg, cl_object v3asdf_concatenate_source__o, cl_object v4asdf_concatenate_source__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1982]);
 {
  return LC5275perform(v3asdf_concatenate_source__o, v4asdf_concatenate_source__s);
 }
}
/* function definition for INITIAL-PACKAGE-INFERRED-SYSTEMS-TABLE             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5276initial_package_inferred_systems_table()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1asdf_package_inferred_system__h;
  v1asdf_package_inferred_system__h = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
  {
   cl_object v2;
   v2 = cl_list_all_packages();
   goto L7;
L6:;
   {
    cl_object v3asdf_package_inferred_system__p;
    v3asdf_package_inferred_system__p = ecl_car(v2);
    {
     cl_object v4;
     v4 = L4227package_names(v3asdf_package_inferred_system__p);
     goto L15;
L14:;
     {
      cl_object v5asdf_package_inferred_system__n;
      v5asdf_package_inferred_system__n = ecl_car(v4);
      si_hash_set(v5asdf_package_inferred_system__n, v1asdf_package_inferred_system__h, ECL_T);
     }
     v4 = ecl_cdr(v4);
L15:;
     if (Null(v4)){
      goto L22;
     }
     goto L14;
L22:;
    }
   }
   v2 = ecl_cdr(v2);
L7:;
   if (Null(v2)){
    goto L26;
   }
   goto L6;
L26:;
  }
  value0 = v1asdf_package_inferred_system__h;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L5276initial_package_inferred_systems_table_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2609]);
 {
  return L5276initial_package_inferred_systems_table();
 }
}
/* function definition for DEFPACKAGE-FORM-P                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5277defpackage_form_p(cl_object v1asdf_package_inferred_system__form)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ECL_CONSP(v1asdf_package_inferred_system__form))){
  goto L3;
 }
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  cl_object v5;
  v2 = ecl_car(v1asdf_package_inferred_system__form);
  v3 = ecl_cmp_symbol_value(cl_env_copy,VV[2608]);
  v4 = v2;
  v5 = v3;
  value0 = ecl_memql(v4,v5);
  cl_env_copy->nvalues = 1;
  return value0;
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5277defpackage_form_p_va(cl_narg narg, cl_object v6asdf_package_inferred_system__form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2614]);
 {
  return L5277defpackage_form_p(v6asdf_package_inferred_system__form);
 }
}
/* function definition for STREAM-DEFPACKAGE-FORM                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5278stream_defpackage_form(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_package_inferred_system__form;
  v2asdf_package_inferred_system__form = ECL_NIL;
L3:;
  v2asdf_package_inferred_system__form = cl_read(3, v1stream, ECL_NIL, ECL_NIL);
  if (v2asdf_package_inferred_system__form!=ECL_NIL) {
   goto L7;
  }
  goto L4;
L7:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[2614]))->cfun.entry(1, v2asdf_package_inferred_system__form) /*  DEFPACKAGE-FORM-P */)){
   goto L9;
  }
  value0 = v2asdf_package_inferred_system__form;
  cl_env_copy->nvalues = 1;
  return value0;
L9:;
  goto L3;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L5278stream_defpackage_form_va(cl_narg narg, cl_object v3stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2616]);
 {
  return L5278stream_defpackage_form(v3stream);
 }
}
/* function definition for FILE-DEFPACKAGE-FORM                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5280file_defpackage_form(cl_object v1asdf_package_inferred_system__file)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = ecl_make_cfun_va((cl_objectfn)LC5279__lambda8053_va,ECL_NIL,Cblock,1);
  T0 = v2;
 }
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[852]))->cfun.entry(2, v1asdf_package_inferred_system__file, T0) /*  CALL-WITH-INPUT-FILE */;
 return value0;
}
static cl_object L5280file_defpackage_form_va(cl_narg narg, cl_object v2asdf_package_inferred_system__file, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2618]);
 {
  return L5280file_defpackage_form(v2asdf_package_inferred_system__file);
 }
}
/* local function LAMBDA8055                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5282__lambda8055()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC5281__lambda8057_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC5282__lambda8055_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2622]);
 {
  return LC5282__lambda8055();
 }
}
/* function definition for PACKAGE-DEPENDENCIES                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5284package_dependencies(cl_object v1asdf_package_inferred_system__defpackage_form)
{
 cl_object T0, T1, T2;
 volatile cl_object lex0[1];
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 goto L4;
L3:;
 si_assert_failure(1, VV[2627]);
L4:;
 if ((cl_env_copy->function=ecl_fdefinition(VV[2614]))->cfun.entry(1, v1asdf_package_inferred_system__defpackage_form) /*  DEFPACKAGE-FORM-P */!=ECL_NIL) {
  goto L7;
 }
 goto L3;
L7:;
 lex0[0] = ECL_NIL;
 {
  cl_object v2;
  cl_object v3asdf_package_inferred_system__option;
  cl_object v4asdf_package_inferred_system__arguments;
  cl_object v5;
  {
   cl_object v6;
   v6 = ecl_cddr(v1asdf_package_inferred_system__defpackage_form);
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v2 = v6;
  }
  v3asdf_package_inferred_system__option = ECL_NIL;
  v4asdf_package_inferred_system__arguments = ECL_NIL;
  v5 = v2;
L17:;
  if (!(ecl_endp(v5))){
   goto L19;
  }
  goto L18;
L19:;
  {
   cl_object v6;
   v6 = ECL_CONS_CAR(v5);
   v3asdf_package_inferred_system__option = ecl_car(v6);
   v6 = ecl_cdr(v6);
   v4asdf_package_inferred_system__arguments = v6;
  }
  {
   cl_object v6;
   v6 = ECL_CONS_CDR(v5);
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v5 = v6;
  }
  {
   cl_object v6;
   cl_object v7;
   v6 = v3asdf_package_inferred_system__option;
   v7 = VV[2629];
   if (Null(ecl_memql(v6,v7))){
    goto L33;
   }
  }
  {
   cl_object v6;
   v6 = v4asdf_package_inferred_system__arguments;
   goto L40;
L39:;
   {
    cl_object v7asdf_package_inferred_system__p;
    v7asdf_package_inferred_system__p = ecl_car(v6);
    T1 = cl_string(v7asdf_package_inferred_system__p);
    LC5283dep(lex0, T1);
   }
   v6 = ecl_cdr(v6);
L40:;
   if (Null(v6)){
    goto L47;
   }
   goto L39;
L47:;
   goto L32;
  }
L33:;
  if (!((v3asdf_package_inferred_system__option)==(ECL_SYM("IMPORT-FROM",1283)))){
   goto L54;
  }
  goto L51;
L54:;
  goto L52;
L52:;
  if (!((v3asdf_package_inferred_system__option)==(VV[115]))){
   goto L49;
  }
  goto L50;
L51:;
L50:;
  T1 = ecl_car(v4asdf_package_inferred_system__arguments);
  T2 = cl_string(T1);
  LC5283dep(lex0, T2);
  goto L32;
L49:;
  {
   cl_object v7;
   cl_object v8;
   v7 = v3asdf_package_inferred_system__option;
   v8 = VV[2632];
   if (ecl_memql(v7,v8)!=ECL_NIL) {
    goto L32;
   }
  }
  si_ecase_error(v3asdf_package_inferred_system__option, VV[2633]);
L32:;
  goto L17;
L18:;
 }
 T0 = cl_reverse(lex0[0]);
 value0 = cl_remove_duplicates(5, T0, VV[91], ECL_T, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
 return value0;
}
static cl_object L5284package_dependencies_va(cl_narg narg, cl_object v2asdf_package_inferred_system__defpackage_form, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2626]);
 {
  return L5284package_dependencies(v2asdf_package_inferred_system__defpackage_form);
 }
}
/* function definition for PACKAGE-DESIGNATOR-NAME                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5285package_designator_name(cl_object v1package)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_packagep(v1package))){
  goto L2;
 }
 value0 = cl_package_name(v1package);
 return value0;
L2:;
 if (!(ECL_STRINGP(v1package))){
  goto L4;
 }
 value0 = v1package;
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 if (!(ECL_SYMBOLP(v1package))){
  goto L6;
 }
 value0 = cl_string(v1package);
 return value0;
L6:;
 value0 = si_etypecase_error(v1package, VV[2636]);
 return value0;
}
static cl_object L5285package_designator_name_va(cl_narg narg, cl_object v2package, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2635]);
 {
  return L5285package_designator_name(v2package);
 }
}
/* function definition for REGISTER-SYSTEM-PACKAGES                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5286register_system_packages(cl_object v1asdf_system_system, cl_object v2asdf_package_inferred_system__packages)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3asdf_component_name;
  value0 = ecl_make_bool((v1asdf_system_system)==(ECL_T));
  if (value0!=ECL_NIL) {
   goto L4;
  }
  v3asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v1asdf_system_system) /*  COERCE-NAME */;
  goto L2;
L4:;
  v3asdf_component_name = value0;
  goto L2;
L2:;
  {
   cl_object v4;
   v4 = (cl_env_copy->function=ecl_fdefinition(VV[257]))->cfun.entry(1, v2asdf_package_inferred_system__packages) /*  ENSURE-LIST */;
   goto L9;
L8:;
   {
    cl_object v5asdf_package_inferred_system__p;
    v5asdf_package_inferred_system__p = ecl_car(v4);
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[2635]))->cfun.entry(1, v5asdf_package_inferred_system__p) /*  PACKAGE-DESIGNATOR-NAME */;
    si_hash_set(T0, ecl_cmp_symbol_value(cl_env_copy,VV[2611]), v3asdf_component_name);
   }
   v4 = ecl_cdr(v4);
L9:;
   if (Null(v4)){
    goto L16;
   }
   goto L8;
L16:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object L5286register_system_packages_va(cl_narg narg, cl_object v5asdf_system_system, cl_object v6asdf_package_inferred_system__packages, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2638]);
 {
  return L5286register_system_packages(v5asdf_system_system, v6asdf_package_inferred_system__packages);
 }
}
/* function definition for PACKAGE-NAME-SYSTEM                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5287package_name_system(cl_object v1package_name)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = v1package_name;
  if (ECL_STRINGP(v2)) {
   goto L4;
  }
  v1package_name = si_do_check_type(v2, ECL_SYM("STRING",808), ECL_NIL, ECL_SYM("PACKAGE-NAME",622));
L4:;
 }
 {
  cl_object v2asdf_package_inferred_system__system_name;
  v2asdf_package_inferred_system__system_name = ecl_gethash_safe(v1package_name,ecl_cmp_symbol_value(cl_env_copy,VV[2611]),ECL_NIL);
  if (Null(v2asdf_package_inferred_system__system_name)){
   goto L8;
  }
  value0 = v2asdf_package_inferred_system__system_name;
  cl_env_copy->nvalues = 1;
  return value0;
L8:;
  value0 = cl_string_downcase(1, v1package_name);
  return value0;
 }
}
static cl_object L5287package_name_system_va(cl_narg narg, cl_object v3package_name, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2640]);
 {
  return L5287package_name_system(v3package_name);
 }
}
/* function definition for PACKAGE-INFERRED-SYSTEM-FILE-DEPENDENCIES          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5288package_inferred_system_file_dependencies(cl_narg narg, cl_object v1asdf_package_inferred_system__file, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2642]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[2642]);
 {
  cl_object v2asdf_system_system;
  va_list args; va_start(args,v1asdf_package_inferred_system__file);
  {
   int i = 1;
   if (i >= narg) {
    v2asdf_system_system = ECL_NIL;
   } else {
    i++;
    v2asdf_system_system = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v3asdf_package_inferred_system__defpackage_form;
   v3asdf_package_inferred_system__defpackage_form = (cl_env_copy->function=ecl_fdefinition(VV[2618]))->cfun.entry(1, v1asdf_package_inferred_system__file) /*  FILE-DEFPACKAGE-FORM */;
   if (Null(v3asdf_package_inferred_system__defpackage_form)){
    goto L3;
   }
   {
    cl_object v4;
    cl_object v5;
    cl_object v6;
    {
     cl_object v7;
     v7 = (cl_env_copy->function=ecl_fdefinition(VV[2626]))->cfun.entry(1, v3asdf_package_inferred_system__defpackage_form) /*  PACKAGE-DEPENDENCIES */;
     if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v4 = v7;
    }
    v5 = ECL_NIL;
    v6 = v4;
    {
     cl_object v7;
     cl_object v8;
     v7 = ecl_list1(ECL_NIL);
     v8 = v7;
L13:;
     if (!(ecl_endp(v6))){
      goto L15;
     }
     goto L14;
L15:;
     v5 = ECL_CONS_CAR(v6);
     {
      cl_object v9;
      v9 = ECL_CONS_CDR(v6);
      if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v6 = v9;
     }
     {
      cl_object v9;
      v9 = v8;
      if (ecl_unlikely(ECL_ATOM(v9))) FEtype_error_cons(v9);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T1 = v9;
     }
     T2 = ecl_function_dispatch(cl_env_copy,VV[2640])(1, v5);
     v8 = ecl_list1(T2);
     (ECL_CONS_CDR(T1)=v8,T1);
     goto L13;
L14:;
     T0 = ecl_cdr(v7);
     goto L5;
    }
   }
L5:;
   value0 = cl_remove(2, ECL_T, T0);
   return value0;
L3:;
   value0 = cl_error(5, VV[2621], VV[2124], v2asdf_system_system, ECL_SYM("PATHNAME",1322), v1asdf_package_inferred_system__file);
   return value0;
  }
 }
}
/* function definition for SAME-PACKAGE-INFERRED-SYSTEM-P                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5289same_package_inferred_system_p(cl_object v1asdf_system_system, cl_object v2asdf_component_name, cl_object v3directory, cl_object v4asdf_package_inferred_system__subpath, cl_object v5asdf_component_around_compile, cl_object v6asdf_package_inferred_system__dependencies)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_type_of(v1asdf_system_system);
 if (!((T0)==(VV[2612]))){
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1636]))->cfun.entry(1, v1asdf_system_system) /*  COMPONENT-NAME */;
 if (!(ecl_equal(T0,v2asdf_component_name))){
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1638]))->cfun.entry(1, v1asdf_system_system) /*  COMPONENT-PATHNAME */;
 if (Null((cl_env_copy->function=ecl_fdefinition(VV[536]))->cfun.entry(2, v3directory, T0) /*  PATHNAME-EQUAL */)){
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1951]))->cfun.entry(1, v1asdf_system_system) /*  COMPONENT-SIDEWAY-DEPENDENCIES */;
 if (!(ecl_equal(v6asdf_package_inferred_system__dependencies,T0))){
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1681]))->cfun.entry(1, v1asdf_system_system) /*  AROUND-COMPILE-HOOK */;
 if (!(ecl_equal(v5asdf_component_around_compile,T0))){
  goto L3;
 }
 {
  cl_object v7asdf_component_children;
  v7asdf_component_children = (cl_env_copy->function=ecl_fdefinition(VV[1672]))->cfun.entry(1, v1asdf_system_system) /*  COMPONENT-CHILDREN */;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[253]))->cfun.entry(2, v7asdf_component_children, ecl_make_int8_t(1)) /*  LENGTH=N-P */)){
   goto L11;
  }
  {
   cl_object v8asdf_package_inferred_system__child;
   v8asdf_package_inferred_system__child = ecl_car(v7asdf_component_children);
   T0 = cl_type_of(v8asdf_package_inferred_system__child);
   if (!((T0)==(VV[1993]))){
    goto L15;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1636]))->cfun.entry(1, v8asdf_package_inferred_system__child) /*  COMPONENT-NAME */;
   if (!(ecl_equal(T0,VV[1415]))){
    goto L15;
   }
   if (Null(cl_slot_boundp(v8asdf_package_inferred_system__child, VV[1678]))){
    goto L19;
   }
   T0 = cl_slot_value(v8asdf_package_inferred_system__child, VV[1678]);
   value0 = ecl_make_bool(ecl_equal(T0,v4asdf_package_inferred_system__subpath));
   cl_env_copy->nvalues = 1;
   return value0;
L19:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L15:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L11:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L5289same_package_inferred_system_p_va(cl_narg narg, cl_object v9asdf_system_system, cl_object v10asdf_component_name, cl_object v11directory, cl_object v12asdf_package_inferred_system__subpath, cl_object v13asdf_component_around_compile, cl_object v14asdf_package_inferred_system__dependencies, ...)
{
 if (ecl_unlikely(narg!=6)) FEwrong_num_arguments(VV[2644]);
 {
  return L5289same_package_inferred_system_p(v9asdf_system_system, v10asdf_component_name, v11directory, v12asdf_package_inferred_system__subpath, v13asdf_component_around_compile, v14asdf_package_inferred_system__dependencies);
 }
}
/* function definition for SYSDEF-PACKAGE-INFERRED-SYSTEM-SEARCH              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5290sysdef_package_inferred_system_search(cl_object v1asdf_system_system)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_package_inferred_system__primary;
  v2asdf_package_inferred_system__primary = (cl_env_copy->function=ecl_fdefinition(VV[1756]))->cfun.entry(1, v1asdf_system_system) /*  PRIMARY-SYSTEM-NAME */;
  if (ecl_equal(v2asdf_package_inferred_system__primary,v1asdf_system_system)) {
   goto L3;
  }
  {
   cl_object v3asdf_package_inferred_system__top;
   v3asdf_package_inferred_system__top = (cl_env_copy->function=ecl_fdefinition(VV[1690]))->cfun.entry(2, v2asdf_package_inferred_system__primary, ECL_NIL) /*  FIND-SYSTEM */;
   if (Null(si_of_class_p(2, v3asdf_package_inferred_system__top, VV[2612]))){
    goto L6;
   }
   {
    cl_object v4asdf_package_inferred_system__dir;
    v4asdf_package_inferred_system__dir = (cl_env_copy->function=ecl_fdefinition(VV[1638]))->cfun.entry(1, v3asdf_package_inferred_system__top) /*  COMPONENT-PATHNAME */;
    if (Null(v4asdf_package_inferred_system__dir)){
     goto L9;
    }
    {
     cl_object v5asdf_package_inferred_system__sub;
     cl_object v6asdf_package_inferred_system__f;
     {
      cl_fixnum v7;
      v7 = ecl_length(v2asdf_package_inferred_system__primary);
      T0 = ecl_make_integer((v7)+1);
      v5asdf_package_inferred_system__sub = cl_subseq(2, v1asdf_system_system, T0);
     }
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(4, v4asdf_package_inferred_system__dir, v5asdf_package_inferred_system__sub, ECL_SYM("TYPE",1356), VV[1415]) /*  SUBPATHNAME */;
     v6asdf_package_inferred_system__f = (cl_env_copy->function=ecl_fdefinition(VV[669]))->cfun.entry(3, T0, VV[681], ecl_cmp_symbol_value(cl_env_copy,VV[715])) /*  PROBE-FILE* */;
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[550]))->cfun.entry(1, v6asdf_package_inferred_system__f) /*  FILE-PATHNAME-P */)){
      goto L13;
     }
     {
      cl_object v7;
      cl_object v8;
      cl_object v9;
      v7 = (cl_env_copy->function=ecl_fdefinition(VV[2642]))->cfun.entry(2, v6asdf_package_inferred_system__f, v1asdf_system_system) /*  PACKAGE-INFERRED-SYSTEM-FILE-DEPENDENCIES */;
      v8 = (cl_env_copy->function=ecl_fdefinition(VV[1764]))->cfun.entry(1, v1asdf_system_system) /*  REGISTERED-SYSTEM */;
      v9 = (cl_env_copy->function=ecl_fdefinition(VV[1681]))->cfun.entry(1, v3asdf_package_inferred_system__top) /*  AROUND-COMPILE-HOOK */;
      if (Null((cl_env_copy->function=ecl_fdefinition(VV[2644]))->cfun.entry(6, v8, v1asdf_system_system, v4asdf_package_inferred_system__dir, v5asdf_package_inferred_system__sub, v9, v7) /*  SAME-PACKAGE-INFERRED-SYSTEM-P */)){
       goto L18;
      }
      value0 = v8;
      cl_env_copy->nvalues = 1;
      return value0;
L18:;
      T0 = cl_list(4, VV[1993], VV[1415], ECL_SYM("PATHNAME",1322), v5asdf_package_inferred_system__sub);
      T1 = ecl_list1(T0);
      T2 = cl_list(14, VV[2472], v1asdf_system_system, VV[1779], VV[2612], VV[1780], ECL_NIL, ECL_SYM("PATHNAME",1322), v4asdf_package_inferred_system__dir, VV[2447], v7, VV[2647], v9, VV[2441], T1);
      value0 = cl_eval(T2);
      return value0;
     }
L13:;
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     return value0;
    }
L9:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
   }
L6:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object L5290sysdef_package_inferred_system_search_va(cl_narg narg, cl_object v10asdf_system_system, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2646]);
 {
  return L5290sysdef_package_inferred_system_search(v10asdf_system_system);
 }
}
/* function definition for LOAD-SYSDEF                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5291load_sysdef(cl_object v1asdf_backward_internals__name, cl_object v2pathname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(1, VV[2652]);
 return value0;
}
static cl_object L5291load_sysdef_va(cl_narg narg, cl_object v3asdf_backward_internals__name, cl_object v4pathname, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2651]);
 {
  return L5291load_sysdef(v3asdf_backward_internals__name, v4pathname);
 }
}
/* local function LAMBDA8162                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5293__lambda8162()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v1;
  v1 = ecl_make_cfun_va((cl_objectfn)LC5292__lambda8164_va,ECL_NIL,Cblock,2);
  value0 = v1;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC5293__lambda8162_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2655]);
 {
  return LC5293__lambda8162();
 }
}
/* function definition for COMPONENT-LOAD-DEPENDENCIES                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5294component_load_dependencies(cl_object v1asdf_component_component)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1951]))->cfun.entry(1, v1asdf_component_component) /*  COMPONENT-SIDEWAY-DEPENDENCIES */;
 return value0;
}
static cl_object L5294component_load_dependencies_va(cl_narg narg, cl_object v2asdf_component_component, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2663]);
 {
  return L5294component_load_dependencies(v2asdf_component_component);
 }
}
/* local function OPERATION-FORCED                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5295operation_forced(cl_object v1asdf_backward_interface__o)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1891]))->cfun.entry(1, v1asdf_backward_interface__o) /*  OPERATION-ORIGINAL-INITARGS */;
 value0 = cl_getf(2, T0, VV[2666]);
 return value0;
}
static cl_object LC5295operation_forced_va(cl_narg narg, cl_object v2asdf_backward_interface__o, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2665]);
 {
  return LC5295operation_forced(v2asdf_backward_interface__o);
 }
}
/* local function OPERATION-ON-WARNINGS                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5296operation_on_warnings(cl_object v1asdf_backward_interface__o)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[1299]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5296operation_on_warnings_va(cl_narg narg, cl_object v2asdf_backward_interface__o, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2667]);
 {
  return LC5296operation_on_warnings(v2asdf_backward_interface__o);
 }
}
/* local function OPERATION-ON-FAILURE                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5297operation_on_failure(cl_object v1asdf_backward_interface__o)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[1301]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5297operation_on_failure_va(cl_narg narg, cl_object v2asdf_backward_interface__o, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2668]);
 {
  return LC5297operation_on_failure(v2asdf_backward_interface__o);
 }
}
/* local function OPERATION-ON-WARNINGS                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5298operation_on_warnings(cl_object v1asdf_backward_interface__x, cl_object v2asdf_backward_interface__o)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = v1asdf_backward_interface__x;
 ecl_cmp_setq(cl_env_copy,VV[1299],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[1299]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5298operation_on_warnings_va(cl_narg narg, cl_object v3asdf_backward_interface__x, cl_object v4asdf_backward_interface__o, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2667]);
 {
  return LC5298operation_on_warnings(v3asdf_backward_interface__x, v4asdf_backward_interface__o);
 }
}
/* local function OPERATION-ON-FAILURE                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5299operation_on_failure(cl_object v1asdf_backward_interface__x, cl_object v2asdf_backward_interface__o)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = v1asdf_backward_interface__x;
 ecl_cmp_setq(cl_env_copy,VV[1301],T0);
 value0 = ecl_cmp_symbol_value(cl_env_copy,VV[1301]);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5299operation_on_failure_va(cl_narg narg, cl_object v3asdf_backward_interface__x, cl_object v4asdf_backward_interface__o, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2668]);
 {
  return LC5299operation_on_failure(v3asdf_backward_interface__x, v4asdf_backward_interface__o);
 }
}
/* function definition for SYSTEM-DEFINITION-PATHNAME                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5300system_definition_pathname(cl_object v1asdf_backward_interface__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, v1asdf_backward_interface__x) /*  SYSTEM-SOURCE-FILE */;
 return value0;
}
static cl_object L5300system_definition_pathname_va(cl_narg narg, cl_object v2asdf_backward_interface__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2669]);
 {
  return L5300system_definition_pathname(v2asdf_backward_interface__x);
 }
}
/* local function TRAVERSE                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5301traverse(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2671]);
 {
  cl_object v3;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3,TRUE);
  ecl_va_end(args);
  {
   cl_object v4asdf_component_component;
   v4asdf_component_component = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[834]))->cfun.entry(3, v1asdf_operation_operation, ECL_SYM("PACKAGE",1321), VV[1899]) /*  SAFE-READ-FROM-STRING */;
   value0 = cl_apply(4, VV[2671], T0, v4asdf_component_component, v3);
   return value0;
  }
 }
}
/* local function TRAVERSE                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5302traverse(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2671]);
 {
  cl_object v3;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3,TRUE);
  ecl_va_end(args);
  if (Null(v1asdf_operation_operation)){
   goto L1;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1898]))->cfun.entry(1, v1asdf_operation_operation) /*  MAKE-OPERATION */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = ECL_NIL;
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  value0 = cl_apply(4, VV[2671], T0, T1, v3);
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function TRAVERSE                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5303traverse(cl_narg narg, cl_object v1asdf_operation_operation, cl_object v2asdf_component_component, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2671]);
 {
  cl_object v3;
  ecl_va_list args; ecl_va_start(args,v2asdf_component_component,narg,2);
  cl_parse_key(args,0,NULL,NULL,(cl_object*)&v3,TRUE);
  ecl_va_end(args);
  if (Null(si_of_class_p(2, v2asdf_component_component, VV[1652]))){
   goto L1;
  }
  T0 = CONS(v1asdf_operation_operation,v2asdf_component_component);
  value0 = cl_error(3, VV[1931], VV[2671], T0);
  return value0;
L1:;
  {
   cl_object v4;
   v4 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, v2asdf_component_component) /*  FIND-COMPONENT */;
   if (Null(v4)){
    goto L4;
   }
   value0 = cl_apply(4, VV[2671], v1asdf_operation_operation, v4, v3);
   return value0;
L4:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* local function TRAVERSE                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5304traverse(cl_narg narg, cl_object v1asdf_backward_interface__o, cl_object v2asdf_backward_interface__c, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2671]);
 {
  cl_object v3asdf_backward_interface__keys;
  cl_object v4asdf_backward_interface__plan_class;
  ecl_va_list args; ecl_va_start(args,v2asdf_backward_interface__c,narg,2);
  {
   cl_object keyvars[2];
   cl_parse_key(args,1,LC5304traversekeys,keyvars,(cl_object*)&v3asdf_backward_interface__keys,TRUE);
   ecl_va_end(args);
   v4asdf_backward_interface__plan_class = keyvars[0];
  }
  T0 = cl_apply(5, VV[2120], v4asdf_backward_interface__plan_class, v1asdf_backward_interface__o, v2asdf_backward_interface__c, v3asdf_backward_interface__keys);
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2091]))->cfun.entry(1, T0) /*  PLAN-ACTIONS */;
  return value0;
 }
}
/* function definition for ENABLE-ASDF-BINARY-LOCATIONS-COMPATIBILITY         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5305enable_asdf_binary_locations_compatibility(cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1asdf_backward_interface__centralize_lisp_binaries;
  cl_object v2asdf_backward_interface__default_toplevel_directory;
  cl_object v3asdf_backward_interface__include_per_user_information;
  cl_object v4asdf_backward_interface__map_all_source_files;
  cl_object v5asdf_backward_interface__source_to_target_mappings;
  cl_object v6asdf_backward_interface__file_types;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  {
   cl_object keyvars[12];
   cl_parse_key(args,6,L5305enable_asdf_binary_locations_compatibilitykeys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v1asdf_backward_interface__centralize_lisp_binaries = keyvars[0];
   if (Null(keyvars[7])) {
    T0 = cl_user_homedir_pathname(0);
    v2asdf_backward_interface__default_toplevel_directory = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(2, T0, VV[2673]) /*  SUBPATHNAME */;
   } else {
    v2asdf_backward_interface__default_toplevel_directory = keyvars[1];
   }
   v3asdf_backward_interface__include_per_user_information = keyvars[2];
   if (Null(keyvars[9])) {
    value0 = ECL_T;
    v4asdf_backward_interface__map_all_source_files = value0;
    goto L2;
L2:;
   } else {
    v4asdf_backward_interface__map_all_source_files = keyvars[3];
   }
   v5asdf_backward_interface__source_to_target_mappings = keyvars[4];
   if (Null(keyvars[11])) {
    T0 = (cl_env_copy->function=ecl_fdefinition(VV[1417]))->cfun.entry(0) /*  COMPILE-FILE-TYPE */;
    v6asdf_backward_interface__file_types = CONS(T0,VV[2674]);
   } else {
    v6asdf_backward_interface__file_types = keyvars[5];
   }
  }
  if (!(v4asdf_backward_interface__map_all_source_files==ECL_NIL)){
   goto L7;
  }
  cl_error(1, VV[2675]);
L7:;
  {
   cl_object v7asdf_backward_interface__patterns;
   cl_object v8asdf_backward_interface__destination_directory;
   if (Null(v4asdf_backward_interface__map_all_source_files)){
    goto L10;
   }
   v7asdf_backward_interface__patterns = ecl_list1(ecl_cmp_symbol_value(cl_env_copy,VV[635]));
   goto L9;
L10:;
   {
    cl_object v9;
    cl_object v10type;
    cl_object v11;
    {
     cl_object v12;
     v12 = v6asdf_backward_interface__file_types;
     if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v9 = v12;
    }
    v10type = ECL_NIL;
    v11 = v9;
    {
     cl_object v12;
     cl_object v13;
     v12 = ecl_list1(ECL_NIL);
     v13 = v12;
L19:;
     if (!(ecl_endp(v11))){
      goto L21;
     }
     goto L20;
L21:;
     v10type = ECL_CONS_CAR(v11);
     {
      cl_object v14;
      v14 = ECL_CONS_CDR(v11);
      if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v11 = v14;
     }
     {
      cl_object v14;
      v14 = v13;
      if (ecl_unlikely(ECL_ATOM(v14))) FEtype_error_cons(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v14;
     }
     T1 = cl_make_pathname(4, ECL_SYM("TYPE",1356), v10type, ECL_SYM("DEFAULTS",1247), ecl_cmp_symbol_value(cl_env_copy,VV[635]));
     v13 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v13,T0);
     goto L19;
L20:;
     v7asdf_backward_interface__patterns = ecl_cdr(v12);
     goto L9;
    }
   }
L9:;
   if (Null(v1asdf_backward_interface__centralize_lisp_binaries)){
    goto L37;
   }
   if (Null(v3asdf_backward_interface__include_per_user_information)){
    goto L40;
   }
   T1 = cl_user_homedir_pathname(0);
   T2 = cl_pathname_directory(1, T1);
   T0 = ecl_cdr(T2);
   goto L39;
L40:;
   T0 = ECL_NIL;
L39:;
   T1 = cl_list(2, VV[1585], ecl_cmp_symbol_value(cl_env_copy,VV[638]));
   T2 = ecl_append(T0,T1);
   v8asdf_backward_interface__destination_directory = CONS(v2asdf_backward_interface__default_toplevel_directory,T2);
   goto L36;
L37:;
   v8asdf_backward_interface__destination_directory = cl_list(3, VV[1509], ecl_cmp_symbol_value(cl_env_copy,VV[638]), VV[1585]);
L36:;
   {
    cl_object v9;
    cl_object v10asdf_backward_interface__pattern;
    cl_object v11;
    {
     cl_object v12;
     v12 = v7asdf_backward_interface__patterns;
     if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v9 = v12;
    }
    v10asdf_backward_interface__pattern = ECL_NIL;
    v11 = v9;
    {
     cl_object v12;
     cl_object v13;
     v12 = ecl_list1(ECL_NIL);
     v13 = v12;
L50:;
     if (!(ecl_endp(v11))){
      goto L52;
     }
     goto L51;
L52:;
     v10asdf_backward_interface__pattern = ECL_CONS_CAR(v11);
     {
      cl_object v14;
      v14 = ECL_CONS_CDR(v11);
      if (ecl_unlikely(!ECL_LISTP(v14))) FEtype_error_list(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v11 = v14;
     }
     {
      cl_object v14;
      v14 = v13;
      if (ecl_unlikely(ECL_ATOM(v14))) FEtype_error_cons(v14);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T1 = v14;
     }
     T2 = cl_list(3, VV[1509], ecl_cmp_symbol_value(cl_env_copy,VV[638]), v10asdf_backward_interface__pattern);
     T3 = ecl_list1(v10asdf_backward_interface__pattern);
     T4 = ecl_append(v8asdf_backward_interface__destination_directory,T3);
     T5 = cl_list(2, T2, T4);
     v13 = ecl_list1(T5);
     (ECL_CONS_CDR(T1)=v13,T1);
     goto L50;
L51:;
     T0 = ecl_cdr(v12);
     goto L42;
    }
   }
L42:;
   T1 = cl_append(3, v5asdf_backward_interface__source_to_target_mappings, T0, VV[2676]);
   T2 = CONS(VV[2197],T1);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[2250]))->cfun.entry(1, T2) /*  INITIALIZE-OUTPUT-TRANSLATIONS */;
   return value0;
  }
 }
}
/* local function OPERATE                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5306operate(cl_narg narg, cl_object v1asdf_backward_interface__operation_class, cl_object v2asdf_system_system, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[2131]);
 {
  ecl_va_list args; ecl_va_start(args,v2asdf_system_system,narg,2);
  cl_parse_key(args,0,NULL,NULL,NULL,TRUE);
  ecl_va_end(args);
  if (Null(L4198find_symbol_(3, VV[2678], VV[1601], ECL_NIL))){
   goto L1;
  }
  value0 = cl_error(1, VV[2679]);
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for RUN-SHELL-COMMAND                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5308run_shell_command(volatile cl_narg narg, cl_object volatile v1asdf_backward_interface__control_string, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile env0 = ECL_NIL;
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2680]);
 {
  cl_object volatile v2asdf_backward_interface__args;
  ecl_va_list args; ecl_va_start(args,v1asdf_backward_interface__control_string,narg,1);
  v2asdf_backward_interface__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  {
   volatile cl_object v3asdf_backward_interface__command;
   v3asdf_backward_interface__command = cl_apply(4, ECL_SYM("FORMAT",389), ECL_NIL, v1asdf_backward_interface__control_string, v2asdf_backward_interface__args);
   (cl_env_copy->function=ecl_fdefinition(VV[1611]))->cfun.entry(2, VV[2681], v3asdf_backward_interface__command) /*  ASDF-MESSAGE */;
   {
    volatile cl_object v4asdf_backward_interface__exit_code;
    {
     volatile cl_object env1 = env0;
     env1 = ECL_NIL;
     CLV0 = env1 = CONS(ECL_NIL,env1);
     {
      volatile cl_object env2 = env1;
      CLV1 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY     */
      {
       ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV1));
       if (__ecl_frs_push_result!=0) {
       if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
        goto L4;
       }
       ecl_internal_error("GO found an inexistent tag");
       } else {
       {
        cl_object v5;
        v5 = ecl_make_cclosure_va((cl_objectfn)LC5307__lambda8225,env2,Cblock,1);
        T0 = v5;
       }
       T1 = CONS(ECL_SYM("ERROR",339),T0);
       T2 = ecl_list1(T1);
       T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
       ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
       {
        struct ecl_stack_frame _ecl_inner_frame_aux;
        cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
        cl_env_copy->values[0] = (cl_env_copy->function=ecl_fdefinition(VV[1227]))->cfun.entry(7, v3asdf_backward_interface__command, VV[2684], ECL_T, VV[1266], ECL_T, ECL_SYM("OUTPUT",1319), ecl_cmp_symbol_value(cl_env_copy,VV[1610])) /*  RUN-PROGRAM */;
        ecl_stack_frame_push_values(_ecl_inner_frame);
        T0 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
        ecl_stack_frame_close(_ecl_inner_frame);
       }
       v4asdf_backward_interface__exit_code = ecl_caddr(T0);
       ecl_frs_pop_n(cl_env_copy, 1);
       ecl_bds_unwind1(cl_env_copy);
       goto L3;
L4:;
       {
        cl_object v5condition;
        v5condition = ECL_CONS_CAR(CLV0);
        cl_env_copy->nvalues = 2;
        cl_env_copy->values[1] = v5condition;
        cl_env_copy->values[0] = ECL_NIL;
        v4asdf_backward_interface__exit_code = cl_env_copy->values[0];
        ecl_frs_pop_n(cl_env_copy, 1);
        goto L3;
       }
       }
      }
     }
    }
L3:;
    {
     cl_fixnum v5;
     cl_fixnum v6;
     v5 = (cl_fixnum)(0);
     v6 = v5;
     if (!(ECL_FIXNUMP(v4asdf_backward_interface__exit_code))){
      goto L11;
     }
     v6 = ecl_fixnum(v4asdf_backward_interface__exit_code);
     if (!((v6)<=((cl_fixnum)(255)))){
      goto L11;
     }
     if (!((v6)>=((cl_fixnum)(0)))){
      goto L11;
     }
    }
    value0 = v4asdf_backward_interface__exit_code;
    cl_env_copy->nvalues = 1;
    return value0;
L11:;
    value0 = ecl_make_uint8_t(255);
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* local function COMPONENT-PROPERTY                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5309component_property(cl_object v1asdf_backward_interface__c, cl_object v2asdf_backward_interface__property)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6;
  v3 = cl_slot_value(v1asdf_backward_interface__c, VV[2688]);
  v4 = (ECL_SYM("EQUAL",337)->symbol.gfdef);
  v5 = v2asdf_backward_interface__property;
  v6 = v3;
  T0 = ecl_assoc(v5,v6);
 }
 value0 = ecl_cdr(T0);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5309component_property_va(cl_narg narg, cl_object v3asdf_backward_interface__c, cl_object v4asdf_backward_interface__property, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2687]);
 {
  return LC5309component_property(v3asdf_backward_interface__c, v4asdf_backward_interface__property);
 }
}
/* local function COMPONENT-PROPERTY                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5310component_property(cl_object v1asdf_backward_interface__new_value, cl_object v2asdf_backward_interface__c, cl_object v3asdf_backward_interface__property)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4asdf_backward_interface__a;
  {
   cl_object v5;
   cl_object v6;
   cl_object v7;
   cl_object v8;
   v5 = cl_slot_value(v2asdf_backward_interface__c, VV[2688]);
   v6 = (ECL_SYM("EQUAL",337)->symbol.gfdef);
   v7 = v3asdf_backward_interface__property;
   v8 = v5;
   v4asdf_backward_interface__a = ecl_assoc(v7,v8);
  }
  if (Null(v4asdf_backward_interface__a)){
   goto L8;
  }
  {
   cl_object v5;
   v5 = v1asdf_backward_interface__new_value;
   {
    cl_object v6;
    v6 = v4asdf_backward_interface__a;
    if (ecl_unlikely(ECL_ATOM(v6))) FEtype_error_cons(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T0 = v6;
   }
   (ECL_CONS_CDR(T0)=v5,T0);
   goto L2;
  }
L8:;
  {
   cl_object v6;
   T0 = cl_slot_value(v2asdf_backward_interface__c, VV[2688]);
   v6 = cl_acons(v3asdf_backward_interface__property, v1asdf_backward_interface__new_value, T0);
   (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v6, v2asdf_backward_interface__c, VV[2688]) /*  (SETF SLOT-VALUE) */;
  }
 }
L2:;
 value0 = v1asdf_backward_interface__new_value;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5310component_property_va(cl_narg narg, cl_object v4asdf_backward_interface__new_value, cl_object v5asdf_backward_interface__c, cl_object v6asdf_backward_interface__property, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[2687]);
 {
  return LC5310component_property(v4asdf_backward_interface__new_value, v5asdf_backward_interface__c, v6asdf_backward_interface__property);
 }
}
/* function definition for WRAP-MODULE-PROVIDER                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5311wrap_module_provider(cl_object v1provider, cl_object v2name)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3results;
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   cl_env_copy->values[0] = ecl_function_dispatch(cl_env_copy,v1provider)(1, v2name);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   v3results = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
   ecl_stack_frame_close(_ecl_inner_frame);
  }
  if (Null(ecl_car(v3results))){
   goto L4;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, v2name) /*  COERCE-NAME */;
  (cl_env_copy->function=ecl_fdefinition(VV[1791]))->cfun.entry(1, T0) /*  REGISTER-PRELOADED-SYSTEM */;
L4:;
  value0 = cl_values_list(v3results);
  return value0;
 }
}
static cl_object L5311wrap_module_provider_va(cl_narg narg, cl_object v4provider, cl_object v5name, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2690]);
 {
  return L5311wrap_module_provider(v4provider, v5name);
 }
}
/* function definition for WRAP-MODULE-PROVIDER-FUNCTION                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L5313wrap_module_provider_function(cl_object v1provider)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1provider,env0);             /*  PROVIDER                */
 T0 = ecl_cmp_symbol_value(cl_env_copy,VV[2689]);
 {
  cl_object v2;
  v2 = ecl_make_cclosure_va((cl_objectfn)LC5312__lambda8290,env0,Cblock,1);
  T1 = v2;
 }
 T2 = cl_constantly(T1);
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[367]))->cfun.entry(3, ECL_CONS_CAR(CLV0), T0, T2) /*  ENSURE-GETHASH */;
 return value0;
}
static cl_object L5313wrap_module_provider_function_va(cl_narg narg, cl_object v2provider, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2692]);
 {
  return L5313wrap_module_provider_function(v2provider);
 }
}
/* local function IMPORT-OPTIONS                                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4234import_options(cl_object v1uiop_package__key, cl_object v2uiop_package__table)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4uiop_package__i;
  cl_object v5;
  {
   cl_object v6;
   T0 = LC4232table_keys(v2uiop_package__table);
   v6 = LC4231sort_names(T0);
   if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v3 = v6;
  }
  v4uiop_package__i = ECL_NIL;
  v5 = v3;
  {
   cl_object v6;
   cl_object v7;
   v6 = ecl_list1(ECL_NIL);
   v7 = v6;
L10:;
   if (!(ecl_endp(v5))){
    goto L12;
   }
   goto L11;
L12:;
   v4uiop_package__i = ECL_CONS_CAR(v5);
   {
    cl_object v8;
    v8 = ECL_CONS_CDR(v5);
    if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v8;
   }
   {
    cl_object v8;
    v8 = v7;
    if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T0 = v8;
   }
   T2 = ecl_gethash_safe(v4uiop_package__i,v2uiop_package__table,ECL_NIL);
   T1 = LC4231sort_names(T2);
   T2 = cl_listX(3, v1uiop_package__key, v4uiop_package__i, T1);
   v7 = ecl_list1(T2);
   (ECL_CONS_CDR(T0)=v7,T0);
   goto L10;
L11:;
   value0 = ecl_cdr(v6);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
static cl_object LC4234import_options_va(cl_narg narg, cl_object v8uiop_package__key, cl_object v9uiop_package__table, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[114]);
 {
  return LC4234import_options(v8uiop_package__key, v9uiop_package__table);
 }
}
/* local function WHEN-RELEVANT                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4233when_relevant(cl_object v1uiop_package__key, cl_object v2uiop_package__value)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v2uiop_package__value)){
  goto L2;
 }
 T0 = CONS(v1uiop_package__key,v2uiop_package__value);
 value0 = ecl_list1(T0);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4233when_relevant_va(cl_narg narg, cl_object v3uiop_package__key, cl_object v4uiop_package__value, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[113]);
 {
  return LC4233when_relevant(v3uiop_package__key, v4uiop_package__value);
 }
}
/* local function TABLE-KEYS                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4232table_keys(cl_object v1uiop_package__table)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3uiop_package__k;
  cl_object v4;
  v2 = ECL_NIL;
  v3uiop_package__k = ECL_NIL;
  v4 = ECL_NIL;
  {
   cl_object v5;
   v5 = si_hash_table_iterator(v1uiop_package__table);
   {
    cl_object v6;
    cl_object v7;
    v6 = ecl_list1(ECL_NIL);
    v7 = v6;
L8:;
    {
     cl_object v8;
     cl_object v9;
     cl_object v10;
     value0 = ecl_function_dispatch(cl_env_copy,v5)(0);
     {
      const int v11 = cl_env_copy->nvalues;
      v8 = value0;
      cl_object v12;
      v12 = (v11<=1)? ECL_NIL : cl_env_copy->values[1];
      v9 = v12;
      v12 = (v11<=2)? ECL_NIL : cl_env_copy->values[2];
      v10 = v12;
     }
     if (Null(v8)){
      goto L13;
     }
     v4 = v10;
     v3uiop_package__k = v9;
L13:;
     v2 = v8;
     if (v2!=ECL_NIL) {
      goto L10;
     }
    }
    goto L9;
L10:;
    {
     cl_object v8;
     v8 = v7;
     if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     T0 = v8;
    }
    v7 = ecl_list1(v3uiop_package__k);
    (ECL_CONS_CDR(T0)=v7,T0);
    goto L8;
L9:;
    value0 = ecl_cdr(v6);
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
static cl_object LC4232table_keys_va(cl_narg narg, cl_object v8uiop_package__table, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[111]);
 {
  return LC4232table_keys(v8uiop_package__table);
 }
}
/* local function SORT-NAMES                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4231sort_names(cl_object v1uiop_package__names)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_copy_list(v1uiop_package__names);
 T1 = (ECL_SYM("STRING<",823)->symbol.gfdef);
 value0 = cl_sort(2, T0, T1);
 return value0;
}
static cl_object LC4231sort_names_va(cl_narg narg, cl_object v2uiop_package__names, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[110]);
 {
  return LC4231sort_names(v2uiop_package__names);
 }
}
/* closure LAMBDA820                                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4247__lambda820(cl_narg narg, cl_object v1uiop_package__x, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  NAMES                   */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[170]);
 {
L1:;
  {
   cl_object v2;
   cl_object v3;
   v2 = v1uiop_package__x;
   v3 = ECL_CONS_CAR(CLV0);
   value0 = ecl_member(v2,v3);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
 }
}
/* closure RECURSE                                                            */
/* optimize speed 0, debug 3, space 1, safety 3                               */
static cl_object LC4255recurse(cl_narg narg, cl_object v1uiop_common_lisp__substrings, cl_object v2uiop_common_lisp__start, cl_object v3uiop_common_lisp__end, ...)
{
 struct ecl_ihs_frame ihs;
 const cl_object _ecl_debug_env = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV5 = env0;
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[205]);
 {
  {
   static const struct ecl_var_debug_info _ecl_descriptors[]={
   {"UIOP/COMMON-LISP::SUBSTRINGS",_ecl_object_loc}
   ,{"UIOP/COMMON-LISP::START",_ecl_object_loc}
   ,{"UIOP/COMMON-LISP::END",_ecl_object_loc}};
   const cl_index _ecl_debug_info_raw[]={
   (cl_index)(ECL_NIL),(cl_index)(_ecl_descriptors),(cl_index)(&v1uiop_common_lisp__substrings),(cl_index)(&v2uiop_common_lisp__start),(cl_index)(&v3uiop_common_lisp__end)};
   ecl_def_ct_vector(_ecl_debug_env,ecl_aet_index,_ecl_debug_info_raw,5,,);
   ecl_ihs_push(cl_env_copy,&ihs,VV[205],ECL_NIL,_ecl_debug_env);
L1:;
   {
    cl_object v4;
    v4 = ecl_make_bool(ecl_greatereq(v2uiop_common_lisp__start,v3uiop_common_lisp__end));
    {
     static const struct ecl_var_debug_info _ecl_descriptors[]={
     {"#:G1139",_ecl_object_loc}};
     const cl_index _ecl_debug_info_raw[]={
     (cl_index)(_ecl_debug_env),(cl_index)(_ecl_descriptors),(cl_index)(&v4)};
     ecl_def_ct_vector(_ecl_debug_env,ecl_aet_index,_ecl_debug_info_raw,3,,);
     ihs.lcl_env = _ecl_debug_env;
     if (Null(v4)){
      goto L3;
     }
     value0 = v4;
     cl_env_copy->nvalues = 1;
     ecl_ihs_pop(cl_env_copy);
     return value0;
L3:;
     if (!(v1uiop_common_lisp__substrings==ECL_NIL)){
      goto L5;
     }
     value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4254emit_substring(2, v2uiop_common_lisp__start, v3uiop_common_lisp__end));
     ecl_ihs_pop(cl_env_copy);
     return value0;
L5:;
     {
      cl_object v5uiop_common_lisp__sub_spec;
      cl_object v6uiop_common_lisp__sub;
      cl_object v7uiop_common_lisp__fun;
      cl_object v8uiop_common_lisp__found;
      cl_object v9uiop_common_lisp__more;
      v5uiop_common_lisp__sub_spec = ecl_car(v1uiop_common_lisp__substrings);
      if (!(ECL_CONSP(v5uiop_common_lisp__sub_spec))){
       goto L9;
      }
      v6uiop_common_lisp__sub = ecl_car(v5uiop_common_lisp__sub_spec);
      goto L8;
L9:;
      v6uiop_common_lisp__sub = v5uiop_common_lisp__sub_spec;
L8:;
      if (!(ECL_CONSP(v5uiop_common_lisp__sub_spec))){
       goto L12;
      }
      v7uiop_common_lisp__fun = ecl_cdr(v5uiop_common_lisp__sub_spec);
      goto L11;
L12:;
      v7uiop_common_lisp__fun = ECL_CONS_CAR(CLV1);
L11:;
      v8uiop_common_lisp__found = (cl_env_copy->function=(ECL_SYM("SEARCH",742)->symbol.gfdef))->cfun.entry(6, v6uiop_common_lisp__sub, ECL_CONS_CAR(CLV0), ECL_SYM("START2",1349), v2uiop_common_lisp__start, ECL_SYM("END2",1258), v3uiop_common_lisp__end) /*  SEARCH */;
      v9uiop_common_lisp__more = ecl_cdr(v1uiop_common_lisp__substrings);
      {
       static const struct ecl_var_debug_info _ecl_descriptors[]={
       {"UIOP/COMMON-LISP::MORE",_ecl_object_loc}
       ,{"UIOP/COMMON-LISP::FOUND",_ecl_object_loc}
       ,{"UIOP/COMMON-LISP::FUN",_ecl_object_loc}
       ,{"UIOP/COMMON-LISP::SUB",_ecl_object_loc}
       ,{"UIOP/COMMON-LISP::SUB-SPEC",_ecl_object_loc}};
       const cl_index _ecl_debug_info_raw[]={
       (cl_index)(_ecl_debug_env),(cl_index)(_ecl_descriptors),(cl_index)(&v9uiop_common_lisp__more),(cl_index)(&v8uiop_common_lisp__found),(cl_index)(&v7uiop_common_lisp__fun),(cl_index)(&v6uiop_common_lisp__sub),(cl_index)(&v5uiop_common_lisp__sub_spec)};
       ecl_def_ct_vector(_ecl_debug_env,ecl_aet_index,_ecl_debug_info_raw,7,,);
       ihs.lcl_env = _ecl_debug_env;
       if (Null(v8uiop_common_lisp__found)){
        goto L16;
       }
       (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4255recurse(3, v9uiop_common_lisp__more, v2uiop_common_lisp__start, v8uiop_common_lisp__found));
       {
        if (v7uiop_common_lisp__fun==ECL_NIL) {
         goto L19;
        }
        if (!(ECL_STRINGP(v7uiop_common_lisp__fun))){
         goto L21;
        }
        (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4253emit_string(1, v7uiop_common_lisp__fun));
        goto L19;
L21:;
        if (Null(cl_functionp(v7uiop_common_lisp__fun))){
         goto L23;
        }
        ecl_function_dispatch(cl_env_copy,v7uiop_common_lisp__fun)(2, v6uiop_common_lisp__sub, ECL_CONS_CAR(CLV5));
        goto L19;
L23:;
        (cl_env_copy->function=(ECL_SYM("ETYPECASE-ERROR",1891)->symbol.gfdef))->cfun.entry(2, v7uiop_common_lisp__fun, VV[206]) /*  ETYPECASE-ERROR */;
       }
L19:;
       {
        cl_fixnum v10;
        v10 = ecl_length(v6uiop_common_lisp__sub);
        v2uiop_common_lisp__start = ecl_plus(v8uiop_common_lisp__found,ecl_make_fixnum(v10));
       }
       ihs.lcl_env = _ecl_debug_env;
       goto L1;
L16:;
       v1uiop_common_lisp__substrings = v9uiop_common_lisp__more;
       ihs.lcl_env = _ecl_debug_env;
       goto L1;
       ihs.lcl_env = _ecl_debug_env;
      }
     }
     ihs.lcl_env = _ecl_debug_env;
    }
   }
  }
 }
 }
}
/* closure EMIT-SUBSTRING                                                     */
/* optimize speed 0, debug 3, space 1, safety 3                               */
static cl_object LC4254emit_substring(cl_narg narg, cl_object v1uiop_common_lisp__start, cl_object v2uiop_common_lisp__end, ...)
{
 struct ecl_ihs_frame ihs;
 const cl_object _ecl_debug_env = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV5 = env0;
 CLV4 = _ecl_cdr(CLV5);                           /*  STREAM                  */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[204]);
 {
  {
   static const struct ecl_var_debug_info _ecl_descriptors[]={
   {"UIOP/COMMON-LISP::START",_ecl_object_loc}
   ,{"UIOP/COMMON-LISP::END",_ecl_object_loc}};
   const cl_index _ecl_debug_info_raw[]={
   (cl_index)(ECL_NIL),(cl_index)(_ecl_descriptors),(cl_index)(&v1uiop_common_lisp__start),(cl_index)(&v2uiop_common_lisp__end)};
   ecl_def_ct_vector(_ecl_debug_env,ecl_aet_index,_ecl_debug_info_raw,4,,);
   ecl_ihs_push(cl_env_copy,&ihs,VV[204],ECL_NIL,_ecl_debug_env);
L1:;
   if (!(ecl_zerop(v1uiop_common_lisp__start))){
    goto L2;
   }
   if (!(ecl_number_equalp(v2uiop_common_lisp__end,ECL_CONS_CAR(CLV3)))){
    goto L2;
   }
   cl_env_copy->values[0] = ECL_CONS_CAR(CLV0);
   cl_env_copy->nvalues = 1;
   cl_return_from(ECL_CONS_CAR(CLV2),VV[202]);
L2:;
   value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4253emit_string(3, ECL_CONS_CAR(CLV0), v1uiop_common_lisp__start, v2uiop_common_lisp__end));
   ecl_ihs_pop(cl_env_copy);
   return value0;
  }
 }
 }
}
/* closure EMIT-STRING                                                        */
/* optimize speed 0, debug 3, space 1, safety 3                               */
static cl_object LC4253emit_string(cl_narg narg, cl_object v1uiop_common_lisp__x, ...)
{
 cl_object T0;
 struct ecl_ihs_frame ihs;
 const cl_object _ecl_debug_env = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV5 = env0;
 CLV4 = _ecl_cdr(CLV5);                           /*  STREAM                  */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[203]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[203]);
 {
  cl_object v2uiop_common_lisp__start;
  cl_object v3uiop_common_lisp__end;
  va_list args; va_start(args,v1uiop_common_lisp__x);
  {
   static const struct ecl_var_debug_info _ecl_descriptors[]={
   {"UIOP/COMMON-LISP::X",_ecl_object_loc}};
   const cl_index _ecl_debug_info_raw[]={
   (cl_index)(ECL_NIL),(cl_index)(_ecl_descriptors),(cl_index)(&v1uiop_common_lisp__x)};
   ecl_def_ct_vector(_ecl_debug_env,ecl_aet_index,_ecl_debug_info_raw,3,,);
   ecl_ihs_push(cl_env_copy,&ihs,VV[203],ECL_NIL,_ecl_debug_env);
   {
    int i = 1;
    if (i >= narg) {
     v2uiop_common_lisp__start = ecl_make_int8_t(0);
    } else {
     i++;
     v2uiop_common_lisp__start = va_arg(args,cl_object);
    }
    if (i >= narg) {
     v3uiop_common_lisp__end = ecl_make_fixnum(ecl_length(v1uiop_common_lisp__x));
    } else {
     i++;
     v3uiop_common_lisp__end = va_arg(args,cl_object);
    }
   }
   va_end(args);
   if (!(ecl_lower(v2uiop_common_lisp__start,v3uiop_common_lisp__end))){
    goto L3;
   }
   if (ECL_CONS_CAR(CLV4)!=ECL_NIL) {
    goto L5;
   }
   ECL_CONS_CAR(CLV4) = cl_make_string_output_stream(0);
L5:;
   T0 = ECL_CONS_CAR(CLV4);
   value0 = cl_write_string(6, v1uiop_common_lisp__x, T0, ECL_SYM("START",1347), v2uiop_common_lisp__start, ECL_SYM("END",1256), v3uiop_common_lisp__end);
   ecl_ihs_pop(cl_env_copy);
   return value0;
L3:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   ecl_ihs_pop(cl_env_copy);
   return value0;
  }
 }
 }
}
/* closure LAMBDA1292                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4264__lambda1292(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[233]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* local function LAMBDA1301                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4266__lambda1301(cl_object v1uiop_utility__outer, cl_object v2uiop_utility__inner)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_list1(v2uiop_utility__inner);
 value0 = ecl_append(v1uiop_utility__outer,T0);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4266__lambda1301_va(cl_narg narg, cl_object v3uiop_utility__outer, cl_object v4uiop_utility__inner, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[237]);
 {
  return LC4266__lambda1301(v3uiop_utility__outer, v4uiop_utility__inner);
 }
}
/* local function LAMBDA1343                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4269__lambda1343(cl_object v1uiop_utility__x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_symbol_name(v1uiop_utility__x);
 value0 = cl_gensym(1, T0);
 return value0;
}
static cl_object LC4269__lambda1343_va(cl_narg narg, cl_object v2uiop_utility__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[242]);
 {
  return LC4269__lambda1343(v2uiop_utility__x);
 }
}
/* local function LAMBDA1372                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4270__lambda1372(cl_object v1uiop_utility__c, cl_object v2uiop_utility__v)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(3, ECL_SYM("PUSH",680), VV[245], v2uiop_utility__v);
 value0 = cl_list(4, v1uiop_utility__c, VV[244], T0, VV[246]);
 return value0;
}
static cl_object LC4270__lambda1372_va(cl_narg narg, cl_object v3uiop_utility__c, cl_object v4uiop_utility__v, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[243]);
 {
  return LC4270__lambda1372(v3uiop_utility__c, v4uiop_utility__v);
 }
}
/* local function LAMBDA1383                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4271__lambda1383(cl_object v1uiop_utility__v)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_list(2, ECL_SYM("REVERSE",730), v1uiop_utility__v);
 return value0;
}
static cl_object LC4271__lambda1383_va(cl_narg narg, cl_object v2uiop_utility__v, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[247]);
 {
  return LC4271__lambda1383(v2uiop_utility__v);
 }
}
/* local function LAMBDA1393                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4273__lambda1393(cl_object v1si__v)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_gensym(0);
 value0 = cl_list(2, T0, v1si__v);
 return value0;
}
static cl_object LC4273__lambda1393_va(cl_narg narg, cl_object v2si__v, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[250]);
 {
  return LC4273__lambda1393(v2si__v);
 }
}
/* closure CONSIDER                                                           */
/* optimize speed 1, debug 1, space 1, safety 0                               */
static cl_object LC4282consider(cl_narg narg, cl_object v1uiop_utility__i, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  NIL                     */
 { /* ... closure scanning finished */
L1:;
 if (!(ecl_number_equalp(v1uiop_utility__i,ecl_make_int8_t(1)))){
  goto L2;
 }
 cl_env_copy->values[0] = v1uiop_utility__i;
 cl_env_copy->nvalues = 1;
 cl_return_from(ECL_CONS_CAR(CLV0),ECL_NIL);
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
 }
}
/* closure DONE                                                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4289done(cl_narg narg, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;                                     /*  END                     */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[296]);
 {
L1:;
  T0 = cl_subseq(3, ECL_CONS_CAR(CLV0), ecl_make_int8_t(0), ECL_CONS_CAR(CLV4));
  cl_env_copy->values[0] = CONS(T0,ECL_CONS_CAR(CLV3));
  cl_env_copy->nvalues = 1;
  cl_return_from(ECL_CONS_CAR(CLV2),ECL_NIL);
 }
 }
}
/* closure SEPARATORP                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4288separatorp(cl_narg narg, cl_object v1char, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);                           /*  SEPARATOR               */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[291]);
 {
L1:;
  {
   cl_object v2;
   v2 = si_make_seq_iterator(2, ECL_CONS_CAR(CLV1), ecl_make_int8_t(0));
L3:;
   if (v2!=ECL_NIL) {
    goto L5;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L5:;
   {
    cl_object v3;
    v3 = si_seq_iterator_ref(ECL_CONS_CAR(CLV1), v2);
    if (!(ecl_eql(v1char,v3))){
     goto L7;
    }
    value0 = v3;
    cl_env_copy->nvalues = 1;
    return value0;
   }
L7:;
   v2 = si_seq_iterator_next(ECL_CONS_CAR(CLV1), v2);
   goto L3;
  }
 }
 }
}
/* closure C                                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4294c(cl_narg narg, cl_object v1uiop_utility__end, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  NIL                     */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[309]);
 {
L1:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[300]))->cfun.entry(2, ECL_CONS_CAR(CLV0), v1uiop_utility__end) /*  STRING-SUFFIX-P */)){
   goto L2;
  }
  {
   cl_fixnum v2;
   v2 = ecl_length(ECL_CONS_CAR(CLV0));
   {
    cl_fixnum v3;
    v3 = ecl_length(v1uiop_utility__end);
    T0 = ecl_minus(ecl_make_fixnum(v2),ecl_make_fixnum(v3));
    T1 = cl_subseq(3, ECL_CONS_CAR(CLV0), ecl_make_int8_t(0), T0);
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = v1uiop_utility__end;
    cl_env_copy->values[0] = T1;
   }
  }
  cl_return_from(ECL_CONS_CAR(CLV1),ECL_NIL);
L2:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* local function LAMBDA1648                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4308__lambda1648(cl_object v1si__v)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_gensym(0);
 value0 = cl_list(2, T0, v1si__v);
 return value0;
}
static cl_object LC4308__lambda1648_va(cl_narg narg, cl_object v2si__v, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[342]);
 {
  return LC4308__lambda1648(v2si__v);
 }
}
/* closure LAMBDA1670                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4310__lambda1670(cl_narg narg, cl_object v1uiop_utility__x, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  FUN                     */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[345]);
 {
L1:;
  value0 = cl_gethash(2, v1uiop_utility__x, ECL_CONS_CAR(CLV0));
  return value0;
 }
 }
}
/* closure LAMBDA1672                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4311__lambda1672(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  FUN                     */
 { /* ... closure scanning finished */
 {
  cl_object v1uiop_utility__args;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1uiop_utility__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  T0 = ecl_car(ECL_CONS_CAR(CLV0));
  T1 = ecl_cdr(ECL_CONS_CAR(CLV0));
  T2 = ecl_append(T1,v1uiop_utility__args);
  value0 = cl_apply(2, T0, T2);
  return value0;
 }
 }
}
/* local function ACCESS                                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4313access(cl_object v1uiop_utility__object, cl_object v2uiop_utility__accessor)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_functionp(v2uiop_utility__accessor))){
  goto L2;
 }
 value0 = ecl_function_dispatch(cl_env_copy,v2uiop_utility__accessor)(1, v1uiop_utility__object);
 return value0;
L2:;
 if (!(ECL_FIXNUMP(v2uiop_utility__accessor)||ECL_BIGNUMP(v2uiop_utility__accessor))){
  goto L4;
 }
 value0 = ecl_elt(v1uiop_utility__object,ecl_to_size(v2uiop_utility__accessor));
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 if (Null(cl_keywordp(v2uiop_utility__accessor))){
  goto L6;
 }
 value0 = cl_getf(2, v1uiop_utility__object, v2uiop_utility__accessor);
 return value0;
L6:;
 if (!(v2uiop_utility__accessor==ECL_NIL)){
  goto L8;
 }
 value0 = v1uiop_utility__object;
 cl_env_copy->nvalues = 1;
 return value0;
L8:;
 if (!(ECL_SYMBOLP(v2uiop_utility__accessor))){
  goto L10;
 }
 value0 = ecl_function_dispatch(cl_env_copy,v2uiop_utility__accessor)(1, v1uiop_utility__object);
 return value0;
L10:;
 if (!(ECL_CONSP(v2uiop_utility__accessor))){
  goto L12;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[344]))->cfun.entry(1, v2uiop_utility__accessor) /*  ENSURE-FUNCTION */;
 value0 = ecl_function_dispatch(cl_env_copy,T0)(1, v1uiop_utility__object);
 return value0;
L12:;
 value0 = si_etypecase_error(v2uiop_utility__accessor, VV[351]);
 return value0;
}
static cl_object LC4313access_va(cl_narg narg, cl_object v3uiop_utility__object, cl_object v4uiop_utility__accessor, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[350]);
 {
  return LC4313access(v3uiop_utility__object, v4uiop_utility__accessor);
 }
}
/* closure LAMBDA1790                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4329__lambda1790(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[395]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA1795                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4330__lambda1795(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[397]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA1807                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4333__lambda1807(cl_narg narg, cl_object v1uiop_utility__c, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  CONDITIONS              */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[403]);
 {
L1:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[400]))->cfun.entry(2, v1uiop_utility__c, ECL_CONS_CAR(CLV0)) /*  MATCH-ANY-CONDITION-P */)){
   goto L2;
  }
  value0 = cl_muffle_warning(1, v1uiop_utility__c);
  return value0;
L2:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* local function LAMBDA1824                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4336__lambda1824(cl_object v1condition, cl_object v2stream)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_slot_value(v1condition, VV[411]);
 T1 = cl_slot_value(v1condition, VV[412]);
 T2 = cl_slot_value(v1condition, VV[413]);
 value0 = cl_format(5, v2stream, VV[410], T0, T1, T2);
 return value0;
}
static cl_object LC4336__lambda1824_va(cl_narg narg, cl_object v3condition, cl_object v4stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[409]);
 {
  return LC4336__lambda1824(v3condition, v4stream);
 }
}
/* local function LAMBDA1829                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4339__lambda1829(cl_object v1condition, cl_object v2stream)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_slot_value(v1condition, VV[412]);
 T1 = cl_slot_value(v1condition, VV[411]);
 T2 = cl_slot_value(v1condition, VV[413]);
 value0 = cl_apply(5, ECL_SYM("FORMAT",389), v2stream, T0, T1, T2);
 return value0;
}
static cl_object LC4339__lambda1829_va(cl_narg narg, cl_object v3condition, cl_object v4stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[418]);
 {
  return LC4339__lambda1829(v3condition, v4stream);
 }
}
/* local function LAMBDA1892                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4359__lambda1892(cl_object v1uiop_os__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = si_make_seq_iterator(2, VV[474], ecl_make_int8_t(0));
L3:;
  if (v2!=ECL_NIL) {
   goto L5;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L5:;
  {
   cl_object v3;
   v3 = si_seq_iterator_ref(VV[474], v2);
   if (!(ecl_eql(v1uiop_os__x,v3))){
    goto L7;
   }
   value0 = v3;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L7:;
  v2 = si_seq_iterator_next(VV[474], v2);
  goto L3;
 }
}
static cl_object LC4359__lambda1892_va(cl_narg narg, cl_object v3uiop_os__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[473]);
 {
  return LC4359__lambda1892(v3uiop_os__x);
 }
}
/* closure LAMBDA1947                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4367__lambda1947(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[495]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* local function UNSPECIFIC-HANDLER                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4375unspecific_handler(cl_object v1uiop_pathname__p)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(si_logical_pathname_p(v1uiop_pathname__p))){
  goto L2;
 }
 value0 = ecl_fdefinition(VV[514]);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = (ECL_SYM("IDENTITY",428)->symbol.gfdef);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4375unspecific_handler_va(cl_narg narg, cl_object v2uiop_pathname__p, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[520]);
 {
  return LC4375unspecific_handler(v2uiop_pathname__p);
 }
}
/* local function NORMALIZE-COMPONENT                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4382normalize_component(cl_object v1uiop_pathname__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v1uiop_pathname__x, ECL_NIL))){
  goto L6;
 }
 goto L2;
L6:;
 goto L4;
L4:;
 if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v1uiop_pathname__x, ECL_SYM("UNSPECIFIC",1357)))){
  goto L10;
 }
 goto L2;
L10:;
 goto L8;
L8:;
 if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v1uiop_pathname__x, ECL_SYM("NEWEST",1312)))){
  goto L14;
 }
 goto L2;
L14:;
 goto L12;
L12:;
 if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v1uiop_pathname__x, VV[499]))){
  goto L17;
 }
 goto L2;
L17:;
 goto L3;
L3:;
 value0 = v1uiop_pathname__x;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4382normalize_component_va(cl_narg narg, cl_object v2uiop_pathname__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[537]);
 {
  return LC4382normalize_component(v2uiop_pathname__x);
 }
}
/* local function CHECK-ONE                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4390check_one(cl_object v1uiop_pathname__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v1uiop_pathname__x, ECL_NIL))){
  goto L6;
 }
 value0 = VV[562];
 goto L4;
L6:;
 value0 = ECL_NIL;
 goto L4;
L4:;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 if (Null(ecl_function_dispatch(cl_env_copy,ECL_SYM("EQUAL",337))(2, v1uiop_pathname__x, ECL_SYM("UNSPECIFIC",1357)))){
  goto L9;
 }
 value0 = VV[563];
 cl_env_copy->nvalues = 1;
 return value0;
L9:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4390check_one_va(cl_narg narg, cl_object v2uiop_pathname__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[561]);
 {
  return LC4390check_one(v2uiop_pathname__x);
 }
}
/* closure LAMBDA2143                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4392__lambda2143(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[569]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* local function LAMBDA2194                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4394__lambda2194(cl_object v1uiop_pathname__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = (ECL_SYM("EQUAL",337)->symbol.gfdef);
  if (!(ecl_equal(v1uiop_pathname__x,VV[96]))){
   goto L7;
  }
  value0 = VV[581];
  goto L5;
L7:;
  value0 = ECL_NIL;
  goto L5;
L5:;
  if (value0!=ECL_NIL) {
   goto L4;
  }
  if (!(ecl_equal(v1uiop_pathname__x,VV[378]))){
   goto L10;
  }
  value0 = VV[582];
  cl_env_copy->nvalues = 1;
  return value0;
L10:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4394__lambda2194_va(cl_narg narg, cl_object v3uiop_pathname__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[580]);
 {
  return LC4394__lambda2194(v3uiop_pathname__x);
 }
}
/* local function ERR                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4398err(volatile cl_object *lex0)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_error(2, VV[600], lex0[0]);
 return value0;
}
/* closure LAMBDA2327                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4413__lambda2327(cl_narg narg, cl_object v1uiop_pathname__x, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  SEPARATOR               */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[650]);
 {
L1:;
  value0 = ecl_make_bool(((v1uiop_pathname__x)==ECL_CODE_CHAR((ecl_character)(58))));
  if (value0!=ECL_NIL) {
   goto L3;
  }
  value0 = ecl_make_bool(ecl_eql(v1uiop_pathname__x,ECL_CONS_CAR(CLV0)));
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure LAMBDA2352                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4418__lambda2352(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[663]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA2364                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4420__lambda2364(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  TAGBODY                 */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[667]);
 {
L1:;
  cl_go(ECL_CONS_CAR(CLV0),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA2378                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4422__lambda2378(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[671]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA2405                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4427__lambda2405(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[689]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA2430                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4429__lambda2430(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  TAGBODY                 */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[696]);
 {
L1:;
  ECL_CONS_CAR(CLV1) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV2),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA2432                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4430__lambda2432(cl_narg narg, cl_object v1uiop_filesystem__f, ...)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  DIR                     */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[697]);
 {
L1:;
  T0 = cl_pathname_name(1, v1uiop_filesystem__f);
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[514]))->cfun.entry(1, T0) /*  MAKE-PATHNAME-COMPONENT-LOGICAL */;
  T2 = cl_pathname_type(1, v1uiop_filesystem__f);
  T3 = (cl_env_copy->function=ecl_fdefinition(VV[514]))->cfun.entry(1, T2) /*  MAKE-PATHNAME-COMPONENT-LOGICAL */;
  T4 = cl_pathname_version(v1uiop_filesystem__f);
  T5 = (cl_env_copy->function=ecl_fdefinition(VV[514]))->cfun.entry(1, T4) /*  MAKE-PATHNAME-COMPONENT-LOGICAL */;
  value0 = cl_make_pathname(8, ECL_SYM("DEFAULTS",1247), ECL_CONS_CAR(CLV0), ECL_SYM("NAME",1309), T1, ECL_SYM("TYPE",1356), T3, ECL_SYM("VERSION",1364), T5);
  return value0;
 }
 }
}
/* closure LAMBDA2444                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4432__lambda2444(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  TAGBODY                 */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[701]);
 {
L1:;
  ECL_CONS_CAR(CLV1) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV2),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA2446                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4433__lambda2446(cl_narg narg, cl_object v1uiop_filesystem__d, ...)
{
 cl_object T0, T1, T2;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  PREFIX                  */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[702]);
 {
L1:;
  {
   cl_object v2uiop_filesystem__dir;
   T0 = cl_pathname_directory(1, v1uiop_filesystem__d);
   v2uiop_filesystem__dir = (cl_env_copy->function=ecl_fdefinition(VV[497]))->cfun.entry(1, T0) /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */;
   if (!(ECL_CONSP(v2uiop_filesystem__dir))){
    goto L4;
   }
   T0 = ecl_cdr(v2uiop_filesystem__dir);
   if (!(ECL_CONSP(T0))){
    goto L4;
   }
   T0 = ecl_last(v2uiop_filesystem__dir,1);
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[514]))->cfun.entry(1, T0) /*  MAKE-PATHNAME-COMPONENT-LOGICAL */;
   T2 = ecl_append(ECL_CONS_CAR(CLV1),T1);
   value0 = cl_make_pathname(10, ECL_SYM("DEFAULTS",1247), ECL_CONS_CAR(CLV0), ECL_SYM("NAME",1309), ECL_NIL, ECL_SYM("TYPE",1356), ECL_NIL, ECL_SYM("VERSION",1364), ECL_NIL, ECL_SYM("DIRECTORY",1250), T2);
   return value0;
L4:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
 }
}
/* closure LAMBDA2478                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4436__lambda2478(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[709]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA2483                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4437__lambda2483(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[711]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* closure REPORT-ERROR                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4441report_error(cl_narg narg, cl_object v1keyword, cl_object v2uiop_filesystem__description, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  ON-ERROR                */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[718]);
 {
  cl_object v3uiop_filesystem__arguments;
  ecl_va_list args; ecl_va_start(args,v2uiop_filesystem__description,narg,2);
  v3uiop_filesystem__arguments = cl_grab_rest_args(args);
  ecl_va_end(args);
  value0 = ECL_CONS_CAR(CLV1);
  if (value0!=ECL_NIL) {
   goto L3;
  }
  T0 = ECL_SYM("ERROR",339);
  goto L1;
L3:;
  T0 = value0;
  goto L1;
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(6, T0, VV[719], ECL_CONS_CAR(CLV0), v1keyword, v2uiop_filesystem__description, v3uiop_filesystem__arguments) /*  CALL-FUNCTION */;
  return value0;
 }
 }
}
/* closure LAMBDA2608                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4455__lambda2608(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  TAGBODY                 */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[784]);
 {
L1:;
  cl_go(ECL_CONS_CAR(CLV0),ecl_make_fixnum(0));
 }
 }
}
/* closure C                                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4459c(cl_narg narg, cl_object v1uiop_utility__x, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[802]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = CONS(v1uiop_utility__x,ECL_CONS_CAR(CLV0));
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
 }
}
/* closure LAMBDA2684                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4470__lambda2684(cl_narg narg, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV6 = env0;                                     /*  PRESERVE-WHITESPACE     */
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[835]);
 {
L1:;
  T0 = cl_find_package(ECL_CONS_CAR(CLV1));
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T0); /*  *PACKAGE*         */
  value0 = cl_read_from_string(9, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV2), ECL_CONS_CAR(CLV3), ECL_SYM("START",1347), ECL_CONS_CAR(CLV4), ECL_SYM("END",1256), ECL_CONS_CAR(CLV5), VV[836], ECL_CONS_CAR(CLV6));
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
 }
}
/* closure LAMBDA2735                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4476__lambda2735(cl_narg narg, cl_object v1uiop_stream__output, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  STRING                  */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[850]);
 {
L1:;
  value0 = ecl_princ(ECL_CONS_CAR(CLV0),v1uiop_stream__output);
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* local function LAMBDA2777                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4482__lambda2777(cl_object v1uiop_stream__input)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_function_dispatch(cl_env_copy,VV[863])(1, v1uiop_stream__input);
 return value0;
}
static cl_object LC4482__lambda2777_va(cl_narg narg, cl_object v2uiop_stream__input, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[862]);
 {
  return LC4482__lambda2777(v2uiop_stream__input);
 }
}
/* closure LAMBDA2841                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4489__lambda2841(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[879]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA2851                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4493__lambda2851(volatile cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  ARGS                    */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[884]);
 {
L1:;
  T0 = cl_find_package(VV[36]);
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T0); /*  *PACKAGE*         */
  {
   volatile cl_object env1 = env0;
   CLV3 = env1 = CONS(ECL_NIL,env1);
   {
    volatile cl_object env2 = env1;
    CLV4 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY       */
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV4));
     if (__ecl_frs_push_result!=0) {
     if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
      goto L3;
     }
     ecl_internal_error("GO found an inexistent tag");
     } else {
     {
      cl_object v1;
      v1 = ecl_make_cclosure_va((cl_objectfn)LC4492__lambda2856,env2,Cblock,1);
      T0 = v1;
     }
     T1 = CONS(ECL_SYM("ERROR",339),T0);
     T2 = ecl_list1(T1);
     T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
     ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
     cl_apply(4, VV[881], ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV2));
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     goto L2;
L3:;
     {
      cl_object v1condition;
      v1condition = ECL_CONS_CAR(CLV3);
      ecl_frs_pop_n(cl_env_copy, 1);
      goto L2;
     }
     }
    }
   }
  }
L2:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[877]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  FINISH-OUTPUTS */;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
 }
}
/* closure LAMBDA2916                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4505__lambda2916(cl_narg narg, cl_object v1uiop_stream__input, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  AT                      */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[910]);
 {
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[898]))->cfun.entry(3, v1uiop_stream__input, VV[911], ECL_CONS_CAR(CLV0)) /*  SLURP-STREAM-LINE */;
  return value0;
 }
 }
}
/* closure LAMBDA2919                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4507__lambda2919(cl_narg narg, cl_object v1uiop_stream__input, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  COUNT                   */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[914]);
 {
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[900]))->cfun.entry(3, v1uiop_stream__input, ECL_SYM("COUNT",1499), ECL_CONS_CAR(CLV0)) /*  SLURP-STREAM-FORMS */;
  return value0;
 }
 }
}
/* closure LAMBDA2922                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4509__lambda2922(cl_narg narg, cl_object v1uiop_stream__input, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  AT                      */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[917]);
 {
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[903]))->cfun.entry(3, v1uiop_stream__input, VV[911], ECL_CONS_CAR(CLV0)) /*  SLURP-STREAM-FORM */;
  return value0;
 }
 }
}
/* closure LAMBDA2925                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4511__lambda2925(cl_narg narg, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  PACKAGE                 */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[920]);
 {
L1:;
  T0 = cl_find_package(ECL_CONS_CAR(CLV2));
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T0); /*  *PACKAGE*         */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[259]))->cfun.entry(2, ECL_SYM("PACKAGE",1321), ECL_CONS_CAR(CLV1)) /*  REMOVE-PLIST-KEY */;
  value0 = cl_apply(3, VV[909], ECL_CONS_CAR(CLV0), T0);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
 }
}
/* closure LAMBDA2928                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4513__lambda2928(cl_narg narg, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  PACKAGE                 */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[923]);
 {
L1:;
  T0 = cl_find_package(ECL_CONS_CAR(CLV2));
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T0); /*  *PACKAGE*         */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[259]))->cfun.entry(2, ECL_SYM("PACKAGE",1321), ECL_CONS_CAR(CLV1)) /*  REMOVE-PLIST-KEY */;
  value0 = cl_apply(3, VV[916], ECL_CONS_CAR(CLV0), T0);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
 }
}
/* local function LAMBDA2933                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4515__lambda2933(cl_object v1uiop_stream__input)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2uiop_stream__results;
  v2uiop_stream__results = ECL_NIL;
  {
   cl_object v3uiop_stream__form;
   v3uiop_stream__form = ECL_NIL;
L4:;
   v3uiop_stream__form = cl_read(3, v1uiop_stream__input, ECL_NIL, VV[927]);
   if (!((v3uiop_stream__form)==(VV[927]))){
    goto L8;
   }
   goto L5;
L8:;
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    cl_env_copy->values[0] = cl_eval(v3uiop_stream__form);
    ecl_stack_frame_push_values(_ecl_inner_frame);
    v2uiop_stream__results = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
    ecl_stack_frame_close(_ecl_inner_frame);
   }
   goto L4;
L5:;
   value0 = cl_apply(2, ECL_SYM("VALUES",899), v2uiop_stream__results);
   return value0;
  }
 }
}
static cl_object LC4515__lambda2933_va(cl_narg narg, cl_object v4uiop_stream__input, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[926]);
 {
  return LC4515__lambda2933(v4uiop_stream__input);
 }
}
/* closure LAMBDA2953                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4518__lambda2953(cl_narg narg, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  PACKAGE                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[933]);
 {
L1:;
  T0 = cl_find_package(ECL_CONS_CAR(CLV1));
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T0); /*  *PACKAGE*         */
  ecl_bds_bind(cl_env_copy,ECL_SYM("*READ-EVAL*",65),ECL_T); /*  *READ-EVAL*  */
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[929]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  EVAL-THUNK */;
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
 }
}
/* closure LAMBDA2997                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4525__lambda2997(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[958]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* local function BEFORE3063                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4528__before3063(cl_object v1uiop_stream__pn)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = v1uiop_stream__pn;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4528__before3063_va(cl_narg narg, cl_object v2uiop_stream__pn, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[975]);
 {
  return LC4528__before3063(v2uiop_stream__pn);
 }
}
/* closure LAMBDA3098                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4539__lambda3098(volatile cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  ARGUMENTS               */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1004]);
 {
L1:;
  T0 = cl_find_package(VV[36]);
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T0); /*  *PACKAGE*         */
  {
   volatile cl_object env1 = env0;
   CLV2 = env1 = CONS(ECL_NIL,env1);
   {
    volatile cl_object env2 = env1;
    CLV3 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY       */
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV3));
     if (__ecl_frs_push_result!=0) {
     if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
      goto L2;
     }
     ecl_internal_error("GO found an inexistent tag");
     } else {
     {
      cl_object v1;
      v1 = ecl_make_cclosure_va((cl_objectfn)LC4538__lambda3103,env2,Cblock,1);
      T0 = v1;
     }
     T1 = CONS(ECL_SYM("ERROR",339),T0);
     T2 = ecl_list1(T1);
     T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
     ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[881]))->cfun.entry(4, ecl_cmp_symbol_value(cl_env_copy,VV[811]), VV[1007], ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1)) /*  FORMAT! */;
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     ecl_bds_unwind1(cl_env_copy);
     return value0;
L2:;
     {
      cl_object v1condition;
      v1condition = ECL_CONS_CAR(CLV2);
      cl_env_copy->nvalues = 2;
      cl_env_copy->values[1] = v1condition;
      cl_env_copy->values[0] = ECL_NIL;
      ecl_frs_pop_n(cl_env_copy, 1);
      ecl_bds_unwind1(cl_env_copy);
      return cl_env_copy->values[0];
     }
     }
    }
   }
  }
 }
 }
}
/* closure LAMBDA3134                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4543__lambda3134(volatile cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  KEYS                    */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1013]);
 {
L1:;
  T0 = cl_find_package(VV[36]);
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T0); /*  *PACKAGE*         */
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59),ECL_NIL); /*  *PRINT-READABLY* */
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-CIRCLE*",49),ECL_T); /*  *PRINT-CIRCLE* */
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-MISER-WIDTH*",55),ecl_make_int8_t(75)); /*  *PRINT-MISER-WIDTH* */
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-LENGTH*",52),ECL_NIL); /*  *PRINT-LENGTH* */
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-LEVEL*",53),ECL_NIL); /*  *PRINT-LEVEL* */
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-PRETTY*",57),ECL_T); /*  *PRINT-PRETTY* */
  {
   volatile cl_object env1 = env0;
   CLV1 = env1 = CONS(ECL_NIL,env1);
   {
    volatile cl_object env2 = env1;
    CLV2 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY       */
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV2));
     if (__ecl_frs_push_result!=0) {
     if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
      goto L2;
     }
     ecl_internal_error("GO found an inexistent tag");
     } else {
     {
      cl_object v1;
      v1 = ecl_make_cclosure_va((cl_objectfn)LC4542__lambda3145,env2,Cblock,1);
      T0 = v1;
     }
     T1 = CONS(ECL_SYM("ERROR",339),T0);
     T2 = ecl_list1(T1);
     T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
     ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
     value0 = cl_apply(2, VV[1009], ECL_CONS_CAR(CLV0));
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind_n(cl_env_copy,8);
     return value0;
L2:;
     {
      cl_object v1condition;
      v1condition = ECL_CONS_CAR(CLV1);
      cl_env_copy->nvalues = 2;
      cl_env_copy->values[1] = v1condition;
      cl_env_copy->values[0] = ECL_NIL;
      ecl_frs_pop_n(cl_env_copy, 1);
      ecl_bds_unwind_n(cl_env_copy,7);
      return cl_env_copy->values[0];
     }
     }
    }
   }
  }
 }
 }
}
/* closure LAMBDA3212                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4559__lambda3212(cl_narg narg, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  ENTRY-POINT             */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1056]);
 {
L1:;
  T0 = ECL_CONS_CAR(CLV0);
  ecl_cmp_setq(cl_env_copy,VV[989],T0);
  T0 = ECL_CONS_CAR(CLV1);
  ecl_cmp_setq(cl_env_copy,VV[992],T0);
  T0 = ECL_CONS_CAR(CLV2);
  ecl_cmp_setq(cl_env_copy,VV[994],T0);
  T0 = VV[1057];
  ecl_cmp_setq(cl_env_copy,VV[993],T0);
  (cl_env_copy->function=ecl_fdefinition(VV[1037]))->cfun.entry(0) /*  CALL-IMAGE-RESTORE-HOOK */;
  (cl_env_copy->function=ecl_fdefinition(VV[932]))->cfun.entry(1, ECL_CONS_CAR(CLV2)) /*  STANDARD-EVAL-THUNK */;
  T0 = ECL_T;
  ecl_cmp_setq(cl_env_copy,VV[993],T0);
  {
   cl_object v1uiop_image__results;
   {
    struct ecl_stack_frame _ecl_inner_frame_aux;
    cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
    if (Null(ECL_CONS_CAR(CLV3))){
     goto L16;
    }
    cl_env_copy->values[0] = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(1, ECL_CONS_CAR(CLV3)) /*  CALL-FUNCTION */;
    goto L15;
L16:;
    cl_env_copy->values[0] = ECL_T;
    cl_env_copy->nvalues = 1;
L15:;
    ecl_stack_frame_push_values(_ecl_inner_frame);
    v1uiop_image__results = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
    ecl_stack_frame_close(_ecl_inner_frame);
   }
   if (Null(ECL_CONS_CAR(CLV0))){
    goto L18;
   }
   value0 = cl_apply(2, ECL_SYM("VALUES",899), v1uiop_image__results);
   return value0;
L18:;
   T0 = ecl_car(v1uiop_image__results);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1031]))->cfun.entry(1, T0) /*  SHELL-BOOLEAN-EXIT */;
   return value0;
  }
 }
 }
}
/* closure LAMBDA3281                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4563__lambda3281(cl_narg narg, cl_object v1uiop_run_program__c, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;
 CLV0 = _ecl_cdr(CLV1);                           /*  GOOD-CHARS              */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1082]);
 {
L1:;
  {
   cl_object v2;
   v2 = si_make_seq_iterator(2, ECL_CONS_CAR(CLV0), ecl_make_int8_t(0));
L4:;
   if (v2!=ECL_NIL) {
    goto L6;
   }
   T0 = ECL_NIL;
   goto L2;
L6:;
   {
    cl_object v3;
    v3 = si_seq_iterator_ref(ECL_CONS_CAR(CLV0), v2);
    if (!(ecl_eql(v1uiop_run_program__c,v3))){
     goto L8;
    }
    T0 = v3;
    goto L2;
   }
L8:;
   v2 = si_seq_iterator_next(ECL_CONS_CAR(CLV0), v2);
   goto L4;
  }
L2:;
  value0 = Null(T0)?ECL_T:ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure LAMBDA3305                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4564__lambda3305(cl_narg narg, cl_object v1uiop_run_program__c, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  BAD-CHARS               */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1083]);
 {
L1:;
  {
   cl_object v2;
   v2 = si_make_seq_iterator(2, ECL_CONS_CAR(CLV1), ecl_make_int8_t(0));
L3:;
   if (v2!=ECL_NIL) {
    goto L5;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L5:;
   {
    cl_object v3;
    v3 = si_seq_iterator_ref(ECL_CONS_CAR(CLV1), v2);
    if (!(ecl_eql(v1uiop_run_program__c,v3))){
     goto L7;
    }
    value0 = v3;
    cl_env_copy->nvalues = 1;
    return value0;
   }
L7:;
   v2 = si_seq_iterator_next(ECL_CONS_CAR(CLV1), v2);
   goto L3;
  }
 }
 }
}
/* closure LAMBDA3329                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4566__lambda3329(cl_narg narg, cl_object v1stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  ESCAPER                 */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1089]);
 {
L1:;
  if (Null(ECL_CONS_CAR(CLV1))){
   goto L3;
  }
  T0 = cl_list(2, VV[1090], ECL_CONS_CAR(CLV1));
  goto L2;
L3:;
  T0 = ECL_NIL;
L2:;
  value0 = cl_apply(4, ECL_CONS_CAR(CLV2), ECL_CONS_CAR(CLV0), v1stream, T0);
  return value0;
 }
 }
}
/* local function ISSUE-BACKSLASH                                             */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4569issue_backslash(volatile cl_object *lex0, cl_object v1uiop_run_program__n)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  {
   cl_object v3;
   v3 = v1uiop_run_program__n;
   T0 = cl_realp(v3);
   if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(ECL_SYM("REAL",706),v3);
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 0;
   v2 = v3;
  }
L5:;
  v2 = ecl_minus(v2,ecl_make_int8_t(1));
  T0 = v2;
  if (!(ecl_minusp(T0))){
   goto L7;
  }
  goto L6;
L7:;
  LC4568issue(lex0, ECL_CODE_CHAR(92));
  goto L5;
L6:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* local function ISSUE                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4568issue(volatile cl_object *lex0, cl_object v1uiop_run_program__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_princ(v1uiop_run_program__c,lex0[0]);
 cl_env_copy->nvalues = 1;
 return value0;
}
/* local function LAMBDA3399                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4570__lambda3399(cl_object v1uiop_run_program__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_make_bool(((v1uiop_run_program__c)==ECL_CODE_CHAR((ecl_character)(92))));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4570__lambda3399_va(cl_narg narg, cl_object v2uiop_run_program__c, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1097]);
 {
  return LC4570__lambda3399(v2uiop_run_program__c);
 }
}
/* closure LAMBDA3493                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4578__lambda3493(cl_narg narg, cl_object v1uiop_run_program__s, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  ESCAPER                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1116]);
 {
L1:;
  {
   cl_object v2first;
   v2first = ECL_NIL;
   {
    cl_object v3;
    cl_object v4uiop_run_program__token;
    cl_object v5;
    {
     cl_object v6;
     v6 = ECL_CONS_CAR(CLV0);
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v3 = v6;
    }
    v4uiop_run_program__token = ECL_NIL;
    v5 = v3;
    v2first = ECL_T;
L8:;
    if (!(ecl_endp(v5))){
     goto L12;
    }
    goto L9;
L12:;
    v4uiop_run_program__token = ECL_CONS_CAR(v5);
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v6;
    }
    if (v2first!=ECL_NIL) {
     goto L21;
    }
    ecl_princ_char((ecl_character)(32),v1uiop_run_program__s);
L21:;
    ecl_function_dispatch(cl_env_copy,ECL_CONS_CAR(CLV1))(2, v4uiop_run_program__token, v1uiop_run_program__s);
    v2first = ECL_NIL;
    goto L8;
L9:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
 }
}
/* closure LAMBDA3514                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4595__lambda3514(cl_narg narg, cl_object v1uiop_run_program__output, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  LINEWISE                */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1136]);
 {
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[888]))->cfun.entry(8, ECL_CONS_CAR(CLV0), v1uiop_run_program__output, ECL_SYM("ELEMENT-TYPE",1255), ECL_CONS_CAR(CLV1), VV[1131], ECL_CONS_CAR(CLV2), VV[1130], ECL_CONS_CAR(CLV3)) /*  COPY-STREAM-TO-STREAM */;
  return value0;
 }
 }
}
/* closure LAMBDA3524                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4604__lambda3524(cl_narg narg, cl_object v1uiop_run_program__output, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  LINEWISE                */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1140]);
 {
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[888]))->cfun.entry(8, ECL_CONS_CAR(CLV0), v1uiop_run_program__output, ECL_SYM("ELEMENT-TYPE",1255), ECL_CONS_CAR(CLV1), VV[1131], ECL_CONS_CAR(CLV2), VV[1130], ECL_CONS_CAR(CLV3)) /*  COPY-STREAM-TO-STREAM */;
  return value0;
 }
 }
}
/* local function LAMBDA3529                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4607__lambda3529(cl_object v1condition, cl_object v2stream)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1146]))->cfun.entry(1, v1condition) /*  SUBPROCESS-ERROR-PROCESS */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1147]))->cfun.entry(1, v1condition) /*  SUBPROCESS-ERROR-COMMAND */;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[1148]))->cfun.entry(1, v1condition) /*  SUBPROCESS-ERROR-CODE */;
 value0 = cl_format(5, v2stream, VV[1145], T0, T1, T2);
 return value0;
}
static cl_object LC4607__lambda3529_va(cl_narg narg, cl_object v3condition, cl_object v4stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1144]);
 {
  return LC4607__lambda3529(v3condition, v4stream);
 }
}
/* local function LAMBDA3596                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4616__lambda3596(cl_object v1stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(cl_streamp(v1stream))){
  goto L3;
 }
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[987]))->cfun.entry(1, v1stream) /*  FILE-OR-SYNONYM-STREAM-P */;
 value0 = Null(T0)?ECL_T:ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4616__lambda3596_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1179]);
 {
  return LC4616__lambda3596(v2stream);
 }
}
/* closure LAMBDA3598                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4617__lambda3598(cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV8 = env0;                                     /*  %ERROR-OUTPUT           */
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1181]);
 {
L1:;
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   T0 = ecl_car(ECL_CONS_CAR(CLV4));
   T1 = ecl_cdr(ECL_CONS_CAR(CLV4));
   T2 = cl_list(2, T0, T1);
   T3 = cl_listX(7, ECL_SYM("INPUT",1289), ECL_CONS_CAR(CLV6), ECL_SYM("OUTPUT",1319), ECL_CONS_CAR(CLV7), ECL_SYM("WAIT",1367), ECL_CONS_CAR(CLV3), VV[1182]);
   T4 = cl_list(2, ECL_SYM("ERROR",1260), ECL_CONS_CAR(CLV8));
   T5 = cl_list(6, ECL_SYM("IF-INPUT-DOES-NOT-EXIST",1280), ECL_CONS_CAR(CLV1), ECL_SYM("IF-OUTPUT-EXISTS",1281), ECL_CONS_CAR(CLV5), ECL_SYM("IF-ERROR-EXISTS",1278), ECL_CONS_CAR(CLV2));
   T6 = cl_append(5, T2, T3, T4, T5, ECL_CONS_CAR(CLV0));
   cl_env_copy->values[0] = cl_apply(2, ECL_SYM("RUN-PROGRAM",1842), T6);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   value0 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
   ecl_stack_frame_close(_ecl_inner_frame);
   return value0;
  }
 }
 }
}
/* local function STORE-CODES                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4619store_codes(cl_narg narg, volatile cl_object *lex0, cl_object v1uiop_run_program__exit_code, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1185]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1185]);
 {
  cl_object v2uiop_run_program__signal_code;
  va_list args; va_start(args,v1uiop_run_program__exit_code);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_run_program__signal_code = ECL_NIL;
   } else {
    i++;
    v2uiop_run_program__signal_code = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(v2uiop_run_program__signal_code)){
   goto L2;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1175]))->cfun.entry(1, v2uiop_run_program__signal_code) /*  %SIGNAL-TO-EXIT-CODE */;
  LC4618prop(lex0, VV[1186], T0);
  value0 = LC4618prop(lex0, VV[1187], v2uiop_run_program__signal_code);
  return value0;
L2:;
  value0 = LC4618prop(lex0, VV[1186], v1uiop_run_program__exit_code);
  return value0;
 }
}
/* local function PROP                                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4618prop(volatile cl_object *lex0, cl_object v1uiop_run_program__key, cl_object v2uiop_run_program__value)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ECL_CONS_CAR(VV[3452]))->cfun.entry(3, v2uiop_run_program__value, lex0[0], v1uiop_run_program__key) /*  (SETF SLOT-VALUE) */;
 return value0;
}
/* closure HARD-CASE                                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4637hard_case(cl_narg narg, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV9 = env0;
 CLV8 = _ecl_cdr(CLV9);
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1232]);
 {
L1:;
  if (Null(ECL_CONS_CAR(CLV3))){
   goto L2;
  }
  value0 = ecl_function_dispatch(cl_env_copy,ECL_CONS_CAR(CLV1))(2, ECL_SYM("STREAM",1350), ECL_CONS_CAR(CLV9));
  return value0;
L2:;
  {
   cl_object v1;
   v1 = ecl_make_cclosure_va((cl_objectfn)LC4636__before3733,env0,Cblock,1);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[948]))->cfun.entry(5, v1, VV[970], ECL_NIL, VV[971], ECL_T) /*  CALL-WITH-TEMPORARY-FILE */;
   return value0;
  }
 }
 }
}
/* closure EASY-CASE                                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4633easy_case(cl_narg narg, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV9 = env0;
 CLV8 = _ecl_cdr(CLV9);
 CLV7 = _ecl_cdr(CLV8);                           /*  ACTUAL-SPEC             */
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1231]);
 {
L1:;
  value0 = ecl_function_dispatch(cl_env_copy,ECL_CONS_CAR(CLV1))(2, ECL_CONS_CAR(CLV7), ECL_NIL);
  return value0;
 }
 }
}
/* closure ACTIVITY                                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4632activity(cl_narg narg, cl_object v1stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV9 = env0;
 CLV8 = _ecl_cdr(CLV9);                           /*  ACTIVITY-SPEC           */
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1230]);
 {
L1:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1125]))->cfun.entry(3, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV8), v1stream) /*  CALL-STREAM-PROCESSOR */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, ECL_CONS_CAR(CLV4), T0) /*  CALL-FUNCTION */;
  return value0;
 }
 }
}
/* closure LAMBDA3870                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4648__lambda3870(volatile cl_narg narg, cl_object volatile v1uiop_run_program__reduced_output, cl_object volatile v2uiop_run_program__output_activity, ...)
{
 cl_object T0, T1, T2;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9, CLV10, CLV11;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV9 = env0;                                     /*  PROCESS-INFO            */
 CLV8 = _ecl_cdr(CLV9);
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1257]);
 {
  CLV10 = env0 = CONS(v1uiop_run_program__reduced_output,env0); /*  REDUCED-OUTPUT */
  CLV11 = env0 = CONS(v2uiop_run_program__output_activity,env0); /*  OUTPUT-ACTIVITY */
  T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*ERROR-OUTPUT*",35));
  {
   cl_object volatile v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4646__lambda3872,env0,Cblock,2);
   T1 = v3;
  }
  {
   bool v3;
   v3 = (ECL_CONS_CAR(CLV4))==(VV[1164]);
   {
    cl_object volatile v4;
    v4 = ecl_make_cclosure_va((cl_objectfn)LC4647__lambda3893,env0,Cblock,1);
    T2 = v4;
   }
   value0 = cl_apply(10, VV[1224], VV[1127], T0, ECL_T, T1, VV[1164], ECL_CONS_CAR(CLV3), ecl_make_bool(v3), T2, ECL_CONS_CAR(CLV1));
   return value0;
  }
 }
 }
}
/* closure LAMBDA3897                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4649__lambda3897(cl_narg narg, cl_object v1, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV9 = env0;
 CLV8 = _ecl_cdr(CLV9);
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);                           /*  OUTPUT-RESULT           */
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1265]);
 {
L1:;
  ECL_CONS_CAR(CLV6) = v1;
  value0 = ECL_CONS_CAR(CLV6);
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* local function REDIRECT                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4652redirect(cl_object v1uiop_run_program__spec, cl_object v2uiop_run_program__operator)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3pathname;
  if (!(v1uiop_run_program__spec==ECL_NIL)){
   goto L3;
  }
  v3pathname = (cl_env_copy->function=ecl_fdefinition(VV[865]))->cfun.entry(0) /*  NULL-DEVICE-PATHNAME */;
  goto L2;
L3:;
  if (!(ECL_STRINGP(v1uiop_run_program__spec))){
   goto L5;
  }
  v3pathname = (cl_env_copy->function=ecl_fdefinition(VV[658]))->cfun.entry(1, v1uiop_run_program__spec) /*  PARSE-NATIVE-NAMESTRING */;
  goto L2;
L5:;
  if (Null(cl_pathnamep(v1uiop_run_program__spec))){
   goto L7;
  }
  v3pathname = v1uiop_run_program__spec;
  goto L2;
L7:;
  if (Null(cl_typep(2, v1uiop_run_program__spec, VV[1163]))){
   goto L9;
  }
  goto L13;
L12:;
  si_assert_failure(1, VV[1273]);
L13:;
  if (ecl_equal(v2uiop_run_program__operator,VV[1274])) {
   goto L16;
  }
  goto L12;
L16:;
  value0 = VV[1275];
  cl_env_copy->nvalues = 1;
  return value0;
L9:;
  v3pathname = ECL_NIL;
L2:;
  if (Null(v3pathname)){
   goto L18;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[656]))->cfun.entry(1, v3pathname) /*  NATIVE-NAMESTRING */;
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[1113]))->cfun.entry(1, T0) /*  ESCAPE-SHELL-TOKEN */;
  value0 = cl_list(3, v2uiop_run_program__operator, VV[1276], T1);
  return value0;
L18:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4652redirect_va(cl_narg narg, cl_object v4uiop_run_program__spec, cl_object v5uiop_run_program__operator, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1272]);
 {
  return LC4652redirect(v4uiop_run_program__spec, v5uiop_run_program__operator);
 }
}
/* closure LAMBDA3912                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4654__lambda3912(cl_narg narg, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  %COMMAND                */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1285]);
 {
L1:;
  {
   cl_object v1;
   cl_object v2;
   cl_object v3;
   v1 = ecl_cmp_symbol_value(cl_env_copy,VV[805]);
   v2 = ecl_cmp_symbol_value(cl_env_copy,VV[808]);
   v3 = ecl_cmp_symbol_value(cl_env_copy,VV[811]);
   ecl_bds_bind(cl_env_copy,ECL_SYM("*STANDARD-INPUT*",68),v1); /*  *STANDARD-INPUT* */
   ecl_bds_bind(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69),v2); /*  *STANDARD-OUTPUT* */
   ecl_bds_bind(cl_env_copy,ECL_SYM("*ERROR-OUTPUT*",35),v3); /*  *ERROR-OUTPUT* */
   value0 = si_system(ECL_CONS_CAR(CLV0));
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   ecl_bds_unwind1(cl_env_copy);
   return value0;
  }
 }
 }
}
/* closure LAMBDA3935                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4659__lambda3935(cl_narg narg, cl_object v1uiop_run_program__reduced_output, cl_object v2, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV6 = env0;                                     /*  EXIT-CODE               */
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1288]);
 {
  CLV7 = env0 = CONS(v1uiop_run_program__reduced_output,env0); /*  REDUCED-OUTPUT */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4657__lambda3938,env0,Cblock,2);
   T0 = v3;
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4658__lambda3945,env0,Cblock,1);
   T1 = v3;
  }
  value0 = cl_apply(10, VV[1224], VV[1127], ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*ERROR-OUTPUT*",35)), ECL_NIL, T0, VV[1164], ECL_CONS_CAR(CLV3), ECL_NIL, T1, ECL_CONS_CAR(CLV1));
  return value0;
 }
 }
}
/* closure LAMBDA3949                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4660__lambda3949(cl_narg narg, cl_object v1, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV6 = env0;
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);                           /*  OUTPUT-RESULT           */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1292]);
 {
L1:;
  ECL_CONS_CAR(CLV4) = v1;
  value0 = ECL_CONS_CAR(CLV4);
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* local function DEFAULT                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4663default(cl_object v1uiop_run_program__x, cl_object v2uiop_run_program__xp, cl_object v3uiop_run_program__output)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v2uiop_run_program__xp)){
  goto L2;
 }
 value0 = v1uiop_run_program__x;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!((v3uiop_run_program__output)==(ECL_SYM("INTERACTIVE",1290)))){
  goto L4;
 }
 value0 = ECL_SYM("INTERACTIVE",1290);
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4663default_va(cl_narg narg, cl_object v4uiop_run_program__x, cl_object v5uiop_run_program__xp, cl_object v6uiop_run_program__output, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[1297]);
 {
  return LC4663default(v4uiop_run_program__x, v5uiop_run_program__xp, v6uiop_run_program__output);
 }
}
/* local function LAMBDA4037                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4672__lambda4037(cl_object v1uiop_lisp_build__c, cl_object v2uiop_lisp_build__s)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1330]))->cfun.entry(1, v1uiop_lisp_build__c) /*  COMPILE-CONDITION-DESCRIPTION */;
 if (value0!=ECL_NIL) {
  goto L4;
 }
 T0 = cl_type_of(v1uiop_lisp_build__c);
 goto L2;
L4:;
 T0 = value0;
 goto L2;
L2:;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1331]))->cfun.entry(1, v1uiop_lisp_build__c) /*  COMPILE-CONDITION-CONTEXT-FORMAT */;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[1332]))->cfun.entry(1, v1uiop_lisp_build__c) /*  COMPILE-CONDITION-CONTEXT-ARGUMENTS */;
 value0 = cl_format(5, v2uiop_lisp_build__s, VV[1329], T0, T1, T2);
 return value0;
}
static cl_object LC4672__lambda4037_va(cl_narg narg, cl_object v3uiop_lisp_build__c, cl_object v4uiop_lisp_build__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1328]);
 {
  return LC4672__lambda4037(v3uiop_lisp_build__c, v4uiop_lisp_build__s);
 }
}
/* closure LAMBDA4071                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4681__lambda4071(cl_narg narg, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  S                       */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1363]);
 {
L1:;
  T0 = cl_find_package(VV[36]);
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),T0); /*  *PACKAGE*         */
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1354]))->cfun.entry(0) /*  REIFY-DEFERRED-WARNINGS */;
  cl_write(7, T0, ECL_SYM("STREAM",1350), ECL_CONS_CAR(CLV0), ECL_SYM("PRETTY",1326), ECL_T, ECL_SYM("READABLY",1333), ECL_T);
  value0 = (ecl_terpri(ECL_CONS_CAR(CLV0)));
  cl_env_copy->nvalues = 1;
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
 }
}
/* closure LAMBDA4158                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4687__lambda4158(cl_narg narg, cl_object v1uiop_lisp_build__c, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  WARNINGS-P              */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1396]);
 {
L1:;
  ECL_CONS_CAR(CLV3) = ECL_T;
  if (si_of_class_p(2, v1uiop_lisp_build__c, ECL_SYM("STYLE-WARNING",830))!=ECL_NIL) {
   goto L4;
  }
  ECL_CONS_CAR(CLV2) = ECL_T;
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L4:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure LAMBDA4162                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4689__lambda4162(volatile cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);                           /*  FILE-ERRORS             */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1398]);
 {
L1:;
  (cl_env_copy->function=ecl_fdefinition(VV[1359]))->cfun.entry(0) /*  RESET-DEFERRED-WARNINGS */;
  {
   volatile cl_object v1;
   v1 = ECL_CONS_CAR(CLV0);
   goto L6;
L5:;
   {
    volatile cl_object v2uiop_lisp_build__file;
    v2uiop_lisp_build__file = ecl_car(v1);
    {
     volatile cl_object env1 = env0;
     CLV4 = env1 = CONS(ECL_NIL,env1);
     {
      volatile cl_object env2 = env1;
      CLV5 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY     */
      {
       ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV5));
       if (__ecl_frs_push_result!=0) {
       if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
        goto L12;
       }
       ecl_internal_error("GO found an inexistent tag");
       } else {
       {
        cl_object v3;
        v3 = ecl_make_cclosure_va((cl_objectfn)LC4688__lambda4170,env2,Cblock,1);
        T1 = v3;
       }
       T2 = CONS(ECL_SYM("ERROR",339),T1);
       T3 = ecl_list1(T2);
       T4 = CONS(T3,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
       ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T4); /*  *HANDLER-CLUSTERS* */
       T0 = (cl_env_copy->function=ecl_fdefinition(VV[922]))->cfun.entry(1, v2uiop_lisp_build__file) /*  SAFE-READ-FILE-FORM */;
       ecl_frs_pop_n(cl_env_copy, 1);
       ecl_bds_unwind1(cl_env_copy);
       goto L11;
L12:;
       {
        cl_object v3uiop_lisp_build__c;
        v3uiop_lisp_build__c = ECL_CONS_CAR(CLV4);
        ECL_CONS_CAR(CLV1) = CONS(v3uiop_lisp_build__c,ECL_CONS_CAR(CLV1));
        T0 = ECL_NIL;
        ecl_frs_pop_n(cl_env_copy, 1);
        goto L11;
       }
       }
      }
     }
    }
L11:;
    (cl_env_copy->function=ecl_fdefinition(VV[1357]))->cfun.entry(1, T0) /*  UNREIFY-DEFERRED-WARNINGS */;
   }
   v1 = ecl_cdr(v1);
L6:;
   if (Null(v1)){
    goto L21;
   }
   goto L5;
L21:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
 }
}
/* closure LAMBDA4177                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4691__lambda4177(volatile cl_narg narg, ...)
{
 cl_object volatile CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  WARNINGS-FILE           */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1404]);
 {
L1:;
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    {
     struct ecl_stack_frame _ecl_inner_frame_aux;
     volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
     cl_env_copy->values[0] = ecl_function_dispatch(cl_env_copy,ECL_CONS_CAR(CLV0))(0);
     ecl_stack_frame_push_values(_ecl_inner_frame);
     (cl_env_copy->function=ecl_fdefinition(VV[1362]))->cfun.entry(1, ECL_CONS_CAR(CLV1)) /*  SAVE-DEFERRED-WARNINGS */;
     ecl_stack_frame_pop_values(_ecl_inner_frame);
     ecl_stack_frame_close(_ecl_inner_frame);
    }
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   (cl_env_copy->function=ecl_fdefinition(VV[1359]))->cfun.entry(0) /*  RESET-DEFERRED-WARNINGS */;
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
 }
}
/* closure LAMBDA4213                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4702__lambda4213(cl_narg narg, cl_object v1uiop_lisp_build__input_file, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  TMP-FILE                */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1430]);
 {
  CLV4 = env0 = CONS(v1uiop_lisp_build__input_file,env0); /*  INPUT-FILE      */
  {
   cl_object v2;
   v2 = ecl_make_cclosure_va((cl_objectfn)LC4701__lambda4215,env0,Cblock,0);
   T0 = v2;
  }
  T1 = cl_namestring(ECL_CONS_CAR(CLV4));
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1403]))->cfun.entry(4, T0, ECL_CONS_CAR(CLV0), VV[1406], T1) /*  CALL-WITH-SAVED-DEFERRED-WARNINGS */;
  return value0;
 }
 }
}
/* local function CHECK-FLAG                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4703check_flag(cl_object v1uiop_lisp_build__flag, cl_object v2uiop_lisp_build__behaviour)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = Null(v1uiop_lisp_build__flag)?ECL_T:ECL_NIL;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 if (!((v2uiop_lisp_build__behaviour)==(VV[1436]))){
  goto L9;
 }
 value0 = VV[1435];
 goto L7;
L9:;
 value0 = ECL_NIL;
 goto L7;
L7:;
 if (value0!=ECL_NIL) {
  goto L6;
 }
 if (!((v2uiop_lisp_build__behaviour)==(VV[1300]))){
  goto L13;
 }
 value0 = VV[1437];
 goto L11;
L13:;
 value0 = ECL_NIL;
 goto L11;
L11:;
 if (value0!=ECL_NIL) {
  goto L6;
 }
 if (!((v2uiop_lisp_build__behaviour)==(ECL_SYM("IGNORE",1282)))){
  goto L16;
 }
 value0 = VV[792];
 cl_env_copy->nvalues = 1;
 return value0;
L16:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L6:;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4703check_flag_va(cl_narg narg, cl_object v3uiop_lisp_build__flag, cl_object v4uiop_lisp_build__behaviour, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1434]);
 {
  return LC4703check_flag(v3uiop_lisp_build__flag, v4uiop_lisp_build__behaviour);
 }
}
/* closure LAMBDA4236                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4705__lambda4236(cl_narg narg, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  KEYS                    */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1441]);
 {
L1:;
  if (cl_pathnamep(ECL_CONS_CAR(CLV0))!=ECL_NIL) {
   goto L4;
  }
  if (ECL_STRINGP(ECL_CONS_CAR(CLV0))) {
   goto L4;
  }
  if (Null(cl_streamp(ECL_CONS_CAR(CLV0)))){
   goto L2;
  }
  goto L3;
L4:;
L3:;
  value0 = cl_apply(3, ECL_SYM("LOAD",489), ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1));
  return value0;
L2:;
  value0 = si_etypecase_error(ECL_CONS_CAR(CLV0), VV[1442]);
  return value0;
 }
 }
}
/* local function LAMBDA4244                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4709__lambda4244(cl_object v1uiop_configuration__c, cl_object v2uiop_configuration__s)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1453]))->cfun.entry(1, v1uiop_configuration__c) /*  CONDITION-FORMAT */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1454]))->cfun.entry(1, v1uiop_configuration__c) /*  CONDITION-FORM */;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[1455]))->cfun.entry(1, v1uiop_configuration__c) /*  CONDITION-LOCATION */;
 T3 = (cl_env_copy->function=ecl_fdefinition(VV[1456]))->cfun.entry(1, v1uiop_configuration__c) /*  CONDITION-ARGUMENTS */;
 T4 = cl_listX(3, T1, T2, T3);
 value0 = cl_format(4, v2uiop_configuration__s, VV[1452], T0, T4);
 return value0;
}
static cl_object LC4709__lambda4244_va(cl_narg narg, cl_object v3uiop_configuration__c, cl_object v4uiop_configuration__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1451]);
 {
  return LC4709__lambda4244(v3uiop_configuration__c, v4uiop_configuration__s);
 }
}
/* closure LAMBDA4320                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4715__lambda4320(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1475]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* local function RELATIVE-COMPONENT-P                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4721relative_component_p(cl_object v1uiop_configuration__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_make_bool(ECL_STRINGP(v1uiop_configuration__c));
 if (value0!=ECL_NIL) {
  goto L3;
 }
 value0 = cl_pathnamep(v1uiop_configuration__c);
 if (value0!=ECL_NIL) {
  goto L3;
 }
 {
  cl_object v2;
  cl_object v3;
  v2 = v1uiop_configuration__c;
  v3 = VV[1517];
  value0 = ecl_memql(v2,v3);
  cl_env_copy->nvalues = 1;
  return value0;
 }
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4721relative_component_p_va(cl_narg narg, cl_object v4uiop_configuration__c, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1516]);
 {
  return LC4721relative_component_p(v4uiop_configuration__c);
 }
}
/* local function ABSOLUTE-COMPONENT-P                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4720absolute_component_p(cl_object v1uiop_configuration__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = ecl_make_bool(ECL_STRINGP(v1uiop_configuration__c));
 if (value0!=ECL_NIL) {
  goto L3;
 }
 value0 = cl_pathnamep(v1uiop_configuration__c);
 if (value0!=ECL_NIL) {
  goto L3;
 }
 if (!((v1uiop_configuration__c)==(VV[1509]))){
  goto L10;
 }
 value0 = VV[1508];
 goto L8;
L10:;
 value0 = ECL_NIL;
 goto L8;
L8:;
 if (value0!=ECL_NIL) {
  goto L7;
 }
 if (!((v1uiop_configuration__c)==(VV[1510]))){
  goto L14;
 }
 value0 = VV[1511];
 goto L12;
L14:;
 value0 = ECL_NIL;
 goto L12;
L12:;
 if (value0!=ECL_NIL) {
  goto L7;
 }
 if (!((v1uiop_configuration__c)==(VV[1512]))){
  goto L18;
 }
 value0 = VV[1513];
 goto L16;
L18:;
 value0 = ECL_NIL;
 goto L16;
L16:;
 if (value0!=ECL_NIL) {
  goto L7;
 }
 if (!((v1uiop_configuration__c)==(VV[1514]))){
  goto L21;
 }
 value0 = VV[1515];
 cl_env_copy->nvalues = 1;
 return value0;
L21:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L7:;
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC4720absolute_component_p_va(cl_narg narg, cl_object v2uiop_configuration__c, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1507]);
 {
  return LC4720absolute_component_p(v2uiop_configuration__c);
 }
}
/* closure LAMBDA4428                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4730__lambda4428(cl_narg narg, cl_object v1uiop_configuration__d, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  MORE                    */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1549]);
 {
L1:;
  T0 = cl_list(2, v1uiop_configuration__d, ECL_CONS_CAR(CLV0));
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1504]))->cfun.entry(1, T0) /*  RESOLVE-LOCATION */;
  return value0;
 }
 }
}
/* closure LAMBDA4452                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4732__lambda4452(cl_narg narg, cl_object v1uiop_configuration__d, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  MORE                    */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1554]);
 {
L1:;
  T0 = cl_list(2, v1uiop_configuration__d, ECL_CONS_CAR(CLV0));
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1504]))->cfun.entry(1, T0) /*  RESOLVE-LOCATION */;
  return value0;
 }
 }
}
/* closure LAMBDA4516                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4747__lambda4516(cl_narg narg, cl_object v1uiop_backward_driver__dir, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  X                       */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1594]);
 {
L1:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[565]))->cfun.entry(1, v1uiop_backward_driver__dir) /*  ENSURE-DIRECTORY-PATHNAME */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[608]))->cfun.entry(2, T0, ECL_CONS_CAR(CLV0)) /*  SUBPATHNAME */;
  return value0;
 }
 }
}
/* local function LAMBDA4573                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4759__lambda4573(cl_object v1asdf_component__c, cl_object v2asdf_component__s)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1651]))->cfun.entry(1, v1asdf_component__c) /*  DUPLICATE-NAMES-NAME */;
 value0 = cl_format(3, v2asdf_component__s, VV[1650], T0);
 return value0;
}
static cl_object LC4759__lambda4573_va(cl_narg narg, cl_object v3asdf_component__c, cl_object v4asdf_component__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1649]);
 {
  return LC4759__lambda4573(v3asdf_component__c, v4asdf_component__s);
 }
}
/* closure .PRINT-UNREADABLE-OBJECT-BODY.                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4763si___print_unreadable_object_body_(cl_narg narg, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  STREAM                  */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1657]);
 {
L1:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1654]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  COMPONENT-FIND-PATH */;
  value0 = cl_format(3, ECL_CONS_CAR(CLV1), VV[1658], T0);
  return value0;
 }
 }
}
/* closure C                                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4778c(cl_narg narg, cl_object v1uiop_utility__x, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1686]);
 {
L1:;
  ECL_CONS_CAR(CLV1) = CONS(v1uiop_utility__x,ECL_CONS_CAR(CLV1));
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
 }
}
/* closure RECURSE                                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4779recurse(cl_narg narg, cl_object v1asdf_component__x, ...)
{
 cl_object T0;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1687]);
 {
L1:;
  {
   cl_object v2asdf_component__it;
   v2asdf_component__it = (cl_env_copy->function=ecl_fdefinition(VV[1688]))->cfun.entry(1, v1asdf_component__x) /*  COMPONENT-IF-FEATURE */;
   if (Null(v2asdf_component__it)){
    goto L5;
   }
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[420]))->cfun.entry(1, v2asdf_component__it) /*  FEATUREP */)){
    goto L2;
   }
   goto L3;
L5:;
  }
L3:;
  if (Null(cl_typep(2, v1asdf_component__x, ECL_CONS_CAR(CLV0)))){
   goto L7;
  }
  (aux_closure.env=ecl_nthcdr(1,env0),cl_env_copy->function=(cl_object)&aux_closure,LC4778c(1, v1asdf_component__x));
L7:;
  if (Null(si_of_class_p(2, v1asdf_component__x, VV[1667]))){
   goto L9;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1672]))->cfun.entry(1, v1asdf_component__x) /*  COMPONENT-CHILDREN */;
  value0 = cl_map(3, ECL_NIL, ECL_CONS_CAR(CLV2), T0);
  return value0;
L9:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L2:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4787call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* closure LAMBDA4723                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4797__lambda4723(cl_narg narg, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  KEY                     */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1713]);
 {
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1708]))->cfun.entry(2, ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV0)) /*  CONSULT-ASDF-CACHE */;
  return value0;
 }
 }
}
/* closure LAMBDA4731                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4798__lambda4731(cl_narg narg, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  TAGBODY                 */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1si__temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1si__temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV2) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV3),ecl_make_fixnum(0));
 }
 }
}
/* local function LAMBDA4733                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4799__lambda4733(cl_object v1asdf_cache__s)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(2, v1asdf_cache__s, VV[1720]);
 return value0;
}
static cl_object LC4799__lambda4733_va(cl_narg narg, cl_object v2asdf_cache__s, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1719]);
 {
  return LC4799__lambda4733(v2asdf_cache__s);
 }
}
/* closure LAMBDA4735                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4800__lambda4735(cl_narg narg, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  TAGBODY                 */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1si__temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1si__temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV2) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV3),ecl_make_fixnum(1));
 }
 }
}
/* local function LAMBDA4737                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4801__lambda4737(cl_object v1asdf_cache__s)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_format(2, v1asdf_cache__s, VV[1724]);
 return value0;
}
static cl_object LC4801__lambda4737_va(cl_narg narg, cl_object v2asdf_cache__s, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1723]);
 {
  return LC4801__lambda4737(v2asdf_cache__s);
 }
}
/* closure LAMBDA4761                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4807__lambda4761(cl_narg narg, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  NAMESTRING              */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1736]);
 {
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1731]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  COMPUTE-FILE-STAMP */;
  return value0;
 }
 }
}
/* local function LAMBDA4765                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4809__lambda4765(cl_object v1asdf_find_system__c, cl_object v2asdf_find_system__s)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1742]))->cfun.entry(1, v1asdf_find_system__c) /*  FORMAT-CONTROL */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1743]))->cfun.entry(1, v1asdf_find_system__c) /*  FORMAT-ARGUMENTS */;
 value0 = cl_apply(4, ECL_SYM("FORMAT",389), v2asdf_find_system__s, T0, T1);
 return value0;
}
static cl_object LC4809__lambda4765_va(cl_narg narg, cl_object v3asdf_find_system__c, cl_object v4asdf_find_system__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1741]);
 {
  return LC4809__lambda4765(v3asdf_find_system__c, v4asdf_find_system__s);
 }
}
/* local function LAMBDA4769                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4811__lambda4769(cl_object v1asdf_find_system__c, cl_object v2asdf_find_system__s)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1748]))->cfun.entry(1, v1asdf_find_system__c) /*  ERROR-NAME */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1749]))->cfun.entry(1, v1asdf_find_system__c) /*  ERROR-PATHNAME */;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[1750]))->cfun.entry(1, v1asdf_find_system__c) /*  ERROR-CONDITION */;
 value0 = cl_format(5, v2asdf_find_system__s, VV[1747], T0, T1, T2);
 return value0;
}
static cl_object LC4811__lambda4769_va(cl_narg narg, cl_object v3asdf_find_system__c, cl_object v4asdf_find_system__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1746]);
 {
  return LC4811__lambda4769(v3asdf_find_system__c, v4asdf_find_system__s);
 }
}
/* closure LAMBDA4860                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4821__lambda4860(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1775]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA5029                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4833__lambda5029(cl_narg narg, cl_object v1asdf_find_system__x, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  OBSOLETE                */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1811]);
 {
L1:;
  {
   cl_object v2;
   cl_object v3;
   v2 = v1asdf_find_system__x;
   v3 = ECL_CONS_CAR(CLV0);
   value0 = ecl_memql(v2,v3);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
 }
}
/* local function LAMBDA5041                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4834__lambda5041(cl_object v1asdf_find_system__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  cl_object v3;
  cl_object v4;
  v2 = ecl_cmp_symbol_value(cl_env_copy,VV[1808]);
  v3 = v1asdf_find_system__x;
  v4 = v2;
  value0 = ecl_memql(v3,v4);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC4834__lambda5041_va(cl_narg narg, cl_object v5asdf_find_system__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1812]);
 {
  return LC4834__lambda5041(v5asdf_find_system__x);
 }
}
/* closure TRY                                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4836try(cl_narg narg, cl_object v1asdf_find_system__f, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  NAME                    */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1816]);
 {
L1:;
  {
   cl_object v2asdf_find_system__x;
   v2asdf_find_system__x = ecl_function_dispatch(cl_env_copy,v1asdf_find_system__f)(1, ECL_CONS_CAR(CLV1));
   if (Null(v2asdf_find_system__x)){
    goto L3;
   }
   cl_env_copy->values[0] = v2asdf_find_system__x;
   cl_env_copy->nvalues = 1;
   cl_return_from(ECL_CONS_CAR(CLV0),VV[1815]);
L3:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
 }
}
/* closure LAMBDA5056                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4838__lambda5056(cl_narg narg, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  DEFAULTS                */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1822]);
 {
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[617]))->cfun.entry(3, ECL_CONS_CAR(CLV0), VV[676], ECL_NIL) /*  ENSURE-ABSOLUTE-PATHNAME */;
  return value0;
 }
 }
}
/* closure LAMBDA5119                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4840__lambda5119(cl_narg narg, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;                                     /*  TAGBODY                 */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1si__temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1si__temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV3) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV4),ecl_make_fixnum(0));
 }
 }
}
/* local function LAMBDA5121                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4841__lambda5121(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_write_string(2, VV[1829], v1stream);
 return value0;
}
static cl_object LC4841__lambda5121_va(cl_narg narg, cl_object v2stream, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1828]);
 {
  return LC4841__lambda5121(v2stream);
 }
}
/* closure LAMBDA5123                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4842__lambda5123(cl_narg narg, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;                                     /*  TAGBODY                 */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1si__temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1si__temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV3) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV4),ecl_make_fixnum(1));
 }
 }
}
/* closure LAMBDA5125                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4843__lambda5125(cl_narg narg, cl_object v1asdf_find_system__s, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);                           /*  DIRECTORIZED            */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1832]);
 {
L1:;
  T0 = ECL_CONS_CAR(CLV2);
  value0 = cl_format(4, v1asdf_find_system__s, VV[1833], T0, ECL_CONS_CAR(CLV0));
  return value0;
 }
 }
}
/* closure LAMBDA5127                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4844__lambda5127(cl_narg narg, cl_object v1asdf_find_system__c, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);                           /*  DIRECTORIZED            */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1835]);
 {
L1:;
  if ((cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, ECL_CONS_CAR(CLV1)) /*  DIRECTORY-PATHNAME-P */!=ECL_NIL) {
   goto L3;
  }
  ECL_CONS_CAR(CLV2) = (cl_env_copy->function=ecl_fdefinition(VV[565]))->cfun.entry(1, ECL_CONS_CAR(CLV1)) /*  ENSURE-DIRECTORY-PATHNAME */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[560]))->cfun.entry(1, ECL_CONS_CAR(CLV2)) /*  DIRECTORY-PATHNAME-P */;
  return value0;
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure LAMBDA5146                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4850__lambda5146(cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;                                     /*  PRINT-PPRINT-DISPATCH   */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1841]);
 {
L1:;
  {
   cl_object v1;
   v1 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("+IO-SYNTAX-PROGV-LIST+",1805));
   {
    cl_object v3, v4; cl_index v2;
    v3 = ECL_CONS_CAR(v1);
    v4 = ECL_CONS_CDR(v1);
    v2 = ecl_progv(cl_env_copy, v3, v4);
    {
     cl_object v5;
     cl_object v6;
     v5 = cl_find_package(VV[1842]);
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[529]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  PHYSICALIZE-PATHNAME */;
     v6 = (cl_env_copy->function=ecl_fdefinition(VV[555]))->cfun.entry(1, T0) /*  PATHNAME-DIRECTORY-PATHNAME */;
     ecl_bds_bind(cl_env_copy,ECL_SYM("*PACKAGE*",45),v5); /*  *PACKAGE*      */
     ecl_bds_bind(cl_env_copy,ECL_SYM("*READTABLE*",67),ECL_CONS_CAR(CLV3)); /*  *READTABLE* */
     ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-PPRINT-DISPATCH*",56),ECL_CONS_CAR(CLV4)); /*  *PRINT-PPRINT-DISPATCH* */
     ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59),ECL_NIL); /*  *PRINT-READABLY* */
     ecl_bds_bind(cl_env_copy,ECL_SYM("*DEFAULT-PATHNAME-DEFAULTS*",34),v6); /*  *DEFAULT-PATHNAME-DEFAULTS* */
     {
      cl_object v7;
      v7 = ecl_make_cclosure_va((cl_objectfn)LC4849__lambda5153,env0,Cblock,1);
      T0 = v7;
     }
     T1 = CONS(VV[1843],T0);
     T2 = ecl_list1(T1);
     T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
     ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
     (cl_env_copy->function=ecl_fdefinition(VV[1611]))->cfun.entry(3, VV[1845], ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV0)) /*  ASDF-MESSAGE */;
     value0 = (cl_env_copy->function=ecl_fdefinition(VV[1440]))->cfun.entry(3, ECL_CONS_CAR(CLV0), ECL_SYM("EXTERNAL-FORMAT",1267), ECL_CONS_CAR(CLV2)) /*  LOAD* */;
     ecl_bds_unwind(cl_env_copy,v2);
     return value0;
    }
   }
  }
 }
 }
}
/* closure LAMBDA5156                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4852__lambda5156(cl_narg narg, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  OLD-VERSION             */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1850]);
 {
L1:;
  {
   cl_object v1asdf_find_system__old_pathname;
   {
    cl_object v2asdf_find_system__pair;
    v2asdf_find_system__pair = (cl_env_copy->function=ecl_fdefinition(VV[1762]))->cfun.entry(1, VV[1803]) /*  SYSTEM-REGISTERED-P */;
    if (Null(v2asdf_find_system__pair)){
     goto L4;
    }
    T0 = ecl_cdr(v2asdf_find_system__pair);
    v1asdf_find_system__old_pathname = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, T0) /*  SYSTEM-SOURCE-FILE */;
    goto L2;
L4:;
    v1asdf_find_system__old_pathname = ECL_NIL;
   }
L2:;
   value0 = (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(5, VV[1851], ECL_CONS_CAR(CLV2), v1asdf_find_system__old_pathname, ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV0)) /*  WARN */;
   return value0;
  }
 }
 }
}
/* closure LAMBDA5171                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4854__lambda5171(cl_narg narg, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  NAME                    */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1854]);
 {
L1:;
  {
   cl_object v1asdf_component_name;
   cl_object v2asdf_find_system__in_memory;
   cl_object v3asdf_find_system__previous;
   cl_object v4asdf_find_system__previous;
   cl_object v5asdf_find_system__previous_time;
   cl_object v6asdf_find_system__found;
   cl_object v7asdf_find_system__found_system;
   cl_object v8pathname;
   cl_object v9asdf_find_system__foundp;
   v1asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  COERCE-NAME */;
   v2asdf_find_system__in_memory = (cl_env_copy->function=ecl_fdefinition(VV[1762]))->cfun.entry(1, v1asdf_component_name) /*  SYSTEM-REGISTERED-P */;
   v3asdf_find_system__previous = ecl_cdr(v2asdf_find_system__in_memory);
   if (Null(si_of_class_p(2, v3asdf_find_system__previous, VV[1695]))){
    goto L7;
   }
   v4asdf_find_system__previous = v3asdf_find_system__previous;
   goto L5;
L7:;
   v4asdf_find_system__previous = ECL_NIL;
   goto L5;
L5:;
   v5asdf_find_system__previous_time = ecl_car(v2asdf_find_system__in_memory);
   v6asdf_find_system__found = (cl_env_copy->function=ecl_fdefinition(VV[1815]))->cfun.entry(1, v1asdf_component_name) /*  SEARCH-FOR-SYSTEM-DEFINITION */;
   if (Null(si_of_class_p(2, v6asdf_find_system__found, VV[1695]))){
    goto L13;
   }
   v7asdf_find_system__found_system = v6asdf_find_system__found;
   goto L11;
L13:;
   v7asdf_find_system__found_system = ECL_NIL;
   goto L11;
L11:;
   if (cl_pathnamep(v6asdf_find_system__found)!=ECL_NIL) {
    goto L23;
   }
   if (!(ECL_STRINGP(v6asdf_find_system__found))){
    goto L21;
   }
   goto L22;
L23:;
L22:;
   value0 = cl_pathname(v6asdf_find_system__found);
   goto L19;
L21:;
   value0 = ECL_NIL;
   goto L19;
L19:;
   if (value0!=ECL_NIL) {
    goto L18;
   }
   if (Null(v7asdf_find_system__found_system)){
    goto L27;
   }
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, v7asdf_find_system__found_system) /*  SYSTEM-SOURCE-FILE */;
   goto L25;
L27:;
   value0 = ECL_NIL;
   goto L25;
L25:;
   if (value0!=ECL_NIL) {
    goto L18;
   }
   if (Null(v4asdf_find_system__previous)){
    goto L30;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, v4asdf_find_system__previous) /*  SYSTEM-SOURCE-FILE */;
   goto L16;
L30:;
   T0 = ECL_NIL;
   goto L16;
L18:;
   T0 = value0;
   goto L16;
L16:;
   v8pathname = (cl_env_copy->function=ecl_fdefinition(VV[596]))->cfun.entry(5, T0, VV[737], ECL_T, ECL_SYM("RESOLVE-SYMLINKS",1950), ecl_cmp_symbol_value(cl_env_copy,VV[715])) /*  ENSURE-PATHNAME */;
   if (v7asdf_find_system__found_system!=ECL_NIL) {
    goto L36;
   }
   if (v8pathname!=ECL_NIL) {
    goto L36;
   }
   if (Null(v4asdf_find_system__previous)){
    goto L34;
   }
   goto L35;
L36:;
L35:;
   v9asdf_find_system__foundp = ECL_T;
   goto L32;
L34:;
   v9asdf_find_system__foundp = ECL_NIL;
   goto L32;
L32:;
   {
    cl_object v10;
    v10 = v6asdf_find_system__found;
    if (v10==ECL_NIL) {
     goto L41;
    }
    if (cl_pathnamep(v10)!=ECL_NIL) {
     goto L41;
    }
    if (si_of_class_p(2, v10, VV[1695])!=ECL_NIL) {
     goto L41;
    }
    v6asdf_find_system__found = si_do_check_type(v10, VV[1855], ECL_NIL, VV[1856]);
L41:;
   }
   if ((cl_env_copy->function=ecl_fdefinition(VV[1848]))->cfun.entry(2, v1asdf_component_name, v8pathname) /*  CHECK-NOT-OLD-ASDF-SYSTEM */!=ECL_NIL) {
    goto L46;
   }
   {
    cl_object v10;
    v10 = v4asdf_find_system__previous;
    if (si_of_class_p(2, v10, VV[1695])!=ECL_NIL) {
     goto L50;
    }
    v4asdf_find_system__previous = si_do_check_type(v10, VV[1695], ECL_NIL, VV[1857]);
L50:;
   }
   v7asdf_find_system__found_system = ECL_NIL;
   v8pathname = ECL_NIL;
L46:;
   cl_env_copy->nvalues = 5;
   cl_env_copy->values[4] = v5asdf_find_system__previous_time;
   cl_env_copy->values[3] = v4asdf_find_system__previous;
   cl_env_copy->values[2] = v8pathname;
   cl_env_copy->values[1] = v7asdf_find_system__found_system;
   cl_env_copy->values[0] = v9asdf_find_system__foundp;
   return cl_env_copy->values[0];
  }
 }
 }
}
/* closure LAMBDA5190                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4856__lambda5190(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  FIND-SYSTEM             */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1859]);
 {
L1:;
  {
   cl_object v1asdf_find_system__primary_name;
   v1asdf_find_system__primary_name = (cl_env_copy->function=ecl_fdefinition(VV[1756]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  PRIMARY-SYSTEM-NAME */;
   if (ecl_equal(ECL_CONS_CAR(CLV0),v1asdf_find_system__primary_name)) {
    goto L2;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[1690]))->cfun.entry(2, v1asdf_find_system__primary_name, ECL_NIL) /*  FIND-SYSTEM */;
  }
L2:;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1793]))){
   goto L9;
  }
  if (Null(ecl_gethash_safe(ECL_CONS_CAR(CLV0),ecl_cmp_symbol_value(cl_env_copy,VV[1793]),ECL_NIL))){
   goto L9;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1764]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  REGISTERED-SYSTEM */;
  goto L7;
L9:;
  value0 = ECL_NIL;
  goto L7;
L7:;
  if (value0!=ECL_NIL) {
   goto L6;
  }
  {
   cl_object v1;                                  /*  FOUNDP                  */
   cl_object v2;                                  /*  FOUND-SYSTEM            */
   cl_object v3;                                  /*  PATHNAME                */
   cl_object v4;                                  /*  PREVIOUS                */
   cl_object v5;                                  /*  PREVIOUS-TIME           */
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1853]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  LOCATE-SYSTEM */;
   {
    const int v6 = cl_env_copy->nvalues;
    v1 = value0;
    cl_object v7;
    v7 = (v6<=1)? ECL_NIL : cl_env_copy->values[1];
    v2 = v7;
    v7 = (v6<=2)? ECL_NIL : cl_env_copy->values[2];
    v3 = v7;
    v7 = (v6<=3)? ECL_NIL : cl_env_copy->values[3];
    v4 = v7;
    v7 = (v6<=4)? ECL_NIL : cl_env_copy->values[4];
    v5 = v7;
   }
   goto L15;
L14:;
   si_assert_failure(1, VV[1860]);
L15:;
   if (v2!=ECL_NIL) {
    goto L24;
   }
   if (v3!=ECL_NIL) {
    goto L24;
   }
   if (Null(v4)){
    goto L22;
   }
   goto L23;
L24:;
L23:;
   T0 = ECL_T;
   goto L20;
L22:;
   T0 = ECL_NIL;
   goto L20;
L20:;
   if ((v1)==(T0)) {
    goto L18;
   }
   goto L14;
L18:;
   {
    cl_object v6;
    cl_object v7;
    if (Null(v4)){
     goto L30;
    }
    v6 = (cl_env_copy->function=ecl_fdefinition(VV[1691]))->cfun.entry(1, v4) /*  SYSTEM-SOURCE-FILE */;
    goto L28;
L30:;
    v6 = ECL_NIL;
    goto L28;
L28:;
    value0 = v4;
    if (value0!=ECL_NIL) {
     goto L34;
    }
    v7 = v2;
    goto L32;
L34:;
    v7 = value0;
    goto L32;
L32:;
    if (Null(v2)){
     goto L36;
    }
    if (v4!=ECL_NIL) {
     goto L36;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[1771]))->cfun.entry(1, v2) /*  REGISTER-SYSTEM */;
L36:;
    if (Null(v7)){
     goto L39;
    }
    if (Null(v3)){
     goto L39;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[1861]))->cfun.entry(2, v3, v7) /*  (SETF SYSTEM-SOURCE-FILE) */;
L39:;
    if (Null(v3)){
     goto L27;
    }
    {
     cl_object v8asdf_find_system__stamp;
     v8asdf_find_system__stamp = (cl_env_copy->function=ecl_fdefinition(VV[1734]))->cfun.entry(1, v3) /*  GET-FILE-STAMP */;
     if (Null(v8asdf_find_system__stamp)){
      goto L27;
     }
     if (Null(v4)){
      goto L47;
     }
     if ((cl_env_copy->function=ecl_fdefinition(VV[536]))->cfun.entry(2, v3, v6) /*  PATHNAME-EQUAL */!=ECL_NIL) {
      goto L50;
     }
     if (Null(v3)){
      goto L47;
     }
     if (Null(v6)){
      goto L47;
     }
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[529]))->cfun.entry(1, v3) /*  PHYSICALIZE-PATHNAME */;
     T1 = (cl_env_copy->function=ecl_fdefinition(VV[529]))->cfun.entry(1, v6) /*  PHYSICALIZE-PATHNAME */;
     if (Null((cl_env_copy->function=ecl_fdefinition(VV[536]))->cfun.entry(2, T0, T1) /*  PATHNAME-EQUAL */)){
      goto L47;
     }
     goto L49;
L50:;
L49:;
     if ((cl_env_copy->function=ecl_fdefinition(VV[326]))->cfun.entry(2, v8asdf_find_system__stamp, v5) /*  STAMP<= */!=ECL_NIL) {
      goto L27;
     }
     goto L42;
L47:;
     goto L42;
    }
L42:;
    (cl_env_copy->function=ecl_fdefinition(VV[1840]))->cfun.entry(3, v3, ECL_SYM("NAME",1309), ECL_CONS_CAR(CLV0)) /*  LOAD-ASD */;
   }
L27:;
   {
    cl_object v6asdf_find_system__in_memory;
    v6asdf_find_system__in_memory = (cl_env_copy->function=ecl_fdefinition(VV[1762]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  SYSTEM-REGISTERED-P */;
    if (Null(v6asdf_find_system__in_memory)){
     goto L55;
    }
    if (Null(v3)){
     goto L57;
    }
    {
     cl_object v7;
     v7 = (cl_env_copy->function=ecl_fdefinition(VV[1734]))->cfun.entry(1, v3) /*  GET-FILE-STAMP */;
     {
      cl_object v8;
      v8 = v6asdf_find_system__in_memory;
      if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v8;
     }
     (ECL_CONS_CAR(T0)=v7,T0);
    }
L57:;
    value0 = ecl_cdr(v6asdf_find_system__in_memory);
    cl_env_copy->nvalues = 1;
    return value0;
L55:;
    if (Null(ECL_CONS_CAR(CLV1))){
     goto L64;
    }
    value0 = cl_error(3, VV[1738], VV[1862], ECL_CONS_CAR(CLV0));
    return value0;
L64:;
    cl_env_copy->values[0] = ECL_NIL;
    cl_env_copy->nvalues = 1;
    cl_return_from(ECL_CONS_CAR(CLV2),VV[1690]);
   }
  }
L6:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4858call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* closure LAMBDA5228                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4870__lambda5228(cl_narg narg, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  TAGBODY                 */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1si__temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1si__temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV2) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV3),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA5230                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4871__lambda5230(cl_narg narg, cl_object v1asdf_find_component__c, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);                           /*  NAME                    */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1880]);
 {
L1:;
  value0 = ecl_make_bool(v1asdf_find_component__c==ECL_NIL);
  if (value0!=ECL_NIL) {
   goto L3;
  }
  if (Null(si_of_class_p(2, v1asdf_find_component__c, VV[1864]))){
   goto L6;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1866]))->cfun.entry(1, v1asdf_find_component__c) /*  MISSING-REQUIRED-BY */;
  if (!((T0)==(ECL_CONS_CAR(CLV0)))){
   goto L6;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1869]))->cfun.entry(1, v1asdf_find_component__c) /*  MISSING-REQUIRES */;
  value0 = ecl_make_bool(ecl_equal(T0,ECL_CONS_CAR(CLV1)));
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure LAMBDA5232                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4872__lambda5232(cl_narg narg, cl_object v1asdf_find_component__s, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);                           /*  NAME                    */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1881]);
 {
L1:;
  value0 = cl_format(3, v1asdf_find_component__s, VV[1882], ECL_CONS_CAR(CLV1));
  return value0;
 }
 }
}
/* closure .PRINT-UNREADABLE-OBJECT-BODY.                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4880si___print_unreadable_object_body_(volatile cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object volatile CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  STREAM                  */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1657]);
 {
L1:;
  {
   volatile cl_object env1 = env0;
   CLV2 = env1 = CONS(ECL_NIL,env1);
   {
    volatile cl_object env2 = env1;
    CLV3 = env2 = CONS(ECL_NEW_FRAME_ID(cl_env_copy),env2); /*  TAGBODY       */
    {
     ecl_frs_push(cl_env_copy,ECL_CONS_CAR(CLV3));
     if (__ecl_frs_push_result!=0) {
     if (cl_env_copy->values[0]==ecl_make_int8_t(0)) {
      goto L2;
     }
     ecl_internal_error("GO found an inexistent tag");
     } else {
     {
      cl_object v1;
      v1 = ecl_make_cclosure_va((cl_objectfn)LC4879__lambda5279,env2,Cblock,1);
      T0 = v1;
     }
     T1 = CONS(ECL_SYM("ERROR",339),T0);
     T2 = ecl_list1(T1);
     T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
     ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[1891]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  OPERATION-ORIGINAL-INITARGS */;
     value0 = cl_format(3, ECL_CONS_CAR(CLV1), VV[1658], T0);
     ecl_frs_pop_n(cl_env_copy, 1);
     ecl_bds_unwind1(cl_env_copy);
     return value0;
L2:;
     {
      cl_object v1condition;
      v1condition = ECL_CONS_CAR(CLV2);
      cl_env_copy->nvalues = 2;
      cl_env_copy->values[1] = v1condition;
      cl_env_copy->values[0] = ECL_NIL;
      ecl_frs_pop_n(cl_env_copy, 1);
      return cl_env_copy->values[0];
     }
     }
    }
   }
  }
 }
 }
}
/* local function NEXT-METHOD                                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4892next_method(volatile cl_object *lex0, cl_object v1asdf_action__o, cl_object v2asdf_action__c)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(lex0[2])){
  goto L2;
 }
 T0 = cl_list(2, ECL_SYM("QUOTE",682), lex0[0]);
 T1 = ecl_list1(lex0[1]);
 T2 = ecl_append(lex0[4],T1);
 T3 = cl_listX(3, v1asdf_action__o, v2asdf_action__c, T2);
 T4 = ecl_append(lex0[3],T3);
 value0 = cl_listX(3, ECL_SYM("APPLY",91), T0, T4);
 return value0;
L2:;
 T0 = cl_listX(3, v1asdf_action__o, v2asdf_action__c, lex0[4]);
 T1 = ecl_append(lex0[3],T0);
 value0 = CONS(lex0[0],T1);
 cl_env_copy->nvalues = 1;
 return value0;
}
/* closure CALL-NEXT-METHOD                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4903call_next_method(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  .NEXT-METHODS.          */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (ECL_CONS_CAR(CLV1)!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(ECL_CONS_CAR(CLV1));
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = ECL_CONS_CAR(CLV0);
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(ECL_CONS_CAR(CLV1));
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
 }
}
/* closure LAMBDA5360                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4905__lambda5360(cl_narg narg, ...)
{
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  .NEXT-METHODS.          */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1942]);
 {
L1:;
  value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4903call_next_method(0));
  return value0;
 }
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4908call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4912call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4916call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4920call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* closure CALL-NEXT-METHOD                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4938call_next_method(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  .NEXT-METHODS.          */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (ECL_CONS_CAR(CLV2)!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(ECL_CONS_CAR(CLV2));
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = ECL_CONS_CAR(CLV1);
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(ECL_CONS_CAR(CLV2));
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
 }
}
/* closure LAMBDA5438                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4940__lambda5438(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  .NEXT-METHODS.          */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1965]);
 {
L1:;
  {
   cl_object v1;                                  /*  PATHNAMES               */
   cl_object v2;                                  /*  FIXEDP                  */
   value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4938call_next_method(0));
   {
    const int v3 = cl_env_copy->nvalues;
    v1 = value0;
    cl_object v4;
    v4 = (v3<=1)? ECL_NIL : cl_env_copy->values[1];
    v2 = v4;
   }
   {
    cl_object v3directory;
    cl_object v4asdf_action__absolute_pathnames;
    T1 = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_NIL, ECL_CONS_CAR(CLV0)) /*  FIND-COMPONENT */;
    T2 = (cl_env_copy->function=ecl_fdefinition(VV[1638]))->cfun.entry(1, T1) /*  COMPONENT-PATHNAME */;
    v3directory = (cl_env_copy->function=ecl_fdefinition(VV[555]))->cfun.entry(1, T2) /*  PATHNAME-DIRECTORY-PATHNAME */;
    {
     cl_object v5;
     cl_object v6pathname;
     cl_object v7;
     {
      cl_object v8;
      v8 = v1;
      if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v5 = v8;
     }
     v6pathname = ECL_NIL;
     v7 = v5;
     {
      cl_object v8;
      cl_object v9;
      v8 = ecl_list1(ECL_NIL);
      v9 = v8;
L13:;
      if (!(ecl_endp(v7))){
       goto L15;
      }
      goto L14;
L15:;
      v6pathname = ECL_CONS_CAR(v7);
      {
       cl_object v10;
       v10 = ECL_CONS_CDR(v7);
       if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v7 = v10;
      }
      {
       cl_object v10;
       v10 = v9;
       if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T1 = v10;
      }
      T2 = (cl_env_copy->function=ecl_fdefinition(VV[617]))->cfun.entry(2, v6pathname, v3directory) /*  ENSURE-ABSOLUTE-PATHNAME */;
      v9 = ecl_list1(T2);
      (ECL_CONS_CDR(T1)=v9,T1);
      goto L13;
L14:;
      v4asdf_action__absolute_pathnames = ecl_cdr(v8);
      goto L5;
     }
    }
L5:;
    if (Null(v2)){
     goto L30;
    }
    T0 = v4asdf_action__absolute_pathnames;
    goto L2;
L30:;
    {
     cl_object v5;
     v5 = ecl_cmp_symbol_value(cl_env_copy,VV[655]);
     {
      cl_object v6;
      cl_object v7;
      cl_object v8;
      {
       cl_object v9;
       v9 = v4asdf_action__absolute_pathnames;
       if (ecl_unlikely(!ECL_LISTP(v9))) FEtype_error_list(v9);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v6 = v9;
      }
      v7 = ECL_NIL;
      v8 = v6;
      {
       cl_object v9;
       cl_object v10;
       v9 = ecl_list1(ECL_NIL);
       v10 = v9;
L40:;
       if (!(ecl_endp(v8))){
        goto L42;
       }
       goto L41;
L42:;
       v7 = ECL_CONS_CAR(v8);
       {
        cl_object v11;
        v11 = ECL_CONS_CDR(v8);
        if (ecl_unlikely(!ECL_LISTP(v11))) FEtype_error_list(v11);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v8 = v11;
       }
       {
        cl_object v11;
        v11 = v10;
        if (ecl_unlikely(ECL_ATOM(v11))) FEtype_error_cons(v11);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T1 = v11;
       }
       T2 = ecl_function_dispatch(cl_env_copy,v5)(1, v7);
       v10 = ecl_list1(T2);
       (ECL_CONS_CDR(T1)=v10,T1);
       goto L40;
L41:;
       T0 = ecl_cdr(v9);
       goto L2;
      }
     }
    }
   }
  }
L2:;
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = ECL_T;
  cl_env_copy->values[0] = T0;
  return cl_env_copy->values[0];
 }
 }
}
/* closure CALL-NEXT-METHOD                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4944call_next_method(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  .NEXT-METHODS.          */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (ECL_CONS_CAR(CLV1)!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(ECL_CONS_CAR(CLV1));
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = ECL_CONS_CAR(CLV0);
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(ECL_CONS_CAR(CLV1));
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
 }
}
/* closure LAMBDA5459                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4946__lambda5459(cl_narg narg, ...)
{
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  .NEXT-METHODS.          */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1969]);
 {
L1:;
  value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4944call_next_method(0));
  return value0;
 }
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4949call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* closure .PRINT-UNREADABLE-OBJECT-BODY.                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4955si___print_unreadable_object_body_(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  STREAM                  */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1657]);
 {
L1:;
  T0 = cl_slot_value(ECL_CONS_CAR(CLV0), VV[1977]);
  T1 = cl_slot_value(ECL_CONS_CAR(CLV0), VV[1979]);
  value0 = cl_format(6, ECL_CONS_CAR(CLV1), VV[1975], VV[1976], T0, VV[1978], T1);
  return value0;
 }
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4968call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* closure LAMBDA5617                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4970__lambda5617(cl_narg narg, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  TAGBODY                 */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1si__temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1si__temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV2) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV3),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA5619                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4971__lambda5619(cl_narg narg, cl_object v1asdf_action__s, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);                           /*  COMPONENT               */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1987]);
 {
L1:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1933]))->cfun.entry(2, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1)) /*  ACTION-DESCRIPTION */;
  value0 = cl_format(3, v1asdf_action__s, VV[1988], T0);
  return value0;
 }
 }
}
/* closure LAMBDA5621                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4972__lambda5621(cl_narg narg, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  TAGBODY                 */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1si__temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1si__temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV2) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV3),ecl_make_fixnum(1));
 }
 }
}
/* closure LAMBDA5623                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4973__lambda5623(cl_narg narg, cl_object v1asdf_action__s, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);                           /*  COMPONENT               */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1991]);
 {
L1:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1933]))->cfun.entry(2, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1)) /*  ACTION-DESCRIPTION */;
  value0 = cl_format(3, v1asdf_action__s, VV[1992], T0);
  return value0;
 }
 }
}
/* closure LAMBDA5648                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4981__lambda5648(cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV5 = env0;                                     /*  WARNINGS-FILE           */
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1asdf_lisp_action_flags;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1asdf_lisp_action_flags = cl_grab_rest_args(args);
  ecl_va_end(args);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1640]))->cfun.entry(1, ECL_CONS_CAR(CLV1)) /*  COMPONENT-EXTERNAL-FORMAT */;
  T1 = cl_list(2, VV[2011], ECL_CONS_CAR(CLV4));
  T2 = (cl_env_copy->function=ecl_fdefinition(VV[2012]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  COMPILE-OP-FLAGS */;
  T3 = cl_append(3, T1, v1asdf_lisp_action_flags, T2);
  value0 = cl_apply(9, VV[1426], ECL_CONS_CAR(CLV2), VV[1429], ECL_CONS_CAR(CLV3), ECL_SYM("EXTERNAL-FORMAT",1267), T0, VV[2010], ECL_CONS_CAR(CLV5), T3);
  return value0;
 }
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4995call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* closure LAMBDA5728                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4997__lambda5728(cl_narg narg, ...)
{
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  TAGBODY                 */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1si__temp;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1si__temp = cl_grab_rest_args(args);
  ecl_va_end(args);
  ECL_CONS_CAR(CLV1) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV2),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA5730                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4998__lambda5730(cl_narg narg, cl_object v1asdf_lisp_action__s, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);                           /*  C                       */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2032]);
 {
L1:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1636]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  COMPONENT-NAME */;
  value0 = cl_format(3, v1asdf_lisp_action__s, VV[2033], T0);
  return value0;
 }
 }
}
/* closure LAMBDA5742                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5008__lambda5742(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  C                       */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2040]);
 {
L1:;
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1963]))->cfun.entry(2, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1)) /*  INPUT-FILES */;
  T1 = ecl_car(T0);
  T2 = (cl_env_copy->function=ecl_fdefinition(VV[1640]))->cfun.entry(1, ECL_CONS_CAR(CLV1)) /*  COMPONENT-EXTERNAL-FORMAT */;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1440]))->cfun.entry(3, T1, ECL_SYM("EXTERNAL-FORMAT",1267), T2) /*  LOAD* */;
  return value0;
 }
 }
}
/* closure .PRINT-UNREADABLE-OBJECT-BODY.                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5016si___print_unreadable_object_body_(cl_narg narg, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  STREAM                  */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1657]);
 {
L1:;
  T0 = cl_slot_value(ECL_CONS_CAR(CLV0), VV[1977]);
  T1 = cl_slot_value(ECL_CONS_CAR(CLV0), VV[1979]);
  T2 = cl_slot_value(ECL_CONS_CAR(CLV0), VV[2050]);
  T3 = cl_slot_value(ECL_CONS_CAR(CLV0), VV[2052]);
  value0 = cl_format(10, ECL_CONS_CAR(CLV1), VV[1975], VV[1976], T0, VV[1978], T1, VV[2049], T2, VV[2051], T3);
  return value0;
 }
 }
}
/* closure LAMBDA5893                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5024__lambda5893(cl_narg narg, cl_object v1asdf_plan__x, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  NAME                    */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2069]);
 {
L1:;
  {
   bool v2;
   v2 = ecl_equal(v1asdf_plan__x,ECL_CONS_CAR(CLV0));
   value0 = (v2)?ECL_NIL:ECL_T;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
 }
}
/* closure LAMBDA5895                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5025__lambda5895(cl_narg narg, cl_object v1asdf_plan__x, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  REQUESTED               */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2070]);
 {
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, ECL_CONS_CAR(CLV0), v1asdf_plan__x) /*  CALL-FUNCTION */;
  if (value0!=ECL_NIL) {
   goto L3;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[355]))->cfun.entry(2, ecl_cmp_symbol_value(cl_env_copy,VV[1793]), v1asdf_plan__x) /*  CALL-FUNCTION */;
  return value0;
L3:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure LAMBDA5921                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5035__lambda5921(cl_narg narg, cl_object v1asdf_plan__dep_o, cl_object v2asdf_plan__dep_c, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  SEED                    */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2083]);
 {
L1:;
  ECL_CONS_CAR(CLV1) = ecl_function_dispatch(cl_env_copy,ECL_CONS_CAR(CLV0))(3, v1asdf_plan__dep_o, v2asdf_plan__dep_c, ECL_CONS_CAR(CLV1));
  value0 = ECL_CONS_CAR(CLV1);
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure LAMBDA5958                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5038__lambda5958(cl_narg narg, cl_object v1asdf_plan__o, cl_object v2asdf_plan__c, cl_object v3asdf_action_stamp, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  PLAN                    */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[2087]);
 {
L1:;
  {
   cl_object v4asdf_plan__it;
   v4asdf_plan__it = (cl_env_copy->function=ecl_fdefinition(VV[2046]))->cfun.entry(3, ECL_CONS_CAR(CLV0), v1asdf_plan__o, v2asdf_plan__c) /*  PLAN-ACTION-STATUS */;
   if (Null(v4asdf_plan__it)){
    goto L3;
   }
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[2059]))->cfun.entry(1, v4asdf_plan__it) /*  ACTION-STAMP */;
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[339]))->cfun.entry(2, v3asdf_action_stamp, T0) /*  LATEST-STAMP */;
   return value0;
L3:;
   value0 = ECL_T;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
 }
}
/* local function LAMBDA6062                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5044__lambda6062(cl_object v1asdf_plan__c, cl_object v2asdf_plan__s)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2098]))->cfun.entry(1, v1asdf_plan__c) /*  CIRCULAR-DEPENDENCY-ACTIONS */;
 value0 = cl_format(3, v2asdf_plan__s, VV[2097], T0);
 return value0;
}
static cl_object LC5044__lambda6062_va(cl_narg narg, cl_object v3asdf_plan__c, cl_object v4asdf_plan__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2096]);
 {
  return LC5044__lambda6062(v3asdf_plan__c, v4asdf_plan__s);
 }
}
/* closure VISIT-ACTION                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5049visit_action(cl_narg narg, cl_object v1asdf_plan__niip, ...)
{
 cl_object T0, T1, T2;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV5 = env0;                                     /*  STATUS                  */
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2107]);
 {
  CLV6 = env0 = CONS(v1asdf_plan__niip,env0);     /*  NIIP                    */
  {
   cl_object v2;
   v2 = ecl_make_cclosure_va((cl_objectfn)LC5048__lambda6297,env0,Cblock,2);
   T0 = v2;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[2080]))->cfun.entry(4, ECL_T, ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV2), T0) /*  MAP-DIRECT-DEPENDENCIES */;
  {
   cl_object v2;                                  /*  STAMP                   */
   cl_object v3;                                  /*  DONE-P                  */
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[1973]))->cfun.entry(3, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV2)) /*  COMPUTE-ACTION-STAMP */;
   {
    const int v4 = cl_env_copy->nvalues;
    v2 = value0;
    cl_object v5;
    v5 = (v4<=1)? ECL_NIL : cl_env_copy->values[1];
    v3 = v5;
   }
   {
    cl_object v4asdf_plan__add_to_plan_p;
    value0 = ecl_make_bool((v2)==(ECL_T));
    if (value0!=ECL_NIL) {
     goto L6;
    }
    if (Null(ECL_CONS_CAR(CLV6))){
     goto L9;
    }
    v4asdf_plan__add_to_plan_p = Null(v3)?ECL_T:ECL_NIL;
    goto L4;
L9:;
    v4asdf_plan__add_to_plan_p = ECL_NIL;
    goto L4;
L6:;
    v4asdf_plan__add_to_plan_p = value0;
    goto L4;
L4:;
    if (Null(v4asdf_plan__add_to_plan_p)){
     goto L11;
    }
    if (ECL_CONS_CAR(CLV6)!=ECL_NIL) {
     goto L11;
    }
    value0 = (aux_closure.env=ecl_nthcdr(1,env0),cl_env_copy->function=(cl_object)&aux_closure,LC5049visit_action(1, ECL_T));
    return value0;
L11:;
    {
     cl_object v5;
     if (Null(v3)){
      goto L18;
     }
     T0 = Null(v4asdf_plan__add_to_plan_p)?ECL_T:ECL_NIL;
     goto L16;
L18:;
     T0 = ECL_NIL;
     goto L16;
L16:;
     if (Null(ECL_CONS_CAR(CLV5))){
      goto L21;
     }
     T1 = (cl_env_copy->function=ecl_fdefinition(VV[2109]))->cfun.entry(1, ECL_CONS_CAR(CLV5)) /*  ACTION-INDEX */;
     goto L20;
L21:;
     {
      cl_object v6;
      T2 = (cl_env_copy->function=ecl_fdefinition(VV[2110]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  PLAN-TOTAL-ACTION-COUNT */;
      v6 = ecl_plus(T2,ecl_make_int8_t(1));
      T1 = (cl_env_copy->function=ecl_fdefinition(VV[2111]))->cfun.entry(2, v6, ECL_CONS_CAR(CLV0)) /*  (SETF PLAN-TOTAL-ACTION-COUNT) */;
     }
L20:;
     v5 = (cl_env_copy->function=(ECL_SYM("MAKE-INSTANCE",953)->symbol.gfdef))->cfun.entry(9, VV[2048], VV[1976], v2, VV[1978], T0, VV[2049], v4asdf_plan__add_to_plan_p, VV[2051], T1) /*  MAKE-INSTANCE */;
     (cl_env_copy->function=ecl_fdefinition(VV[2047]))->cfun.entry(4, v5, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV2)) /*  (SETF PLAN-ACTION-STATUS) */;
    }
    if (Null(v3)){
     goto L24;
    }
    if (v4asdf_plan__add_to_plan_p!=ECL_NIL) {
     goto L24;
    }
    (cl_env_copy->function=ecl_fdefinition(VV[1971]))->cfun.entry(3, v2, ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV2)) /*  (SETF COMPONENT-OPERATION-TIME) */;
L24:;
    if (Null(v4asdf_plan__add_to_plan_p)){
     goto L27;
    }
    {
     cl_object v5;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[2112]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  PLAN-PLANNED-ACTION-COUNT */;
     v5 = ecl_plus(T0,ecl_make_int8_t(1));
     (cl_env_copy->function=ecl_fdefinition(VV[2113]))->cfun.entry(2, v5, ECL_CONS_CAR(CLV0)) /*  (SETF PLAN-PLANNED-ACTION-COUNT) */;
    }
    if (ECL_CONS_CAR(CLV3)!=ECL_NIL) {
     goto L27;
    }
    {
     cl_object v5;
     T0 = (cl_env_copy->function=ecl_fdefinition(VV[2114]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  PLAN-PLANNED-OUTPUT-ACTION-COUNT */;
     v5 = ecl_plus(T0,ecl_make_int8_t(1));
     (cl_env_copy->function=ecl_fdefinition(VV[2115]))->cfun.entry(2, v5, ECL_CONS_CAR(CLV0)) /*  (SETF PLAN-PLANNED-OUTPUT-ACTION-COUNT) */;
    }
L27:;
    value0 = v2;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
 }
}
/* closure LAMBDA6315                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5050__lambda6315(cl_narg narg, ...)
{
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV5 = env0;                                     /*  STATUS                  */
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2116]);
 {
L1:;
  value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC5049visit_action(1, ECL_CONS_CAR(CLV4)));
  return value0;
 }
 }
}
/* closure CALL-NEXT-METHOD                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5059call_next_method(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  .NEXT-METHODS.          */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (ECL_CONS_CAR(CLV1)!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(ECL_CONS_CAR(CLV1));
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = ECL_CONS_CAR(CLV0);
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(ECL_CONS_CAR(CLV1));
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
 }
}
/* closure LAMBDA6346                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5061__lambda6346(cl_narg narg, ...)
{
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  .NEXT-METHODS.          */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2125]);
 {
L1:;
  value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC5059call_next_method(0));
  return value0;
 }
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5073call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* closure CALL-NEXT-METHOD                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5080call_next_method(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;                                     /*  .NEXT-METHODS.          */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,narg,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (ECL_CONS_CAR(CLV4)!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(ECL_CONS_CAR(CLV4));
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = ECL_CONS_CAR(CLV3);
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(ECL_CONS_CAR(CLV4));
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
 }
}
/* closure LAMBDA6551                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5082__lambda6551(cl_narg narg, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV6 = env0;                                     /*  INITARGS                */
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2133]);
 {
L1:;
  value0 = cl_apply(5, VV[1898], ECL_CONS_CAR(CLV5), VV[1929], ECL_CONS_CAR(CLV6), ECL_CONS_CAR(CLV6));
  return value0;
 }
 }
}
/* closure LAMBDA6555                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5083__lambda6555(cl_narg narg, ...)
{
 cl_object T0;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;                                     /*  .NEXT-METHODS.          */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2135]);
 {
L1:;
  if (Null(ECL_CONS_CAR(CLV0))){
   goto L4;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69));
  goto L2;
L4:;
  T0 = ECL_NIL;
  goto L2;
L2:;
  ecl_bds_bind(cl_env_copy,VV[1610],T0);          /*  *VERBOSE-OUT*           */
  ecl_bds_bind(cl_env_copy,VV[1299],ECL_CONS_CAR(CLV1)); /*  *COMPILE-FILE-WARNINGS-BEHAVIOUR* */
  ecl_bds_bind(cl_env_copy,VV[1301],ECL_CONS_CAR(CLV2)); /*  *COMPILE-FILE-FAILURE-BEHAVIOUR* */
  value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC5080call_next_method(0));
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  ecl_bds_unwind1(cl_env_copy);
  return value0;
 }
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5088call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5091call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* closure LAMBDA6639                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5106__lambda6639(cl_narg narg, cl_object v1asdf_operate__e, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  NAME                    */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2166]);
 {
L1:;
  value0 = cl_format(4, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*ERROR-OUTPUT*",35)), VV[2167], ECL_CONS_CAR(CLV0), v1asdf_operate__e);
  return value0;
 }
 }
}
/* local function LAMBDA6713                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5112__lambda6713(cl_object v1asdf_output_translations__x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2;
  v2 = ecl_car(v1asdf_output_translations__x);
  if (Null(cl_typep(2, v2, VV[40]))){
   goto L3;
  }
  value0 = ecl_make_int8_t(-1);
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (Null(cl_pathnamep(v2))){
   goto L5;
  }
  {
   cl_object v3directory;
   T0 = ecl_car(v1asdf_output_translations__x);
   v3directory = cl_pathname_directory(1, T0);
   if (!(ECL_LISTP(v3directory))){
    goto L8;
   }
   value0 = ecl_make_fixnum(ecl_length(v3directory));
   cl_env_copy->nvalues = 1;
   return value0;
L8:;
   value0 = ecl_make_int8_t(0);
   cl_env_copy->nvalues = 1;
   return value0;
  }
L5:;
  value0 = si_etypecase_error(v2, VV[2182]);
  return value0;
 }
}
static cl_object LC5112__lambda6713_va(cl_narg narg, cl_object v4asdf_output_translations__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2181]);
 {
  return LC5112__lambda6713(v4asdf_output_translations__x);
 }
}
/* closure C                                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5136c(cl_narg narg, cl_object v1uiop_utility__x, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2247]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = CONS(v1uiop_utility__x,ECL_CONS_CAR(CLV0));
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
 }
}
/* closure LAMBDA6886                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5147__lambda6886(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2279]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* closure RECURSEP                                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5151recursep(cl_narg narg, cl_object v1asdf_source_registry__x, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV5 = env0;                                     /*  VISITED                 */
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2285]);
 {
L1:;
  {
   cl_object v2;
   cl_object v3;
   cl_object v4;
   cl_object v5;
   T0 = cl_pathname_directory(1, v1asdf_source_registry__x);
   T1 = ecl_last(T0,1);
   v2 = ecl_car(T1);
   v3 = (ECL_SYM("EQUAL",337)->symbol.gfdef);
   v4 = v2;
   v5 = ECL_CONS_CAR(CLV1);
   if (ecl_member(v4,v5)!=ECL_NIL) {
    goto L3;
   }
  }
  {
   cl_object v2asdf_source_registry__visitedp;
   T0 = LC5150pathname_key(v1asdf_source_registry__x);
   v2asdf_source_registry__visitedp = ecl_gethash_safe(T0,ECL_CONS_CAR(CLV5),ECL_NIL);
   if (Null(v2asdf_source_registry__visitedp)){
    goto L11;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L11:;
   T0 = LC5150pathname_key(v1asdf_source_registry__x);
   value0 = si_hash_set(T0, ECL_CONS_CAR(CLV5), ECL_T);
   return value0;
  }
L3:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure COLLECTP                                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5149collectp(cl_narg narg, cl_object v1asdf_source_registry__dir, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV5 = env0;
 CLV4 = _ecl_cdr(CLV5);                           /*  IGNORE-CACHE            */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2284]);
 {
L1:;
  if (ECL_CONS_CAR(CLV4)!=ECL_NIL) {
   goto L5;
  }
  if ((cl_env_copy->function=ecl_fdefinition(VV[2277]))->cfun.entry(2, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV2)) /*  PROCESS-SOURCE-REGISTRY-CACHE */!=ECL_NIL) {
   goto L2;
  }
  goto L3;
L5:;
  goto L3;
L3:;
  {
   cl_object v2asdf_source_registry__asds;
   v2asdf_source_registry__asds = (cl_env_copy->function=ecl_fdefinition(VV[2274]))->cfun.entry(2, v1asdf_source_registry__dir, ECL_CONS_CAR(CLV2)) /*  COLLECT-ASDS-IN-DIRECTORY */;
   value0 = ECL_CONS_CAR(CLV3);
   if (value0!=ECL_NIL) {
    goto L9;
   }
   value0 = Null(v2asdf_source_registry__asds)?ECL_T:ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L9:;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L2:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* local function CHECK                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5157check(volatile cl_object *lex0, cl_object v1asdf_source_registry__dir)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if ((cl_env_copy->function=ecl_fdefinition(VV[544]))->cfun.entry(1, v1asdf_source_registry__dir) /*  ABSOLUTE-PATHNAME-P */!=ECL_NIL) {
  goto L2;
 }
 cl_error(2, VV[2312], lex0[0]);
L2:;
 value0 = v1asdf_source_registry__dir;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* closure COLLECT                                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5176collect(cl_narg narg, cl_object v1uiop_utility__x, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2360]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = CONS(v1uiop_utility__x,ECL_CONS_CAR(CLV0));
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
 }
}
/* closure LAMBDA7170                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5177__lambda7170(cl_narg narg, cl_object v1directory, ...)
{
 cl_object T0;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2361]);
 {
  cl_object v2asdf_source_registry__recurse;
  cl_object v3asdf_source_registry__exclude;
  ecl_va_list args; ecl_va_start(args,v1directory,narg,1);
  {
   cl_object keyvars[4];
   cl_parse_key(args,2,LC5177__lambda7170keys,keyvars,NULL,FALSE);
   ecl_va_end(args);
   v2asdf_source_registry__recurse = keyvars[0];
   v3asdf_source_registry__exclude = keyvars[1];
  }
  T0 = cl_list(5, v1directory, VV[2354], v2asdf_source_registry__recurse, VV[2296], v3asdf_source_registry__exclude);
  value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC5176collect(1, T0));
  return value0;
 }
 }
}
/* closure LAMBDA7221                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5179__lambda7221(cl_narg narg, cl_object v1asdf_source_registry__asd, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  H                       */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2365]);
 {
L1:;
  {
   cl_object v2asdf_source_registry__name;
   cl_object v3asdf_source_registry__name;
   v2asdf_source_registry__name = cl_pathname_name(1, v1asdf_source_registry__asd);
   if (Null(si_logical_pathname_p(v1asdf_source_registry__asd))){
    goto L4;
   }
   v3asdf_source_registry__name = cl_string_downcase(1, v2asdf_source_registry__name);
   goto L3;
L4:;
   v3asdf_source_registry__name = v2asdf_source_registry__name;
L3:;
   if (Null(ecl_gethash_safe(v3asdf_source_registry__name,ECL_CONS_CAR(CLV0),ECL_NIL))){
    goto L6;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L6:;
   if (Null(ecl_gethash_safe(v3asdf_source_registry__name,ECL_CONS_CAR(CLV3),ECL_NIL))){
    goto L8;
   }
   if (Null(ecl_cmp_symbol_value(cl_env_copy,VV[1610]))){
    goto L10;
   }
   T0 = cl_gethash(2, v3asdf_source_registry__name, ECL_CONS_CAR(CLV3));
   value0 = (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(6, VV[2366], ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV2), v3asdf_source_registry__name, T0, v1asdf_source_registry__asd) /*  WARN */;
   return value0;
L10:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L8:;
   si_hash_set(v3asdf_source_registry__name, ECL_CONS_CAR(CLV0), v1asdf_source_registry__asd);
   value0 = si_hash_set(v3asdf_source_registry__name, ECL_CONS_CAR(CLV3), v1asdf_source_registry__asd);
   return value0;
  }
 }
 }
}
/* local function LAMBDA7246                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5184__lambda7246()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[1412]))->cfun.entry(0) /*  LOAD-PATHNAME */;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[617]))->cfun.entry(3, T0, VV[676], ECL_NIL) /*  ENSURE-ABSOLUTE-PATHNAME */;
 return value0;
}
static cl_object LC5184__lambda7246_va(cl_narg narg, ...)
{
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2376]);
 {
  return LC5184__lambda7246();
 }
}
/* local function LAMBDA7254                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5187__lambda7254(cl_object v1asdf_parse_defsystem__c, cl_object v2asdf_parse_defsystem__s)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2387]))->cfun.entry(1, v1asdf_parse_defsystem__c) /*  NON-SYSTEM-SYSTEM-NAME */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[2388]))->cfun.entry(1, v1asdf_parse_defsystem__c) /*  NON-SYSTEM-SYSTEM-CLASS-NAME */;
 value0 = cl_format(5, v2asdf_parse_defsystem__s, VV[2386], T0, T1, VV[1695]);
 return value0;
}
static cl_object LC5187__lambda7254_va(cl_narg narg, cl_object v3asdf_parse_defsystem__c, cl_object v4asdf_parse_defsystem__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2385]);
 {
  return LC5187__lambda7254(v3asdf_parse_defsystem__c, v4asdf_parse_defsystem__s);
 }
}
/* local function LAMBDA7258                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5189__lambda7258(cl_object v1asdf_parse_defsystem__c, cl_object v2asdf_parse_defsystem__s)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2393]))->cfun.entry(1, v1asdf_parse_defsystem__c) /*  NON-TOPLEVEL-SYSTEM-PARENT */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[2394]))->cfun.entry(1, v1asdf_parse_defsystem__c) /*  NON-TOPLEVEL-SYSTEM-NAME */;
 value0 = cl_format(4, v2asdf_parse_defsystem__s, VV[2392], T0, T1);
 return value0;
}
static cl_object LC5189__lambda7258_va(cl_narg narg, cl_object v3asdf_parse_defsystem__c, cl_object v4asdf_parse_defsystem__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2391]);
 {
  return LC5189__lambda7258(v3asdf_parse_defsystem__c, v4asdf_parse_defsystem__s);
 }
}
/* closure INVALID-PARSE                                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5194invalid_parse(cl_narg narg, cl_object v1asdf_parse_defsystem__control, ...)
{
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  PARENT                  */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[2407]);
 {
  cl_object v2asdf_parse_defsystem__args;
  ecl_va_list args; ecl_va_start(args,v1asdf_parse_defsystem__control,narg,1);
  v2asdf_parse_defsystem__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  {
   cl_object v3asdf_parse_defsystem__target;
   v3asdf_parse_defsystem__target = (cl_env_copy->function=ecl_fdefinition(VV[1873]))->cfun.entry(2, ECL_CONS_CAR(CLV3), ECL_CONS_CAR(CLV2)) /*  FIND-COMPONENT */;
   if (Null(v3asdf_parse_defsystem__target)){
    goto L4;
   }
   if ((cl_env_copy->function=ecl_fdefinition(VV[2024]))->cfun.entry(1, v3asdf_parse_defsystem__target) /*  BUILTIN-SYSTEM-P */!=ECL_NIL) {
    goto L1;
   }
   goto L2;
L4:;
  }
L2:;
  cl_apply(3, ECL_SYM("WARN",907), v1asdf_parse_defsystem__control, v2asdf_parse_defsystem__args);
  value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC5193invalid(0));
  return value0;
L1:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure INVALID                                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5193invalid(cl_narg narg, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  PARENT                  */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(VV[2405]);
 {
  cl_object v1asdf_parse_defsystem__continuation;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1asdf_parse_defsystem__continuation = VV[2404];
   } else {
    i++;
    v1asdf_parse_defsystem__continuation = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = (cl_env_copy->function=(ECL_SYM("WARN",907)->symbol.gfdef))->cfun.entry(6, VV[2406], ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV2), ECL_CONS_CAR(CLV3), ECL_CONS_CAR(CLV1), v1asdf_parse_defsystem__continuation) /*  WARN */;
  return value0;
 }
 }
}
/* closure LAMBDA7317                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5197__lambda7317(cl_narg narg, cl_object v1asdf_parse_defsystem__m, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  NAME                    */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2421]);
 {
L1:;
  T0 = cl_symbol_function(ECL_CONS_CAR(CLV0));
  value0 = (cl_env_copy->function=(ECL_SYM("REMOVE-METHOD",968)->symbol.gfdef))->cfun.entry(2, T0, v1asdf_parse_defsystem__m) /*  REMOVE-METHOD */;
  return value0;
 }
 }
}
/* local function LAMBDA7563                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5203__lambda7563(cl_object v1asdf_parse_defsystem__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[1690]))->cfun.entry(2, v1asdf_parse_defsystem__x, ECL_NIL) /*  FIND-SYSTEM */;
 return value0;
}
static cl_object LC5203__lambda7563_va(cl_narg narg, cl_object v2asdf_parse_defsystem__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2461]);
 {
  return LC5203__lambda7563(v2asdf_parse_defsystem__x);
 }
}
/* closure LAMBDA7576                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5205__lambda7576(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV6 = env0;                                     /*  DEFSYSTEM-DEPENDS-ON    */
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[2466]);
 {
L1:;
  {
   cl_object v1asdf_component_name;
   cl_object v2asdf_component_source_file;
   cl_object v3asdf_parse_defsystem__checked_defsystem_depends_on;
   cl_object v4asdf_parse_defsystem__registered;
   cl_object v5asdf_parse_defsystem__registered_;
   cl_object v6asdf_system_system;
   cl_object v7asdf_parse_defsystem__component_options;
   v1asdf_component_name = (cl_env_copy->function=ecl_fdefinition(VV[1753]))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  COERCE-NAME */;
   if (Null(ECL_CONS_CAR(CLV5))){
    goto L4;
   }
   v2asdf_component_source_file = ECL_CONS_CAR(CLV4);
   goto L3;
L4:;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[1412]))->cfun.entry(0) /*  LOAD-PATHNAME */;
   v2asdf_component_source_file = (cl_env_copy->function=ecl_fdefinition(VV[716]))->cfun.entry(1, T0) /*  RESOLVE-SYMLINKS* */;
L3:;
   {
    cl_object v8asdf_parse_defsystem__dep_forms;
    cl_object v9asdf_parse_defsystem__deps;
    v8asdf_parse_defsystem__dep_forms = (cl_env_copy->function=ecl_fdefinition(VV[2437]))->cfun.entry(1, ECL_CONS_CAR(CLV6)) /*  PARSE-DEPENDENCY-DEFS */;
    {
     cl_object v10;
     cl_object v11asdf_parse_defsystem__spec;
     cl_object v12;
     {
      cl_object v13;
      v13 = v8asdf_parse_defsystem__dep_forms;
      if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v10 = v13;
     }
     v11asdf_parse_defsystem__spec = ECL_NIL;
     v12 = v10;
     {
      cl_object v13;
      v13 = ECL_NIL;
      {
       cl_object v14;
       cl_object v15;
       v14 = ecl_list1(ECL_NIL);
       v15 = v14;
L17:;
       if (!(ecl_endp(v12))){
        goto L19;
       }
       goto L18;
L19:;
       v11asdf_parse_defsystem__spec = ECL_CONS_CAR(v12);
       {
        cl_object v16;
        v16 = ECL_CONS_CDR(v12);
        if (ecl_unlikely(!ECL_LISTP(v16))) FEtype_error_list(v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v12 = v16;
       }
       v13 = (cl_env_copy->function=ecl_fdefinition(VV[1885]))->cfun.entry(2, ECL_NIL, v11asdf_parse_defsystem__spec) /*  RESOLVE-DEPENDENCY-SPEC */;
       if (Null(v13)){
        goto L27;
       }
       {
        cl_object v16;
        v16 = v15;
        if (ecl_unlikely(ECL_ATOM(v16))) FEtype_error_cons(v16);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T0 = v16;
       }
       v15 = ecl_list1(v13);
       (ECL_CONS_CDR(T0)=v15,T0);
L27:;
       goto L17;
L18:;
       v9asdf_parse_defsystem__deps = ecl_cdr(v14);
       goto L8;
      }
     }
    }
L8:;
    (cl_env_copy->function=ecl_fdefinition(VV[2145]))->cfun.entry(1, v9asdf_parse_defsystem__deps) /*  LOAD-SYSTEMS* */;
    v3asdf_parse_defsystem__checked_defsystem_depends_on = v8asdf_parse_defsystem__dep_forms;
   }
   v4asdf_parse_defsystem__registered = (cl_env_copy->function=ecl_fdefinition(VV[1762]))->cfun.entry(1, v1asdf_component_name) /*  SYSTEM-REGISTERED-P */;
   if (Null(v4asdf_parse_defsystem__registered)){
    goto L39;
   }
   {
    cl_object v8;
    v8 = v4asdf_parse_defsystem__registered;
    if (ecl_unlikely(ECL_ATOM(v8))) FEtype_error_cons(v8);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    T0 = v8;
   }
   T1 = (cl_env_copy->function=ecl_fdefinition(VV[1734]))->cfun.entry(1, v2asdf_component_source_file) /*  GET-FILE-STAMP */;
   v5asdf_parse_defsystem__registered_ = (ECL_CONS_CAR(T0)=T1,T0);
   goto L38;
L39:;
   T0 = (cl_env_copy->function=(ECL_SYM("MAKE-INSTANCE",953)->symbol.gfdef))->cfun.entry(5, VV[1695], ECL_SYM("NAME",1309), v1asdf_component_name, VV[1780], v2asdf_component_source_file) /*  MAKE-INSTANCE */;
   v5asdf_parse_defsystem__registered_ = (cl_env_copy->function=ecl_fdefinition(VV[1771]))->cfun.entry(1, T0) /*  REGISTER-SYSTEM */;
L38:;
   T0 = ecl_cdr(v5asdf_parse_defsystem__registered_);
   v6asdf_system_system = (cl_env_copy->function=ecl_fdefinition(VV[1696]))->cfun.entry(5, T0, ECL_SYM("NAME",1309), v1asdf_component_name, VV[1780], v2asdf_component_source_file) /*  RESET-SYSTEM */;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[261]))->cfun.entry(2, VV[2467], ECL_CONS_CAR(CLV1)) /*  REMOVE-PLIST-KEYS */;
   if (Null(v3asdf_parse_defsystem__checked_defsystem_depends_on)){
    goto L47;
   }
   T1 = cl_list(2, VV[2468], v3asdf_parse_defsystem__checked_defsystem_depends_on);
   goto L46;
L47:;
   T1 = ECL_NIL;
L46:;
   v7asdf_parse_defsystem__component_options = ecl_append(T0,T1);
   T0 = cl_list(2, VV[1690], v1asdf_component_name);
   T1 = ecl_list1(v6asdf_system_system);
   (cl_env_copy->function=ecl_fdefinition(VV[1704]))->cfun.entry(2, T0, T1) /*  SET-ASDF-CACHE-ENTRY */;
   {
    cl_object v8class;
    v8class = (cl_env_copy->function=ecl_fdefinition(VV[2379]))->cfun.entry(2, ECL_NIL, ECL_CONS_CAR(CLV3)) /*  CLASS-FOR-TYPE */;
    if (cl_subtypep(2, v8class, VV[1695])!=ECL_NIL) {
     goto L52;
    }
    T0 = (cl_env_copy->function=(ECL_SYM("CLASS-NAME",938)->symbol.gfdef))->cfun.entry(1, v8class) /*  CLASS-NAME */;
    cl_error(5, VV[2383], ECL_SYM("NAME",1309), v1asdf_component_name, VV[2469], T0);
L52:;
    T0 = cl_type_of(v6asdf_system_system);
    if ((T0)==(v8class)) {
     goto L50;
    }
    (cl_env_copy->function=(ECL_SYM("CHANGE-CLASS",936)->symbol.gfdef))->cfun.entry(2, v6asdf_system_system, v8class) /*  CHANGE-CLASS */;
   }
L50:;
   T0 = (cl_env_copy->function=ecl_fdefinition(VV[2374]))->cfun.entry(1, ECL_CONS_CAR(CLV2)) /*  DETERMINE-SYSTEM-DIRECTORY */;
   T1 = cl_listX(5, VV[2470], v1asdf_component_name, ECL_SYM("PATHNAME",1322), T0, v7asdf_parse_defsystem__component_options);
   value0 = (cl_env_copy->function=ecl_fdefinition(VV[2439]))->cfun.entry(2, ECL_NIL, T1) /*  PARSE-COMPONENT-FORM */;
   return value0;
  }
 }
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5216call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* closure COLLECT                                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5224collect(cl_narg narg, cl_object v1uiop_utility__x, ...)
{
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2552]);
 {
L1:;
  ECL_CONS_CAR(CLV2) = CONS(v1uiop_utility__x,ECL_CONS_CAR(CLV2));
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
 }
}
/* closure LAMBDA7749                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5225__lambda7749(cl_narg narg, cl_object v1asdf_bundle__sub_o, cl_object v2asdf_bundle__sub_c, ...)
{
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2553]);
 {
L1:;
  {
   cl_object v3;
   cl_object v4asdf_bundle__f;
   cl_object v5;
   {
    cl_object v6;
    v6 = ecl_function_dispatch(cl_env_copy,ECL_CONS_CAR(CLV1))(2, v1asdf_bundle__sub_o, v2asdf_bundle__sub_c);
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v3 = v6;
   }
   v4asdf_bundle__f = ECL_NIL;
   v5 = v3;
L7:;
   if (!(ecl_endp(v5))){
    goto L9;
   }
   goto L8;
L9:;
   v4asdf_bundle__f = ECL_CONS_CAR(v5);
   {
    cl_object v6;
    v6 = ECL_CONS_CDR(v5);
    if (ecl_unlikely(!ECL_LISTP(v6))) FEtype_error_list(v6);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v5 = v6;
   }
   if (Null(ecl_function_dispatch(cl_env_copy,ECL_CONS_CAR(CLV0))(1, v4asdf_bundle__f))){
    goto L17;
   }
   (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC5224collect(1, v4asdf_bundle__f));
L17:;
   goto L7;
L8:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
 }
}
/* closure LAMBDA7755                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5227__lambda7755(cl_narg narg, cl_object v1asdf_bundle__p, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  TYPE                    */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2556]);
 {
L1:;
  T0 = cl_pathname_type(1, v1asdf_bundle__p);
  value0 = ecl_make_bool(ecl_equalp(T0,ECL_CONS_CAR(CLV0)));
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure LAMBDA7845                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5231__lambda7845(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2568]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5234call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* local function LAMBDA7855                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5240__lambda7855(cl_object v1asdf_bundle__c)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = si_of_class_p(2, v1asdf_bundle__c, VV[2537]);
 return value0;
}
static cl_object LC5240__lambda7855_va(cl_narg narg, cl_object v2asdf_bundle__c, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2572]);
 {
  return LC5240__lambda7855(v2asdf_bundle__c);
 }
}
/* closure X                                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5254x(cl_narg narg, cl_object v1uiop_utility__x, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2574]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = CONS(v1uiop_utility__x,ECL_CONS_CAR(CLV0));
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  return value0;
 }
 }
}
/* closure LAMBDA7879                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5255__lambda7879(cl_narg narg, cl_object v1asdf_bundle__o, cl_object v2asdf_bundle__c, ...)
{
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2575]);
 {
L1:;
  if (Null(si_of_class_p(2, v1asdf_bundle__o, VV[1999]))){
   goto L2;
  }
  if (Null(si_of_class_p(2, v2asdf_bundle__c, VV[1695]))){
   goto L2;
  }
  value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC5254x(1, v2asdf_bundle__c));
  return value0;
L2:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5259call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* local function CALL-NEXT-METHOD                                            */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5264call_next_method(cl_narg narg, volatile cl_object *lex0, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 {
  cl_object v1clos__args;
  ecl_va_list args; ecl_va_start(args,lex0,narg,0);
  v1clos__args = cl_grab_rest_args(args);
  ecl_va_end(args);
  if (lex0[1]!=ECL_NIL) {
   goto L1;
  }
  cl_error(1, VV[1702]);
L1:;
  T0 = ecl_car(lex0[1]);
  value0 = v1clos__args;
  if (value0!=ECL_NIL) {
   goto L5;
  }
  T1 = lex0[0];
  goto L3;
L5:;
  T1 = value0;
  goto L3;
L3:;
  T2 = ecl_cdr(lex0[1]);
  value0 = ecl_function_dispatch(cl_env_copy,T0)(2, T1, T2);
  return value0;
 }
}
/* local function ENSURE-LINKABLE-SYSTEM                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5266ensure_linkable_system(cl_object v1asdf_bundle__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v2asdf_bundle__s;
  v2asdf_bundle__s = (cl_env_copy->function=ecl_fdefinition(VV[1690]))->cfun.entry(1, v1asdf_bundle__x) /*  FIND-SYSTEM */;
  if (Null(v2asdf_bundle__s)){
   goto L6;
  }
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[1698]))->cfun.entry(1, v1asdf_bundle__x) /*  SYSTEM-SOURCE-DIRECTORY */)){
   goto L9;
  }
  value0 = v2asdf_bundle__s;
  goto L4;
L9:;
  value0 = ECL_NIL;
  goto L4;
L6:;
  value0 = ECL_NIL;
 }
L4:;
 if (value0!=ECL_NIL) {
  goto L3;
 }
 {
  cl_object v2asdf_bundle__p;
  v2asdf_bundle__p = (cl_env_copy->function=ecl_fdefinition(VV[2581]))->cfun.entry(1, v1asdf_bundle__x) /*  SYSTEM-MODULE-PATHNAME */;
  if (Null(v2asdf_bundle__p)){
   goto L12;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2584]))->cfun.entry(2, v1asdf_bundle__x, v2asdf_bundle__p) /*  MAKE-PREBUILT-SYSTEM */;
  return value0;
L12:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L3:;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5266ensure_linkable_system_va(cl_narg narg, cl_object v3asdf_bundle__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2586]);
 {
  return LC5266ensure_linkable_system(v3asdf_bundle__x);
 }
}
/* local function LAMBDA7997                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5269__lambda7997(cl_object v1asdf_concatenate_source__x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = ecl_car(v1asdf_concatenate_source__x);
 T1 = ecl_cdr(v1asdf_concatenate_source__x);
 T2 = cl_reverse(T1);
 T3 = ecl_list1(T2);
 value0 = CONS(T0,T3);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC5269__lambda7997_va(cl_narg narg, cl_object v2asdf_concatenate_source__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2606]);
 {
  return LC5269__lambda7997(v2asdf_concatenate_source__x);
 }
}
/* local function LAMBDA8053                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5279__lambda8053(cl_object v1asdf_package_inferred_system__f)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = (cl_env_copy->function=ecl_fdefinition(VV[2616]))->cfun.entry(1, v1asdf_package_inferred_system__f) /*  STREAM-DEFPACKAGE-FORM */;
 return value0;
}
static cl_object LC5279__lambda8053_va(cl_narg narg, cl_object v2asdf_package_inferred_system__f, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2619]);
 {
  return LC5279__lambda8053(v2asdf_package_inferred_system__f);
 }
}
/* local function LAMBDA8057                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5281__lambda8057(cl_object v1asdf_package_inferred_system__c, cl_object v2asdf_package_inferred_system__s)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[2625]))->cfun.entry(1, v1asdf_package_inferred_system__c) /*  ERROR-SYSTEM */;
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[1749]))->cfun.entry(1, v1asdf_package_inferred_system__c) /*  ERROR-PATHNAME */;
 value0 = cl_format(4, v2asdf_package_inferred_system__s, VV[2624], T0, T1);
 return value0;
}
static cl_object LC5281__lambda8057_va(cl_narg narg, cl_object v3asdf_package_inferred_system__c, cl_object v4asdf_package_inferred_system__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2623]);
 {
  return LC5281__lambda8057(v3asdf_package_inferred_system__c, v4asdf_package_inferred_system__s);
 }
}
/* local function DEP                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5283dep(volatile cl_object *lex0, cl_object v1uiop_utility__x)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 lex0[0] = CONS(v1uiop_utility__x,lex0[0]);
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 0;
 return value0;
}
/* local function LAMBDA8164                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5292__lambda8164(cl_object v1asdf_backward_interface__c, cl_object v2asdf_backward_interface__s)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_type_of(v1asdf_backward_interface__c);
 T1 = (cl_env_copy->function=ecl_fdefinition(VV[2658]))->cfun.entry(1, v1asdf_backward_interface__c) /*  ERROR-OPERATION */;
 T2 = (cl_env_copy->function=ecl_fdefinition(VV[2659]))->cfun.entry(1, v1asdf_backward_interface__c) /*  ERROR-COMPONENT */;
 value0 = cl_format(5, v2asdf_backward_interface__s, VV[2657], T0, T1, T2);
 return value0;
}
static cl_object LC5292__lambda8164_va(cl_narg narg, cl_object v3asdf_backward_interface__c, cl_object v4asdf_backward_interface__s, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2656]);
 {
  return LC5292__lambda8164(v3asdf_backward_interface__c, v4asdf_backward_interface__s);
 }
}
/* closure LAMBDA8225                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5307__lambda8225(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  TAGBODY                 */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2683]);
 {
L1:;
  ECL_CONS_CAR(CLV0) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV1),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA8290                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5312__lambda8290(cl_narg narg, cl_object v1module_name, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  PROVIDER                */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2693]);
 {
L1:;
  value0 = L5311wrap_module_provider(ECL_CONS_CAR(CLV0), v1module_name);
  return value0;
 }
 }
}
/* closure LAMBDA2856                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4492__lambda2856(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;                                     /*  TAGBODY                 */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[886]);
 {
L1:;
  ECL_CONS_CAR(CLV3) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV4),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA3103                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4538__lambda3103(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  TAGBODY                 */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1006]);
 {
L1:;
  ECL_CONS_CAR(CLV2) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV3),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA3145                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4542__lambda3145(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  TAGBODY                 */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1015]);
 {
L1:;
  ECL_CONS_CAR(CLV1) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV2),ecl_make_fixnum(0));
 }
 }
}
/* closure BEFORE3733                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4636__before3733(cl_narg narg, cl_object v1uiop_run_program__tmp, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV9 = env0;
 CLV8 = _ecl_cdr(CLV9);                           /*  ACTIVITY-SPEC           */
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1233]);
 {
L1:;
  if (!((ECL_CONS_CAR(CLV2))==(ECL_SYM("INPUT",1289)))){
   goto L2;
  }
  {
   cl_object v2;
   v2 = ecl_make_cclosure_va((cl_objectfn)LC4634__lambda3738,env0,Cblock,1);
   T0 = v2;
  }
  (cl_env_copy->function=ecl_fdefinition(VV[838]))->cfun.entry(8, v1uiop_run_program__tmp, T0, ECL_SYM("IF-EXISTS",1279), ECL_SYM("OVERWRITE",1320), ECL_SYM("EXTERNAL-FORMAT",1267), ECL_CONS_CAR(CLV6), ECL_SYM("ELEMENT-TYPE",1255), ECL_CONS_CAR(CLV5)) /*  CALL-WITH-OUTPUT-FILE */;
  value0 = ecl_function_dispatch(cl_env_copy,ECL_CONS_CAR(CLV1))(2, v1uiop_run_program__tmp, ECL_NIL);
  return value0;
L2:;
  if (!((ECL_CONS_CAR(CLV2))==(ECL_SYM("OUTPUT",1319)))){
   goto L11;
  }
  goto L8;
L11:;
  goto L9;
L9:;
  if (!((ECL_CONS_CAR(CLV2))==(VV[1164]))){
   goto L6;
  }
  goto L7;
L8:;
L7:;
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   cl_env_copy->values[0] = ecl_function_dispatch(cl_env_copy,ECL_CONS_CAR(CLV1))(2, v1uiop_run_program__tmp, ECL_NIL);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   {
    cl_object v2;
    v2 = ecl_make_cclosure_va((cl_objectfn)LC4635__lambda3750,env0,Cblock,1);
    T0 = v2;
   }
   (cl_env_copy->function=ecl_fdefinition(VV[852]))->cfun.entry(6, v1uiop_run_program__tmp, T0, ECL_SYM("EXTERNAL-FORMAT",1267), ECL_CONS_CAR(CLV6), ECL_SYM("ELEMENT-TYPE",1255), ECL_CONS_CAR(CLV5)) /*  CALL-WITH-INPUT-FILE */;
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
L6:;
  value0 = si_ecase_error(ECL_CONS_CAR(CLV2), VV[1237]);
  return value0;
 }
 }
}
/* closure LAMBDA3872                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4646__lambda3872(volatile cl_narg narg, cl_object volatile v1uiop_run_program__reduced_error_output, cl_object volatile v2uiop_run_program__error_output_activity, ...)
{
 cl_object T0, T1;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9, CLV10, CLV11, CLV12, CLV13;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV11 = env0;                                    /*  OUTPUT-ACTIVITY         */
 CLV10 = _ecl_cdr(CLV11);
 CLV9 = _ecl_cdr(CLV10);
 CLV8 = _ecl_cdr(CLV9);
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1258]);
 {
  CLV12 = env0 = CONS(v1uiop_run_program__reduced_error_output,env0); /*  REDUCED-ERROR-OUTPUT */
  CLV13 = env0 = CONS(v2uiop_run_program__error_output_activity,env0); /*  ERROR-OUTPUT-ACTIVITY */
  T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-INPUT*",68));
  {
   cl_object volatile v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4645__lambda3874,env0,Cblock,2);
   T1 = v3;
  }
  {
   bool v3;
   v3 = (ECL_CONS_CAR(CLV4))==(ECL_SYM("INPUT",1289));
   value0 = cl_apply(10, VV[1224], VV[1139], T0, ECL_T, T1, ECL_SYM("INPUT",1289), ECL_CONS_CAR(CLV2), ecl_make_bool(v3), ECL_NIL, ECL_CONS_CAR(CLV1));
   return value0;
  }
 }
 }
}
/* closure LAMBDA3893                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4647__lambda3893(cl_narg narg, cl_object v1, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9, CLV10, CLV11;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV11 = env0;
 CLV10 = _ecl_cdr(CLV11);
 CLV9 = _ecl_cdr(CLV10);
 CLV8 = _ecl_cdr(CLV9);
 CLV7 = _ecl_cdr(CLV8);                           /*  ERROR-OUTPUT-RESULT     */
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1264]);
 {
L1:;
  ECL_CONS_CAR(CLV7) = v1;
  value0 = ECL_CONS_CAR(CLV7);
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure LAMBDA3938                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4657__lambda3938(cl_narg narg, cl_object v1uiop_run_program__reduced_error_output, cl_object v2, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV7 = env0;                                     /*  REDUCED-OUTPUT          */
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1289]);
 {
  CLV8 = env0 = CONS(v1uiop_run_program__reduced_error_output,env0); /*  REDUCED-ERROR-OUTPUT */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC4656__lambda3941,env0,Cblock,2);
   T0 = v3;
  }
  value0 = cl_apply(10, VV[1224], VV[1139], ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-INPUT*",68)), ECL_NIL, T0, ECL_SYM("INPUT",1289), ECL_CONS_CAR(CLV2), ECL_NIL, ECL_NIL, ECL_CONS_CAR(CLV1));
  return value0;
 }
 }
}
/* closure LAMBDA3945                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4658__lambda3945(cl_narg narg, cl_object v1, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV7 = env0;
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);                           /*  ERROR-OUTPUT-RESULT     */
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1291]);
 {
L1:;
  ECL_CONS_CAR(CLV5) = v1;
  value0 = ECL_CONS_CAR(CLV5);
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure LAMBDA4170                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4688__lambda4170(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV5 = env0;                                     /*  TAGBODY                 */
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1400]);
 {
L1:;
  ECL_CONS_CAR(CLV4) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV5),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA4215                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4701__lambda4215(cl_narg narg, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;                                     /*  INPUT-FILE              */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1431]);
 {
L1:;
  {
   cl_object v1;
   v1 = ecl_make_cclosure_va((cl_objectfn)LC4700__lambda4217,env0,Cblock,0);
   T0 = v1;
  }
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[1318]))->cfun.entry(1, T0) /*  CALL-WITH-MUFFLED-COMPILER-CONDITIONS */;
  return value0;
 }
 }
}
/* closure LAMBDA5153                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4849__lambda5153(cl_narg narg, cl_object v1condition, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);                           /*  NAME                    */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1844]);
 {
L1:;
  value0 = cl_error(7, VV[1744], ECL_SYM("NAME",1309), ECL_CONS_CAR(CLV1), ECL_SYM("PATHNAME",1322), ECL_CONS_CAR(CLV0), VV[1018], v1condition);
  return value0;
 }
 }
}
/* closure LAMBDA5279                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4879__lambda5279(cl_narg narg, cl_object v1si__temp, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  TAGBODY                 */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1894]);
 {
L1:;
  ECL_CONS_CAR(CLV2) = v1si__temp;
  cl_go(ECL_CONS_CAR(CLV3),ecl_make_fixnum(0));
 }
 }
}
/* closure LAMBDA6297                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5048__lambda6297(cl_narg narg, cl_object v1asdf_plan__o, cl_object v2asdf_plan__c, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV6 = env0;                                     /*  NIIP                    */
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2108]);
 {
L1:;
  value0 = (cl_env_copy->function=ecl_fdefinition(VV[2106]))->cfun.entry(4, ECL_CONS_CAR(CLV0), v1asdf_plan__o, v2asdf_plan__c, ECL_CONS_CAR(CLV6)) /*  TRAVERSE-ACTION */;
  return value0;
 }
 }
}
/* local function PATHNAME-KEY                                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC5150pathname_key(cl_object v1asdf_source_registry__x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = (cl_env_copy->function=ecl_fdefinition(VV[661]))->cfun.entry(1, v1asdf_source_registry__x) /*  TRUENAME* */;
 value0 = cl_namestring(T0);
 return value0;
}
static cl_object LC5150pathname_key_va(cl_narg narg, cl_object v2asdf_source_registry__x, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[2286]);
 {
  return LC5150pathname_key(v2asdf_source_registry__x);
 }
}
/* closure LAMBDA3738                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4634__lambda3738(cl_narg narg, cl_object v1uiop_run_program__s, ...)
{
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV9 = env0;
 CLV8 = _ecl_cdr(CLV9);                           /*  ACTIVITY-SPEC           */
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1234]);
 {
L1:;
  value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4632activity(1, v1uiop_run_program__s));
  return value0;
 }
 }
}
/* closure LAMBDA3750                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4635__lambda3750(cl_narg narg, cl_object v1uiop_run_program__s, ...)
{
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV9 = env0;
 CLV8 = _ecl_cdr(CLV9);                           /*  ACTIVITY-SPEC           */
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[1236]);
 {
L1:;
  value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4632activity(1, v1uiop_run_program__s));
  return value0;
 }
 }
}
/* closure LAMBDA3874                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4645__lambda3874(volatile cl_narg narg, cl_object volatile v1uiop_run_program__reduced_input, cl_object volatile v2uiop_run_program__input_activity, ...)
{
 cl_object T0;
 volatile struct ecl_cclosure aux_closure;
 cl_object volatile CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9, CLV10, CLV11, CLV12, CLV13;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile env0 = cl_env_copy->function->cclosure.env;
 cl_object volatile value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV13 = env0;                                    /*  ERROR-OUTPUT-ACTIVITY   */
 CLV12 = _ecl_cdr(CLV13);
 CLV11 = _ecl_cdr(CLV12);
 CLV10 = _ecl_cdr(CLV11);
 CLV9 = _ecl_cdr(CLV10);
 CLV8 = _ecl_cdr(CLV9);
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1259]);
 {
L1:;
  if (!((ECL_CONS_CAR(CLV3))==(ECL_SYM("OUTPUT",1319)))){
   goto L5;
  }
  T0 = ECL_SYM("OUTPUT",1319);
  goto L4;
L5:;
  T0 = ECL_CONS_CAR(CLV12);
L4:;
  ECL_CONS_CAR(CLV9) = cl_apply(11, VV[1178], ECL_CONS_CAR(CLV0), ECL_SYM("WAIT",1367), ECL_CONS_CAR(CLV5), ECL_SYM("INPUT",1289), v1uiop_run_program__reduced_input, ECL_SYM("OUTPUT",1319), ECL_CONS_CAR(CLV10), VV[1164], T0, ECL_CONS_CAR(CLV1));
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   volatile cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   volatile bool unwinding = FALSE;
   ecl_frame_ptr next_fr;
   {
    ecl_frs_push(cl_env_copy,ECL_PROTECT_TAG);
    if (__ecl_frs_push_result!=0) {
      unwinding = TRUE; next_fr=cl_env_copy->frs_stack.nlj_fr;
    } else {
    if (!((ECL_CONS_CAR(CLV4))==(ECL_NIL))){
     goto L8;
    }
    cl_env_copy->values[0] = ECL_NIL;
    cl_env_copy->nvalues = 1;
    goto L7;
L8:;
    if (!((ECL_CONS_CAR(CLV4))==(ECL_SYM("INPUT",1289)))){
     goto L11;
    }
    cl_env_copy->values[0] = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4644run_activity(3, v2uiop_run_program__input_activity, VV[1188], ECL_T));
    goto L7;
L11:;
    if (!((ECL_CONS_CAR(CLV4))==(ECL_SYM("OUTPUT",1319)))){
     goto L13;
    }
    cl_env_copy->values[0] = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4644run_activity(3, ECL_CONS_CAR(CLV11), VV[1189], ECL_T));
    goto L7;
L13:;
    if (!((ECL_CONS_CAR(CLV4))==(VV[1164]))){
     goto L15;
    }
    cl_env_copy->values[0] = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4644run_activity(2, ECL_CONS_CAR(CLV13), VV[1194]));
    goto L7;
L15:;
    cl_env_copy->values[0] = si_ecase_error(ECL_CONS_CAR(CLV4), VV[1263]);
L7:;
    }
   }
   ecl_frs_pop(cl_env_copy);
   ecl_stack_frame_push_values(_ecl_inner_frame);
   (cl_env_copy->function=ecl_fdefinition(VV[1215]))->cfun.entry(1, ECL_CONS_CAR(CLV9)) /*  CLOSE-STREAMS */;
   ECL_CONS_CAR(CLV8) = (cl_env_copy->function=ecl_fdefinition(VV[1209]))->cfun.entry(1, ECL_CONS_CAR(CLV9)) /*  WAIT-PROCESS */;
   ecl_stack_frame_pop_values(_ecl_inner_frame);
   if (unwinding) ecl_unwind(cl_env_copy,next_fr);
   ecl_stack_frame_close(_ecl_inner_frame);
   return cl_env_copy->values[0];
  }
 }
 }
}
/* closure LAMBDA3941                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4656__lambda3941(cl_narg narg, cl_object v1uiop_run_program__reduced_input, cl_object v2, ...)
{
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV8 = env0;                                     /*  REDUCED-ERROR-OUTPUT    */
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[1290]);
 {
L1:;
  ECL_CONS_CAR(CLV6) = cl_apply(9, VV[1284], ECL_CONS_CAR(CLV0), ECL_SYM("INPUT",1289), v1uiop_run_program__reduced_input, ECL_SYM("OUTPUT",1319), ECL_CONS_CAR(CLV7), VV[1164], ECL_CONS_CAR(CLV8), ECL_CONS_CAR(CLV1));
  value0 = ECL_CONS_CAR(CLV6);
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure LAMBDA4217                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4700__lambda4217(cl_narg narg, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV4 = env0;                                     /*  INPUT-FILE              */
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=0)) FEwrong_num_arguments(VV[1432]);
 {
L1:;
  if (Null(ECL_CONS_CAR(CLV2))){
   goto L3;
  }
  T0 = cl_listX(4, ECL_CONS_CAR(CLV2), VV[1433], ECL_T, ECL_CONS_CAR(CLV1));
  goto L2;
L3:;
  T0 = CONS(ECL_CONS_CAR(CLV3),ECL_CONS_CAR(CLV1));
L2:;
  value0 = cl_apply(4, ECL_SYM("COMPILE-FILE",236), ECL_CONS_CAR(CLV4), VV[1429], T0);
  return value0;
 }
 }
}
/* closure RUN-ACTIVITY                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4644run_activity(cl_narg narg, cl_object v1uiop_run_program__activity, cl_object v2uiop_run_program__stream_name, ...)
{
 cl_object T0;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9, CLV10, CLV11, CLV12, CLV13;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV13 = env0;
 CLV12 = _ecl_cdr(CLV13);
 CLV11 = _ecl_cdr(CLV12);
 CLV10 = _ecl_cdr(CLV11);
 CLV9 = _ecl_cdr(CLV10);                          /*  PROCESS-INFO            */
 CLV8 = _ecl_cdr(CLV9);
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[1261]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[1261]);
 {
  cl_object v3uiop_run_program__fallbackp;
  va_list args; va_start(args,v2uiop_run_program__stream_name);
  {
   int i = 2;
   if (i >= narg) {
    v3uiop_run_program__fallbackp = ECL_NIL;
   } else {
    i++;
    v3uiop_run_program__fallbackp = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v4stream;
   v4stream = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC4643get_stream(2, v2uiop_run_program__stream_name, v3uiop_run_program__fallbackp));
   if (Null(v4stream)){
    goto L3;
   }
   value0 = ecl_function_dispatch(cl_env_copy,v1uiop_run_program__activity)(1, v4stream);
   return value0;
L3:;
   T0 = cl_list(2, VV[1262], v2uiop_run_program__stream_name);
   value0 = cl_error(7, VV[1142], ECL_SYM("CODE",1914), T0, VV[1213], ECL_CONS_CAR(CLV0), ECL_SYM("PROCESS",1331), ECL_CONS_CAR(CLV9));
   return value0;
  }
 }
 }
}
/* closure GET-STREAM                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC4643get_stream(cl_narg narg, cl_object v1uiop_run_program__stream_name, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3, CLV4, CLV5, CLV6, CLV7, CLV8, CLV9, CLV10, CLV11, CLV12, CLV13;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV13 = env0;
 CLV12 = _ecl_cdr(CLV13);
 CLV11 = _ecl_cdr(CLV12);
 CLV10 = _ecl_cdr(CLV11);
 CLV9 = _ecl_cdr(CLV10);                          /*  PROCESS-INFO            */
 CLV8 = _ecl_cdr(CLV9);
 CLV7 = _ecl_cdr(CLV8);
 CLV6 = _ecl_cdr(CLV7);
 CLV5 = _ecl_cdr(CLV6);
 CLV4 = _ecl_cdr(CLV5);
 CLV3 = _ecl_cdr(CLV4);
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1260]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[1260]);
 {
  cl_object v2uiop_run_program__fallbackp;
  va_list args; va_start(args,v1uiop_run_program__stream_name);
  {
   int i = 1;
   if (i >= narg) {
    v2uiop_run_program__fallbackp = ECL_NIL;
   } else {
    i++;
    v2uiop_run_program__fallbackp = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = ECL_CONS_CAR(CLV9);
  value0 = cl_slot_value(T0, v1uiop_run_program__stream_name);
  if (value0!=ECL_NIL) {
   goto L3;
  }
  if (Null(v2uiop_run_program__fallbackp)){
   goto L6;
  }
  T0 = ECL_CONS_CAR(CLV9);
  value0 = cl_slot_value(T0, VV[1190]);
  return value0;
L6:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
#include "ext/asdf.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _eclZRyBEHa3fImi9_x5D1M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("EXT:ASDF;ASDF.LISP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_eclZRyBEHa3fImi9_x5D1M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0, T1, T2, T3, T4, T5;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_0, ECL_NIL, ECL_NIL, ECL_NIL, VVtemp[0], ECL_NIL, ECL_NIL, ECL_NIL, VVtemp[1], ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  si_select_package(_ecl_static_0);
  ecl_cmp_defun(VV[2695]);                        /*  FIND-PACKAGE*           */
  ecl_cmp_defun(VV[2696]);                        /*  FIND-SYMBOL*            */
  ecl_cmp_defun(VV[2697]);                        /*  SYMBOL-CALL             */
  ecl_cmp_defun(VV[2698]);                        /*  INTERN*                 */
  ecl_cmp_defun(VV[2699]);                        /*  EXPORT*                 */
  ecl_cmp_defun(VV[2700]);                        /*  IMPORT*                 */
  ecl_cmp_defun(VV[2701]);                        /*  SHADOWING-IMPORT*       */
  ecl_cmp_defun(VV[2702]);                        /*  SHADOW*                 */
  ecl_cmp_defun(VV[2703]);                        /*  MAKE-SYMBOL*            */
  ecl_cmp_defun(VV[2704]);                        /*  UNINTERN*               */
  ecl_cmp_defun(VV[2705]);                        /*  SYMBOL-SHADOWING-P      */
  ecl_cmp_defun(VV[2706]);                        /*  HOME-PACKAGE-P          */
  ecl_cmp_defun(VV[2707]);                        /*  SYMBOL-PACKAGE-NAME     */
  ecl_cmp_defun(VV[2708]);                        /*  STANDARD-COMMON-LISP-SYMBOL-P */
  ecl_cmp_defun(VV[2709]);                        /*  REIFY-PACKAGE           */
  ecl_cmp_defun(VV[2710]);                        /*  UNREIFY-PACKAGE         */
  ecl_cmp_defun(VV[2711]);                        /*  REIFY-SYMBOL            */
  ecl_cmp_defun(VV[2712]);                        /*  UNREIFY-SYMBOL          */
  si_Xmake_special(VV[50]);
  if (ecl_boundp(cl_env_copy,VV[50])) {
   goto L58;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[50],T0);
L58:;
  si_Xmake_special(VV[51]);
  if (ecl_boundp(cl_env_copy,VV[51])) {
   goto L65;
  }
  T0 = ecl_list1(ECL_T);
  ecl_cmp_setq(cl_env_copy,VV[51],T0);
L65:;
  ecl_cmp_defun(VV[2713]);                        /*  RECORD-FISHY            */
  ecl_cmp_defmacro(VV[2714]);                     /*  WHEN-PACKAGE-FISHINESS  */
  ecl_cmp_defmacro(VV[2715]);                     /*  NOTE-PACKAGE-FISHINESS  */
  ecl_cmp_defun(VV[2716]);                        /*  SET-DUMMY-SYMBOL        */
  ecl_cmp_defun(VV[2717]);                        /*  MAKE-DUMMY-SYMBOL       */
  ecl_cmp_defun(VV[2718]);                        /*  DUMMY-SYMBOL            */
  ecl_cmp_defun(VV[2719]);                        /*  GET-DUMMY-SYMBOL        */
  ecl_cmp_defun(VV[2720]);                        /*  NUKE-SYMBOL-IN-PACKAGE  */
  ecl_cmp_defun(VV[2721]);                        /*  NUKE-SYMBOL             */
  ecl_cmp_defun(VV[2722]);                        /*  REHOME-SYMBOL           */
  ecl_cmp_defun(VV[2723]);                        /*  ENSURE-PACKAGE-UNUSED   */
  ecl_cmp_defun(VV[2724]);                        /*  DELETE-PACKAGE*         */
  ecl_cmp_defun(VV[2725]);                        /*  PACKAGE-NAMES           */
  ecl_cmp_defun(VV[2726]);                        /*  PACKAGES-FROM-NAMES     */
  ecl_cmp_defun(VV[2727]);                        /*  FRESH-PACKAGE-NAME      */
  ecl_cmp_defun(VV[2728]);                        /*  RENAME-PACKAGE-AWAY     */
  ecl_cmp_defun(VV[2729]);                        /*  PACKAGE-DEFINITION-FORM */
  ecl_cmp_defun(VV[2730]);                        /*  ENSURE-SHADOWING-IMPORT */
  ecl_cmp_defun(VV[2731]);                        /*  ENSURE-IMPORTED         */
  ecl_cmp_defun(VV[2732]);                        /*  ENSURE-IMPORT           */
  ecl_cmp_defun(VV[2733]);                        /*  ENSURE-INHERITED        */
  ecl_cmp_defun(VV[2734]);                        /*  ENSURE-MIX              */
  ecl_cmp_defun(VV[2735]);                        /*  RECYCLE-SYMBOL          */
  ecl_cmp_defun(VV[2736]);                        /*  SYMBOL-RECYCLED-P       */
  ecl_cmp_defun(VV[2737]);                        /*  ENSURE-SYMBOL           */
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[2]) /*  MAPC */;
  ecl_cmp_defun(VV[2738]);                        /*  ENSURE-EXPORTED-TO-USER */
  ecl_cmp_defun(VV[2739]);                        /*  ENSURE-EXPORTED         */
  ecl_cmp_defun(VV[2740]);                        /*  ENSURE-EXPORT           */
  ecl_cmp_defun(VV[2741]);                        /*  ENSURE-PACKAGE          */
  ecl_cmp_defun(VV[2742]);                        /*  PARSE-DEFINE-PACKAGE-FORM */
  ecl_cmp_defmacro(VV[2743]);                     /*  DEFINE-PACKAGE          */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_1, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[3]);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_2, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[4]);
  si_select_package(_ecl_static_2);
  {
   cl_object v1;
   cl_object v2;
   cl_object v3;
   v1 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36));
   v2 = VV[194];
   v3 = v1;
   if (Null(ecl_memql(v2,v3))){
    goto L169;
   }
  }
  T0 = cl_adjoin(2, VV[195], ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36)));
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*FEATURES*",36),T0);
L169:;
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*LOAD-VERBOSE*",41),T0);
  ecl_cmp_defun(VV[2744]);                        /*  USE-ECL-BYTE-COMPILER-P */
  if (L4251use_ecl_byte_compiler_p()!=ECL_NIL) {
   goto L180;
  }
  cl_require(1, VV[199]);
L180:;
  ecl_cmp_defmacro(VV[2745]);                     /*  LOOP*                   */
  ecl_cmp_defun(VV[2746]);                        /*  FROB-SUBSTRINGS         */
  ecl_cmp_defmacro(VV[2747]);                     /*  COMPATFMT               */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_3, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[5]);
  si_select_package(_ecl_static_3);
  ecl_cmp_defun(VV[2748]);                        /*  UNDEFINE-FUNCTION       */
  ecl_cmp_defun(VV[2749]);                        /*  UNDEFINE-FUNCTIONS      */
  ecl_cmp_defmacro(VV[2750]);                     /*  DEFGENERIC*             */
  ecl_cmp_defmacro(VV[2751]);                     /*  DEFUN*                  */
  ecl_cmp_defmacro(VV[2752]);                     /*  WITH-UPGRADABILITY      */
  si_Xmake_special(VV[227]);
  if (ecl_boundp(cl_env_copy,VV[227])) {
   goto L205;
  }
  T0 = VVtemp[6];
  ecl_cmp_setq(cl_env_copy,VV[227],T0);
L205:;
  ecl_cmp_defmacro(VV[2753]);                     /*  UIOP-DEBUG              */
  L4258undefine_function(VV[229]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[7]) /*  MAPC */;
  ecl_cmp_defun(VV[2754]);                        /*  LOAD-UIOP-DEBUG-UTILITY */
  ecl_cmp_defmacro(VV[2755]);                     /*  NEST                    */
  ecl_cmp_defmacro(VV[2756]);                     /*  IF-LET                  */
  ecl_cmp_defmacro(VV[2757]);                     /*  WHILE-COLLECTING        */
  ecl_cmp_defmacro(VV[2758]);                     /*  APPENDF                 */
  L4258undefine_function(VV[253]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[8]) /*  MAPC */;
  ecl_cmp_defun(VV[2759]);                        /*  LENGTH=N-P              */
  L4258undefine_function(VV[257]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[9]) /*  MAPC */;
  ecl_cmp_defun(VV[2760]);                        /*  ENSURE-LIST             */
  L4258undefine_function(VV[259]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[10]) /*  MAPC */;
  ecl_cmp_defun(VV[2761]);                        /*  REMOVE-PLIST-KEY        */
  L4258undefine_function(VV[261]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[11]) /*  MAPC */;
  ecl_cmp_defun(VV[2762]);                        /*  REMOVE-PLIST-KEYS       */
  L4258undefine_function(VV[263]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[12]) /*  MAPC */;
  ecl_cmp_defun(VV[2763]);                        /*  EMPTYP                  */
  si_Xmake_special(VV[265]);
  T0 = VVtemp[13];
  ecl_cmp_setq(cl_env_copy,VV[265],T0);
  si_Xmake_special(VV[266]);
  {
   cl_fixnum v1;
   v1 = ecl_length(ecl_cmp_symbol_value(cl_env_copy,VV[265]));
   T0 = ecl_make_integer((v1)-1);
   ecl_cmp_setq(cl_env_copy,VV[266],T0);
  }
  {
   bool v1;
   v1 = ecl_plusp(ecl_cmp_symbol_value(cl_env_copy,VV[266]));
   si_Xmake_constant(VV[267], ecl_make_bool(v1));
  }
  T0 = cl_adjoin(2, VV[268], ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36)));
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*FEATURES*",36),T0);
  L4258undefine_function(VV[269]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[14]) /*  MAPC */;
  ecl_cmp_defun(VV[2764]);                        /*  CHARACTER-TYPE-INDEX    */
  L4258undefine_function(VV[272]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[15]) /*  MAPC */;
  ecl_cmp_defun(VV[2765]);                        /*  BASE-STRING-P           */
  L4258undefine_function(VV[274]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[16]) /*  MAPC */;
  ecl_cmp_defun(VV[2766]);                        /*  STRINGS-COMMON-ELEMENT-TYPE */
  L4258undefine_function(VV[280]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[17]) /*  MAPC */;
  ecl_cmp_defun(VV[2767]);                        /*  REDUCE/STRCAT           */
  L4258undefine_function(VV[283]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[18]) /*  MAPC */;
  ecl_cmp_defun(VV[2768]);                        /*  STRCAT                  */
  L4258undefine_function(VV[285]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[19]) /*  MAPC */;
  ecl_cmp_defun(VV[2769]);                        /*  FIRST-CHAR              */
  L4258undefine_function(VV[287]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[20]) /*  MAPC */;
  ecl_cmp_defun(VV[2770]);                        /*  LAST-CHAR               */
  L4258undefine_function(VV[289]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[21]) /*  MAPC */;
  ecl_cmp_defun(VV[2771]);                        /*  SPLIT-STRING            */
  L4258undefine_function(VV[298]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[22]) /*  MAPC */;
  ecl_cmp_defun(VV[2772]);                        /*  STRING-PREFIX-P         */
  L4258undefine_function(VV[300]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[23]) /*  MAPC */;
  ecl_cmp_defun(VV[2773]);                        /*  STRING-SUFFIX-P         */
  L4258undefine_function(VV[302]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[24]) /*  MAPC */;
  ecl_cmp_defun(VV[2774]);                        /*  STRING-ENCLOSED-P       */
  si_Xmake_special(VV[304]);
  if (ecl_boundp(cl_env_copy,VV[304])) {
   goto L342;
  }
  T0 = si_coerce_to_vector(VVtemp[25], ECL_SYM("CHARACTER",224), ECL_SYM("*",20), ECL_NIL);
  ecl_cmp_setq(cl_env_copy,VV[304],T0);
L342:;
  si_Xmake_special(VV[306]);
  if (ecl_boundp(cl_env_copy,VV[306])) {
   goto L349;
  }
  T0 = si_coerce_to_vector(VVtemp[26], ECL_SYM("CHARACTER",224), ECL_SYM("*",20), ECL_NIL);
  ecl_cmp_setq(cl_env_copy,VV[306],T0);
L349:;
  si_Xmake_special(VV[307]);
  if (ecl_boundp(cl_env_copy,VV[307])) {
   goto L356;
  }
  T0 = si_coerce_to_vector(VVtemp[27], ECL_SYM("CHARACTER",224), ECL_SYM("*",20), ECL_NIL);
  ecl_cmp_setq(cl_env_copy,VV[307],T0);
L356:;
  L4258undefine_function(VV[308]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[28]) /*  MAPC */;
  ecl_cmp_defun(VV[2775]);                        /*  STRIPLN                 */
  L4258undefine_function(VV[311]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[29]) /*  MAPC */;
  ecl_cmp_defun(VV[2776]);                        /*  STANDARD-CASE-SYMBOL-NAME */
  L4258undefine_function(VV[315]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[30]) /*  MAPC */;
  ecl_cmp_defun(VV[2777]);                        /*  FIND-STANDARD-CASE-SYMBOL */
  si_do_deftype(3, VV[318], VVtemp[31], VVtemp[32]);
  L4258undefine_function(VV[319]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[33]) /*  MAPC */;
  ecl_cmp_defun(VV[2778]);                        /*  STAMP<                  */
  L4258undefine_function(VV[322]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[34]) /*  MAPC */;
  ecl_cmp_defun(VV[2779]);                        /*  STAMPS<                 */
  L4258undefine_function(VV[324]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[35]) /*  MAPC */;
  ecl_cmp_defun(VV[2780]);                        /*  STAMP*<                 */
  L4258undefine_function(VV[326]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[36]) /*  MAPC */;
  ecl_cmp_defun(VV[2781]);                        /*  STAMP<=                 */
  L4258undefine_function(VV[328]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[37]) /*  MAPC */;
  ecl_cmp_defun(VV[2782]);                        /*  EARLIER-STAMP           */
  L4258undefine_function(VV[330]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[38]) /*  MAPC */;
  ecl_cmp_defun(VV[2783]);                        /*  STAMPS-EARLIEST         */
  L4258undefine_function(VV[333]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[39]) /*  MAPC */;
  ecl_cmp_defun(VV[2784]);                        /*  EARLIEST-STAMP          */
  L4258undefine_function(VV[335]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[40]) /*  MAPC */;
  ecl_cmp_defun(VV[2785]);                        /*  LATER-STAMP             */
  L4258undefine_function(VV[337]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[41]) /*  MAPC */;
  ecl_cmp_defun(VV[2786]);                        /*  STAMPS-LATEST           */
  L4258undefine_function(VV[339]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[42]) /*  MAPC */;
  ecl_cmp_defun(VV[2787]);                        /*  LATEST-STAMP            */
  ecl_cmp_defmacro(VV[2788]);                     /*  LATEST-STAMP-F          */
  L4258undefine_function(VV[344]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[43]) /*  MAPC */;
  ecl_cmp_defun(VV[2789]);                        /*  ENSURE-FUNCTION         */
  L4258undefine_function(VV[349]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[44]) /*  MAPC */;
  ecl_cmp_defun(VV[2790]);                        /*  ACCESS-AT               */
  L4258undefine_function(VV[353]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[45]) /*  MAPC */;
  ecl_cmp_defun(VV[2791]);                        /*  ACCESS-AT-COUNT         */
  L4258undefine_function(VV[355]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[46]) /*  MAPC */;
  ecl_cmp_defun(VV[2792]);                        /*  CALL-FUNCTION           */
  L4258undefine_function(VV[357]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[47]) /*  MAPC */;
  ecl_cmp_defun(VV[2793]);                        /*  CALL-FUNCTIONS          */
  L4258undefine_function(VV[359]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[48]) /*  MAPC */;
  ecl_cmp_defun(VV[2794]);                        /*  REGISTER-HOOK-FUNCTION  */
  L4258undefine_function(VV[361]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[49]) /*  MAPC */;
  ecl_cmp_defun(VV[2795]);                        /*  COERCE-CLASS            */
  L4258undefine_function(VV[367]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[50]) /*  MAPC */;
  ecl_cmp_defun(VV[2796]);                        /*  ENSURE-GETHASH          */
  L4258undefine_function(VV[369]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[51]) /*  MAPC */;
  ecl_cmp_defun(VV[2797]);                        /*  LIST-TO-HASH-SET        */
  L4258undefine_function(VV[371]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[52]) /*  MAPC */;
  ecl_cmp_defun(VV[2798]);                        /*  UNPARSE-VERSION         */
  L4258undefine_function(VV[374]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[53]) /*  MAPC */;
  ecl_cmp_defun(VV[2799]);                        /*  PARSE-VERSION           */
  L4258undefine_function(VV[381]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[54]) /*  MAPC */;
  ecl_cmp_defun(VV[2800]);                        /*  LEXICOGRAPHIC<          */
  L4258undefine_function(VV[383]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[55]) /*  MAPC */;
  ecl_cmp_defun(VV[2801]);                        /*  LEXICOGRAPHIC<=         */
  L4258undefine_function(VV[385]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[56]) /*  MAPC */;
  ecl_cmp_defun(VV[2802]);                        /*  VERSION<                */
  L4258undefine_function(VV[387]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[57]) /*  MAPC */;
  ecl_cmp_defun(VV[2803]);                        /*  VERSION<=               */
  L4258undefine_function(VV[389]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[58]) /*  MAPC */;
  ecl_cmp_defun(VV[2804]);                        /*  VERSION-COMPATIBLE-P    */
  si_Xmake_special(VV[391]);
  T0 = VV[392];
  ecl_cmp_setq(cl_env_copy,VV[391],T0);
  L4258undefine_function(VV[393]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[59]) /*  MAPC */;
  ecl_cmp_defun(VV[2805]);                        /*  MATCH-CONDITION-P       */
  L4258undefine_function(VV[400]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[60]) /*  MAPC */;
  ecl_cmp_defun(VV[2806]);                        /*  MATCH-ANY-CONDITION-P   */
  L4258undefine_function(VV[402]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[61]) /*  MAPC */;
  ecl_cmp_defun(VV[2807]);                        /*  CALL-WITH-MUFFLED-CONDITIONS */
  ecl_cmp_defmacro(VV[2808]);                     /*  WITH-MUFFLED-CONDITIONS */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4337__lambda1822_va,ECL_NIL,Cblock,0);
   T0 = v1;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[63]);
  T2 = cl_list(4, T1, VVtemp[64], VVtemp[65], VVtemp[66]);
  clos_load_defclass(VV[407], VVtemp[62], T2, ECL_NIL);
  L4258undefine_function(VV[407]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[67]) /*  MAPC */;
  ecl_cmp_defun(VV[2809]);                        /*  NOT-IMPLEMENTED-ERROR   */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4340__lambda1827_va,ECL_NIL,Cblock,0);
   T0 = v1;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[68]);
  T2 = cl_list(4, T1, VVtemp[64], VVtemp[65], VVtemp[66]);
  clos_load_defclass(VV[416], VVtemp[62], T2, ECL_NIL);
  L4258undefine_function(VV[416]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[69]) /*  MAPC */;
  ecl_cmp_defun(VV[2810]);                        /*  PARAMETER-ERROR         */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_4, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[70]);
  si_select_package(_ecl_static_4);
  L4258undefine_function(VV[420]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[71]) /*  MAPC */;
  ecl_cmp_defun(VV[2811]);                        /*  FEATUREP                */
  L4258undefine_function(VV[427]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[72]) /*  MAPC */;
  ecl_cmp_defun(VV[2812]);                        /*  OS-MACOSX-P             */
  L4258undefine_function(VV[430]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[73]) /*  MAPC */;
  ecl_cmp_defun(VV[2813]);                        /*  OS-UNIX-P               */
  L4258undefine_function(VV[433]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[74]) /*  MAPC */;
  ecl_cmp_defun(VV[2814]);                        /*  OS-WINDOWS-P            */
  L4258undefine_function(VV[436]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[75]) /*  MAPC */;
  ecl_cmp_defun(VV[2815]);                        /*  OS-GENERA-P             */
  L4258undefine_function(VV[439]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[76]) /*  MAPC */;
  ecl_cmp_defun(VV[2816]);                        /*  OS-OLDMAC-P             */
  L4258undefine_function(VV[442]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[77]) /*  MAPC */;
  ecl_cmp_defun(VV[2817]);                        /*  OS-HAIKU-P              */
  L4258undefine_function(VV[445]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[78]) /*  MAPC */;
  ecl_cmp_defun(VV[2818]);                        /*  DETECT-OS               */
  ecl_cmp_defmacro(VV[2819]);                     /*  OS-COND                 */
  (cl_env_copy->function=ecl_fdefinition(VV[445]))->cfun.entry(0) /*  DETECT-OS */;
  L4258undefine_function(VV[452]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[79]) /*  MAPC */;
  ecl_cmp_defun(VV[2820]);                        /*  GETENV                  */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4352__lambda1880_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, VV[452], T0, ecl_make_int8_t(1));
  L4258undefine_function(VV[455]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[80]) /*  MAPC */;
  ecl_cmp_defun(VV[2821]);                        /*  GETENVP                 */
  L4258undefine_function(VV[457]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[81]) /*  MAPC */;
  ecl_cmp_defun(VV[2822]);                        /*  FIRST-FEATURE           */
  L4258undefine_function(VV[459]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[82]) /*  MAPC */;
  ecl_cmp_defun(VV[2823]);                        /*  IMPLEMENTATION-TYPE     */
  si_Xmake_special(VV[462]);
  if (ecl_boundp(cl_env_copy,VV[462])) {
   goto L667;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[459]))->cfun.entry(0) /*  IMPLEMENTATION-TYPE */;
  ecl_cmp_setq(cl_env_copy,VV[462],T0);
L667:;
  L4258undefine_function(VV[463]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[83]) /*  MAPC */;
  ecl_cmp_defun(VV[2824]);                        /*  OPERATING-SYSTEM        */
  L4258undefine_function(VV[466]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[84]) /*  MAPC */;
  ecl_cmp_defun(VV[2825]);                        /*  ARCHITECTURE            */
  L4258undefine_function(VV[469]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[85]) /*  MAPC */;
  ecl_cmp_defun(VV[2826]);                        /*  LISP-VERSION-STRING     */
  L4258undefine_function(VV[472]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[86]) /*  MAPC */;
  ecl_cmp_defun(VV[2827]);                        /*  IMPLEMENTATION-IDENTIFIER */
  L4258undefine_function(VV[477]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[87]) /*  MAPC */;
  ecl_cmp_defun(VV[2828]);                        /*  HOSTNAME                */
  L4258undefine_function(VV[479]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[88]) /*  MAPC */;
  ecl_cmp_defun(VV[2829]);                        /*  GETCWD                  */
  L4258undefine_function(VV[482]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[89]) /*  MAPC */;
  ecl_cmp_defun(VV[2830]);                        /*  CHDIR                   */
  si_Xmake_special(VV[484]);
  T0 = ecl_make_int8_t(76);
  ecl_cmp_setq(cl_env_copy,VV[484],T0);
  si_Xmake_special(VV[485]);
  T0 = VVtemp[90];
  ecl_cmp_setq(cl_env_copy,VV[485],T0);
  L4258undefine_function(VV[486]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[91]) /*  MAPC */;
  ecl_cmp_defun(VV[2831]);                        /*  READ-NULL-TERMINATED-STRING */
  L4258undefine_function(VV[488]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[92]) /*  MAPC */;
  ecl_cmp_defun(VV[2832]);                        /*  READ-LITTLE-ENDIAN      */
  L4258undefine_function(VV[490]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[93]) /*  MAPC */;
  ecl_cmp_defun(VV[2833]);                        /*  PARSE-FILE-LOCATION-INFO */
  L4258undefine_function(VV[492]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[94]) /*  MAPC */;
  ecl_cmp_defun(VV[2834]);                        /*  PARSE-WINDOWS-SHORTCUT  */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_5, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[95]);
  si_select_package(_ecl_static_5);
  L4258undefine_function(VV[497]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[96]) /*  MAPC */;
  ecl_cmp_defun(VV[2835]);                        /*  NORMALIZE-PATHNAME-DIRECTORY-COMPONENT */
  L4258undefine_function(VV[502]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[97]) /*  MAPC */;
  ecl_cmp_defun(VV[2836]);                        /*  DENORMALIZE-PATHNAME-DIRECTORY-COMPONENT */
  L4258undefine_function(VV[504]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[98]) /*  MAPC */;
  ecl_cmp_defun(VV[2837]);                        /*  MERGE-PATHNAME-DIRECTORY-COMPONENTS */
  si_Xmake_special(VV[511]);
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[511],T0);
  L4258undefine_function(VV[512]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[99]) /*  MAPC */;
  ecl_cmp_defun(VV[2838]);                        /*  MAKE-PATHNAME*          */
  L4258undefine_function(VV[514]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[100]) /*  MAPC */;
  ecl_cmp_defun(VV[2839]);                        /*  MAKE-PATHNAME-COMPONENT-LOGICAL */
  L4258undefine_function(VV[517]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[101]) /*  MAPC */;
  ecl_cmp_defun(VV[2840]);                        /*  MAKE-PATHNAME-LOGICAL   */
  L4258undefine_function(VV[519]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[102]) /*  MAPC */;
  ecl_cmp_defun(VV[2841]);                        /*  MERGE-PATHNAMES*        */
  L4258undefine_function(VV[525]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[103]) /*  MAPC */;
  ecl_cmp_defun(VV[2842]);                        /*  LOGICAL-PATHNAME-P      */
  L4258undefine_function(VV[527]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[104]) /*  MAPC */;
  ecl_cmp_defun(VV[2843]);                        /*  PHYSICAL-PATHNAME-P     */
  L4258undefine_function(VV[529]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[105]) /*  MAPC */;
  ecl_cmp_defun(VV[2844]);                        /*  PHYSICALIZE-PATHNAME    */
  L4258undefine_function(VV[531]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[106]) /*  MAPC */;
  ecl_cmp_defun(VV[2845]);                        /*  NIL-PATHNAME            */
  si_Xmake_special(VV[533]);
  if (ecl_boundp(cl_env_copy,VV[533])) {
   goto L827;
  }
  T0 = cl_user_homedir_pathname(0);
  T1 = (cl_env_copy->function=ecl_fdefinition(VV[529]))->cfun.entry(1, T0) /*  PHYSICALIZE-PATHNAME */;
  T2 = (cl_env_copy->function=ecl_fdefinition(VV[531]))->cfun.entry(1, T1) /*  NIL-PATHNAME */;
  ecl_cmp_setq(cl_env_copy,VV[533],T2);
L827:;
  ecl_cmp_defmacro(VV[2846]);                     /*  WITH-PATHNAME-DEFAULTS  */
  L4258undefine_function(VV[536]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[107]) /*  MAPC */;
  ecl_cmp_defun(VV[2847]);                        /*  PATHNAME-EQUAL          */
  L4258undefine_function(VV[544]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[108]) /*  MAPC */;
  ecl_cmp_defun(VV[2848]);                        /*  ABSOLUTE-PATHNAME-P     */
  L4258undefine_function(VV[546]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[109]) /*  MAPC */;
  ecl_cmp_defun(VV[2849]);                        /*  RELATIVE-PATHNAME-P     */
  L4258undefine_function(VV[548]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[110]) /*  MAPC */;
  ecl_cmp_defun(VV[2850]);                        /*  HIDDEN-PATHNAME-P       */
  L4258undefine_function(VV[550]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[111]) /*  MAPC */;
  ecl_cmp_defun(VV[2851]);                        /*  FILE-PATHNAME-P         */
  L4258undefine_function(VV[555]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[112]) /*  MAPC */;
  ecl_cmp_defun(VV[2852]);                        /*  PATHNAME-DIRECTORY-PATHNAME */
  L4258undefine_function(VV[557]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[113]) /*  MAPC */;
  ecl_cmp_defun(VV[2853]);                        /*  PATHNAME-PARENT-DIRECTORY-PATHNAME */
  L4258undefine_function(VV[560]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[114]) /*  MAPC */;
  ecl_cmp_defun(VV[2854]);                        /*  DIRECTORY-PATHNAME-P    */
  L4258undefine_function(VV[565]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[115]) /*  MAPC */;
  ecl_cmp_defun(VV[2855]);                        /*  ENSURE-DIRECTORY-PATHNAME */
  L4258undefine_function(VV[572]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[116]) /*  MAPC */;
  ecl_cmp_defun(VV[2856]);                        /*  SPLIT-UNIX-NAMESTRING-DIRECTORY-COMPONENTS */
  L4258undefine_function(VV[585]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[117]) /*  MAPC */;
  ecl_cmp_defun(VV[2857]);                        /*  SPLIT-NAME-TYPE         */
  L4258undefine_function(VV[590]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[118]) /*  MAPC */;
  ecl_cmp_defun(VV[2858]);                        /*  PARSE-UNIX-NAMESTRING   */
  L4258undefine_function(VV[573]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[119]) /*  MAPC */;
  ecl_cmp_defun(VV[2859]);                        /*  UNIX-NAMESTRING         */
  L4258undefine_function(VV[608]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[120]) /*  MAPC */;
  ecl_cmp_defun(VV[2860]);                        /*  SUBPATHNAME             */
  L4258undefine_function(VV[611]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[121]) /*  MAPC */;
  ecl_cmp_defun(VV[2861]);                        /*  SUBPATHNAME*            */
  L4258undefine_function(VV[613]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[122]) /*  MAPC */;
  ecl_cmp_defun(VV[2862]);                        /*  PATHNAME-ROOT           */
  L4258undefine_function(VV[615]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[123]) /*  MAPC */;
  ecl_cmp_defun(VV[2863]);                        /*  PATHNAME-HOST-PATHNAME  */
  L4258undefine_function(VV[617]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[124]) /*  MAPC */;
  ecl_cmp_defun(VV[2864]);                        /*  ENSURE-ABSOLUTE-PATHNAME */
  L4258undefine_function(VV[623]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[125]) /*  MAPC */;
  ecl_cmp_defun(VV[2865]);                        /*  SUBPATHP                */
  L4258undefine_function(VV[625]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[126]) /*  MAPC */;
  ecl_cmp_defun(VV[2866]);                        /*  ENOUGH-PATHNAME         */
  L4258undefine_function(VV[627]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[127]) /*  MAPC */;
  ecl_cmp_defun(VV[2867]);                        /*  CALL-WITH-ENOUGH-PATHNAME */
  ecl_cmp_defmacro(VV[2868]);                     /*  WITH-ENOUGH-PATHNAME    */
  si_Xmake_special(VV[632]);
  T0 = ECL_SYM("WILD",1365);
  ecl_cmp_setq(cl_env_copy,VV[632],T0);
  si_Xmake_special(VV[633]);
  T0 = ECL_SYM("WILD",1365);
  ecl_cmp_setq(cl_env_copy,VV[633],T0);
  si_Xmake_special(VV[634]);
  T0 = ECL_SYM("WILD-INFERIORS",1366);
  ecl_cmp_setq(cl_env_copy,VV[634],T0);
  si_Xmake_special(VV[635]);
  T0 = cl_make_pathname(8, ECL_SYM("DIRECTORY",1250), ECL_NIL, ECL_SYM("NAME",1309), ecl_cmp_symbol_value(cl_env_copy,VV[632]), ECL_SYM("TYPE",1356), ecl_cmp_symbol_value(cl_env_copy,VV[632]), ECL_SYM("VERSION",1364), ecl_cmp_symbol_value(cl_env_copy,VV[632]));
  ecl_cmp_setq(cl_env_copy,VV[635],T0);
  si_Xmake_special(VV[636]);
  T0 = cl_make_pathname(8, ECL_SYM("DIRECTORY",1250), ECL_NIL, ECL_SYM("NAME",1309), ecl_cmp_symbol_value(cl_env_copy,VV[632]), ECL_SYM("TYPE",1356), ecl_cmp_symbol_value(cl_env_copy,VV[632]), ECL_SYM("VERSION",1364), ecl_cmp_symbol_value(cl_env_copy,VV[632]));
  ecl_cmp_setq(cl_env_copy,VV[636],T0);
  si_Xmake_special(VV[637]);
  T0 = cl_list(2, ECL_SYM("RELATIVE",1336), ecl_cmp_symbol_value(cl_env_copy,VV[633]));
  T1 = cl_make_pathname(8, ECL_SYM("DIRECTORY",1250), T0, ECL_SYM("NAME",1309), ECL_NIL, ECL_SYM("TYPE",1356), ECL_NIL, ECL_SYM("VERSION",1364), ECL_NIL);
  ecl_cmp_setq(cl_env_copy,VV[637],T1);
  si_Xmake_special(VV[638]);
  T0 = cl_list(2, ECL_SYM("RELATIVE",1336), ecl_cmp_symbol_value(cl_env_copy,VV[634]));
  T1 = cl_make_pathname(8, ECL_SYM("DIRECTORY",1250), T0, ECL_SYM("NAME",1309), ECL_NIL, ECL_SYM("TYPE",1356), ECL_NIL, ECL_SYM("VERSION",1364), ECL_NIL);
  ecl_cmp_setq(cl_env_copy,VV[638],T1);
  si_Xmake_special(VV[639]);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[519]))->cfun.entry(2, ecl_cmp_symbol_value(cl_env_copy,VV[635]), ecl_cmp_symbol_value(cl_env_copy,VV[638])) /*  MERGE-PATHNAMES* */;
  ecl_cmp_setq(cl_env_copy,VV[639],T0);
  L4258undefine_function(VV[640]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[128]) /*  MAPC */;
  ecl_cmp_defun(VV[2869]);                        /*  WILDEN                  */
  L4258undefine_function(VV[642]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[129]) /*  MAPC */;
  ecl_cmp_defun(VV[2870]);                        /*  RELATIVIZE-DIRECTORY-COMPONENT */
  L4258undefine_function(VV[644]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[130]) /*  MAPC */;
  ecl_cmp_defun(VV[2871]);                        /*  RELATIVIZE-PATHNAME-DIRECTORY */
  L4258undefine_function(VV[646]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[131]) /*  MAPC */;
  ecl_cmp_defun(VV[2872]);                        /*  DIRECTORY-SEPARATOR-FOR-HOST */
  L4258undefine_function(VV[649]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[132]) /*  MAPC */;
  ecl_cmp_defun(VV[2873]);                        /*  DIRECTORIZE-PATHNAME-HOST-DEVICE */
  L4258undefine_function(VV[652]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[133]) /*  MAPC */;
  ecl_cmp_defun(VV[2874]);                        /*  TRANSLATE-PATHNAME*     */
  si_Xmake_special(VV[655]);
  if (ecl_boundp(cl_env_copy,VV[655])) {
   goto L1048;
  }
  T0 = ECL_SYM("IDENTITY",428);
  ecl_cmp_setq(cl_env_copy,VV[655],T0);
L1048:;
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_6, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[134]);
  si_select_package(_ecl_static_6);
  L4258undefine_function(VV[656]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[135]) /*  MAPC */;
  ecl_cmp_defun(VV[2875]);                        /*  NATIVE-NAMESTRING       */
  L4258undefine_function(VV[658]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[136]) /*  MAPC */;
  ecl_cmp_defun(VV[2876]);                        /*  PARSE-NATIVE-NAMESTRING */
  L4258undefine_function(VV[661]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[137]) /*  MAPC */;
  ecl_cmp_defun(VV[2877]);                        /*  TRUENAME*               */
  L4258undefine_function(VV[665]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[138]) /*  MAPC */;
  ecl_cmp_defun(VV[2878]);                        /*  SAFE-FILE-WRITE-DATE    */
  L4258undefine_function(VV[669]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[139]) /*  MAPC */;
  ecl_cmp_defun(VV[2879]);                        /*  PROBE-FILE*             */
  L4258undefine_function(VV[680]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[140]) /*  MAPC */;
  ecl_cmp_defun(VV[2880]);                        /*  DIRECTORY-EXISTS-P      */
  L4258undefine_function(VV[683]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[141]) /*  MAPC */;
  ecl_cmp_defun(VV[2881]);                        /*  FILE-EXISTS-P           */
  L4258undefine_function(VV[685]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[142]) /*  MAPC */;
  ecl_cmp_defun(VV[2882]);                        /*  DIRECTORY*              */
  L4258undefine_function(VV[687]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[143]) /*  MAPC */;
  ecl_cmp_defun(VV[2883]);                        /*  FILTER-LOGICAL-DIRECTORY-RESULTS */
  L4258undefine_function(VV[691]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[144]) /*  MAPC */;
  ecl_cmp_defun(VV[2884]);                        /*  DIRECTORY-FILES         */
  L4258undefine_function(VV[699]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[145]) /*  MAPC */;
  ecl_cmp_defun(VV[2885]);                        /*  SUBDIRECTORIES          */
  L4258undefine_function(VV[704]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[146]) /*  MAPC */;
  ecl_cmp_defun(VV[2886]);                        /*  COLLECT-SUB*DIRECTORIES */
  L4258undefine_function(VV[706]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[147]) /*  MAPC */;
  ecl_cmp_defun(VV[2887]);                        /*  TRUENAMIZE              */
  L4258undefine_function(VV[713]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[148]) /*  MAPC */;
  ecl_cmp_defun(VV[2888]);                        /*  RESOLVE-SYMLINKS        */
  si_Xmake_special(VV[715]);
  if (ecl_boundp(cl_env_copy,VV[715])) {
   goto L1142;
  }
  T0 = ECL_T;
  ecl_cmp_setq(cl_env_copy,VV[715],T0);
L1142:;
  L4258undefine_function(VV[716]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[149]) /*  MAPC */;
  ecl_cmp_defun(VV[2889]);                        /*  RESOLVE-SYMLINKS*       */
  L4258undefine_function(VV[596]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[150]) /*  MAPC */;
  ecl_cmp_defun(VV[2890]);                        /*  ENSURE-PATHNAME         */
  L4258undefine_function(VV[676]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[151]) /*  MAPC */;
  ecl_cmp_defun(VV[2891]);                        /*  GET-PATHNAME-DEFAULTS   */
  L4258undefine_function(VV[756]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[152]) /*  MAPC */;
  ecl_cmp_defun(VV[2892]);                        /*  CALL-WITH-CURRENT-DIRECTORY */
  ecl_cmp_defmacro(VV[2893]);                     /*  WITH-CURRENT-DIRECTORY  */
  L4258undefine_function(VV[760]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[153]) /*  MAPC */;
  ecl_cmp_defun(VV[2894]);                        /*  INTER-DIRECTORY-SEPARATOR */
  L4258undefine_function(VV[762]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[154]) /*  MAPC */;
  ecl_cmp_defun(VV[2895]);                        /*  SPLIT-NATIVE-PATHNAMES-STRING */
  L4258undefine_function(VV[764]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[155]) /*  MAPC */;
  ecl_cmp_defun(VV[2896]);                        /*  GETENV-PATHNAME         */
  L4258undefine_function(VV[767]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[156]) /*  MAPC */;
  ecl_cmp_defun(VV[2897]);                        /*  GETENV-PATHNAMES        */
  L4258undefine_function(VV[771]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[157]) /*  MAPC */;
  ecl_cmp_defun(VV[2898]);                        /*  GETENV-ABSOLUTE-DIRECTORY */
  L4258undefine_function(VV[773]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[158]) /*  MAPC */;
  ecl_cmp_defun(VV[2899]);                        /*  GETENV-ABSOLUTE-DIRECTORIES */
  L4258undefine_function(VV[775]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[159]) /*  MAPC */;
  ecl_cmp_defun(VV[2900]);                        /*  LISP-IMPLEMENTATION-DIRECTORY */
  L4258undefine_function(VV[778]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[160]) /*  MAPC */;
  ecl_cmp_defun(VV[2901]);                        /*  LISP-IMPLEMENTATION-PATHNAME-P */
  L4258undefine_function(VV[780]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[161]) /*  MAPC */;
  ecl_cmp_defun(VV[2902]);                        /*  ENSURE-ALL-DIRECTORIES-EXIST */
  L4258undefine_function(VV[782]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[162]) /*  MAPC */;
  ecl_cmp_defun(VV[2903]);                        /*  DELETE-FILE-IF-EXISTS   */
  L4258undefine_function(VV[786]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[163]) /*  MAPC */;
  ecl_cmp_defun(VV[2904]);                        /*  RENAME-FILE-OVERWRITING-TARGET */
  L4258undefine_function(VV[788]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[164]) /*  MAPC */;
  ecl_cmp_defun(VV[2905]);                        /*  DELETE-EMPTY-DIRECTORY  */
  L4258undefine_function(VV[790]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[165]) /*  MAPC */;
  ecl_cmp_defun(VV[2906]);                        /*  DELETE-DIRECTORY-TREE   */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_7, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[166]);
  si_select_package(_ecl_static_7);
  si_Xmake_special(VV[804]);
  if (ecl_boundp(cl_env_copy,VV[804])) {
   goto L1256;
  }
  T0 = ECL_SYM("DEFAULT",1246);
  ecl_cmp_setq(cl_env_copy,VV[804],T0);
L1256:;
  si_Xmake_special(VV[805]);
  if (ecl_boundp(cl_env_copy,VV[805])) {
   goto L1263;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-INPUT*",68));
  ecl_cmp_setq(cl_env_copy,VV[805],T0);
L1263:;
  L4258undefine_function(VV[806]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[167]) /*  MAPC */;
  ecl_cmp_defun(VV[2907]);                        /*  SETUP-STDIN             */
  si_Xmake_special(VV[808]);
  if (ecl_boundp(cl_env_copy,VV[808])) {
   goto L1276;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69));
  ecl_cmp_setq(cl_env_copy,VV[808],T0);
L1276:;
  L4258undefine_function(VV[809]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[168]) /*  MAPC */;
  ecl_cmp_defun(VV[2908]);                        /*  SETUP-STDOUT            */
  si_Xmake_special(VV[811]);
  if (ecl_boundp(cl_env_copy,VV[811])) {
   goto L1289;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*ERROR-OUTPUT*",35));
  ecl_cmp_setq(cl_env_copy,VV[811],T0);
L1289:;
  L4258undefine_function(VV[812]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[169]) /*  MAPC */;
  ecl_cmp_defun(VV[2909]);                        /*  SETUP-STDERR            */
  (cl_env_copy->function=ecl_fdefinition(VV[806]))->cfun.entry(0) /*  SETUP-STDIN */;
  (cl_env_copy->function=ecl_fdefinition(VV[809]))->cfun.entry(0) /*  SETUP-STDOUT */;
  (cl_env_copy->function=ecl_fdefinition(VV[812]))->cfun.entry(0) /*  SETUP-STDERR */;
  si_Xmake_special(VV[814]);
  {
   cl_object v1uiop_stream__previous;
   if (!(ecl_boundp(cl_env_copy,VV[814]))){
    goto L1312;
   }
   v1uiop_stream__previous = cl_symbol_value(VV[814]);
   goto L1310;
L1312:;
   v1uiop_stream__previous = ECL_NIL;
   goto L1310;
L1310:;
   if (Null(v1uiop_stream__previous)){
    goto L1314;
   }
   if ((v1uiop_stream__previous)==(ECL_SYM("DEFAULT",1246))) {
    goto L1316;
   }
   value0 = v1uiop_stream__previous;
   goto L1309;
L1316:;
   value0 = ECL_NIL;
   goto L1309;
L1314:;
   value0 = ECL_NIL;
  }
L1309:;
  if (value0!=ECL_NIL) {
   goto L1308;
  }
  T0 = ECL_SYM("UTF-8",1759);
  ecl_cmp_setq(cl_env_copy,VV[814],T0);
  goto L1306;
L1308:;
  T0 = value0;
  ecl_cmp_setq(cl_env_copy,VV[814],T0);
  goto L1306;
L1306:;
  si_Xmake_special(VV[815]);
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[420]))->cfun.entry(1, VV[195]) /*  FEATUREP */)){
   goto L1324;
  }
  T0 = ECL_SYM("UTF-8",1759);
  ecl_cmp_setq(cl_env_copy,VV[815],T0);
  goto L1323;
L1324:;
  T0 = ECL_SYM("DEFAULT",1246);
  ecl_cmp_setq(cl_env_copy,VV[815],T0);
L1323:;
  L4258undefine_function(VV[816]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[170]) /*  MAPC */;
  ecl_cmp_defun(VV[2910]);                        /*  ALWAYS-DEFAULT-ENCODING */
  si_Xmake_special(VV[818]);
  if (ecl_boundp(cl_env_copy,VV[818])) {
   goto L1336;
  }
  T0 = ecl_fdefinition(VV[816]);
  ecl_cmp_setq(cl_env_copy,VV[818],T0);
L1336:;
  L4258undefine_function(VV[819]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[171]) /*  MAPC */;
  ecl_cmp_defun(VV[2911]);                        /*  DETECT-ENCODING         */
  L4258undefine_function(VV[821]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[172]) /*  MAPC */;
  ecl_cmp_defun(VV[2912]);                        /*  DEFAULT-ENCODING-EXTERNAL-FORMAT */
  si_Xmake_special(VV[825]);
  if (ecl_boundp(cl_env_copy,VV[825])) {
   goto L1355;
  }
  T0 = ecl_fdefinition(VV[821]);
  ecl_cmp_setq(cl_env_copy,VV[825],T0);
L1355:;
  L4258undefine_function(VV[826]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[173]) /*  MAPC */;
  ecl_cmp_defun(VV[2913]);                        /*  ENCODING-EXTERNAL-FORMAT */
  si_Xmake_special(VV[828]);
  if (ecl_boundp(cl_env_copy,VV[828])) {
   goto L1368;
  }
  {
   cl_object v1;
   v1 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("+IO-SYNTAX-PROGV-LIST+",1805));
   {
    cl_object v3, v4; cl_index v2;
    v3 = ECL_CONS_CAR(v1);
    v4 = ECL_CONS_CDR(v1);
    v2 = ecl_progv(cl_env_copy, v3, v4);
    T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*READTABLE*",67));
    ecl_bds_unwind(cl_env_copy,v2);
    ecl_cmp_setq(cl_env_copy,VV[828],T0);
   }
  }
L1368:;
  ecl_cmp_defmacro(VV[2914]);                     /*  WITH-SAFE-IO-SYNTAX     */
  L4258undefine_function(VV[831]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[174]) /*  MAPC */;
  ecl_cmp_defun(VV[2915]);                        /*  CALL-WITH-SAFE-IO-SYNTAX */
  L4258undefine_function(VV[834]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[175]) /*  MAPC */;
  ecl_cmp_defun(VV[2916]);                        /*  SAFE-READ-FROM-STRING   */
  L4258undefine_function(VV[838]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[176]) /*  MAPC */;
  ecl_cmp_defun(VV[2917]);                        /*  CALL-WITH-OUTPUT-FILE   */
  ecl_cmp_defmacro(VV[2918]);                     /*  WITH-OUTPUT-FILE        */
  L4258undefine_function(VV[843]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[177]) /*  MAPC */;
  ecl_cmp_defun(VV[2919]);                        /*  CALL-WITH-OUTPUT        */
  ecl_cmp_defmacro(VV[2920]);                     /*  WITH-OUTPUT             */
  L4258undefine_function(VV[849]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[178]) /*  MAPC */;
  ecl_cmp_defun(VV[2921]);                        /*  OUTPUT-STRING           */
  L4258undefine_function(VV[852]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[179]) /*  MAPC */;
  ecl_cmp_defun(VV[2922]);                        /*  CALL-WITH-INPUT-FILE    */
  ecl_cmp_defmacro(VV[2923]);                     /*  WITH-INPUT-FILE         */
  L4258undefine_function(VV[857]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[180]) /*  MAPC */;
  ecl_cmp_defun(VV[2924]);                        /*  CALL-WITH-INPUT         */
  ecl_cmp_defmacro(VV[2925]);                     /*  WITH-INPUT              */
  L4258undefine_function(VV[861]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[181]) /*  MAPC */;
  ecl_cmp_defun(VV[2926]);                        /*  INPUT-STRING            */
  L4258undefine_function(VV[865]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[182]) /*  MAPC */;
  ecl_cmp_defun(VV[2927]);                        /*  NULL-DEVICE-PATHNAME    */
  L4258undefine_function(VV[868]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[183]) /*  MAPC */;
  ecl_cmp_defun(VV[2928]);                        /*  CALL-WITH-NULL-INPUT    */
  ecl_cmp_defmacro(VV[2929]);                     /*  WITH-NULL-INPUT         */
  L4258undefine_function(VV[872]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[184]) /*  MAPC */;
  ecl_cmp_defun(VV[2930]);                        /*  CALL-WITH-NULL-OUTPUT   */
  ecl_cmp_defmacro(VV[2931]);                     /*  WITH-NULL-OUTPUT        */
  L4258undefine_function(VV[877]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[185]) /*  MAPC */;
  ecl_cmp_defun(VV[2932]);                        /*  FINISH-OUTPUTS          */
  L4258undefine_function(VV[881]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[186]) /*  MAPC */;
  ecl_cmp_defun(VV[2933]);                        /*  FORMAT!                 */
  L4258undefine_function(VV[883]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[187]) /*  MAPC */;
  ecl_cmp_defun(VV[2934]);                        /*  SAFE-FORMAT!            */
  L4258undefine_function(VV[888]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[188]) /*  MAPC */;
  ecl_cmp_defun(VV[2935]);                        /*  COPY-STREAM-TO-STREAM   */
  L4258undefine_function(VV[890]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[189]) /*  MAPC */;
  ecl_cmp_defun(VV[2936]);                        /*  CONCATENATE-FILES       */
  L4258undefine_function(VV[892]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[190]) /*  MAPC */;
  ecl_cmp_defun(VV[2937]);                        /*  COPY-FILE               */
  L4258undefine_function(VV[863]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[191]) /*  MAPC */;
  ecl_cmp_defun(VV[2938]);                        /*  SLURP-STREAM-STRING     */
  L4258undefine_function(VV[895]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[192]) /*  MAPC */;
  ecl_cmp_defun(VV[2939]);                        /*  SLURP-STREAM-LINES      */
  L4258undefine_function(VV[898]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[193]) /*  MAPC */;
  ecl_cmp_defun(VV[2940]);                        /*  SLURP-STREAM-LINE       */
  L4258undefine_function(VV[900]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[194]) /*  MAPC */;
  ecl_cmp_defun(VV[2941]);                        /*  SLURP-STREAM-FORMS      */
  L4258undefine_function(VV[903]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[195]) /*  MAPC */;
  ecl_cmp_defun(VV[2942]);                        /*  SLURP-STREAM-FORM       */
  L4258undefine_function(VV[905]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[196]) /*  MAPC */;
  ecl_cmp_defun(VV[2943]);                        /*  READ-FILE-STRING        */
  L4258undefine_function(VV[907]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[197]) /*  MAPC */;
  ecl_cmp_defun(VV[2944]);                        /*  READ-FILE-LINES         */
  L4258undefine_function(VV[909]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[198]) /*  MAPC */;
  ecl_cmp_defun(VV[2945]);                        /*  READ-FILE-LINE          */
  L4258undefine_function(VV[913]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[199]) /*  MAPC */;
  ecl_cmp_defun(VV[2946]);                        /*  READ-FILE-FORMS         */
  L4258undefine_function(VV[916]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[200]) /*  MAPC */;
  ecl_cmp_defun(VV[2947]);                        /*  READ-FILE-FORM          */
  L4258undefine_function(VV[919]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[201]) /*  MAPC */;
  ecl_cmp_defun(VV[2948]);                        /*  SAFE-READ-FILE-LINE     */
  L4258undefine_function(VV[922]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[202]) /*  MAPC */;
  ecl_cmp_defun(VV[2949]);                        /*  SAFE-READ-FILE-FORM     */
  L4258undefine_function(VV[925]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[203]) /*  MAPC */;
  ecl_cmp_defun(VV[2950]);                        /*  EVAL-INPUT              */
  L4258undefine_function(VV[929]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[204]) /*  MAPC */;
  ecl_cmp_defun(VV[2951]);                        /*  EVAL-THUNK              */
  L4258undefine_function(VV[932]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[205]) /*  MAPC */;
  ecl_cmp_defun(VV[2952]);                        /*  STANDARD-EVAL-THUNK     */
  L4258undefine_function(VV[935]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[206]) /*  MAPC */;
  ecl_cmp_defun(VV[2953]);                        /*  PRINTLN                 */
  L4258undefine_function(VV[937]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[207]) /*  MAPC */;
  ecl_cmp_defun(VV[2954]);                        /*  WRITELN                 */
  L4258undefine_function(VV[939]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[208]) /*  MAPC */;
  ecl_cmp_defun(VV[2955]);                        /*  DEFAULT-TEMPORARY-DIRECTORY */
  si_Xmake_special(VV[943]);
  if (ecl_boundp(cl_env_copy,VV[943])) {
   goto L1602;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[943],T0);
L1602:;
  L4258undefine_function(VV[944]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[209]) /*  MAPC */;
  ecl_cmp_defun(VV[2956]);                        /*  TEMPORARY-DIRECTORY     */
  L4258undefine_function(VV[946]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[210]) /*  MAPC */;
  ecl_cmp_defun(VV[2957]);                        /*  SETUP-TEMPORARY-DIRECTORY */
  L4258undefine_function(VV[948]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[211]) /*  MAPC */;
  ecl_cmp_defun(VV[2958]);                        /*  CALL-WITH-TEMPORARY-FILE */
  ecl_cmp_defmacro(VV[2959]);                     /*  WITH-TEMPORARY-FILE     */
  L4258undefine_function(VV[974]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[212]) /*  MAPC */;
  ecl_cmp_defun(VV[2960]);                        /*  GET-TEMPORARY-FILE      */
  L4258undefine_function(VV[977]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[213]) /*  MAPC */;
  ecl_cmp_defun(VV[2961]);                        /*  ADD-PATHNAME-SUFFIX     */
  L4258undefine_function(VV[979]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[214]) /*  MAPC */;
  ecl_cmp_defun(VV[2962]);                        /*  TMPIZE-PATHNAME         */
  L4258undefine_function(VV[981]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[215]) /*  MAPC */;
  ecl_cmp_defun(VV[2963]);                        /*  CALL-WITH-STAGING-PATHNAME */
  ecl_cmp_defmacro(VV[2964]);                     /*  WITH-STAGING-PATHNAME   */
  L4258undefine_function(VV[985]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[216]) /*  MAPC */;
  ecl_cmp_defun(VV[2965]);                        /*  FILE-STREAM-P           */
  L4258undefine_function(VV[987]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[217]) /*  MAPC */;
  ecl_cmp_defun(VV[2966]);                        /*  FILE-OR-SYNONYM-STREAM-P */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_8, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[218]);
  si_select_package(_ecl_static_8);
  si_Xmake_special(VV[989]);
  if (ecl_boundp(cl_env_copy,VV[989])) {
   goto L1670;
  }
  T0 = ECL_T;
  ecl_cmp_setq(cl_env_copy,VV[989],T0);
L1670:;
  si_Xmake_special(VV[990]);
  if (ecl_boundp(cl_env_copy,VV[990])) {
   goto L1677;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[990],T0);
L1677:;
  si_Xmake_special(VV[991]);
  if (ecl_boundp(cl_env_copy,VV[991])) {
   goto L1684;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[991],T0);
L1684:;
  si_Xmake_special(VV[992]);
  if (ecl_boundp(cl_env_copy,VV[992])) {
   goto L1691;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[992],T0);
L1691:;
  si_Xmake_special(VV[993]);
  if (ecl_boundp(cl_env_copy,VV[993])) {
   goto L1698;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[993],T0);
L1698:;
  si_Xmake_special(VV[994]);
  if (ecl_boundp(cl_env_copy,VV[994])) {
   goto L1705;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[994],T0);
L1705:;
  si_Xmake_special(VV[995]);
  if (ecl_boundp(cl_env_copy,VV[995])) {
   goto L1712;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[995],T0);
L1712:;
  si_Xmake_special(VV[996]);
  if (ecl_boundp(cl_env_copy,VV[996])) {
   goto L1719;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[996],T0);
L1719:;
  si_Xmake_special(VV[997]);
  if (ecl_boundp(cl_env_copy,VV[997])) {
   goto L1726;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[997],T0);
L1726:;
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4536__lambda3088_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_deftype(3, VV[998], VVtemp[219], T0);
  L4258undefine_function(VV[1001]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[220]) /*  MAPC */;
  ecl_cmp_defun(VV[2967]);                        /*  QUIT                    */
  L4258undefine_function(VV[1003]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[221]) /*  MAPC */;
  ecl_cmp_defun(VV[2968]);                        /*  DIE                     */
  L4258undefine_function(VV[1009]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[222]) /*  MAPC */;
  ecl_cmp_defun(VV[2969]);                        /*  RAW-PRINT-BACKTRACE     */
  L4258undefine_function(VV[1012]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[223]) /*  MAPC */;
  ecl_cmp_defun(VV[2970]);                        /*  PRINT-BACKTRACE         */
  L4258undefine_function(VV[1017]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[224]) /*  MAPC */;
  ecl_cmp_defun(VV[2971]);                        /*  PRINT-CONDITION-BACKTRACE */
  L4258undefine_function(VV[1021]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[225]) /*  MAPC */;
  ecl_cmp_defun(VV[2972]);                        /*  FATAL-CONDITION-P       */
  L4258undefine_function(VV[1023]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[226]) /*  MAPC */;
  ecl_cmp_defun(VV[2973]);                        /*  HANDLE-FATAL-CONDITION  */
  L4258undefine_function(VV[1027]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[227]) /*  MAPC */;
  ecl_cmp_defun(VV[2974]);                        /*  CALL-WITH-FATAL-CONDITION-HANDLER */
  ecl_cmp_defmacro(VV[2975]);                     /*  WITH-FATAL-CONDITION-HANDLER */
  L4258undefine_function(VV[1031]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[228]) /*  MAPC */;
  ecl_cmp_defun(VV[2976]);                        /*  SHELL-BOOLEAN-EXIT      */
  L4258undefine_function(VV[1033]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[229]) /*  MAPC */;
  ecl_cmp_defun(VV[2977]);                        /*  REGISTER-IMAGE-RESTORE-HOOK */
  L4258undefine_function(VV[1035]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[230]) /*  MAPC */;
  ecl_cmp_defun(VV[2978]);                        /*  REGISTER-IMAGE-DUMP-HOOK */
  L4258undefine_function(VV[1037]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[231]) /*  MAPC */;
  ecl_cmp_defun(VV[2979]);                        /*  CALL-IMAGE-RESTORE-HOOK */
  L4258undefine_function(VV[1039]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[232]) /*  MAPC */;
  ecl_cmp_defun(VV[2980]);                        /*  CALL-IMAGE-DUMP-HOOK    */
  L4258undefine_function(VV[1041]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[233]) /*  MAPC */;
  ecl_cmp_defun(VV[2981]);                        /*  RAW-COMMAND-LINE-ARGUMENTS */
  L4258undefine_function(VV[1043]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[234]) /*  MAPC */;
  ecl_cmp_defun(VV[2982]);                        /*  COMMAND-LINE-ARGUMENTS  */
  L4258undefine_function(VV[1048]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[235]) /*  MAPC */;
  ecl_cmp_defun(VV[2983]);                        /*  ARGV0                   */
  L4258undefine_function(VV[1051]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[236]) /*  MAPC */;
  ecl_cmp_defun(VV[2984]);                        /*  SETUP-COMMAND-LINE-ARGUMENTS */
  L4258undefine_function(VV[1053]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[237]) /*  MAPC */;
  ecl_cmp_defun(VV[2985]);                        /*  RESTORE-IMAGE           */
  L4258undefine_function(VV[1059]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[238]) /*  MAPC */;
  ecl_cmp_defun(VV[2986]);                        /*  DUMP-IMAGE              */
  L4258undefine_function(VV[1064]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[239]) /*  MAPC */;
  ecl_cmp_defun(VV[2987]);                        /*  CREATE-IMAGE            */
  cl_map(3, ECL_NIL, VV[1033], VVtemp[240]);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_9, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[241]);
  si_select_package(_ecl_static_9);
  L4258undefine_function(VV[1080]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[242]) /*  MAPC */;
  ecl_cmp_defun(VV[2988]);                        /*  REQUIRES-ESCAPING-P     */
  L4258undefine_function(VV[1086]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[243]) /*  MAPC */;
  ecl_cmp_defun(VV[2989]);                        /*  ESCAPE-TOKEN            */
  L4258undefine_function(VV[1092]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[244]) /*  MAPC */;
  ecl_cmp_defun(VV[2990]);                        /*  ESCAPE-WINDOWS-TOKEN-WITHIN-DOUBLE-QUOTES */
  L4258undefine_function(VV[1099]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[245]) /*  MAPC */;
  ecl_cmp_defun(VV[2991]);                        /*  EASY-WINDOWS-CHARACTER-P */
  L4258undefine_function(VV[1102]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[246]) /*  MAPC */;
  ecl_cmp_defun(VV[2992]);                        /*  ESCAPE-WINDOWS-TOKEN    */
  L4258undefine_function(VV[1105]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[247]) /*  MAPC */;
  ecl_cmp_defun(VV[2993]);                        /*  ESCAPE-SH-TOKEN-WITHIN-DOUBLE-QUOTES */
  L4258undefine_function(VV[1108]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[248]) /*  MAPC */;
  ecl_cmp_defun(VV[2994]);                        /*  EASY-SH-CHARACTER-P     */
  L4258undefine_function(VV[1111]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[249]) /*  MAPC */;
  ecl_cmp_defun(VV[2995]);                        /*  ESCAPE-SH-TOKEN         */
  L4258undefine_function(VV[1113]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[250]) /*  MAPC */;
  ecl_cmp_defun(VV[2996]);                        /*  ESCAPE-SHELL-TOKEN      */
  L4258undefine_function(VV[1115]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[251]) /*  MAPC */;
  ecl_cmp_defun(VV[2997]);                        /*  ESCAPE-COMMAND          */
  L4258undefine_function(VV[1119]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[252]) /*  MAPC */;
  ecl_cmp_defun(VV[2998]);                        /*  ESCAPE-WINDOWS-COMMAND  */
  L4258undefine_function(VV[1121]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[253]) /*  MAPC */;
  ecl_cmp_defun(VV[2999]);                        /*  ESCAPE-SH-COMMAND       */
  L4258undefine_function(VV[1123]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[254]) /*  MAPC */;
  ecl_cmp_defun(VV[3000]);                        /*  ESCAPE-SHELL-COMMAND    */
  L4258undefine_function(VV[1125]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[255]) /*  MAPC */;
  ecl_cmp_defun(VV[3001]);                        /*  CALL-STREAM-PROCESSOR   */
  L4258undefine_function(VV[1127]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[256]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1127], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[257], ECL_SYM("DOCUMENTATION",1253), VVtemp[258]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4584slurp_input_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, VVtemp[259], VVtemp[260], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4585slurp_input_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, VVtemp[261], VVtemp[262], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4586slurp_input_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, VVtemp[263], VVtemp[264], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4587slurp_input_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, VVtemp[265], VVtemp[266], T0);
  T0 = cl_list(2, ECL_SYM("EQL",336), VV[1133]);
  T1 = cl_list(2, T0, ECL_T);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4588slurp_input_stream,ECL_NIL,Cblock,2);
   T2 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, T1, VVtemp[266], T2);
  T0 = cl_list(2, ECL_SYM("EQL",336), ECL_SYM("LINES",1300));
  T1 = cl_list(2, T0, ECL_T);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4589slurp_input_stream,ECL_NIL,Cblock,2);
   T2 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, T1, VVtemp[267], T2);
  T0 = cl_list(2, ECL_SYM("EQL",336), ECL_SYM("LINE",1677));
  T1 = cl_list(2, T0, ECL_T);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4590slurp_input_stream,ECL_NIL,Cblock,2);
   T2 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, T1, VVtemp[268], T2);
  T0 = cl_list(2, ECL_SYM("EQL",336), VV[1134]);
  T1 = cl_list(2, T0, ECL_T);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4591slurp_input_stream,ECL_NIL,Cblock,2);
   T2 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, T1, VVtemp[267], T2);
  T0 = cl_list(2, ECL_SYM("EQL",336), VV[1135]);
  T1 = cl_list(2, T0, ECL_T);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4592slurp_input_stream,ECL_NIL,Cblock,2);
   T2 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, T1, VVtemp[268], T2);
  T0 = cl_list(2, ECL_SYM("EQL",336), ECL_T);
  T1 = cl_list(2, T0, ECL_T);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4593slurp_input_stream,ECL_NIL,Cblock,2);
   T2 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, T1, VVtemp[269], T2);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4594slurp_input_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, VVtemp[270], VVtemp[271], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4596slurp_input_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, VVtemp[272], VVtemp[273], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4597slurp_input_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1127], ECL_NIL, VV[1137], VVtemp[274], T0);
  L4258undefine_function(VV[1139]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[275]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1139], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[276], ECL_SYM("DOCUMENTATION",1253), VVtemp[277]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4598vomit_output_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1139], ECL_NIL, VVtemp[259], VVtemp[278], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4599vomit_output_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1139], ECL_NIL, VVtemp[261], VVtemp[279], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4600vomit_output_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1139], ECL_NIL, VVtemp[263], VVtemp[280], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4601vomit_output_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1139], ECL_NIL, VVtemp[281], VVtemp[282], T0);
  T0 = cl_list(2, ECL_SYM("EQL",336), ECL_T);
  T1 = cl_list(2, T0, ECL_T);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4602vomit_output_stream,ECL_NIL,Cblock,2);
   T2 = v1;
  }
  clos_install_method(5, VV[1139], ECL_NIL, T1, VVtemp[269], T2);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4603vomit_output_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1139], ECL_NIL, VVtemp[270], VVtemp[271], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4605vomit_output_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1139], ECL_NIL, VVtemp[272], VVtemp[273], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4606vomit_output_stream,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, VV[1139], ECL_NIL, VV[1137], VVtemp[274], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4608__lambda3527_va,ECL_NIL,Cblock,0);
   T0 = v1;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[283]);
  T2 = cl_list(4, T1, VVtemp[284], VVtemp[285], VVtemp[286]);
  clos_load_defclass(VV[1142], VVtemp[62], T2, ECL_NIL);
  L4258undefine_function(VV[1149]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[287]) /*  MAPC */;
  ecl_cmp_defun(VV[3002]);                        /*  %CMD-SHELL-PATHNAME     */
  L4258undefine_function(VV[1152]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[288]) /*  MAPC */;
  ecl_cmp_defun(VV[3003]);                        /*  %NORMALIZE-COMMAND      */
  L4258undefine_function(VV[1156]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[289]) /*  MAPC */;
  ecl_cmp_defun(VV[3004]);                        /*  %ACTIVE-IO-SPECIFIER-P  */
  L4258undefine_function(VV[1160]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[290]) /*  MAPC */;
  ecl_cmp_defun(VV[3005]);                        /*  %NORMALIZE-IO-SPECIFIER */
  L4258undefine_function(VV[1168]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[291]) /*  MAPC */;
  ecl_cmp_defun(VV[3006]);                        /*  %NORMALIZE-IF-EXISTS    */
  L4258undefine_function(VV[1173]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[292]) /*  MAPC */;
  ecl_cmp_defun(VV[3007]);                        /*  %INTERACTIVEP           */
  L4258undefine_function(VV[1175]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[293]) /*  MAPC */;
  ecl_cmp_defun(VV[3008]);                        /*  %SIGNAL-TO-EXIT-CODE    */
  clos_load_defclass(VV[1177], ECL_NIL, VVtemp[294], ECL_NIL);
  L4258undefine_function(VV[1178]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[295]) /*  MAPC */;
  ecl_cmp_defun(VV[3009]);                        /*  %RUN-PROGRAM            */
  L4258undefine_function(VV[1193]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[296]) /*  MAPC */;
  ecl_cmp_defun(VV[3010]);                        /*  PROCESS-INFO-ERROR-OUTPUT */
  L4258undefine_function(VV[1196]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[297]) /*  MAPC */;
  ecl_cmp_defun(VV[3011]);                        /*  PROCESS-INFO-INPUT      */
  L4258undefine_function(VV[1198]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[298]) /*  MAPC */;
  ecl_cmp_defun(VV[3012]);                        /*  PROCESS-INFO-OUTPUT     */
  L4258undefine_function(VV[1200]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[299]) /*  MAPC */;
  ecl_cmp_defun(VV[3013]);                        /*  PROCESS-INFO-PID        */
  L4258undefine_function(VV[1202]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[300]) /*  MAPC */;
  ecl_cmp_defun(VV[3014]);                        /*  %PROCESS-STATUS         */
  L4258undefine_function(VV[1204]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[301]) /*  MAPC */;
  ecl_cmp_defun(VV[3015]);                        /*  PROCESS-ALIVE-P         */
  L4258undefine_function(VV[1209]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[302]) /*  MAPC */;
  ecl_cmp_defun(VV[3016]);                        /*  WAIT-PROCESS            */
  L4258undefine_function(VV[1211]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[303]) /*  MAPC */;
  ecl_cmp_defun(VV[3017]);                        /*  %CHECK-RESULT           */
  L4258undefine_function(VV[1215]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[304]) /*  MAPC */;
  ecl_cmp_defun(VV[3018]);                        /*  CLOSE-STREAMS           */
  L4258undefine_function(VV[1217]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[305]) /*  MAPC */;
  ecl_cmp_defun(VV[3019]);                        /*  %POSIX-SEND-SIGNAL      */
  L4258undefine_function(VV[1220]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[306]) /*  MAPC */;
  ecl_cmp_defun(VV[3020]);                        /*  TERMINATE-PROCESS       */
  L4258undefine_function(VV[1224]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[307]) /*  MAPC */;
  ecl_cmp_defun(VV[3021]);                        /*  %CALL-WITH-PROGRAM-IO   */
  ecl_cmp_defmacro(VV[3022]);                     /*  PLACE-SETTER            */
  ecl_cmp_defmacro(VV[3023]);                     /*  WITH-PROGRAM-INPUT      */
  ecl_cmp_defmacro(VV[3024]);                     /*  WITH-PROGRAM-OUTPUT     */
  ecl_cmp_defmacro(VV[3025]);                     /*  WITH-PROGRAM-ERROR-OUTPUT */
  L4258undefine_function(VV[1255]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[308]) /*  MAPC */;
  ecl_cmp_defun(VV[3026]);                        /*  %USE-RUN-PROGRAM        */
  L4258undefine_function(VV[1268]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[309]) /*  MAPC */;
  ecl_cmp_defun(VV[3027]);                        /*  %NORMALIZE-SYSTEM-COMMAND */
  L4258undefine_function(VV[1271]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[310]) /*  MAPC */;
  ecl_cmp_defun(VV[3028]);                        /*  %REDIRECTED-SYSTEM-COMMAND */
  L4258undefine_function(VV[1284]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[311]) /*  MAPC */;
  ecl_cmp_defun(VV[3029]);                        /*  %SYSTEM                 */
  L4258undefine_function(VV[1287]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[312]) /*  MAPC */;
  ecl_cmp_defun(VV[3030]);                        /*  %USE-SYSTEM             */
  L4258undefine_function(VV[1294]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[313]) /*  MAPC */;
  ecl_cmp_defun(VV[3031]);                        /*  LAUNCH-PROGRAM          */
  L4258undefine_function(VV[1227]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[314]) /*  MAPC */;
  ecl_cmp_defun(VV[3032]);                        /*  RUN-PROGRAM             */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_10, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[315]);
  si_select_package(_ecl_static_10);
  si_Xmake_special(VV[1299]);
  if (ecl_boundp(cl_env_copy,VV[1299])) {
   goto L2174;
  }
  T0 = VV[1300];
  ecl_cmp_setq(cl_env_copy,VV[1299],T0);
L2174:;
  si_Xmake_special(VV[1301]);
  if (ecl_boundp(cl_env_copy,VV[1301])) {
   goto L2181;
  }
  T0 = VV[1300];
  ecl_cmp_setq(cl_env_copy,VV[1301],T0);
L2181:;
  si_Xmake_special(VV[1302]);
  if (ecl_boundp(cl_env_copy,VV[1302])) {
   goto L2188;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1302],T0);
L2188:;
  si_Xmake_special(VV[1303]);
  if (ecl_boundp(cl_env_copy,VV[1303])) {
   goto L2195;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1303],T0);
L2195:;
  si_Xmake_special(VV[1304]);
  if (ecl_boundp(cl_env_copy,VV[1304])) {
   goto L2202;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1304],T0);
L2202:;
  si_Xmake_special(VV[1305]);
  if (L4251use_ecl_byte_compiler_p()!=ECL_NIL) {
   goto L2211;
  }
  T0 = VVtemp[316];
  ecl_cmp_setq(cl_env_copy,VV[1305],T0);
  goto L2210;
L2211:;
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1305],T0);
L2210:;
  L4258undefine_function(VV[1306]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[317]) /*  MAPC */;
  ecl_cmp_defun(VV[3033]);                        /*  GET-OPTIMIZATION-SETTINGS */
  L4258undefine_function(VV[1309]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[318]) /*  MAPC */;
  ecl_cmp_defun(VV[3034]);                        /*  PROCLAIM-OPTIMIZATION-SETTINGS */
  ecl_cmp_defmacro(VV[3035]);                     /*  WITH-OPTIMIZATION-SETTINGS */
  si_Xmake_special(VV[1314]);
  if (ecl_boundp(cl_env_copy,VV[1314])) {
   goto L2231;
  }
  T0 = cl_append(1, VVtemp[319]);
  ecl_cmp_setq(cl_env_copy,VV[1314],T0);
L2231:;
  si_Xmake_special(VV[1315]);
  if (ecl_boundp(cl_env_copy,VV[1315])) {
   goto L2238;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1315],T0);
L2238:;
  si_Xmake_special(VV[1316]);
  if (ecl_boundp(cl_env_copy,VV[1316])) {
   goto L2245;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1316],T0);
L2245:;
  si_Xmake_special(VV[1317]);
  if (ecl_boundp(cl_env_copy,VV[1317])) {
   goto L2252;
  }
  T0 = cl_append(1, VVtemp[320]);
  ecl_cmp_setq(cl_env_copy,VV[1317],T0);
L2252:;
  L4258undefine_function(VV[1318]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[321]) /*  MAPC */;
  ecl_cmp_defun(VV[3036]);                        /*  CALL-WITH-MUFFLED-COMPILER-CONDITIONS */
  ecl_cmp_defmacro(VV[3037]);                     /*  WITH-MUFFLED-COMPILER-CONDITIONS */
  L4258undefine_function(VV[1322]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[322]) /*  MAPC */;
  ecl_cmp_defun(VV[3038]);                        /*  CALL-WITH-MUFFLED-LOADER-CONDITIONS */
  ecl_cmp_defmacro(VV[3039]);                     /*  WITH-MUFFLED-LOADER-CONDITIONS */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4673__lambda4035_va,ECL_NIL,Cblock,0);
   T0 = v1;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[324]);
  T2 = cl_list(4, T1, VVtemp[325], VVtemp[326], VVtemp[327]);
  clos_load_defclass(VV[1326], VVtemp[323], T2, ECL_NIL);
  clos_load_defclass(VV[1333], VVtemp[328], ECL_NIL, ECL_NIL);
  clos_load_defclass(VV[1334], VVtemp[329], ECL_NIL, ECL_NIL);
  clos_load_defclass(VV[1335], VVtemp[328], ECL_NIL, ECL_NIL);
  clos_load_defclass(VV[1336], VVtemp[329], ECL_NIL, ECL_NIL);
  clos_load_defclass(VV[1337], VVtemp[328], ECL_NIL, ECL_NIL);
  L4258undefine_function(VV[1338]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[330]) /*  MAPC */;
  ecl_cmp_defun(VV[3040]);                        /*  CHECK-LISP-COMPILE-WARNINGS */
  L4258undefine_function(VV[1344]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[331]) /*  MAPC */;
  ecl_cmp_defun(VV[3041]);                        /*  CHECK-LISP-COMPILE-RESULTS */
  L4258undefine_function(VV[1346]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[332]) /*  MAPC */;
  ecl_cmp_defun(VV[3042]);                        /*  REIFY-SIMPLE-SEXP       */
  L4258undefine_function(VV[1350]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[333]) /*  MAPC */;
  ecl_cmp_defun(VV[3043]);                        /*  UNREIFY-SIMPLE-SEXP     */
  L4258undefine_function(VV[1354]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[334]) /*  MAPC */;
  ecl_cmp_defun(VV[3044]);                        /*  REIFY-DEFERRED-WARNINGS */
  L4258undefine_function(VV[1357]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[335]) /*  MAPC */;
  ecl_cmp_defun(VV[3045]);                        /*  UNREIFY-DEFERRED-WARNINGS */
  L4258undefine_function(VV[1359]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[336]) /*  MAPC */;
  ecl_cmp_defun(VV[3046]);                        /*  RESET-DEFERRED-WARNINGS */
  L4258undefine_function(VV[1362]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[337]) /*  MAPC */;
  ecl_cmp_defun(VV[3047]);                        /*  SAVE-DEFERRED-WARNINGS  */
  L4258undefine_function(VV[1365]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[338]) /*  MAPC */;
  ecl_cmp_defun(VV[3048]);                        /*  WARNINGS-FILE-TYPE      */
  si_Xmake_special(VV[1388]);
  if (ecl_boundp(cl_env_copy,VV[1388])) {
   goto L2348;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1388],T0);
L2348:;
  L4258undefine_function(VV[1389]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[339]) /*  MAPC */;
  ecl_cmp_defun(VV[3049]);                        /*  ENABLE-DEFERRED-WARNINGS-CHECK */
  L4258undefine_function(VV[1391]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[340]) /*  MAPC */;
  ecl_cmp_defun(VV[3050]);                        /*  DISABLE-DEFERRED-WARNINGS-CHECK */
  L4258undefine_function(VV[1393]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[341]) /*  MAPC */;
  ecl_cmp_defun(VV[3051]);                        /*  WARNINGS-FILE-P         */
  L4258undefine_function(VV[1395]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[342]) /*  MAPC */;
  ecl_cmp_defun(VV[3052]);                        /*  CHECK-DEFERRED-WARNINGS */
  L4258undefine_function(VV[1403]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[343]) /*  MAPC */;
  ecl_cmp_defun(VV[3053]);                        /*  CALL-WITH-SAVED-DEFERRED-WARNINGS */
  ecl_cmp_defmacro(VV[3054]);                     /*  WITH-SAVED-DEFERRED-WARNINGS */
  L4258undefine_function(VV[1410]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[344]) /*  MAPC */;
  ecl_cmp_defun(VV[3055]);                        /*  CURRENT-LISP-FILE-PATHNAME */
  L4258undefine_function(VV[1412]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[345]) /*  MAPC */;
  ecl_cmp_defun(VV[3056]);                        /*  LOAD-PATHNAME           */
  L4258undefine_function(VV[1414]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[346]) /*  MAPC */;
  ecl_cmp_defun(VV[3057]);                        /*  LISPIZE-PATHNAME        */
  L4258undefine_function(VV[1417]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[347]) /*  MAPC */;
  ecl_cmp_defun(VV[3058]);                        /*  COMPILE-FILE-TYPE       */
  L4258undefine_function(VV[1420]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[348]) /*  MAPC */;
  ecl_cmp_defun(VV[3059]);                        /*  CALL-AROUND-HOOK        */
  L4258undefine_function(VV[1422]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[349]) /*  MAPC */;
  ecl_cmp_defun(VV[3060]);                        /*  COMPILE-FILE-PATHNAME*  */
  si_Xmake_special(VV[1425]);
  if (ecl_boundp(cl_env_copy,VV[1425])) {
   goto L2423;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1425],T0);
L2423:;
  L4258undefine_function(VV[1426]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[350]) /*  MAPC */;
  ecl_cmp_defun(VV[3061]);                        /*  COMPILE-FILE*           */
  L4258undefine_function(VV[1440]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[351]) /*  MAPC */;
  ecl_cmp_defun(VV[3062]);                        /*  LOAD*                   */
  L4258undefine_function(VV[1444]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[352]) /*  MAPC */;
  ecl_cmp_defun(VV[3063]);                        /*  LOAD-FROM-STRING        */
  L4258undefine_function(VV[1446]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[353]) /*  MAPC */;
  ecl_cmp_defun(VV[3064]);                        /*  COMBINE-FASLS           */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_11, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[354]);
  si_select_package(_ecl_static_11);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC4710__lambda4242_va,ECL_NIL,Cblock,0);
   T0 = v1;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[355]);
  T2 = cl_list(5, T1, VVtemp[356], VVtemp[357], VVtemp[358], VVtemp[359]);
  clos_load_defclass(VV[1449], VVtemp[323], T2, ECL_NIL);
  L4258undefine_function(VV[1457]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[360]) /*  MAPC */;
  ecl_cmp_defun(VV[3065]);                        /*  CONFIGURATION-INHERITANCE-DIRECTIVE-P */
  L4258undefine_function(VV[1460]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[361]) /*  MAPC */;
  ecl_cmp_defun(VV[3066]);                        /*  REPORT-INVALID-FORM     */
  si_Xmake_special(VV[1463]);
  if (ecl_boundp(cl_env_copy,VV[1463])) {
   goto L2473;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1463],T0);
L2473:;
  L4258undefine_function(VV[1464]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[362]) /*  MAPC */;
  ecl_cmp_defun(VV[3067]);                        /*  VALIDATE-CONFIGURATION-FORM */
  L4258undefine_function(VV[1470]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[363]) /*  MAPC */;
  ecl_cmp_defun(VV[3068]);                        /*  VALIDATE-CONFIGURATION-FILE */
  L4258undefine_function(VV[1473]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[364]) /*  MAPC */;
  ecl_cmp_defun(VV[3069]);                        /*  VALIDATE-CONFIGURATION-DIRECTORY */
  L4258undefine_function(VV[1479]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[365]) /*  MAPC */;
  ecl_cmp_defun(VV[3070]);                        /*  RESOLVE-RELATIVE-LOCATION */
  si_Xmake_special(VV[1495]);
  if (ecl_boundp(cl_env_copy,VV[1495])) {
   goto L2504;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1495],T0);
L2504:;
  si_Xmake_special(VV[1496]);
  if (ecl_boundp(cl_env_copy,VV[1496])) {
   goto L2511;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1496],T0);
L2511:;
  L4258undefine_function(VV[1497]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[366]) /*  MAPC */;
  ecl_cmp_defun(VV[3071]);                        /*  RESOLVE-ABSOLUTE-LOCATION */
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[367]) /*  MAPC */;
  L4258undefine_function(VV[1504]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[368]) /*  MAPC */;
  ecl_cmp_defun(VV[3072]);                        /*  RESOLVE-LOCATION        */
  L4258undefine_function(VV[1506]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[369]) /*  MAPC */;
  ecl_cmp_defun(VV[3073]);                        /*  LOCATION-DESIGNATOR-P   */
  L4258undefine_function(VV[1519]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[370]) /*  MAPC */;
  ecl_cmp_defun(VV[3074]);                        /*  LOCATION-FUNCTION-P     */
  si_Xmake_special(VV[1521]);
  if (ecl_boundp(cl_env_copy,VV[1521])) {
   goto L2544;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1521],T0);
L2544:;
  L4258undefine_function(VV[1522]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[371]) /*  MAPC */;
  ecl_cmp_defun(VV[3075]);                        /*  REGISTER-CLEAR-CONFIGURATION-HOOK */
  L4258undefine_function(VV[1524]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[372]) /*  MAPC */;
  ecl_cmp_defun(VV[3076]);                        /*  CLEAR-CONFIGURATION     */
  (cl_env_copy->function=ecl_fdefinition(VV[1035]))->cfun.entry(1, VV[1524]) /*  REGISTER-IMAGE-DUMP-HOOK */;
  L4258undefine_function(VV[1526]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[373]) /*  MAPC */;
  ecl_cmp_defun(VV[3077]);                        /*  UPGRADE-CONFIGURATION   */
  L4258undefine_function(VV[1528]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[374]) /*  MAPC */;
  ecl_cmp_defun(VV[3078]);                        /*  GET-FOLDER-PATH         */
  L4258undefine_function(VV[1540]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[375]) /*  MAPC */;
  ecl_cmp_defun(VV[3079]);                        /*  XDG-DATA-HOME           */
  L4258undefine_function(VV[1544]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[376]) /*  MAPC */;
  ecl_cmp_defun(VV[3080]);                        /*  XDG-CONFIG-HOME         */
  L4258undefine_function(VV[1548]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[377]) /*  MAPC */;
  ecl_cmp_defun(VV[3081]);                        /*  XDG-DATA-DIRS           */
  L4258undefine_function(VV[1553]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[378]) /*  MAPC */;
  ecl_cmp_defun(VV[3082]);                        /*  XDG-CONFIG-DIRS         */
  L4258undefine_function(VV[1558]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[379]) /*  MAPC */;
  ecl_cmp_defun(VV[3083]);                        /*  XDG-CACHE-HOME          */
  L4258undefine_function(VV[1562]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[380]) /*  MAPC */;
  ecl_cmp_defun(VV[3084]);                        /*  XDG-RUNTIME-DIR         */
  L4258undefine_function(VV[1565]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[381]) /*  MAPC */;
  ecl_cmp_defun(VV[3085]);                        /*  SYSTEM-CONFIG-PATHNAMES */
  L4258undefine_function(VV[1568]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[382]) /*  MAPC */;
  ecl_cmp_defun(VV[3086]);                        /*  FILTER-PATHNAME-SET     */
  L4258undefine_function(VV[1570]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[383]) /*  MAPC */;
  ecl_cmp_defun(VV[3087]);                        /*  XDG-DATA-PATHNAMES      */
  L4258undefine_function(VV[1572]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[384]) /*  MAPC */;
  ecl_cmp_defun(VV[3088]);                        /*  XDG-CONFIG-PATHNAMES    */
  L4258undefine_function(VV[1574]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[385]) /*  MAPC */;
  ecl_cmp_defun(VV[3089]);                        /*  FIND-PREFERRED-FILE     */
  L4258undefine_function(VV[1579]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[386]) /*  MAPC */;
  ecl_cmp_defun(VV[3090]);                        /*  XDG-DATA-PATHNAME       */
  L4258undefine_function(VV[1581]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[387]) /*  MAPC */;
  ecl_cmp_defun(VV[3091]);                        /*  XDG-CONFIG-PATHNAME     */
  L4258undefine_function(VV[1583]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[388]) /*  MAPC */;
  ecl_cmp_defun(VV[3092]);                        /*  COMPUTE-USER-CACHE      */
  (cl_env_copy->function=ecl_fdefinition(VV[1033]))->cfun.entry(1, VV[1583]) /*  REGISTER-IMAGE-RESTORE-HOOK */;
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_12, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[389]);
  si_select_package(_ecl_static_12);
  L4258undefine_function(VV[1587]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[390]) /*  MAPC */;
  ecl_cmp_defun(VV[3093]);                        /*  COERCE-PATHNAME         */
  L4258undefine_function(VV[1589]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[391]) /*  MAPC */;
  ecl_cmp_defun(VV[3094]);                        /*  USER-CONFIGURATION-DIRECTORIES */
  L4258undefine_function(VV[1591]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[392]) /*  MAPC */;
  ecl_cmp_defun(VV[3095]);                        /*  SYSTEM-CONFIGURATION-DIRECTORIES */
  L4258undefine_function(VV[1593]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[393]) /*  MAPC */;
  ecl_cmp_defun(VV[3096]);                        /*  IN-FIRST-DIRECTORY      */
  L4258undefine_function(VV[1596]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[394]) /*  MAPC */;
  ecl_cmp_defun(VV[3097]);                        /*  IN-USER-CONFIGURATION-DIRECTORY */
  L4258undefine_function(VV[1598]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[395]) /*  MAPC */;
  ecl_cmp_defun(VV[3098]);                        /*  IN-SYSTEM-CONFIGURATION-DIRECTORY */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_13, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[396]);
  cl_provide(VVtemp[397]);
  cl_provide(VVtemp[398]);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_14, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[399]);
  si_select_package(_ecl_static_14);
  L4258undefine_function(VV[1600]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[400]) /*  MAPC */;
  ecl_cmp_defun(VV[3099]);                        /*  ASDF-VERSION            */
  si_Xmake_special(VV[1607]);
  if (ecl_boundp(cl_env_copy,VV[1607])) {
   goto L2713;
  }
  {
   cl_object v1asdf_upgrade__previous;
   v1asdf_upgrade__previous = (cl_env_copy->function=ecl_fdefinition(VV[1600]))->cfun.entry(0) /*  ASDF-VERSION */;
   if (Null(v1asdf_upgrade__previous)){
    goto L2717;
   }
   if (Null((cl_env_copy->function=ecl_fdefinition(VV[385]))->cfun.entry(2, v1asdf_upgrade__previous, VVtemp[401]) /*  VERSION< */)){
    goto L2717;
   }
   {
    cl_object v2asdf_upgrade__away;
    v2asdf_upgrade__away = cl_format(4, ECL_NIL, VVtemp[402], VV[1601], v1asdf_upgrade__previous);
    cl_rename_package(2, VV[1601], v2asdf_upgrade__away);
    if (Null(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*LOAD-VERBOSE*",41)))){
     goto L2717;
    }
    cl_format(4, ECL_T, VVtemp[403], VV[1601], v2asdf_upgrade__away);
   }
L2717:;
   T0 = ecl_list1(v1asdf_upgrade__previous);
   ecl_cmp_setq(cl_env_copy,VV[1607],T0);
  }
L2713:;
  si_Xmake_special(VV[1608]);
  if (ecl_boundp(cl_env_copy,VV[1608])) {
   goto L2727;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1608],T0);
L2727:;
  si_Xmake_special(VV[1609]);
  T0 = VVtemp[404];
  ecl_cmp_setq(cl_env_copy,VV[1609],T0);
  si_Xmake_special(VV[1610]);
  if (ecl_boundp(cl_env_copy,VV[1610])) {
   goto L2740;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1610],T0);
L2740:;
  L4258undefine_function(VV[1611]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[405]) /*  MAPC */;
  ecl_cmp_defun(VV[3100]);                        /*  ASDF-MESSAGE            */
  si_Xmake_special(VV[1613]);
  if (ecl_boundp(cl_env_copy,VV[1613])) {
   goto L2753;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1613],T0);
L2753:;
  si_Xmake_special(VV[1614]);
  if (ecl_boundp(cl_env_copy,VV[1614])) {
   goto L2760;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1614],T0);
L2760:;
  L4258undefine_function(VV[1615]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[406]) /*  MAPC */;
  ecl_cmp_defun(VV[3101]);                        /*  UPGRADING-P             */
  ecl_cmp_defmacro(VV[3102]);                     /*  DEFPARAMETER*           */
  ecl_cmp_defmacro(VV[3103]);                     /*  WHEN-UPGRADING          */
  {
   cl_object v1asdf_upgrade__existing_version;
   v1asdf_upgrade__existing_version = (cl_env_copy->function=ecl_fdefinition(VV[1600]))->cfun.entry(0) /*  ASDF-VERSION */;
   T0 = VVtemp[407];
   ecl_cmp_setq(cl_env_copy,VV[1608],T0);
   if (Null(v1asdf_upgrade__existing_version)){
    goto L2776;
   }
   if (ecl_equal(VVtemp[407],v1asdf_upgrade__existing_version)) {
    goto L2776;
   }
   T0 = CONS(v1asdf_upgrade__existing_version,ecl_cmp_symbol_value(cl_env_copy,VV[1607]));
   ecl_cmp_setq(cl_env_copy,VV[1607],T0);
   if (ecl_cmp_symbol_value(cl_env_copy,VV[1610])!=ECL_NIL) {
    goto L2785;
   }
   if (Null(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*LOAD-VERBOSE*",41)))){
    goto L2776;
   }
   goto L2784;
L2785:;
L2784:;
   value0 = ecl_cmp_symbol_value(cl_env_copy,VV[1610]);
   if (value0!=ECL_NIL) {
    goto L2789;
   }
   T0 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*TRACE-OUTPUT*",71));
   goto L2787;
L2789:;
   T0 = value0;
   goto L2787;
L2787:;
   cl_format(4, T0, VVtemp[408], v1asdf_upgrade__existing_version, VVtemp[407]);
  }
L2776:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[1615]))->cfun.entry(1, VVtemp[404]) /*  UPGRADING-P */)){
   goto L2791;
  }
  T0 = (ECL_SYM("MUFFLE-WARNING",573)->symbol.gfdef);
  T1 = CONS(ECL_SYM("STYLE-WARNING",830),T0);
  T2 = ecl_list1(T1);
  T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
  ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
  cl_eval(VVtemp[409]);
  ecl_bds_unwind1(cl_env_copy);
L2791:;
  L4258undefine_function(VV[1628]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[410]) /*  MAPC */;
  ecl_cmp_defun(VV[3104]);                        /*  CLEANUP-UPGRADED-ASDF   */
  L4258undefine_function(VV[1632]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[411]) /*  MAPC */;
  ecl_cmp_defun(VV[3105]);                        /*  UPGRADE-ASDF            */
  (cl_env_copy->function=ecl_fdefinition(VV[359]))->cfun.entry(2, VV[1613], VV[1526]) /*  REGISTER-HOOK-FUNCTION */;
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_15, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[412]);
  si_select_package(_ecl_static_15);
  L4258undefine_function(VV[1636]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[413]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1636], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414], ECL_SYM("DOCUMENTATION",1253), VVtemp[415]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1637]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[416]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1637], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414], ECL_SYM("DOCUMENTATION",1253), VVtemp[417]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1638]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[418]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1638], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414], ECL_SYM("DOCUMENTATION",1253), VVtemp[419]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1639]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[420]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1639], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414], ECL_SYM("DOCUMENTATION",1253), VVtemp[421]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1640]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[422]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1640], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414], ECL_SYM("DOCUMENTATION",1253), VVtemp[423]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1641]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[424]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1641], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414], ECL_SYM("DOCUMENTATION",1253), VVtemp[425]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1642]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[426]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1642], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[427], ECL_SYM("DOCUMENTATION",1253), VVtemp[428]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1643]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[429]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1643], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414], ECL_SYM("DOCUMENTATION",1253), VVtemp[430]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VVtemp[431]);
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VVtemp[431], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[432], ECL_SYM("DOCUMENTATION",1253), VVtemp[433]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1644]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[434]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1644], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414], ECL_SYM("DOCUMENTATION",1253), VVtemp[435]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4758component_parent_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1644], ECL_NIL, VVtemp[436], VVtemp[414], T0);
  L4258undefine_function(VV[1645]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[437]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1645], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[438], ECL_SYM("DOCUMENTATION",1253), VVtemp[439]) /*  ENSURE-GENERIC-FUNCTION */;
  clos_load_defclass(VV[1646], VVtemp[62], ECL_NIL, ECL_NIL);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4760__lambda4571_va,ECL_NIL,Cblock,0);
   T0 = v2;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[441]);
  T2 = cl_list(2, T1, VVtemp[442]);
  clos_load_defclass(VV[1647], VVtemp[440], T2, ECL_NIL);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4761__lambda4575_va,ECL_NIL,Cblock,0);
   T0 = v2;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[453]);
  T2 = cl_list(16, VVtemp[443], VVtemp[444], VVtemp[445], VVtemp[446], VVtemp[447], VVtemp[448], VVtemp[449], VVtemp[450], VVtemp[451], VVtemp[452], T1, VVtemp[454], VVtemp[455], VVtemp[456], VVtemp[457], VVtemp[458]);
  T3 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[459]);
  clos_load_defclass(VV[1652], ECL_NIL, T2, T3);
  L4258undefine_function(VV[1654]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[460]) /*  MAPC */;
  ecl_cmp_defun(VV[3106]);                        /*  COMPONENT-FIND-PATH     */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4764print_object_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, ECL_SYM("PRINT-OBJECT",965), ECL_NIL, VVtemp[461], VVtemp[462], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4765component_system_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1637], ECL_NIL, VVtemp[414], VVtemp[414], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[463]);
  clos_load_defclass(VV[1659], VVtemp[414], ECL_NIL, T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[466]);
  clos_load_defclass(VV[1660], VVtemp[464], VVtemp[465], T0);
  clos_load_defclass(VV[1661], VVtemp[467], VVtemp[468], ECL_NIL);
  clos_load_defclass(VV[1662], VVtemp[469], VVtemp[470], ECL_NIL);
  clos_load_defclass(VV[1663], VVtemp[469], VVtemp[471], ECL_NIL);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[473]);
  clos_load_defclass(VV[1664], VVtemp[469], VVtemp[472], T0);
  clos_load_defclass(VV[1665], VVtemp[474], ECL_NIL, ECL_NIL);
  clos_load_defclass(VV[1666], VVtemp[475], VVtemp[476], ECL_NIL);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[478]);
  clos_load_defclass(VV[1667], VVtemp[414], VVtemp[477], T0);
  L4258undefine_function(VV[1668]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[479]) /*  MAPC */;
  ecl_cmp_defun(VV[3107]);                        /*  COMPUTE-CHILDREN-BY-NAME */
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[481]);
  clos_load_defclass(VV[1674], VVtemp[480], ECL_NIL, T0);
  L4258undefine_function(VV[1675]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[482]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1675], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414], ECL_SYM("DOCUMENTATION",1253), VVtemp[483]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4767component_parent_pathname_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1675], ECL_NIL, VV[138], VVtemp[414], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4768component_pathname_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1638], ECL_NIL, VVtemp[414], VVtemp[414], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4769component_relative_pathname_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1639], ECL_NIL, VVtemp[414], VVtemp[414], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4770source_file_type_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1645], ECL_NIL, VVtemp[484], VVtemp[438], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4771source_file_type_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1645], ECL_NIL, VVtemp[485], VVtemp[438], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4772component_encoding_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1641], ECL_NIL, VVtemp[414], VVtemp[486], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4773component_external_format_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1640], ECL_NIL, VVtemp[414], VVtemp[486], T0);
  L4258undefine_function(VV[1681]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[487]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1681], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414], ECL_SYM("DOCUMENTATION",1253), VVtemp[488]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4774around_compile_hook_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1681], ECL_NIL, VVtemp[414], VVtemp[486], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4775version_satisfies_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1642], VVtemp[489], VVtemp[490], VVtemp[491], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4776version_satisfies_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1642], ECL_NIL, VVtemp[461], VVtemp[491], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4777version_satisfies_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1642], ECL_NIL, VVtemp[281], VVtemp[492], T0);
  L4258undefine_function(VV[1685]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[493]) /*  MAPC */;
  ecl_cmp_defun(VV[3108]);                        /*  SUB-COMPONENTS          */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_16, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[494]);
  si_select_package(_ecl_static_16);
  L4258undefine_function(VV[1690]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[495]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1690], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[496], ECL_SYM("DOCUMENTATION",1253), VVtemp[497]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1691]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[498]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1691], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[499], ECL_SYM("DOCUMENTATION",1253), VVtemp[500]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1692]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[501]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1692], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414], ECL_SYM("DOCUMENTATION",1253), VVtemp[502]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1693]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[503]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1693], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414], ECL_SYM("DOCUMENTATION",1253), VVtemp[504]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4781component_entry_point_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1693], ECL_NIL, VVtemp[414], VVtemp[505], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[507]);
  clos_load_defclass(VV[1694], ECL_NIL, VVtemp[506], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[510]);
  clos_load_defclass(VV[1695], VVtemp[508], VVtemp[509], T0);
  L4258undefine_function(VV[1696]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[511]) /*  MAPC */;
  ecl_cmp_defun(VV[3109]);                        /*  RESET-SYSTEM            */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4783system_source_file_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1691], ECL_NIL, VVtemp[512], VVtemp[513], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4784system_source_file_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1691], ECL_NIL, VVtemp[514], VVtemp[513], T0);
  L4258undefine_function(VV[1698]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[515]) /*  MAPC */;
  ecl_cmp_defun(VV[3110]);                        /*  SYSTEM-SOURCE-DIRECTORY */
  L4258undefine_function(VV[1700]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[516]) /*  MAPC */;
  ecl_cmp_defun(VV[3111]);                        /*  SYSTEM-RELATIVE-PATHNAME */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4789component_pathname_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(7, VV[1638], ECL_NIL, VVtemp[499], VVtemp[499], T0, ECL_SYM("DOCUMENTATION",1253), VVtemp[517]);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4790component_relative_pathname_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1639], ECL_NIL, VVtemp[499], VVtemp[499], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4791component_parent_pathname_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1675], ECL_NIL, VVtemp[499], VVtemp[499], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4792component_build_pathname_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1692], ECL_NIL, VVtemp[414], VVtemp[505], T0);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_17, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[518]);
  si_select_package(_ecl_static_17);
  si_Xmake_special(VV[1703]);
  if (ecl_boundp(cl_env_copy,VV[1703])) {
   goto L2995;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1703],T0);
L2995:;
  L4258undefine_function(VV[1704]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[519]) /*  MAPC */;
  ecl_cmp_defun(VV[3112]);                        /*  SET-ASDF-CACHE-ENTRY    */
  L4258undefine_function(VV[1706]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[520]) /*  MAPC */;
  ecl_cmp_defun(VV[3113]);                        /*  UNSET-ASDF-CACHE-ENTRY  */
  L4258undefine_function(VV[1708]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[521]) /*  MAPC */;
  ecl_cmp_defun(VV[3114]);                        /*  CONSULT-ASDF-CACHE      */
  ecl_cmp_defmacro(VV[3115]);                     /*  DO-ASDF-CACHE           */
  L4258undefine_function(VV[1712]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[522]) /*  MAPC */;
  ecl_cmp_defun(VV[3116]);                        /*  CALL-WITH-ASDF-CACHE    */
  ecl_cmp_defmacro(VV[3117]);                     /*  WITH-ASDF-CACHE         */
  L4258undefine_function(VV[1729]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[523]) /*  MAPC */;
  ecl_cmp_defun(VV[3118]);                        /*  NORMALIZE-NAMESTRING    */
  L4258undefine_function(VV[1731]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[524]) /*  MAPC */;
  ecl_cmp_defun(VV[3119]);                        /*  COMPUTE-FILE-STAMP      */
  L4258undefine_function(VV[1733]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[525]) /*  MAPC */;
  ecl_cmp_defun(VV[3120]);                        /*  REGISTER-FILE-STAMP     */
  L4258undefine_function(VV[1734]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[526]) /*  MAPC */;
  ecl_cmp_defun(VV[3121]);                        /*  GET-FILE-STAMP          */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_18, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[527]);
  si_select_package(_ecl_static_18);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[528]) /*  MAPC */;
  clos_load_defclass(VV[1738], VVtemp[440], VVtemp[529], ECL_NIL);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4810__lambda4763_va,ECL_NIL,Cblock,0);
   T0 = v2;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[530]);
  T2 = cl_list(3, T1, VVtemp[531], VVtemp[532]);
  clos_load_defclass(VV[1739], VVtemp[440], T2, ECL_NIL);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4812__lambda4767_va,ECL_NIL,Cblock,0);
   T0 = v2;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[533]);
  T2 = cl_list(4, T1, VVtemp[534], VVtemp[535], VVtemp[536]);
  clos_load_defclass(VV[1744], VVtemp[440], T2, ECL_NIL);
  L4258undefine_function(VV[1751]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[537]) /*  MAPC */;
  ecl_cmp_defun(VV[3122]);                        /*  SYSDEF-ERROR            */
  L4258undefine_function(VV[1753]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[538]) /*  MAPC */;
  ecl_cmp_defun(VV[3123]);                        /*  COERCE-NAME             */
  L4258undefine_function(VV[1756]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[539]) /*  MAPC */;
  ecl_cmp_defun(VV[3124]);                        /*  PRIMARY-SYSTEM-NAME     */
  L4258undefine_function(VV[1758]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[540]) /*  MAPC */;
  ecl_cmp_defun(VV[3125]);                        /*  COERCE-FILENAME         */
  si_Xmake_special(VV[1761]);
  if (ecl_boundp(cl_env_copy,VV[1761])) {
   goto L3094;
  }
  T0 = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
  ecl_cmp_setq(cl_env_copy,VV[1761],T0);
L3094:;
  L4258undefine_function(VV[1762]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[541]) /*  MAPC */;
  ecl_cmp_defun(VV[3126]);                        /*  SYSTEM-REGISTERED-P     */
  L4258undefine_function(VV[1764]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[542]) /*  MAPC */;
  ecl_cmp_defun(VV[3127]);                        /*  REGISTERED-SYSTEM       */
  L4258undefine_function(VV[1766]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[543]) /*  MAPC */;
  ecl_cmp_defun(VV[3128]);                        /*  REGISTERED-SYSTEMS*     */
  L4258undefine_function(VV[1769]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[544]) /*  MAPC */;
  ecl_cmp_defun(VV[3129]);                        /*  REGISTERED-SYSTEMS      */
  L4258undefine_function(VV[1771]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[545]) /*  MAPC */;
  ecl_cmp_defun(VV[3130]);                        /*  REGISTER-SYSTEM         */
  si_Xmake_special(VV[1777]);
  if (ecl_boundp(cl_env_copy,VV[1777])) {
   goto L3131;
  }
  T0 = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
  ecl_cmp_setq(cl_env_copy,VV[1777],T0);
L3131:;
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[546]) /*  MAPC */;
  L4258undefine_function(VV[1778]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[547]) /*  MAPC */;
  ecl_cmp_defun(VV[3131]);                        /*  MAKE-PRELOADED-SYSTEM   */
  L4258undefine_function(VV[1784]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[548]) /*  MAPC */;
  ecl_cmp_defun(VV[3132]);                        /*  SYSDEF-PRELOADED-SYSTEM-SEARCH */
  L4258undefine_function(VV[1786]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[549]) /*  MAPC */;
  ecl_cmp_defun(VV[3133]);                        /*  ENSURE-PRELOADED-SYSTEM-REGISTERED */
  L4258undefine_function(VV[1788]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[550]) /*  MAPC */;
  ecl_cmp_defun(VV[3134]);                        /*  ENSURE-ALL-PRELOADED-SYSTEMS-REGISTERED */
  (cl_env_copy->function=ecl_fdefinition(VV[359]))->cfun.entry(2, VV[1614], VV[1788]) /*  REGISTER-HOOK-FUNCTION */;
  L4258undefine_function(VV[1791]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[551]) /*  MAPC */;
  ecl_cmp_defun(VV[3135]);                        /*  REGISTER-PRELOADED-SYSTEM */
  si_Xmake_special(VV[1793]);
  if (ecl_boundp(cl_env_copy,VV[1793])) {
   goto L3171;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1793],T0);
L3171:;
  L4258undefine_function(VV[1794]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[552]) /*  MAPC */;
  ecl_cmp_defun(VV[3136]);                        /*  SYSDEF-IMMUTABLE-SYSTEM-SEARCH */
  L4258undefine_function(VV[1797]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[553]) /*  MAPC */;
  ecl_cmp_defun(VV[3137]);                        /*  REGISTER-IMMUTABLE-SYSTEM */
  L4258undefine_function(VV[1799]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[554]) /*  MAPC */;
  ecl_cmp_defun(VV[3138]);                        /*  CLEAR-SYSTEM            */
  L4258undefine_function(VV[1801]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[555]) /*  MAPC */;
  ecl_cmp_defun(VV[3139]);                        /*  CLEAR-DEFINED-SYSTEMS   */
  (cl_env_copy->function=ecl_fdefinition(VV[359]))->cfun.entry(3, VV[1613], VV[1801], ECL_NIL) /*  REGISTER-HOOK-FUNCTION */;
  L4258undefine_function(VV[1805]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[556]) /*  MAPC */;
  ecl_cmp_defun(VV[3140]);                        /*  MAP-SYSTEMS             */
  si_Xmake_special(VV[1808]);
  if (ecl_boundp(cl_env_copy,VV[1808])) {
   goto L3209;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1808],T0);
L3209:;
  L4258undefine_function(VV[1809]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[557]) /*  MAPC */;
  ecl_cmp_defun(VV[3141]);                        /*  CLEANUP-SYSTEM-DEFINITION-SEARCH-FUNCTIONS */
  (cl_env_copy->function=ecl_fdefinition(VV[1809]))->cfun.entry(0) /*  CLEANUP-SYSTEM-DEFINITION-SEARCH-FUNCTIONS */;
  L4258undefine_function(VV[1815]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[558]) /*  MAPC */;
  ecl_cmp_defun(VV[3142]);                        /*  SEARCH-FOR-SYSTEM-DEFINITION */
  si_Xmake_special(VV[1819]);
  if (ecl_boundp(cl_env_copy,VV[1819])) {
   goto L3229;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[1819],T0);
L3229:;
  L4258undefine_function(VV[1820]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[559]) /*  MAPC */;
  ecl_cmp_defun(VV[3143]);                        /*  PROBE-ASD               */
  L4258undefine_function(VV[1824]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[560]) /*  MAPC */;
  ecl_cmp_defun(VV[3144]);                        /*  SYSDEF-CENTRAL-REGISTRY-SEARCH */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4846find_system,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1690], ECL_NIL, VVtemp[436], VVtemp[561], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4847find_system,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1690], ECL_NIL, VV[138], VVtemp[561], T0);
  L4258undefine_function(VV[1817]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[562]) /*  MAPC */;
  ecl_cmp_defun(VV[3145]);                        /*  FIND-SYSTEM-IF-BEING-DEFINED */
  L4258undefine_function(VV[1840]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[563]) /*  MAPC */;
  ecl_cmp_defun(VV[3146]);                        /*  LOAD-ASD                */
  si_Xmake_special(VV[1847]);
  if (ecl_boundp(cl_env_copy,VV[1847])) {
   goto L3264;
  }
  T0 = cl_make_hash_table(2, ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337));
  ecl_cmp_setq(cl_env_copy,VV[1847],T0);
L3264:;
  L4258undefine_function(VV[1848]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[564]) /*  MAPC */;
  ecl_cmp_defun(VV[3147]);                        /*  CHECK-NOT-OLD-ASDF-SYSTEM */
  L4258undefine_function(VV[1853]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[565]) /*  MAPC */;
  ecl_cmp_defun(VV[3148]);                        /*  LOCATE-SYSTEM           */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4857find_system,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1690], ECL_NIL, VVtemp[512], VVtemp[561], T0);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_19, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[566]);
  si_select_package(_ecl_static_19);
  clos_load_defclass(VV[1863], VVtemp[567], VVtemp[568], ECL_NIL);
  clos_load_defclass(VV[1864], VVtemp[567], VVtemp[569], ECL_NIL);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4860print_object_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, ECL_SYM("PRINT-OBJECT",965), ECL_NIL, VVtemp[570], VVtemp[571], T0);
  clos_load_defclass(VV[1867], VVtemp[572], ECL_NIL, ECL_NIL);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4861print_object_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, ECL_SYM("PRINT-OBJECT",965), ECL_NIL, VVtemp[573], VVtemp[571], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4862print_object_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, ECL_SYM("PRINT-OBJECT",965), ECL_NIL, VVtemp[574], VVtemp[571], T0);
  L4258undefine_function(VV[1873]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[575]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1873], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[576], ECL_SYM("DOCUMENTATION",1253), VVtemp[577]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1874]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[578]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1874], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[579], ECL_SYM("DOCUMENTATION",1253), VVtemp[580]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4863find_component,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1873], ECL_NIL, VVtemp[281], VVtemp[576], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4864find_component,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1873], ECL_NIL, VVtemp[581], VVtemp[576], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4865find_component,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1873], ECL_NIL, VVtemp[261], VVtemp[576], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4866find_component,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1873], ECL_NIL, VVtemp[582], VVtemp[583], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4867find_component,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1873], ECL_NIL, VVtemp[584], VVtemp[585], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4868find_component,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1873], ECL_NIL, VVtemp[586], VVtemp[587], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4869find_component,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1873], ECL_NIL, VVtemp[588], VVtemp[589], T0);
  L4258undefine_function(VV[1877]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[590]) /*  MAPC */;
  ecl_cmp_defun(VV[3149]);                        /*  RESOLVE-DEPENDENCY-NAME */
  L4258undefine_function(VV[1885]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[591]) /*  MAPC */;
  ecl_cmp_defun(VV[3150]);                        /*  RESOLVE-DEPENDENCY-SPEC */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4875resolve_dependency_combination_va,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[1874], ECL_NIL, VVtemp[592], VVtemp[579], T0);
  T0 = cl_list(2, ECL_SYM("EQL",336), VV[1888]);
  T1 = cl_list(3, ECL_T, T0, ECL_T);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4876resolve_dependency_combination_va,ECL_NIL,Cblock,3);
   T2 = v2;
  }
  clos_install_method(5, VV[1874], ECL_NIL, T1, VVtemp[579], T2);
  T0 = cl_list(2, ECL_SYM("EQL",336), ECL_SYM("VERSION",1364));
  T1 = cl_list(3, ECL_T, T0, ECL_T);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4877resolve_dependency_combination_va,ECL_NIL,Cblock,3);
   T2 = v2;
  }
  clos_install_method(5, VV[1874], ECL_NIL, T1, VVtemp[579], T2);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_20, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[593]);
  si_select_package(_ecl_static_20);
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[1615]))->cfun.entry(1, VVtemp[404]) /*  UPGRADING-P */)){
   goto L3345;
  }
  if (Null(cl_find_class(2, VV[1889], ECL_NIL))){
   goto L3345;
  }
  T0 = (ECL_SYM("MUFFLE-WARNING",573)->symbol.gfdef);
  T1 = CONS(ECL_SYM("STYLE-WARNING",830),T0);
  T2 = ecl_list1(T1);
  T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
  ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
  cl_eval(VVtemp[594]);
  ecl_bds_unwind1(cl_env_copy);
L3345:;
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[596]);
  clos_load_defclass(VV[1889], ECL_NIL, VVtemp[595], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4878initialize_instance,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, ECL_SYM("INITIALIZE-INSTANCE",951), VVtemp[597], VVtemp[598], VVtemp[599], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4881print_object_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, ECL_SYM("PRINT-OBJECT",965), ECL_NIL, VVtemp[600], VVtemp[601], T0);
  ecl_cmp_defun(VV[3151]);                        /*  %COMPUTE-OPERATIONS-VALUE */
  si_Xmake_special(VV[1897]);
  if (ecl_boundp(cl_env_copy,VV[1897])) {
   goto L3359;
  }
  T0 = L4882_compute_operations_value();
  ecl_cmp_setq(cl_env_copy,VV[1897],T0);
L3359:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[1615]))->cfun.entry(1, VVtemp[404]) /*  UPGRADING-P */)){
   goto L3365;
  }
  T0 = L4882_compute_operations_value();
  ecl_cmp_setq(cl_env_copy,VV[1897],T0);
L3365:;
  L4258undefine_function(VV[1898]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[602]) /*  MAPC */;
  ecl_cmp_defun(VV[3152]);                        /*  MAKE-OPERATION          */
  L4258undefine_function(VV[1902]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[603]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1902], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[604], ECL_SYM("DOCUMENTATION",1253), VVtemp[605]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4884find_operation_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1902], ECL_NIL, VVtemp[606], VVtemp[604], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4885find_operation_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1902], ECL_NIL, VVtemp[584], VVtemp[604], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4886find_operation_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1902], ECL_NIL, VVtemp[607], VVtemp[604], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4887operation_original_initargs_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1891], ECL_NIL, VVtemp[514], VVtemp[608], T0);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_21, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[609]);
  si_select_package(_ecl_static_21);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4888__lambda5292_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  si_do_deftype(3, VV[1903], VVtemp[610], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4889__lambda5297_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  si_do_deftype(3, VV[1906], VVtemp[611], T0);
  L4258undefine_function(VV[1909]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[612]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(5, VV[1909], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[613]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1910]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[614]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(5, VV[1910], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[615]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1911]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[616]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(5, VV[1911], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[617]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1912]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[618]) /*  MAPC */;
  ecl_cmp_defun(VV[3153]);                        /*  ACTION-PATH             */
  L4258undefine_function(VV[1914]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[619]) /*  MAPC */;
  ecl_cmp_defun(VV[3154]);                        /*  FIND-ACTION             */
  ecl_cmp_defmacro(VV[3155]);                     /*  DEFINE-CONVENIENCE-ACTION-METHODS */
  L4258undefine_function(VV[1933]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[620]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1933], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[621], ECL_SYM("DOCUMENTATION",1253), VVtemp[622]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4894action_description_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1933], ECL_NIL, VV[1137], VVtemp[621], T0);
  L4258undefine_function(VV[1935]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[623]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1935], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[621], ECL_SYM("DOCUMENTATION",1253), VVtemp[624]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4895explain_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1935], ECL_NIL, VVtemp[621], VVtemp[625], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4896explain_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1935], ECL_NIL, VVtemp[281], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4897explain_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1935], ECL_NIL, VVtemp[581], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4898explain_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1935], ECL_NIL, VVtemp[600], VVtemp[621], T0);
  L4258undefine_function(VV[1937]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[626]) /*  MAPC */;
  ecl_cmp_defun(VV[3156]);                        /*  FORMAT-ACTION           */
  L4258undefine_function(VV[1941]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[627]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1941], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[621], ECL_SYM("DOCUMENTATION",1253), VVtemp[628]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4900component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[281], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4901component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[581], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4902component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[600], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4906component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1941], VVtemp[489], VVtemp[621], VVtemp[625], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[630]);
  clos_load_defclass(VV[1943], VVtemp[598], VVtemp[629], T0);
  L4258undefine_function(VV[1944]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[631]) /*  MAPC */;
  ecl_cmp_defun(VV[3157]);                        /*  DOWNWARD-OPERATION-DEPENDS-ON */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4910component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[632], VVtemp[625], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[634]);
  clos_load_defclass(VV[1946], VVtemp[598], VVtemp[633], T0);
  L4258undefine_function(VV[1947]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[635]) /*  MAPC */;
  ecl_cmp_defun(VV[3158]);                        /*  UPWARD-OPERATION-DEPENDS-ON */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4914component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[636], VVtemp[625], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[638]);
  clos_load_defclass(VV[1949], VVtemp[598], VVtemp[637], T0);
  L4258undefine_function(VV[1950]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[639]) /*  MAPC */;
  ecl_cmp_defun(VV[3159]);                        /*  SIDEWAY-OPERATION-DEPENDS-ON */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4918component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[640], VVtemp[625], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[642]);
  clos_load_defclass(VV[1953], VVtemp[598], VVtemp[641], T0);
  L4258undefine_function(VV[1954]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[643]) /*  MAPC */;
  ecl_cmp_defun(VV[3160]);                        /*  SELFWARD-OPERATION-DEPENDS-ON */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4922component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[644], VVtemp[625], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[645]);
  clos_load_defclass(VV[1956], VVtemp[598], ECL_NIL, T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[647]);
  clos_load_defclass(VV[1957], VVtemp[646], ECL_NIL, T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[649]);
  clos_load_defclass(VV[1958], VVtemp[648], ECL_NIL, T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4923initialize_instance,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, ECL_SYM("INITIALIZE-INSTANCE",951), VVtemp[650], VVtemp[598], VVtemp[651], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4924initialize_instance,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, ECL_SYM("INITIALIZE-INSTANCE",951), VVtemp[650], VVtemp[652], VVtemp[651], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4925component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[621], VVtemp[625], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4926downward_operation_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1943], ECL_NIL, VVtemp[598], VVtemp[653], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4927sideway_operation_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[1949], ECL_NIL, VVtemp[598], VVtemp[653], T0);
  L4258undefine_function(VV[1962]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[654]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1962], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[621], ECL_SYM("DOCUMENTATION",1253), VVtemp[655]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1963]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[656]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1963], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[621], ECL_SYM("DOCUMENTATION",1253), VVtemp[657]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1964]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[658]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1964], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[621], ECL_SYM("DOCUMENTATION",1253), VVtemp[659]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4928output_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1962], ECL_NIL, VVtemp[281], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4929output_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1962], ECL_NIL, VVtemp[581], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4930output_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1962], ECL_NIL, VVtemp[600], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4931input_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[281], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4932input_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[581], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4933input_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[600], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4934operation_done_p_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1964], ECL_NIL, VVtemp[281], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4935operation_done_p_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1964], ECL_NIL, VVtemp[581], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4936operation_done_p_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1964], ECL_NIL, VVtemp[600], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4937operation_done_p_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1964], ECL_NIL, VVtemp[621], VVtemp[625], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4941output_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1962], VVtemp[489], VV[1137], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4942output_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1962], ECL_NIL, VVtemp[621], VVtemp[625], T0);
  L4258undefine_function(VV[1966]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[660]) /*  MAPC */;
  ecl_cmp_defun(VV[3161]);                        /*  OUTPUT-FILE             */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4947input_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1963], VVtemp[489], VV[1137], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4948input_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[621], VVtemp[625], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4951input_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[644], VVtemp[625], T0);
  L4258undefine_function(VV[1970]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[661]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1970], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[621], ECL_SYM("DOCUMENTATION",1253), VVtemp[662]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1971]);
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1971], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[663], ECL_SYM("DOCUMENTATION",1253), VVtemp[664]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4952component_operation_time_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1970], ECL_NIL, VVtemp[281], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4953component_operation_time_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1970], ECL_NIL, VVtemp[581], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4954component_operation_time_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1970], ECL_NIL, VVtemp[600], VVtemp[621], T0);
  L4258undefine_function(VV[1972]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[665]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1972], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[621], ECL_SYM("DOCUMENTATION",1253), VVtemp[666]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[1973]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[667]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1973], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[668], ECL_SYM("DOCUMENTATION",1253), VVtemp[669]) /*  ENSURE-GENERIC-FUNCTION */;
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[671]);
  clos_load_defclass(VV[1974], ECL_NIL, VVtemp[670], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4956print_object_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, ECL_SYM("PRINT-OBJECT",965), ECL_NIL, VVtemp[672], VVtemp[673], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4957component_operation_time_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1970], ECL_NIL, VVtemp[621], VVtemp[625], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4958component_operation_time_va,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[1971], ECL_NIL, VVtemp[674], VVtemp[675], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4959mark_operation_done_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1972], ECL_NIL, VVtemp[621], VVtemp[625], T0);
  L4258undefine_function(VV[1982]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[676]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1982], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[621], ECL_SYM("DOCUMENTATION",1253), VVtemp[677]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4960perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[281], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4961perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[581], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4962perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[600], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4963perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], VVtemp[650], VVtemp[621], VVtemp[625], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4964perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], VVtemp[597], VVtemp[621], VVtemp[625], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4965perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[678], VVtemp[625], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4966perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[679], VVtemp[625], T0);
  L4258undefine_function(VV[1984]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[680]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[1984], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[621], ECL_SYM("DOCUMENTATION",1253), VVtemp[681]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4967perform_with_restarts_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1984], ECL_NIL, VV[1137], VVtemp[621], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4974perform_with_restarts_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1984], VVtemp[489], VV[1137], VVtemp[621], T0);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_22, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[682]);
  si_select_package(_ecl_static_22);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[684]);
  clos_load_defclass(VV[1993], VVtemp[469], VVtemp[683], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[687]);
  clos_load_defclass(VV[1994], VVtemp[685], VVtemp[686], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[689]);
  clos_load_defclass(VV[1995], VVtemp[685], VVtemp[688], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[690]);
  clos_load_defclass(VV[1996], VVtemp[598], ECL_NIL, T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[692]);
  clos_load_defclass(VV[1997], VVtemp[598], VVtemp[691], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[695]);
  clos_load_defclass(VV[1998], VVtemp[693], VVtemp[694], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[698]);
  clos_load_defclass(VV[1999], VVtemp[696], VVtemp[697], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[701]);
  clos_load_defclass(VV[2000], VVtemp[699], VVtemp[700], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[703]);
  clos_load_defclass(VV[2001], VVtemp[693], VVtemp[702], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[705]);
  clos_load_defclass(VV[2002], VVtemp[696], VVtemp[704], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[708]);
  clos_load_defclass(VV[2003], VVtemp[706], VVtemp[707], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4975action_description_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1933], ECL_NIL, VVtemp[709], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4976perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[709], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4977input_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[711], VVtemp[712], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4978action_description_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1933], ECL_NIL, VVtemp[713], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4979action_description_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1933], ECL_NIL, VVtemp[714], VVtemp[710], T0);
  L4258undefine_function(VV[2007]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[715]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2007], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[716], ECL_SYM("DOCUMENTATION",1253), VVtemp[717]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4980call_with_around_compile_hook_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[2007], ECL_NIL, VVtemp[461], VVtemp[718], T0);
  L4258undefine_function(VV[2008]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[719]) /*  MAPC */;
  ecl_cmp_defun(VV[3162]);                        /*  PERFORM-LISP-COMPILATION */
  L4258undefine_function(VV[2015]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[720]) /*  MAPC */;
  ecl_cmp_defun(VV[3163]);                        /*  REPORT-FILE-P           */
  L4258undefine_function(VV[2018]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[721]) /*  MAPC */;
  ecl_cmp_defun(VV[3164]);                        /*  PERFORM-LISP-WARNINGS-CHECK */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4985perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[722], VVtemp[710], T0);
  L4258undefine_function(VV[2022]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[723]) /*  MAPC */;
  ecl_cmp_defun(VV[3165]);                        /*  LISP-COMPILATION-OUTPUT-FILES */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4987output_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1962], ECL_NIL, VVtemp[722], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4988perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[724], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4989perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[725], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4990input_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[725], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4991output_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1962], ECL_NIL, VVtemp[725], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4992action_description_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1933], ECL_NIL, VVtemp[726], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4993action_description_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1933], ECL_NIL, VVtemp[727], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4994action_description_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1933], ECL_NIL, VVtemp[728], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC4999perform_with_restarts_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1984], ECL_NIL, VVtemp[726], VVtemp[710], T0);
  L4258undefine_function(VV[2034]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[729]) /*  MAPC */;
  ecl_cmp_defun(VV[3166]);                        /*  PERFORM-LISP-LOAD-FASL  */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5001perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[726], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5002perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[730], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5003action_description_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1933], ECL_NIL, VVtemp[731], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5004input_files_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[732], VVtemp[712], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5005perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[731], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5006action_description_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1933], ECL_NIL, VVtemp[733], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5007action_description_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1933], ECL_NIL, VVtemp[734], VVtemp[710], T0);
  L4258undefine_function(VV[2039]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[735]) /*  MAPC */;
  ecl_cmp_defun(VV[3167]);                        /*  PERFORM-LISP-LOAD-SOURCE */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5010perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[736], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5011perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[737], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5012perform_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[738], VVtemp[710], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5013operation_done_p_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(7, VV[1964], ECL_NIL, VVtemp[739], VVtemp[710], T0, ECL_SYM("DOCUMENTATION",1253), VVtemp[740]);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_23, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[741]);
  si_select_package(_ecl_static_23);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[742]);
  clos_load_defclass(VV[2042], ECL_NIL, ECL_NIL, T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5014__lambda5748_va,ECL_NIL,Cblock,0);
   T0 = v2;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[750]);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5015__lambda5750_va,ECL_NIL,Cblock,0);
   T2 = v2;
  }
  T3 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T2, VVtemp[751]);
  T4 = cl_list(9, VVtemp[744], VVtemp[745], VVtemp[746], VVtemp[747], VVtemp[748], VVtemp[749], T1, T3, VVtemp[752]);
  T5 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[753]);
  clos_load_defclass(VV[2043], VVtemp[743], T4, T5);
  L4258undefine_function(VV[2046]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[754]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2046], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[755], ECL_SYM("DOCUMENTATION",1253), VVtemp[756]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[2047]);
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2047], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[757], ECL_SYM("DOCUMENTATION",1253), VVtemp[758]) /*  ENSURE-GENERIC-FUNCTION */;
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[761]);
  clos_load_defclass(VV[2048], VVtemp[759], VVtemp[760], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5017print_object_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, ECL_SYM("PRINT-OBJECT",965), ECL_NIL, VVtemp[762], VVtemp[763], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5018action_planned_p_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[2053], ECL_NIL, VV[138], VVtemp[759], T0);
  L4258undefine_function(VV[2054]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[764]) /*  MAPC */;
  ecl_cmp_defun(VV[3168]);                        /*  NODE-FOR                */
  L4258undefine_function(VV[2056]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[765]) /*  MAPC */;
  ecl_cmp_defun(VV[3169]);                        /*  ACTION-ALREADY-DONE-P   */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5021plan_action_status_va,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[2046], ECL_NIL, VVtemp[766], VVtemp[767], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5022plan_action_status_va,ECL_NIL,Cblock,4);
   T0 = v2;
  }
  clos_install_method(5, VV[2047], ECL_NIL, VVtemp[768], VVtemp[769], T0);
  L4258undefine_function(VV[2060]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[770]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2060], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[755], ECL_SYM("DOCUMENTATION",1253), VVtemp[771]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[2061]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[772]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2061], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[755], ECL_SYM("DOCUMENTATION",1253), VVtemp[773]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[2062]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[774]) /*  MAPC */;
  ecl_cmp_defun(VV[3170]);                        /*  NORMALIZE-FORCED-SYSTEMS */
  L4258undefine_function(VV[2068]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[775]) /*  MAPC */;
  ecl_cmp_defun(VV[3171]);                        /*  NORMALIZE-FORCED-NOT-SYSTEMS */
  L4258undefine_function(VV[2072]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[776]) /*  MAPC */;
  ecl_cmp_defun(VV[3172]);                        /*  ACTION-OVERRIDE-P       */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5028action_forced_p_va,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[2060], ECL_NIL, VVtemp[592], VVtemp[755], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5029action_forced_not_p_va,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[2061], ECL_NIL, VVtemp[592], VVtemp[755], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5030action_forced_p_va,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[2060], ECL_NIL, VVtemp[766], VVtemp[755], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5031action_forced_not_p_va,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[2061], ECL_NIL, VVtemp[766], VVtemp[755], T0);
  L4258undefine_function(VV[2077]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[777]) /*  MAPC */;
  ecl_cmp_defun(VV[3173]);                        /*  ACTION-VALID-P          */
  L4258undefine_function(VV[2079]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[778]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2079], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[621], ECL_SYM("DOCUMENTATION",1253), VVtemp[779]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5033needed_in_image_p_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[2079], ECL_NIL, VVtemp[621], VVtemp[780], T0);
  L4258undefine_function(VV[2080]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[781]) /*  MAPC */;
  ecl_cmp_defun(VV[3174]);                        /*  MAP-DIRECT-DEPENDENCIES */
  L4258undefine_function(VV[2082]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[782]) /*  MAPC */;
  ecl_cmp_defun(VV[3175]);                        /*  REDUCE-DIRECT-DEPENDENCIES */
  L4258undefine_function(VV[2085]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[783]) /*  MAPC */;
  ecl_cmp_defun(VV[3176]);                        /*  DIRECT-DEPENDENCIES     */
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5039compute_action_stamp,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[1973], ECL_NIL, VVtemp[674], VVtemp[784], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5040initialize_instance,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, ECL_SYM("INITIALIZE-INSTANCE",951), VVtemp[597], VVtemp[785], VVtemp[786], T0);
  L4258undefine_function(VV[2091]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[787]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2091], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[743], ECL_SYM("DOCUMENTATION",1253), VVtemp[788]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5041plan_actions_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[2091], ECL_NIL, VVtemp[789], VVtemp[743], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5042plan_action_status_va,ECL_NIL,Cblock,4);
   T0 = v2;
  }
  clos_install_method(5, VV[2047], ECL_NIL, VVtemp[790], VVtemp[791], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5043plan_action_status_va,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[2046], ECL_NIL, VVtemp[792], VVtemp[793], T0);
  L4258undefine_function(VV[2093]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[794]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2093], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[755], ECL_SYM("DOCUMENTATION",1253), VVtemp[795]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5045__lambda6060_va,ECL_NIL,Cblock,0);
   T0 = v2;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[796]);
  T2 = cl_list(2, T1, VVtemp[797]);
  clos_load_defclass(VV[2094], VVtemp[440], T2, ECL_NIL);
  L4258undefine_function(VV[2099]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[798]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2099], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[799], ECL_SYM("DOCUMENTATION",1253), VVtemp[800]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5046call_while_visiting_action_va,ECL_NIL,Cblock,4);
   T0 = v2;
  }
  clos_install_method(5, VV[2099], ECL_NIL, VVtemp[801], VVtemp[802], T0);
  ecl_cmp_defmacro(VV[3177]);                     /*  WHILE-VISITING-ACTION   */
  L4258undefine_function(VV[2106]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[803]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(5, VV[2106], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[804]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5051traverse_action_va,ECL_NIL,Cblock,4);
   T0 = v2;
  }
  clos_install_method(5, VV[2106], ECL_NIL, VVtemp[805], VVtemp[804], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[807]);
  clos_load_defclass(VV[2117], VVtemp[785], VVtemp[806], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5052plan_actions_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[2091], ECL_NIL, VVtemp[808], VVtemp[743], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5053plan_record_dependency_va,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[2093], ECL_NIL, VVtemp[809], VVtemp[767], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5054plan_action_status_va,ECL_NIL,Cblock,4);
   T0 = v2;
  }
  clos_install_method(5, VV[2047], VVtemp[597], VVtemp[810], VVtemp[791], T0);
  L4258undefine_function(VV[2120]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[811]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2120], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[812], ECL_SYM("DOCUMENTATION",1253), VVtemp[813]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5055make_plan,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[2120], ECL_NIL, VVtemp[814], VVtemp[815], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5056make_plan,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[2120], ECL_NIL, VVtemp[816], VVtemp[815], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5057make_plan,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[2120], ECL_NIL, VVtemp[817], VVtemp[815], T0);
  L4258undefine_function(VV[2121]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[818]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2121], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[819], ECL_SYM("DOCUMENTATION",1253), VVtemp[820]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[2122]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[821]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2122], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[822], ECL_SYM("DOCUMENTATION",1253), VVtemp[823]) /*  ENSURE-GENERIC-FUNCTION */;
  si_Xmake_special(VV[2123]);
  if (ecl_boundp(cl_env_copy,VV[2123])) {
   goto L3900;
  }
  T0 = VV[2117];
  ecl_cmp_setq(cl_env_copy,VV[2123],T0);
L3900:;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5058make_plan,ECL_NIL,Cblock,3);
   T0 = v2;
  }
  clos_install_method(5, VV[2120], ECL_NIL, VVtemp[674], VVtemp[824], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5062perform_plan,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[2121], VVtemp[489], VV[138], VVtemp[819], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5063perform_plan,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[2121], ECL_NIL, VV[138], VVtemp[825], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5064perform_plan,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[2121], ECL_NIL, VVtemp[789], VVtemp[826], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5065plan_operates_on_p_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[2122], ECL_NIL, VVtemp[827], VVtemp[828], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5066plan_operates_on_p_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[2122], ECL_NIL, VVtemp[829], VVtemp[828], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[831]);
  clos_load_defclass(VV[2126], VVtemp[808], VVtemp[830], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5067initialize_instance,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, ECL_SYM("INITIALIZE-INSTANCE",951), VVtemp[597], VVtemp[832], VVtemp[833], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5068traverse_actions,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(7, VV[1909], ECL_NIL, VV[138], VVtemp[834], T0, ECL_SYM("DOCUMENTATION",1253), VVtemp[835]);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5069traverse_sub_actions,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1910], ECL_NIL, VVtemp[281], VVtemp[836], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5070traverse_sub_actions,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1910], ECL_NIL, VVtemp[581], VVtemp[836], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5071traverse_sub_actions,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1910], ECL_NIL, VVtemp[600], VVtemp[836], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5072traverse_sub_actions,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[1910], ECL_NIL, VVtemp[621], VVtemp[837], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5075plan_actions_va,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(5, VV[2091], ECL_NIL, VVtemp[832], VVtemp[743], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5076required_components,ECL_NIL,Cblock,1);
   T0 = v2;
  }
  clos_install_method(7, VV[1911], ECL_NIL, VV[138], VVtemp[838], T0, ECL_SYM("DOCUMENTATION",1253), VVtemp[839]);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_24, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[840]);
  si_select_package(_ecl_static_24);
  L4258undefine_function(VV[2131]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[841]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2131], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[615], ECL_SYM("DOCUMENTATION",1253), VVtemp[842]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5077operate,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[2131], ECL_NIL, VVtemp[281], VVtemp[843], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5078operate,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[2131], ECL_NIL, VVtemp[581], VVtemp[843], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5079operate,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[2131], ECL_NIL, VVtemp[600], VVtemp[843], T0);
  si_Xmake_special(VV[2132]);
  if (ecl_boundp(cl_env_copy,VV[2132])) {
   goto L3950;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[2132],T0);
L3950:;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5084operate,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[2131], VVtemp[489], VV[1137], VVtemp[844], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5085operate,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[2131], VVtemp[650], VVtemp[621], VVtemp[845], T0);
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC5086operate,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  clos_install_method(5, VV[2131], ECL_NIL, VVtemp[621], VVtemp[846], T0);
  L4258undefine_function(VV[2136]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[847]) /*  MAPC */;
  ecl_cmp_defun(VV[3178]);                        /*  OOS                     */
  {
   cl_object v2;
   T0 = (cl_env_copy->function=(ECL_SYM("DOCUMENTATION",314)->symbol.gfdef))->cfun.entry(2, VV[2131], ECL_SYM("FUNCTION",398)) /*  DOCUMENTATION */;
   v2 = cl_format(3, ECL_NIL, VVtemp[848], T0);
   (cl_env_copy->function=ECL_CONS_CAR(VV[3179]))->cfun.entry(3, v2, VV[2136], ECL_SYM("FUNCTION",398)) /*  (SETF DOCUMENTATION) */;
  }
  si_Xmake_special(VV[2138]);
  if (ecl_boundp(cl_env_copy,VV[2138])) {
   goto L3971;
  }
  T0 = VV[1999];
  ecl_cmp_setq(cl_env_copy,VV[2138],T0);
L3971:;
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5090component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[711], VVtemp[849], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[850]);
  clos_load_defclass(VV[2139], VVtemp[652], ECL_NIL, T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5093component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[851], VVtemp[852], T0);
  L4258undefine_function(VV[2141]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[853]) /*  MAPC */;
  ecl_cmp_defun(VV[3180]);                        /*  MAKE                    */
  L4258undefine_function(VV[2143]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[854]) /*  MAPC */;
  ecl_cmp_defun(VV[3181]);                        /*  LOAD-SYSTEM             */
  L4258undefine_function(VV[2145]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[855]) /*  MAPC */;
  ecl_cmp_defun(VV[3182]);                        /*  LOAD-SYSTEMS*           */
  L4258undefine_function(VV[2147]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[856]) /*  MAPC */;
  ecl_cmp_defun(VV[3183]);                        /*  LOAD-SYSTEMS            */
  L4258undefine_function(VV[2149]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[857]) /*  MAPC */;
  ecl_cmp_defun(VV[3184]);                        /*  COMPILE-SYSTEM          */
  L4258undefine_function(VV[2151]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[858]) /*  MAPC */;
  ecl_cmp_defun(VV[3185]);                        /*  TEST-SYSTEM             */
  L4258undefine_function(VV[2153]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[859]) /*  MAPC */;
  ecl_cmp_defun(VV[3186]);                        /*  COMPONENT-LOADED-P      */
  L4258undefine_function(VV[2155]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[860]) /*  MAPC */;
  ecl_cmp_defun(VV[3187]);                        /*  ALREADY-LOADED-SYSTEMS  */
  L4258undefine_function(VV[2157]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[861]) /*  MAPC */;
  ecl_cmp_defun(VV[3188]);                        /*  REQUIRE-SYSTEM          */
  si_Xmake_special(VV[2160]);
  if (ecl_boundp(cl_env_copy,VV[2160])) {
   goto L4038;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[2160],T0);
L4038:;
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[863]);
  clos_load_defclass(VV[2157], VVtemp[499], VVtemp[862], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5103perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[864], VVtemp[852], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5104perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[865], VVtemp[849], T0);
  T0 = cl_list(2, ECL_SYM("EQL",336), VV[2163]);
  T1 = cl_list(3, ECL_T, T0, ECL_T);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5105resolve_dependency_combination_va,ECL_NIL,Cblock,3);
   T2 = v3;
  }
  clos_install_method(5, VV[1874], ECL_NIL, T1, VVtemp[866], T2);
  L4258undefine_function(VV[2165]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[867]) /*  MAPC */;
  ecl_cmp_defun(VV[3189]);                        /*  MODULE-PROVIDE-ASDF     */
  L4258undefine_function(VV[2169]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[868]) /*  MAPC */;
  ecl_cmp_defun(VV[3190]);                        /*  RESTART-UPGRADED-ASDF   */
  (cl_env_copy->function=ecl_fdefinition(VV[359]))->cfun.entry(2, VV[1614], VV[2169]) /*  REGISTER-HOOK-FUNCTION */;
  L4258undefine_function(VV[1782]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[869]) /*  MAPC */;
  ecl_cmp_defun(VV[3191]);                        /*  MARK-COMPONENT-PRELOADED */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_25, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[870]);
  si_select_package(_ecl_static_25);
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[1615]))->cfun.entry(1, VVtemp[404]) /*  UPGRADING-P */)){
   goto L4074;
  }
  T0 = (ECL_SYM("MUFFLE-WARNING",573)->symbol.gfdef);
  T1 = CONS(ECL_SYM("STYLE-WARNING",830),T0);
  T2 = ecl_list1(T1);
  T3 = CONS(T2,ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6)));
  ecl_bds_bind(cl_env_copy,ECL_SYM("*HANDLER-CLUSTERS*",6),T3); /*  *HANDLER-CLUSTERS* */
  cl_eval(VVtemp[871]);
  ecl_bds_unwind1(cl_env_copy);
L4074:;
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5110__lambda6704_va,ECL_NIL,Cblock,0);
   T0 = v3;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[873]);
  T2 = ecl_list1(T1);
  clos_load_defclass(VV[2174], VVtemp[872], T2, ECL_NIL);
  si_Xmake_special(VV[2177]);
  if (ecl_boundp(cl_env_copy,VV[2177])) {
   goto L4082;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[2177],T0);
L4082:;
  L4258undefine_function(VV[2178]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[874]) /*  MAPC */;
  ecl_cmp_defun(VV[3192]);                        /*  OUTPUT-TRANSLATIONS     */
  L4258undefine_function(VV[2180]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[875]) /*  MAPC */;
  ecl_cmp_defun(VV[3193]);                        /*  SET-OUTPUT-TRANSLATIONS */
  L4258undefine_function(VV[2184]);
  ecl_cmp_defun(VV[3194]);                        /*  (SETF OUTPUT-TRANSLATIONS) */
  L4258undefine_function(VV[2186]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[876]) /*  MAPC */;
  ecl_cmp_defun(VV[3195]);                        /*  OUTPUT-TRANSLATIONS-INITIALIZED-P */
  L4258undefine_function(VV[2188]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[877]) /*  MAPC */;
  ecl_cmp_defun(VV[3196]);                        /*  CLEAR-OUTPUT-TRANSLATIONS */
  (cl_env_copy->function=ecl_fdefinition(VV[1522]))->cfun.entry(1, VV[2188]) /*  REGISTER-CLEAR-CONFIGURATION-HOOK */;
  L4258undefine_function(VV[2190]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[878]) /*  MAPC */;
  ecl_cmp_defun(VV[3197]);                        /*  VALIDATE-OUTPUT-TRANSLATIONS-DIRECTIVE */
  L4258undefine_function(VV[2196]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[879]) /*  MAPC */;
  ecl_cmp_defun(VV[3198]);                        /*  VALIDATE-OUTPUT-TRANSLATIONS-FORM */
  L4258undefine_function(VV[2200]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[880]) /*  MAPC */;
  ecl_cmp_defun(VV[3199]);                        /*  VALIDATE-OUTPUT-TRANSLATIONS-FILE */
  L4258undefine_function(VV[2203]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[881]) /*  MAPC */;
  ecl_cmp_defun(VV[3200]);                        /*  VALIDATE-OUTPUT-TRANSLATIONS-DIRECTORY */
  L4258undefine_function(VV[2205]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[882]) /*  MAPC */;
  ecl_cmp_defun(VV[3201]);                        /*  PARSE-OUTPUT-TRANSLATIONS-STRING */
  ecl_cmp_defun(VV[3202]);                        /*  %COMPUTE-DEFAULT-OUTPUT-TRANSLATIONS-VALUE */
  si_Xmake_special(VV[2216]);
  if (ecl_boundp(cl_env_copy,VV[2216])) {
   goto L4151;
  }
  T0 = L5122_compute_default_output_translations_value();
  ecl_cmp_setq(cl_env_copy,VV[2216],T0);
L4151:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[1615]))->cfun.entry(1, VVtemp[404]) /*  UPGRADING-P */)){
   goto L4157;
  }
  T0 = L5122_compute_default_output_translations_value();
  ecl_cmp_setq(cl_env_copy,VV[2216],T0);
L4157:;
  L4258undefine_function(VV[2217]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[883]) /*  MAPC */;
  ecl_cmp_defun(VV[3203]);                        /*  WRAPPING-OUTPUT-TRANSLATIONS */
  si_Xmake_special(VV[2220]);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(1, VVtemp[884]) /*  PARSE-UNIX-NAMESTRING */;
  ecl_cmp_setq(cl_env_copy,VV[2220],T0);
  si_Xmake_special(VV[2221]);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(1, VVtemp[885]) /*  PARSE-UNIX-NAMESTRING */;
  ecl_cmp_setq(cl_env_copy,VV[2221],T0);
  L4258undefine_function(VV[2222]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[886]) /*  MAPC */;
  ecl_cmp_defun(VV[3204]);                        /*  USER-OUTPUT-TRANSLATIONS-PATHNAME */
  L4258undefine_function(VV[2224]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[887]) /*  MAPC */;
  ecl_cmp_defun(VV[3205]);                        /*  SYSTEM-OUTPUT-TRANSLATIONS-PATHNAME */
  L4258undefine_function(VV[2226]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[888]) /*  MAPC */;
  ecl_cmp_defun(VV[3206]);                        /*  USER-OUTPUT-TRANSLATIONS-DIRECTORY-PATHNAME */
  L4258undefine_function(VV[2228]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[889]) /*  MAPC */;
  ecl_cmp_defun(VV[3207]);                        /*  SYSTEM-OUTPUT-TRANSLATIONS-DIRECTORY-PATHNAME */
  L4258undefine_function(VV[2230]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[890]) /*  MAPC */;
  ecl_cmp_defun(VV[3208]);                        /*  ENVIRONMENT-OUTPUT-TRANSLATIONS */
  L4258undefine_function(VV[2233]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[891]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(5, VV[2233], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[892]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[2234]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[893]) /*  MAPC */;
  ecl_cmp_defun(VV[3209]);                        /*  INHERIT-OUTPUT-TRANSLATIONS */
  L4258undefine_function(VV[2238]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[894]) /*  MAPC */;
  ecl_cmp_defun(VV[3210]);                        /*  PROCESS-OUTPUT-TRANSLATIONS-DIRECTIVE */
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5131process_output_translations,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2233], ECL_NIL, VVtemp[514], VVtemp[895], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5132process_output_translations,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2233], ECL_NIL, VVtemp[896], VVtemp[897], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5133process_output_translations,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2233], ECL_NIL, VVtemp[512], VVtemp[898], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5134process_output_translations,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2233], ECL_NIL, VVtemp[436], VVtemp[899], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5135process_output_translations,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2233], ECL_NIL, VVtemp[900], VVtemp[901], T0);
  L4258undefine_function(VV[2246]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[902]) /*  MAPC */;
  ecl_cmp_defun(VV[3211]);                        /*  COMPUTE-OUTPUT-TRANSLATIONS */
  si_Xmake_special(VV[2249]);
  if (ecl_boundp(cl_env_copy,VV[2249])) {
   goto L4241;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[2249],T0);
L4241:;
  L4258undefine_function(VV[2250]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[903]) /*  MAPC */;
  ecl_cmp_defun(VV[3212]);                        /*  INITIALIZE-OUTPUT-TRANSLATIONS */
  L4258undefine_function(VV[2252]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[904]) /*  MAPC */;
  ecl_cmp_defun(VV[3213]);                        /*  DISABLE-OUTPUT-TRANSLATIONS */
  L4258undefine_function(VV[2255]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[905]) /*  MAPC */;
  ecl_cmp_defun(VV[3214]);                        /*  ENSURE-OUTPUT-TRANSLATIONS */
  L4258undefine_function(VV[2257]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[906]) /*  MAPC */;
  ecl_cmp_defun(VV[3215]);                        /*  APPLY-OUTPUT-TRANSLATIONS */
  T0 = VV[2257];
  ecl_cmp_setq(cl_env_copy,VV[655],T0);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_26, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[907]);
  si_select_package(_ecl_static_26);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5142__lambda6865_va,ECL_NIL,Cblock,0);
   T0 = v3;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[908]);
  T2 = ecl_list1(T1);
  clos_load_defclass(VV[2260], VVtemp[872], T2, ECL_NIL);
  si_Xmake_special(VV[2263]);
  if (ecl_boundp(cl_env_copy,VV[2263])) {
   goto L4281;
  }
  T0 = VVtemp[909];
  ecl_cmp_setq(cl_env_copy,VV[2263],T0);
L4281:;
  si_Xmake_special(VV[2264]);
  if (ecl_boundp(cl_env_copy,VV[2264])) {
   goto L4288;
  }
  T0 = ecl_cmp_symbol_value(cl_env_copy,VV[2263]);
  ecl_cmp_setq(cl_env_copy,VV[2264],T0);
L4288:;
  si_Xmake_special(VV[2265]);
  if (ecl_boundp(cl_env_copy,VV[2265])) {
   goto L4295;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[2265],T0);
L4295:;
  si_Xmake_special(VV[2266]);
  if (ecl_boundp(cl_env_copy,VV[2266])) {
   goto L4302;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[2266],T0);
L4302:;
  L4258undefine_function(VV[2267]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[910]) /*  MAPC */;
  ecl_cmp_defun(VV[3216]);                        /*  SOURCE-REGISTRY-INITIALIZED-P */
  L4258undefine_function(VV[2269]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[911]) /*  MAPC */;
  ecl_cmp_defun(VV[3217]);                        /*  CLEAR-SOURCE-REGISTRY   */
  (cl_env_copy->function=ecl_fdefinition(VV[1522]))->cfun.entry(1, VV[2269]) /*  REGISTER-CLEAR-CONFIGURATION-HOOK */;
  si_Xmake_special(VV[2271]);
  T0 = cl_make_pathname(8, ECL_SYM("DIRECTORY",1250), ECL_NIL, ECL_SYM("NAME",1309), ecl_cmp_symbol_value(cl_env_copy,VV[632]), ECL_SYM("TYPE",1356), VV[1821], ECL_SYM("VERSION",1364), ECL_SYM("NEWEST",1312));
  ecl_cmp_setq(cl_env_copy,VV[2271],T0);
  L4258undefine_function(VV[2272]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[912]) /*  MAPC */;
  ecl_cmp_defun(VV[3218]);                        /*  DIRECTORY-ASD-FILES     */
  L4258undefine_function(VV[2274]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[913]) /*  MAPC */;
  ecl_cmp_defun(VV[3219]);                        /*  COLLECT-ASDS-IN-DIRECTORY */
  si_Xmake_special(VV[2276]);
  if (ecl_boundp(cl_env_copy,VV[2276])) {
   goto L4340;
  }
  T0 = ECL_T;
  ecl_cmp_setq(cl_env_copy,VV[2276],T0);
L4340:;
  L4258undefine_function(VV[2277]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[914]) /*  MAPC */;
  ecl_cmp_defun(VV[3220]);                        /*  PROCESS-SOURCE-REGISTRY-CACHE */
  L4258undefine_function(VV[2283]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[915]) /*  MAPC */;
  ecl_cmp_defun(VV[3221]);                        /*  COLLECT-SUB*DIRECTORIES-ASD-FILES */
  L4258undefine_function(VV[2288]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[916]) /*  MAPC */;
  ecl_cmp_defun(VV[3222]);                        /*  VALIDATE-SOURCE-REGISTRY-DIRECTIVE */
  L4258undefine_function(VV[2300]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[917]) /*  MAPC */;
  ecl_cmp_defun(VV[3223]);                        /*  VALIDATE-SOURCE-REGISTRY-FORM */
  L4258undefine_function(VV[2303]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[918]) /*  MAPC */;
  ecl_cmp_defun(VV[3224]);                        /*  VALIDATE-SOURCE-REGISTRY-FILE */
  L4258undefine_function(VV[2306]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[919]) /*  MAPC */;
  ecl_cmp_defun(VV[3225]);                        /*  VALIDATE-SOURCE-REGISTRY-DIRECTORY */
  L4258undefine_function(VV[2308]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[920]) /*  MAPC */;
  ecl_cmp_defun(VV[3226]);                        /*  PARSE-SOURCE-REGISTRY-STRING */
  L4258undefine_function(VV[2316]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[921]) /*  MAPC */;
  ecl_cmp_defun(VV[3227]);                        /*  REGISTER-ASD-DIRECTORY  */
  ecl_cmp_defun(VV[3228]);                        /*  %COMPUTE-DEFAULT-SOURCE-REGISTRIES-VALUE */
  si_Xmake_special(VV[2321]);
  if (ecl_boundp(cl_env_copy,VV[2321])) {
   goto L4398;
  }
  T0 = L5160_compute_default_source_registries_value();
  ecl_cmp_setq(cl_env_copy,VV[2321],T0);
L4398:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[1615]))->cfun.entry(1, VVtemp[922]) /*  UPGRADING-P */)){
   goto L4404;
  }
  T0 = L5160_compute_default_source_registries_value();
  ecl_cmp_setq(cl_env_copy,VV[2321],T0);
L4404:;
  si_Xmake_special(VV[2322]);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(1, VVtemp[923]) /*  PARSE-UNIX-NAMESTRING */;
  ecl_cmp_setq(cl_env_copy,VV[2322],T0);
  si_Xmake_special(VV[2323]);
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[590]))->cfun.entry(1, VVtemp[924]) /*  PARSE-UNIX-NAMESTRING */;
  ecl_cmp_setq(cl_env_copy,VV[2323],T0);
  L4258undefine_function(VV[2324]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[925]) /*  MAPC */;
  ecl_cmp_defun(VV[3229]);                        /*  WRAPPING-SOURCE-REGISTRY */
  L4258undefine_function(VV[2326]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[926]) /*  MAPC */;
  ecl_cmp_defun(VV[3230]);                        /*  DEFAULT-USER-SOURCE-REGISTRY */
  L4258undefine_function(VV[2331]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[927]) /*  MAPC */;
  ecl_cmp_defun(VV[3231]);                        /*  DEFAULT-SYSTEM-SOURCE-REGISTRY */
  L4258undefine_function(VV[2336]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[928]) /*  MAPC */;
  ecl_cmp_defun(VV[3232]);                        /*  USER-SOURCE-REGISTRY    */
  L4258undefine_function(VV[2338]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[929]) /*  MAPC */;
  ecl_cmp_defun(VV[3233]);                        /*  SYSTEM-SOURCE-REGISTRY  */
  L4258undefine_function(VV[2340]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[930]) /*  MAPC */;
  ecl_cmp_defun(VV[3234]);                        /*  USER-SOURCE-REGISTRY-DIRECTORY */
  L4258undefine_function(VV[2342]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[931]) /*  MAPC */;
  ecl_cmp_defun(VV[3235]);                        /*  SYSTEM-SOURCE-REGISTRY-DIRECTORY */
  L4258undefine_function(VV[2344]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[932]) /*  MAPC */;
  ecl_cmp_defun(VV[3236]);                        /*  ENVIRONMENT-SOURCE-REGISTRY */
  L4258undefine_function(VV[2347]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[933]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(5, VV[2347], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[934]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[2348]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[935]) /*  MAPC */;
  ecl_cmp_defun(VV[3237]);                        /*  INHERIT-SOURCE-REGISTRY */
  L4258undefine_function(VV[2351]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[936]) /*  MAPC */;
  ecl_cmp_defun(VV[3238]);                        /*  PROCESS-SOURCE-REGISTRY-DIRECTIVE */
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5171process_source_registry,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2347], ECL_NIL, VVtemp[514], VVtemp[937], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5172process_source_registry,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2347], ECL_NIL, VVtemp[896], VVtemp[938], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5173process_source_registry,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2347], ECL_NIL, VVtemp[512], VVtemp[939], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5174process_source_registry,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2347], ECL_NIL, VVtemp[436], VVtemp[937], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5175process_source_registry,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2347], ECL_NIL, VVtemp[900], VVtemp[940], T0);
  L4258undefine_function(VV[2359]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[941]) /*  MAPC */;
  ecl_cmp_defun(VV[3239]);                        /*  FLATTEN-SOURCE-REGISTRY */
  L4258undefine_function(VV[2363]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[942]) /*  MAPC */;
  ecl_cmp_defun(VV[3240]);                        /*  COMPUTE-SOURCE-REGISTRY */
  L4258undefine_function(VV[2368]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[943]) /*  MAPC */;
  ecl_cmp_defun(VV[3241]);                        /*  INITIALIZE-SOURCE-REGISTRY */
  L4258undefine_function(VV[2370]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[944]) /*  MAPC */;
  ecl_cmp_defun(VV[3242]);                        /*  ENSURE-SOURCE-REGISTRY  */
  L4258undefine_function(VV[2372]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[945]) /*  MAPC */;
  ecl_cmp_defun(VV[3243]);                        /*  SYSDEF-SOURCE-REGISTRY-SEARCH */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_27, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[946]);
  si_select_package(_ecl_static_27);
  L4258undefine_function(VV[2374]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[947]) /*  MAPC */;
  ecl_cmp_defun(VV[3244]);                        /*  DETERMINE-SYSTEM-DIRECTORY */
  si_Xmake_special(VV[2378]);
  if (ecl_boundp(cl_env_copy,VV[2378])) {
   goto L4533;
  }
  T0 = VV[1993];
  ecl_cmp_setq(cl_env_copy,VV[2378],T0);
L4533:;
  L4258undefine_function(VV[2379]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[948]) /*  MAPC */;
  ecl_cmp_defun(VV[3245]);                        /*  CLASS-FOR-TYPE          */
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5188__lambda7252_va,ECL_NIL,Cblock,0);
   T0 = v3;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[949]);
  T2 = cl_list(3, T1, VVtemp[950], VVtemp[951]);
  clos_load_defclass(VV[2383], VVtemp[440], T2, ECL_NIL);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5190__lambda7256_va,ECL_NIL,Cblock,0);
   T0 = v3;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[952]);
  T2 = cl_list(3, T1, VVtemp[953], VVtemp[954]);
  clos_load_defclass(VV[2389], VVtemp[440], T2, ECL_NIL);
  L4258undefine_function(VV[2395]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[955]) /*  MAPC */;
  ecl_cmp_defun(VV[3246]);                        /*  SYSDEF-ERROR-COMPONENT  */
  L4258undefine_function(VV[2398]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[956]) /*  MAPC */;
  ecl_cmp_defun(VV[3247]);                        /*  CHECK-COMPONENT-INPUT   */
  L4258undefine_function(VV[2403]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[957]) /*  MAPC */;
  ecl_cmp_defun(VV[3248]);                        /*  NORMALIZE-VERSION       */
  ecl_cmp_defun(VV[3249]);                        /*  %COMPUTE-+ASDF-METHODS+-VALUE */
  si_Xmake_special(VV[2419]);
  if (ecl_boundp(cl_env_copy,VV[2419])) {
   goto L4575;
  }
  T0 = L5196_compute__asdf_methods__value();
  ecl_cmp_setq(cl_env_copy,VV[2419],T0);
L4575:;
  if (Null((cl_env_copy->function=ecl_fdefinition(VV[1615]))->cfun.entry(1, VVtemp[404]) /*  UPGRADING-P */)){
   goto L4581;
  }
  T0 = L5196_compute__asdf_methods__value();
  ecl_cmp_setq(cl_env_copy,VV[2419],T0);
L4581:;
  L4258undefine_function(VV[2420]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[958]) /*  MAPC */;
  ecl_cmp_defun(VV[3250]);                        /*  %REMOVE-COMPONENT-INLINE-METHODS */
  L4258undefine_function(VV[2424]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[959]) /*  MAPC */;
  ecl_cmp_defun(VV[3251]);                        /*  %DEFINE-COMPONENT-INLINE-METHODS */
  L4258undefine_function(VV[2427]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[960]) /*  MAPC */;
  ecl_cmp_defun(VV[3252]);                        /*  %REFRESH-COMPONENT-INLINE-METHODS */
  L4258undefine_function(VV[2429]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[961]) /*  MAPC */;
  ecl_cmp_defun(VV[3253]);                        /*  PARSE-DEPENDENCY-DEF    */
  L4258undefine_function(VV[2437]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[962]) /*  MAPC */;
  ecl_cmp_defun(VV[3254]);                        /*  PARSE-DEPENDENCY-DEFS   */
  L4258undefine_function(VV[2439]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[963]) /*  MAPC */;
  ecl_cmp_defun(VV[3255]);                        /*  PARSE-COMPONENT-FORM    */
  L4258undefine_function(VV[2465]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[964]) /*  MAPC */;
  ecl_cmp_defun(VV[3256]);                        /*  REGISTER-SYSTEM-DEFINITION */
  ecl_cmp_defmacro(VV[3257]);                     /*  DEFSYSTEM               */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_28, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[965]);
  si_select_package(_ecl_static_28);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[968]);
  clos_load_defclass(VV[2475], VVtemp[966], VVtemp[967], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[969]);
  clos_load_defclass(VV[2476], VVtemp[598], ECL_NIL, T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[972]);
  clos_load_defclass(VV[2477], VVtemp[970], VVtemp[971], T0);
  clos_load_defclass(VV[2478], VVtemp[499], VVtemp[973], ECL_NIL);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5208prologue_code_va,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2479], ECL_NIL, VV[138], VVtemp[974], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5209epilogue_code_va,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2480], ECL_NIL, VV[138], VVtemp[974], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5210no_uiop_va,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2481], ECL_NIL, VV[138], VVtemp[974], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5211prefix_lisp_object_files_va,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2482], ECL_NIL, VV[138], VVtemp[974], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5212postfix_lisp_object_files_va,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2483], ECL_NIL, VV[138], VVtemp[974], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5213extra_object_files_va,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2484], ECL_NIL, VV[138], VVtemp[974], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5214extra_build_args_va,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2485], ECL_NIL, VV[138], VVtemp[974], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[976]);
  clos_load_defclass(VV[2486], VVtemp[975], ECL_NIL, T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[978]);
  clos_load_defclass(VV[2487], VVtemp[975], VVtemp[977], T0);
  L4258undefine_function(VV[2488]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[979]) /*  MAPC */;
  ecl_cmp_defun(VV[3258]);                        /*  OPERATION-MONOLITHIC-P  */
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5218component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[980], VVtemp[981], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[983]);
  clos_load_defclass(VV[2495], VVtemp[975], VVtemp[982], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[986]);
  clos_load_defclass(VV[2496], VVtemp[984], VVtemp[985], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[989]);
  clos_load_defclass(VV[2497], VVtemp[987], VVtemp[988], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[992]);
  clos_load_defclass(VV[2498], VVtemp[990], VVtemp[991], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[995]);
  clos_load_defclass(VV[2499], VVtemp[993], VVtemp[994], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[997]);
  clos_load_defclass(VV[2500], VVtemp[987], VVtemp[996], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1000]);
  clos_load_defclass(VV[2501], VVtemp[998], VVtemp[999], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1003]);
  clos_load_defclass(VV[2502], VVtemp[1001], VVtemp[1002], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1005]);
  clos_load_defclass(VV[2503], VVtemp[1004], ECL_NIL, T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1008]);
  clos_load_defclass(VV[2504], VVtemp[1006], VVtemp[1007], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1011]);
  clos_load_defclass(VV[2505], VVtemp[1009], VVtemp[1010], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1013]);
  clos_load_defclass(VV[2506], VVtemp[1012], VVtemp[1010], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1016]);
  clos_load_defclass(VV[2507], VVtemp[1014], VVtemp[1015], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1019]);
  clos_load_defclass(VV[2508], VVtemp[1017], VVtemp[1018], T0);
  L4258undefine_function(VV[2509]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1020]) /*  MAPC */;
  ecl_cmp_defun(VV[3259]);                        /*  BUNDLE-PATHNAME-TYPE    */
  L4258undefine_function(VV[2530]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1021]) /*  MAPC */;
  ecl_cmp_defun(VV[3260]);                        /*  BUNDLE-OUTPUT-FILES     */
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5221output_files_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1962], ECL_NIL, VVtemp[1022], VVtemp[1023], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1025]);
  clos_load_defclass(VV[2537], VVtemp[467], VVtemp[1024], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1027]);
  clos_load_defclass(VV[2538], VVtemp[499], VVtemp[1026], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1029]);
  clos_load_defclass(VV[2539], VVtemp[499], VVtemp[1028], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5222initialize_instance,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, ECL_SYM("INITIALIZE-INSTANCE",951), VVtemp[597], VVtemp[975], VVtemp[1030], T0);
  L4258undefine_function(VV[2547]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1031]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(5, VV[2547], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[414]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[2548]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1032]) /*  MAPC */;
  ecl_cmp_defun(VV[3261]);                        /*  USER-SYSTEM-P           */
  si_do_deftype(3, VV[2550], VVtemp[1033], VVtemp[1034]);
  L4258undefine_function(VV[2551]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1035]) /*  MAPC */;
  ecl_cmp_defun(VV[3262]);                        /*  DIRECT-DEPENDENCY-FILES */
  L4258undefine_function(VV[2555]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1036]) /*  MAPC */;
  ecl_cmp_defun(VV[3263]);                        /*  PATHNAME-TYPE-EQUAL-FUNCTION */
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5229input_files_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[980], VVtemp[1023], T0);
  L4258undefine_function(VV[2559]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1037]) /*  MAPC */;
  ecl_cmp_defun(VV[3264]);                        /*  SELECT-BUNDLE-OPERATION */
  L4258undefine_function(VV[2563]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1038]) /*  MAPC */;
  ecl_cmp_defun(VV[3265]);                        /*  MAKE-BUILD              */
  L4258undefine_function(VV[2570]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1039]) /*  MAPC */;
  ecl_cmp_defun(VV[3266]);                        /*  BUNDLE-SYSTEM           */
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5236component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[1040], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5237input_files_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[1040], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5238perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1040], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5239mark_operation_done_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1972], VVtemp[597], VVtemp[1040], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5241trivial_system_p_va,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2547], ECL_NIL, VVtemp[499], VVtemp[1041], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5242input_files_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[1042], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5243perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1043], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5244perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1044], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5245perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1042], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5246trivial_system_p_va,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2547], ECL_NIL, VVtemp[1045], VVtemp[1041], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5247perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1046], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5248perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1047], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5249perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1048], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5250perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1049], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5251component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[1050], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5252output_files_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1962], ECL_NIL, VVtemp[1048], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5253output_files_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1962], ECL_NIL, VVtemp[1051], VVtemp[981], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5256perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1051], VVtemp[981], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5257input_files_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[1052], VVtemp[981], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5258perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1052], VVtemp[981], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5261component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1941], ECL_NIL, VVtemp[1053], VVtemp[981], T0);
  L4258undefine_function(VV[2581]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1054]) /*  MAPC */;
  ecl_cmp_defun(VV[3267]);                        /*  SYSTEM-MODULE-PATHNAME  */
  L4258undefine_function(VV[2584]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1055]) /*  MAPC */;
  ecl_cmp_defun(VV[3268]);                        /*  MAKE-PREBUILT-SYSTEM    */
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5267component_depends_on_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1941], VVtemp[489], VVtemp[1056], VVtemp[1023], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5268perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1057], VVtemp[1023], T0);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_29, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[1058]);
  si_select_package(_ecl_static_29);
  clos_load_defclass(VV[2593], VVtemp[975], VVtemp[1059], ECL_NIL);
  clos_load_defclass(VV[2594], VVtemp[993], ECL_NIL, ECL_NIL);
  clos_load_defclass(VV[2595], VVtemp[998], ECL_NIL, ECL_NIL);
  clos_load_defclass(VV[2596], VVtemp[993], ECL_NIL, ECL_NIL);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1061]);
  clos_load_defclass(VV[2597], VVtemp[1060], ECL_NIL, T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1064]);
  clos_load_defclass(VV[2598], VVtemp[1062], VVtemp[1063], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1066]);
  clos_load_defclass(VV[2599], VVtemp[1065], VVtemp[1063], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1069]);
  clos_load_defclass(VV[2600], VVtemp[1067], VVtemp[1068], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1071]);
  clos_load_defclass(VV[2601], VVtemp[1070], ECL_NIL, T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1073]);
  clos_load_defclass(VV[2602], VVtemp[1062], VVtemp[1072], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1074]);
  clos_load_defclass(VV[2603], VVtemp[1065], VVtemp[1072], T0);
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1076]);
  clos_load_defclass(VV[2604], VVtemp[1067], VVtemp[1075], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5270input_files_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1963], ECL_NIL, VVtemp[1077], VVtemp[1078], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5271output_files_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1962], ECL_NIL, VVtemp[1079], VVtemp[1080], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5272perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1077], VVtemp[1080], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5273perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1081], VVtemp[1080], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5274perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1079], VVtemp[1080], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5275perform_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[1982], ECL_NIL, VVtemp[1082], VVtemp[1080], T0);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_30, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[1083]);
  si_select_package(_ecl_static_30);
  si_Xmake_special(VV[2608]);
  T0 = VVtemp[1084];
  ecl_cmp_setq(cl_env_copy,VV[2608],T0);
  L4258undefine_function(VV[2609]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1085]) /*  MAPC */;
  ecl_cmp_defun(VV[3269]);                        /*  INITIAL-PACKAGE-INFERRED-SYSTEMS-TABLE */
  si_Xmake_special(VV[2611]);
  if (ecl_boundp(cl_env_copy,VV[2611])) {
   goto L4871;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[2609]))->cfun.entry(0) /*  INITIAL-PACKAGE-INFERRED-SYSTEMS-TABLE */;
  ecl_cmp_setq(cl_env_copy,VV[2611],T0);
L4871:;
  T0 = cl_list(2, ECL_SYM("DOCUMENTATION",1253), VVtemp[1086]);
  clos_load_defclass(VV[2612], VVtemp[499], ECL_NIL, T0);
  clos_load_defclass(VV[2613], VVtemp[1087], ECL_NIL, ECL_NIL);
  L4258undefine_function(VV[2614]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1088]) /*  MAPC */;
  ecl_cmp_defun(VV[3270]);                        /*  DEFPACKAGE-FORM-P       */
  L4258undefine_function(VV[2616]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1089]) /*  MAPC */;
  ecl_cmp_defun(VV[3271]);                        /*  STREAM-DEFPACKAGE-FORM  */
  L4258undefine_function(VV[2618]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1090]) /*  MAPC */;
  ecl_cmp_defun(VV[3272]);                        /*  FILE-DEFPACKAGE-FORM    */
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5282__lambda8055_va,ECL_NIL,Cblock,0);
   T0 = v3;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[1091]);
  T2 = cl_list(3, T1, VVtemp[1092], VVtemp[535]);
  clos_load_defclass(VV[2621], VVtemp[440], T2, ECL_NIL);
  L4258undefine_function(VV[2626]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1093]) /*  MAPC */;
  ecl_cmp_defun(VV[3273]);                        /*  PACKAGE-DEPENDENCIES    */
  L4258undefine_function(VV[2635]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1094]) /*  MAPC */;
  ecl_cmp_defun(VV[3274]);                        /*  PACKAGE-DESIGNATOR-NAME */
  L4258undefine_function(VV[2638]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1095]) /*  MAPC */;
  ecl_cmp_defun(VV[3275]);                        /*  REGISTER-SYSTEM-PACKAGES */
  L4258undefine_function(VV[2640]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1096]) /*  MAPC */;
  ecl_cmp_defun(VV[3276]);                        /*  PACKAGE-NAME-SYSTEM     */
  L4258undefine_function(VV[2642]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1097]) /*  MAPC */;
  ecl_cmp_defun(VV[3277]);                        /*  PACKAGE-INFERRED-SYSTEM-FILE-DEPENDENCIES */
  L4258undefine_function(VV[2644]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1098]) /*  MAPC */;
  ecl_cmp_defun(VV[3278]);                        /*  SAME-PACKAGE-INFERRED-SYSTEM-P */
  L4258undefine_function(VV[2646]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1099]) /*  MAPC */;
  ecl_cmp_defun(VV[3279]);                        /*  SYSDEF-PACKAGE-INFERRED-SYSTEM-SEARCH */
  T0 = cl_adjoin(2, VV[2646], ecl_cmp_symbol_value(cl_env_copy,VV[1808]));
  ecl_cmp_setq(cl_env_copy,VV[1808],T0);
  T0 = L4198find_symbol_(3, VV[2649], VV[2650], ECL_NIL);
  T1 = cl_remove(2, T0, ecl_cmp_symbol_value(cl_env_copy,VV[1808]));
  ecl_cmp_setq(cl_env_copy,VV[1808],T1);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_31, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[1100]);
  si_select_package(_ecl_static_31);
  L4258undefine_function(VV[2651]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1101]) /*  MAPC */;
  ecl_cmp_defun(VV[3280]);                        /*  LOAD-SYSDEF             */
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_32, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[1102]);
  si_select_package(_ecl_static_32);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5293__lambda8162_va,ECL_NIL,Cblock,0);
   T0 = v3;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[1103]);
  T2 = cl_list(3, T1, VVtemp[1104], VVtemp[1105]);
  clos_load_defclass(VV[2654], VVtemp[62], T2, ECL_NIL);
  clos_load_defclass(VV[2660], VVtemp[1106], ECL_NIL, ECL_NIL);
  clos_load_defclass(VV[2661], VVtemp[1107], ECL_NIL, ECL_NIL);
  clos_load_defclass(VV[2662], VVtemp[1107], ECL_NIL, ECL_NIL);
  L4258undefine_function(VV[2663]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1108]) /*  MAPC */;
  ecl_cmp_defun(VV[3281]);                        /*  COMPONENT-LOAD-DEPENDENCIES */
  L4258undefine_function(VV[2665]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1109]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2665], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[598], ECL_SYM("DOCUMENTATION",1253), VVtemp[1110]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5295operation_forced_va,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2665], ECL_NIL, VVtemp[598], VVtemp[1111], T0);
  L4258undefine_function(VV[2667]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1112]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2667], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[598], ECL_SYM("DOCUMENTATION",1253), VVtemp[1113]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VV[2668]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1114]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2668], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[598], ECL_SYM("DOCUMENTATION",1253), VVtemp[1115]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VVtemp[1116]);
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VVtemp[1116], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[1117], ECL_SYM("DOCUMENTATION",1253), VVtemp[1118]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VVtemp[1119]);
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VVtemp[1119], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[1117], ECL_SYM("DOCUMENTATION",1253), VVtemp[1120]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5296operation_on_warnings_va,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2667], ECL_NIL, VVtemp[598], VVtemp[1111], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5297operation_on_failure_va,ECL_NIL,Cblock,1);
   T0 = v3;
  }
  clos_install_method(5, VV[2668], ECL_NIL, VVtemp[598], VVtemp[1111], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5298operation_on_warnings_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VVtemp[1116], ECL_NIL, VVtemp[606], VVtemp[1121], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5299operation_on_failure_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VVtemp[1119], ECL_NIL, VVtemp[606], VVtemp[1121], T0);
  L4258undefine_function(VV[2669]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1122]) /*  MAPC */;
  ecl_cmp_defun(VV[3282]);                        /*  SYSTEM-DEFINITION-PATHNAME */
  L4258undefine_function(VV[2671]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1123]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(7, VV[2671], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[615], ECL_SYM("DOCUMENTATION",1253), VVtemp[1124]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5301traverse,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[2671], ECL_NIL, VVtemp[281], VVtemp[1125], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5302traverse,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[2671], ECL_NIL, VVtemp[581], VVtemp[1125], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5303traverse,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[2671], ECL_NIL, VVtemp[600], VVtemp[1125], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5304traverse,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[2671], ECL_NIL, VVtemp[621], VVtemp[1126], T0);
  L4258undefine_function(VV[2672]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1127]) /*  MAPC */;
  ecl_cmp_defun(VV[3283]);                        /*  ENABLE-ASDF-BINARY-LOCATIONS-COMPATIBILITY */
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5306operate,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[2131], VVtemp[650], VV[1137], VVtemp[1128], T0);
  L4258undefine_function(VV[2680]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1129]) /*  MAPC */;
  ecl_cmp_defun(VV[3284]);                        /*  RUN-SHELL-COMMAND       */
  si_Xmake_special(VV[2686]);
  if (ecl_boundp(cl_env_copy,VV[2686])) {
   goto L5039;
  }
  T0 = ECL_NIL;
  ecl_cmp_setq(cl_env_copy,VV[2686],T0);
L5039:;
  L4258undefine_function(VV[2687]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1130]) /*  MAPC */;
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(5, VV[2687], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[1131]) /*  ENSURE-GENERIC-FUNCTION */;
  L4258undefine_function(VVtemp[1132]);
  (cl_env_copy->function=(ECL_SYM("ENSURE-GENERIC-FUNCTION",946)->symbol.gfdef))->cfun.entry(5, VVtemp[1132], VV[1128], ECL_T, ECL_SYM("LAMBDA-LIST",1002), VVtemp[1133]) /*  ENSURE-GENERIC-FUNCTION */;
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5309component_property_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  clos_install_method(5, VV[2687], ECL_NIL, VVtemp[461], VVtemp[1134], T0);
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC5310component_property_va,ECL_NIL,Cblock,3);
   T0 = v3;
  }
  clos_install_method(5, VVtemp[1132], ECL_NIL, VVtemp[1135], VVtemp[1136], T0);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_33, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[1137]);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_34, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[1138]);
  (cl_env_copy->function=(VV[0]->symbol.gfdef))->cfun.entry(12, _ecl_static_35, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL, ECL_NIL) /*  DODEFPACKAGE */;
  cl_apply(2, VV[167], VVtemp[1139]);
  si_select_package(_ecl_static_35);
  {
   cl_object v3;
   v3 = VVtemp[1140];
   goto L5066;
L5065:;
   {
    cl_object v4s;
    v4s = ecl_car(v3);
    (cl_env_copy->function=ecl_fdefinition(VV[1791]))->cfun.entry(3, v4s, ECL_SYM("VERSION",1364), ecl_cmp_symbol_value(cl_env_copy,VV[1608])) /*  REGISTER-PRELOADED-SYSTEM */;
   }
   v3 = ecl_cdr(v3);
L5066:;
   if (Null(v3)){
    goto L5073;
   }
   goto L5065;
L5073:;
  }
  T0 = cl_adjoin(2, VV[2165], ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*MODULE-PROVIDER-FUNCTIONS*",44)));
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*MODULE-PROVIDER-FUNCTIONS*",44),T0);
  T0 = cl_adjoin(6, VVtemp[1141], ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*LOAD-HOOKS*",1028)), ECL_SYM("TEST",1353), ECL_SYM("EQUAL",337), ECL_SYM("KEY",1297), ECL_SYM("CAR",182));
  ecl_cmp_setq(cl_env_copy,ECL_SYM("*LOAD-HOOKS*",1028),T0);
  si_Xmake_special(VV[2689]);
  if (ecl_boundp(cl_env_copy,VV[2689])) {
   goto L5080;
  }
  T0 = cl_make_hash_table(0);
  ecl_cmp_setq(cl_env_copy,VV[2689],T0);
L5080:;
  si_hash_set(VV[2165], ecl_cmp_symbol_value(cl_env_copy,VV[2689]), VV[2165]);
  ecl_cmp_defun(VV[3285]);                        /*  WRAP-MODULE-PROVIDER    */
  ecl_cmp_defun(VV[3286]);                        /*  WRAP-MODULE-PROVIDER-FUNCTION */
  {
   cl_object v4;
   v4 = ecl_fdefinition(VV[2692]);
   {
    cl_object v5;
    cl_object v6;
    cl_object v7;
    {
     cl_object v8;
     v8 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*MODULE-PROVIDER-FUNCTIONS*",44));
     if (ecl_unlikely(!ECL_LISTP(v8))) FEtype_error_list(v8);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v5 = v8;
    }
    v6 = ECL_NIL;
    v7 = v5;
    {
     cl_object v8;
     cl_object v9;
     v8 = ecl_list1(ECL_NIL);
     v9 = v8;
L5103:;
     if (!(ecl_endp(v7))){
      goto L5105;
     }
     goto L5104;
L5105:;
     v6 = ECL_CONS_CAR(v7);
     {
      cl_object v10;
      v10 = ECL_CONS_CDR(v7);
      if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v7 = v10;
     }
     {
      cl_object v10;
      v10 = v9;
      if (ecl_unlikely(ECL_ATOM(v10))) FEtype_error_cons(v10);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v10;
     }
     T1 = ecl_function_dispatch(cl_env_copy,v4)(1, v6);
     v9 = ecl_list1(T1);
     (ECL_CONS_CDR(T0)=v9,T0);
     goto L5103;
L5104:;
     T0 = ecl_cdr(v8);
     ecl_cmp_setq(cl_env_copy,ECL_SYM("*MODULE-PROVIDER-FUNCTIONS*",44),T0);
     goto L5094;
    }
   }
  }
L5094:;
  {
   cl_object v4;
   v4 = VVtemp[1142];
   goto L5125;
L5124:;
   {
    cl_object v5f;
    v5f = ecl_car(v4);
    T0 = cl_adjoin(2, v5f, ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*FEATURES*",36)));
    ecl_cmp_setq(cl_env_copy,ECL_SYM("*FEATURES*",36),T0);
   }
   v4 = ecl_cdr(v4);
L5125:;
   if (Null(v4)){
    goto L5133;
   }
   goto L5124;
L5133:;
  }
  cl_provide(VV[1803]);
  cl_provide(VVtemp[1143]);
  (cl_env_copy->function=ecl_fdefinition(VV[1628]))->cfun.entry(0) /*  CLEANUP-UPGRADED-ASDF */;
  if (Null(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*LOAD-VERBOSE*",41)))){
   goto L5138;
  }
  T0 = (cl_env_copy->function=ecl_fdefinition(VV[1600]))->cfun.entry(0) /*  ASDF-VERSION */;
  (cl_env_copy->function=ecl_fdefinition(VV[1611]))->cfun.entry(2, VVtemp[1144], T0) /*  ASDF-MESSAGE */;
L5138:;
 }
}
