/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/lsp/pprint.lsp                      */
#include <ecl/ecl-cmp.h>
#include "clos/pprint.eclh"
/* local function LAMBDA6                                                     */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2543__lambda6()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = cl_make_string(1, ECL_SYM_VAL(cl_env_copy,VV[2]));
 return value0;
}
static cl_object LC2543__lambda6_va(cl_narg narg, ...)
{
 return LC2543__lambda6();
}
/* local function LAMBDA8                                                     */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2544__lambda8()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 T0 = L2559make_logical_block(0);
 value0 = ecl_list1(T0);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2544__lambda8_va(cl_narg narg, ...)
{
 return LC2544__lambda8();
}
/* local function LAMBDA10                                                    */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2545__lambda10()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = cl_make_string(1, ECL_SYM_VAL(cl_env_copy,VV[2]));
 return value0;
}
static cl_object LC2545__lambda10_va(cl_narg narg, ...)
{
 return LC2545__lambda10();
}
/* local function LAMBDA12                                                    */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2546__lambda12()
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = cl_make_string(1, ECL_SYM_VAL(cl_env_copy,VV[2]));
 return value0;
}
static cl_object LC2546__lambda12_va(cl_narg narg, ...)
{
 return LC2546__lambda12();
}
/* function definition for PRETTY-STREAM-P                                    */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2547pretty_stream_p(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = si_of_class_p(2, v1stream, VV[3]);
 return value0;
}
static cl_object L2547pretty_stream_p_va(cl_narg narg, cl_object v2stream, ...)
{
 return L2547pretty_stream_p(v2stream);
}
/* function definition for MAKE-PRETTY-STREAM                                 */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2548make_pretty_stream(cl_object v1target)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = si_file_column(v1target);
 if (value0!=ECL_NIL) {
  goto L4;
 }
 T0 = ecl_make_int8_t(0);
 goto L2;
L4:;
 T0 = value0;
 goto L2;
L2:;
 value0 = ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-RIGHT-MARGIN*",60));
 if (value0!=ECL_NIL) {
  goto L8;
 }
 value0 = (cl_env_copy->function=(ECL_SYM("STREAM-LINE-LENGTH",1707)->symbol.gfdef))->cfun.entry(1, v1target) /*  STREAM-LINE-LENGTH */;
 if (value0!=ECL_NIL) {
  goto L8;
 }
 T1 = ecl_make_int8_t(80);
 goto L6;
L8:;
 T1 = value0;
 goto L6;
L6:;
 value0 = (cl_env_copy->function=(ECL_SYM("MAKE-INSTANCE",953)->symbol.gfdef))->cfun.entry(7, VV[3], VV[14], v1target, VV[15], T0, VV[16], T1) /*  MAKE-INSTANCE */;
 return value0;
}
static cl_object L2548make_pretty_stream_va(cl_narg narg, cl_object v2target, ...)
{
 return L2548make_pretty_stream(v2target);
}
/* local function PRINT-OBJECT                                                */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2549print_object(cl_object v1pretty_stream, cl_object v2stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = si_print_unreadable_object_function(v1pretty_stream, v2stream, ECL_T, ECL_T, ECL_NIL);
 return value0;
}
static cl_object LC2549print_object_va(cl_narg narg, cl_object v3pretty_stream, cl_object v4stream, ...)
{
 return LC2549print_object(v3pretty_stream, v4stream);
}
/* function definition for INDEX-POSN                                         */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2550index_posn(cl_object v1index, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_fixnum v3index;
 v3index = ecl_fixnum(v1index);
L1:;
 T0 = (v2stream)->instance.slots[(cl_fixnum)(5)];
 value0 = ecl_plus(ecl_make_fixnum(v3index),T0);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L2550index_posn_va(cl_narg narg, cl_object v4index, cl_object v5stream, ...)
{
 return L2550index_posn(v4index, v5stream);
}
/* function definition for POSN-INDEX                                         */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2551posn_index(cl_object v1posn, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_fixnum v3posn;
 v3posn = ecl_fixnum(v1posn);
L1:;
 T0 = (v2stream)->instance.slots[(cl_fixnum)(5)];
 value0 = ecl_minus(ecl_make_fixnum(v3posn),T0);
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object L2551posn_index_va(cl_narg narg, cl_object v4posn, cl_object v5stream, ...)
{
 return L2551posn_index(v4posn, v5stream);
}
/* function definition for POSN-COLUMN                                        */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2552posn_column(cl_object v1posn, cl_object v2stream)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_fixnum v3posn;
 v3posn = ecl_fixnum(v1posn);
L1:;
 T1 = (v2stream)->instance.slots[(cl_fixnum)(5)];
 T0 = ecl_minus(ecl_make_fixnum(v3posn),T1);
 value0 = L2606index_column(T0, v2stream);
 return value0;
}
static cl_object L2552posn_column_va(cl_narg narg, cl_object v4posn, cl_object v5stream, ...)
{
 return L2552posn_column(v4posn, v5stream);
}
/* local function STREAM-LINE-LENGTH                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2553gray_stream_line_length(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ecl_instance_ref((v1stream),((cl_fixnum)(2)));
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2553gray_stream_line_length_va(cl_narg narg, cl_object v2stream, ...)
{
 return LC2553gray_stream_line_length(v2stream);
}
/* local function STREAM-WRITE-CHAR                                           */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2554gray_stream_write_char(cl_object v1stream, cl_object v2char)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = L2557pretty_out(v1stream, v2char);
 return value0;
}
static cl_object LC2554gray_stream_write_char_va(cl_narg narg, cl_object v3stream, cl_object v4char, ...)
{
 return LC2554gray_stream_write_char(v3stream, v4char);
}
/* local function STREAM-FORCE-OUTPUT                                         */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2555gray_stream_force_output(cl_object v1stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
static cl_object LC2555gray_stream_force_output_va(cl_narg narg, cl_object v2stream, ...)
{
 return LC2555gray_stream_force_output(v2stream);
}
/* local function STREAM-CLEAR-OUTPUT                                         */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2556gray_stream_clear_output(cl_object v1stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 T0 = (v1stream)->instance.slots[(cl_fixnum)(1)];
 value0 = cl_clear_output(1, T0);
 return value0;
}
static cl_object LC2556gray_stream_clear_output_va(cl_narg narg, cl_object v2stream, ...)
{
 return LC2556gray_stream_clear_output(v2stream);
}
/* function definition for PRETTY-OUT                                         */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2557pretty_out(cl_object v1stream, cl_object v2char)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_character v3char;
 v3char = ECL_CHAR_CODE(v2char);
L1:;
 if (!((v3char)==((ecl_character)(10)))){
  goto L2;
 }
 value0 = L2580enqueue_newline(v1stream, VV[33]);
 return value0;
L2:;
 L2608assure_space_in_buffer(v1stream, ecl_make_int8_t(1));
 {
  cl_object v4fill_pointer;
  v4fill_pointer = (v1stream)->instance.slots[(cl_fixnum)(4)];
  T0 = (v1stream)->instance.slots[(cl_fixnum)(3)];
  ecl_char_set(T0,ecl_fixnum(v4fill_pointer),v3char);
  {
   cl_object v5;
   v5 = ecl_one_plus(v4fill_pointer);
   value0 = (v1stream)->instance.slots[(cl_fixnum)(4)]=(v5);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for PRETTY-SOUT                                        */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2558pretty_sout(cl_object v1stream, cl_object v2string, cl_object v3start, cl_object v4end)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_fixnum v5start;
 v5start = ecl_fixnum(v3start);
L1:;
 {
  cl_object v6end;
  value0 = v4end;
  if (value0!=ECL_NIL) {
   goto L4;
  }
  v6end = ecl_make_fixnum((v2string)->vector.fillp);
  goto L2;
L4:;
  v6end = value0;
  goto L2;
L2:;
  if ((v5start)==(ecl_fixnum(v6end))) {
   goto L6;
  }
  {
   cl_object v7newline;
   v7newline = cl_position(6, ECL_CODE_CHAR(10), v2string, ECL_SYM("START",1347), ecl_make_fixnum(v5start), ECL_SYM("END",1256), v6end);
   if (Null(v7newline)){
    goto L9;
   }
   L2558pretty_sout(v1stream, v2string, ecl_make_fixnum(v5start), v7newline);
   L2580enqueue_newline(v1stream, VV[33]);
   v5start = (ecl_fixnum(v7newline))+1;
   v4end = v6end;
   goto L1;
L9:;
   {
    cl_object v8chars;
    v8chars = ecl_minus(v6end,ecl_make_fixnum(v5start));
L19:;
    {
     cl_object v9available;
     cl_object v10count;
     cl_object v11fill_pointer;
     cl_object v12new_fill_ptr;
     v9available = L2608assure_space_in_buffer(v1stream, v8chars);
     v10count = ((ecl_float_nan_p(v8chars) || ecl_lowereq(v9available,v8chars))?v9available:v8chars);
     v11fill_pointer = (v1stream)->instance.slots[(cl_fixnum)(4)];
     v12new_fill_ptr = ecl_plus(v11fill_pointer,v10count);
     T0 = (v1stream)->instance.slots[(cl_fixnum)(3)];
     cl_replace(8, T0, v2string, ECL_SYM("START1",1348), v11fill_pointer, ECL_SYM("END1",1257), v12new_fill_ptr, ECL_SYM("START2",1349), ecl_make_fixnum(v5start));
     (v1stream)->instance.slots[(cl_fixnum)(4)]=(v12new_fill_ptr);
     v8chars = ecl_minus(v8chars,v10count);
     if (!(ecl_zerop(v10count))){
      goto L33;
     }
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 1;
     return value0;
L33:;
     v5start = ecl_fixnum(ecl_plus(ecl_make_fixnum(v5start),v10count));
    }
    goto L19;
   }
  }
L6:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for MAKE-LOGICAL-BLOCK                                 */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2559make_logical_block(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object v1;
 cl_object v2;
 cl_object v3;
 cl_object v4;
 cl_object v5;
 cl_object v6;
 ecl_va_list args; ecl_va_start(args,narg,narg,0);
 {
  cl_object keyvars[12];
  cl_parse_key(args,6,L2559make_logical_blockkeys,keyvars,NULL,FALSE);
  ecl_va_end(args);
  if (Null(keyvars[6])) {
   v1 = ecl_make_int8_t(0);
  } else {
   v1 = keyvars[0];
  }
  if (Null(keyvars[7])) {
   v2 = ecl_make_int8_t(0);
  } else {
   v2 = keyvars[1];
  }
  if (Null(keyvars[8])) {
   v3 = ecl_make_int8_t(0);
  } else {
   v3 = keyvars[2];
  }
  if (Null(keyvars[9])) {
   v4 = ecl_make_int8_t(0);
  } else {
   v4 = keyvars[3];
  }
  if (Null(keyvars[10])) {
   v5 = ecl_make_int8_t(0);
  } else {
   v5 = keyvars[4];
  }
  if (Null(keyvars[11])) {
   v6 = ecl_make_int8_t(0);
  } else {
   v6 = keyvars[5];
  }
 }
 {
  cl_fixnum v7;
  v7 = (cl_fixnum)(0);
  if (!(ECL_FIXNUMP(v6))){
   goto L11;
  }
  v7 = ecl_fixnum(v6);
  if (!((v7)<=(2305843009213693951))){
   goto L16;
  }
  if ((v7)>=((cl_fixnum)(0))) {
   goto L7;
  }
  goto L8;
L16:;
  goto L8;
L11:;
  goto L8;
 }
L8:;
 si_structure_type_error(v6, VV[44], VV[40], VV[45]);
L7:;
 {
  cl_fixnum v7;
  v7 = (cl_fixnum)(0);
  if (!(ECL_FIXNUMP(v5))){
   goto L22;
  }
  v7 = ecl_fixnum(v5);
  if (!((v7)<=(2305843009213693951))){
   goto L27;
  }
  if ((v7)>=((cl_fixnum)(0))) {
   goto L18;
  }
  goto L19;
L27:;
  goto L19;
L22:;
  goto L19;
 }
L19:;
 si_structure_type_error(v5, VV[44], VV[40], VV[46]);
L18:;
 {
  cl_fixnum v7;
  v7 = (cl_fixnum)(0);
  if (!(ECL_FIXNUMP(v4))){
   goto L33;
  }
  v7 = ecl_fixnum(v4);
  if (!((v7)<=(2305843009213693951))){
   goto L38;
  }
  if ((v7)>=((cl_fixnum)(0))) {
   goto L29;
  }
  goto L30;
L38:;
  goto L30;
L33:;
  goto L30;
 }
L30:;
 si_structure_type_error(v4, VV[44], VV[40], VV[47]);
L29:;
 {
  cl_fixnum v7;
  v7 = (cl_fixnum)(0);
  if (!(ECL_FIXNUMP(v3))){
   goto L44;
  }
  v7 = ecl_fixnum(v3);
  if (!((v7)<=(2305843009213693951))){
   goto L49;
  }
  if ((v7)>=((cl_fixnum)(0))) {
   goto L40;
  }
  goto L41;
L49:;
  goto L41;
L44:;
  goto L41;
 }
L41:;
 si_structure_type_error(v3, VV[44], VV[40], VV[48]);
L40:;
 if (!(ECL_FIXNUMP(v2))){
  goto L54;
 }
 {
  cl_object v7;
  v7 = ecl_make_int8_t(0);
  if (!(ECL_FIXNUMP(v2)||ECL_BIGNUMP(v2))){
   goto L58;
  }
  v7 = v2;
  if (ecl_greatereq(v7,ecl_make_int8_t(0))) {
   goto L51;
  }
  goto L52;
L58:;
  goto L52;
 }
L54:;
 goto L52;
L52:;
 si_structure_type_error(v2, VV[0], VV[40], VV[49]);
L51:;
 if (!(ECL_FIXNUMP(v1))){
  goto L65;
 }
 {
  cl_object v7;
  v7 = ecl_make_int8_t(0);
  if (!(ECL_FIXNUMP(v1)||ECL_BIGNUMP(v1))){
   goto L69;
  }
  v7 = v1;
  if (ecl_greatereq(v7,ecl_make_int8_t(0))) {
   goto L62;
  }
  goto L63;
L69:;
  goto L63;
 }
L65:;
 goto L63;
L63:;
 si_structure_type_error(v1, VV[0], VV[40], VV[50]);
L62:;
 value0 = si_make_structure(7, VV[51], v1, v2, v3, v4, v5, v6);
 return value0;
}
/* local function LAMBDA78                                                    */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2560__lambda78(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[40]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(5), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[40]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(5));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2560__lambda78_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2560__lambda78(v5, v6x);
}
/* local function LAMBDA83                                                    */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2561__lambda83(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[40]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(4), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[40]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(4));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2561__lambda83_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2561__lambda83(v5, v6x);
}
/* local function LAMBDA88                                                    */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2562__lambda88(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[40]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[40]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2562__lambda88_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2562__lambda88(v5, v6x);
}
/* local function LAMBDA93                                                    */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2563__lambda93(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[40]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[40]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2563__lambda93_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2563__lambda93(v5, v6x);
}
/* local function LAMBDA98                                                    */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2564__lambda98(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[40]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[40]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2564__lambda98_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2564__lambda98(v5, v6x);
}
/* local function LAMBDA103                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2565__lambda103(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[40]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[40]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2565__lambda103_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2565__lambda103(v5, v6x);
}
/* function definition for REALLY-START-LOGICAL-BLOCK                         */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2566really_start_logical_block(cl_object v1stream, cl_object v2column, cl_object v3prefix, cl_object v4suffix)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v5blocks;
  cl_object v6prev_block;
  cl_object v7per_line_end;
  cl_object v8prefix_length;
  cl_object v9suffix_length;
  cl_object v10block;
  v5blocks = (v1stream)->instance.slots[(cl_fixnum)(8)];
  v6prev_block = _ecl_car(v5blocks);
  v7per_line_end = (cl_env_copy->function=(VV[60]->symbol.gfdef))->cfun.entry(1, v6prev_block) /*  LOGICAL-BLOCK-PER-LINE-PREFIX-END */;
  v8prefix_length = (cl_env_copy->function=(VV[58]->symbol.gfdef))->cfun.entry(1, v6prev_block) /*  LOGICAL-BLOCK-PREFIX-LENGTH */;
  v9suffix_length = (cl_env_copy->function=(VV[56]->symbol.gfdef))->cfun.entry(1, v6prev_block) /*  LOGICAL-BLOCK-SUFFIX-LENGTH */;
  T0 = (v1stream)->instance.slots[(cl_fixnum)(7)];
  v10block = L2559make_logical_block(12, VV[68], v2column, VV[69], v2column, VV[70], v7per_line_end, VV[71], v8prefix_length, VV[72], v9suffix_length, VV[73], T0);
  {
   cl_object v11;
   v11 = CONS(v10block,v5blocks);
   (v1stream)->instance.slots[(cl_fixnum)(8)]=(v11);
  }
  L2567set_indentation(v1stream, v2column);
  if (Null(v3prefix)){
   goto L16;
  }
  {
   cl_object v11;
   v11 = v2column;
   {
    cl_object v12;
    v12 = v10block;
    (v12)->instance.slots[(cl_fixnum)(2)]=v11;
   }
  }
  T0 = (v1stream)->instance.slots[(cl_fixnum)(9)];
  {
   cl_fixnum v11;
   v11 = ecl_length(v3prefix);
   T1 = ecl_minus(v2column,ecl_make_fixnum(v11));
   cl_replace(6, T0, v3prefix, ECL_SYM("START1",1348), T1, ECL_SYM("END1",1257), v2column);
  }
L16:;
  if (Null(v4suffix)){
   goto L2;
  }
  {
   cl_object v11total_suffix;
   cl_object v12total_suffix_len;
   cl_object v13additional;
   cl_object v14new_suffix_len;
   v11total_suffix = (v1stream)->instance.slots[(cl_fixnum)(10)];
   v12total_suffix_len = ecl_make_fixnum(ecl_length(v11total_suffix));
   v13additional = ecl_make_fixnum(ecl_length(v4suffix));
   v14new_suffix_len = ecl_plus(v9suffix_length,v13additional);
   if (!(ecl_greater(v14new_suffix_len,v12total_suffix_len))){
    goto L29;
   }
   {
    cl_object v15new_total_suffix_len;
    T0 = ecl_times(v12total_suffix_len,ecl_make_int8_t(2));
    T1 = ecl_times(v13additional,ecl_make_int8_t(5));
    T2 = ecl_floor2(T1,ecl_make_int8_t(4));
    T3 = ecl_plus(v9suffix_length,T2);
    v15new_total_suffix_len = ((ecl_float_nan_p(T3) || ecl_greatereq(T0,T3))?T0:T3);
    T0 = cl_make_string(1, v15new_total_suffix_len);
    T1 = ecl_minus(v15new_total_suffix_len,v9suffix_length);
    T2 = ecl_minus(v12total_suffix_len,v9suffix_length);
    v11total_suffix = cl_replace(6, T0, v11total_suffix, ECL_SYM("START1",1348), T1, ECL_SYM("START2",1349), T2);
    v12total_suffix_len = v15new_total_suffix_len;
    (v1stream)->instance.slots[(cl_fixnum)(10)]=(v11total_suffix);
   }
L29:;
   T0 = ecl_minus(v12total_suffix_len,v14new_suffix_len);
   T1 = ecl_minus(v12total_suffix_len,v9suffix_length);
   cl_replace(6, v11total_suffix, v4suffix, ECL_SYM("START1",1348), T0, ECL_SYM("END1",1257), T1);
   {
    cl_object v15;
    v15 = v14new_suffix_len;
    {
     cl_object v16;
     v16 = v10block;
     (v16)->instance.slots[(cl_fixnum)(4)]=v15;
    }
   }
  }
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for SET-INDENTATION                                    */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2567set_indentation(cl_object v1stream, cl_object v2column)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3prefix;
  cl_object v4prefix_len;
  cl_object v5block;
  cl_object v6current;
  cl_object v7minimum;
  cl_object v8column;
  v3prefix = (v1stream)->instance.slots[(cl_fixnum)(9)];
  v4prefix_len = ecl_make_fixnum(ecl_length(v3prefix));
  T0 = (v1stream)->instance.slots[(cl_fixnum)(8)];
  v5block = _ecl_car(T0);
  v6current = (cl_env_copy->function=(VV[58]->symbol.gfdef))->cfun.entry(1, v5block) /*  LOGICAL-BLOCK-PREFIX-LENGTH */;
  v7minimum = (cl_env_copy->function=(VV[60]->symbol.gfdef))->cfun.entry(1, v5block) /*  LOGICAL-BLOCK-PER-LINE-PREFIX-END */;
  v8column = ((ecl_float_nan_p(v2column) || ecl_greatereq(v7minimum,v2column))?v7minimum:v2column);
  if (!(ecl_greater(v8column,v4prefix_len))){
   goto L11;
  }
  T0 = ecl_times(v4prefix_len,ecl_make_int8_t(2));
  T1 = ecl_minus(v8column,v4prefix_len);
  T2 = ecl_times(T1,ecl_make_int8_t(5));
  T3 = ecl_floor2(T2,ecl_make_int8_t(4));
  T4 = ecl_plus(v4prefix_len,T3);
  T5 = ((ecl_float_nan_p(T4) || ecl_greatereq(T0,T4))?T0:T4);
  T6 = cl_make_string(1, T5);
  v3prefix = cl_replace(4, T6, v3prefix, ECL_SYM("END1",1257), v6current);
  (v1stream)->instance.slots[(cl_fixnum)(9)]=(v3prefix);
L11:;
  if (!(ecl_greater(v8column,v6current))){
   goto L16;
  }
  cl_fill(6, v3prefix, ECL_CODE_CHAR(32), ECL_SYM("START",1347), v6current, ECL_SYM("END",1256), v8column);
L16:;
  {
   cl_object v9;
   v9 = v8column;
   {
    cl_object v10;
    v10 = v5block;
    value0 = (v10)->instance.slots[(cl_fixnum)(3)]=v9;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for REALLY-END-LOGICAL-BLOCK                           */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2568really_end_logical_block(cl_object v1stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v2old;
  cl_object v3old_indent;
  cl_object v4new;
  cl_object v5new_indent;
  {
   cl_object v6;
   v6 = (v1stream)->instance.slots[(cl_fixnum)(8)];
   if (Null(v6)){
    goto L7;
   }
   {
    cl_object v7;
    v7 = ECL_CONS_CDR(v6);
    (v1stream)->instance.slots[(cl_fixnum)(8)]=(v7);
    v6 = ECL_CONS_CAR(v6);
   }
L7:;
   v2old = v6;
  }
  v3old_indent = (cl_env_copy->function=(VV[58]->symbol.gfdef))->cfun.entry(1, v2old) /*  LOGICAL-BLOCK-PREFIX-LENGTH */;
  T0 = (v1stream)->instance.slots[(cl_fixnum)(8)];
  v4new = _ecl_car(T0);
  v5new_indent = (cl_env_copy->function=(VV[58]->symbol.gfdef))->cfun.entry(1, v4new) /*  LOGICAL-BLOCK-PREFIX-LENGTH */;
  if (!(ecl_greater(v5new_indent,v3old_indent))){
   goto L2;
  }
  T0 = (v1stream)->instance.slots[(cl_fixnum)(9)];
  cl_fill(6, T0, ECL_CODE_CHAR(32), ECL_SYM("START",1347), v3old_indent, ECL_SYM("END",1256), v5new_indent);
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for MAKE-QUEUED-OP                                     */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2569make_queued_op(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object v1;
 ecl_va_list args; ecl_va_start(args,narg,narg,0);
 {
  cl_object keyvars[2];
  cl_parse_key(args,1,L2569make_queued_opkeys,keyvars,NULL,FALSE);
  ecl_va_end(args);
  if (Null(keyvars[1])) {
   v1 = ecl_make_int8_t(0);
  } else {
   v1 = keyvars[0];
  }
 }
 if (ECL_FIXNUMP(v1)) {
  goto L2;
 }
 si_structure_type_error(v1, VV[1], VV[82], VV[1]);
L2:;
 value0 = si_make_structure(2, VV[86], v1);
 return value0;
}
/* local function LAMBDA141                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2570__lambda141(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[82]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[82]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2570__lambda141_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2570__lambda141(v5, v6x);
}
/* function definition for MAKE-SECTION-START                                 */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2571make_section_start(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object v1;
 cl_object v2;
 cl_object v3;
 ecl_va_list args; ecl_va_start(args,narg,narg,0);
 {
  cl_object keyvars[6];
  cl_parse_key(args,3,L2571make_section_startkeys,keyvars,NULL,FALSE);
  ecl_va_end(args);
  if (Null(keyvars[3])) {
   v1 = ecl_make_int8_t(0);
  } else {
   v1 = keyvars[0];
  }
  if (Null(keyvars[4])) {
   v2 = ecl_make_int8_t(0);
  } else {
   v2 = keyvars[1];
  }
  v3 = keyvars[2];
 }
 if (v3==ECL_NIL) {
  goto L3;
 }
 if (si_of_class_p(2, v3, VV[94])!=ECL_NIL) {
  goto L3;
 }
 if (si_of_class_p(2, v3, VV[95])!=ECL_NIL) {
  goto L3;
 }
 si_structure_type_error(v3, VV[96], VV[90], VV[97]);
L3:;
 {
  cl_fixnum v4;
  v4 = (cl_fixnum)(0);
  if (!(ECL_FIXNUMP(v2))){
   goto L11;
  }
  v4 = ecl_fixnum(v2);
  if (!((v4)<=(2305843009213693951))){
   goto L16;
  }
  if ((v4)>=((cl_fixnum)(0))) {
   goto L7;
  }
  goto L8;
L16:;
  goto L8;
L11:;
  goto L8;
 }
L8:;
 si_structure_type_error(v2, VV[44], VV[90], VV[98]);
L7:;
 if (ECL_FIXNUMP(v1)) {
  goto L18;
 }
 si_structure_type_error(v1, VV[1], VV[90], VV[1]);
L18:;
 value0 = si_make_structure(4, VV[99], v1, v2, v3);
 return value0;
}
/* local function LAMBDA164                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2572__lambda164(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[90]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[90]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2572__lambda164_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2572__lambda164(v5, v6x);
}
/* local function LAMBDA169                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2573__lambda169(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[90]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[90]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2573__lambda169_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2573__lambda169(v5, v6x);
}
/* local function LAMBDA174                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2574__lambda174(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[90]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[90]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2574__lambda174_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2574__lambda174(v5, v6x);
}
/* function definition for MAKE-NEWLINE                                       */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2575make_newline(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object v1;
 cl_object v2;
 cl_object v3;
 cl_object v4;
 ecl_va_list args; ecl_va_start(args,narg,narg,0);
 {
  cl_object keyvars[8];
  cl_parse_key(args,4,L2575make_newlinekeys,keyvars,NULL,FALSE);
  ecl_va_end(args);
  if (Null(keyvars[4])) {
   v1 = ecl_make_int8_t(0);
  } else {
   v1 = keyvars[0];
  }
  if (Null(keyvars[5])) {
   v2 = ecl_make_int8_t(0);
  } else {
   v2 = keyvars[1];
  }
  v3 = keyvars[2];
  if (Null(keyvars[7])) {
   v4 = (cl_env_copy->function=(VV[109]->symbol.gfdef))->cfun.entry(0) /*  REQUIRED-ARGUMENT */;
  } else {
   v4 = keyvars[3];
  }
 }
 {
  cl_object v5;
  cl_object v6;
  v5 = v4;
  v6 = VV[111];
  if (ecl_memql(v5,v6)!=ECL_NIL) {
   goto L4;
  }
 }
 si_structure_type_error(v4, VV[112], VV[94], VV[113]);
L4:;
 if (v3==ECL_NIL) {
  goto L8;
 }
 if (si_of_class_p(2, v3, VV[94])!=ECL_NIL) {
  goto L8;
 }
 if (si_of_class_p(2, v3, VV[95])!=ECL_NIL) {
  goto L8;
 }
 si_structure_type_error(v3, VV[96], VV[94], VV[97]);
L8:;
 {
  cl_fixnum v5;
  v5 = (cl_fixnum)(0);
  if (!(ECL_FIXNUMP(v2))){
   goto L16;
  }
  v5 = ecl_fixnum(v2);
  if (!((v5)<=(2305843009213693951))){
   goto L21;
  }
  if ((v5)>=((cl_fixnum)(0))) {
   goto L12;
  }
  goto L13;
L21:;
  goto L13;
L16:;
  goto L13;
 }
L13:;
 si_structure_type_error(v2, VV[44], VV[94], VV[98]);
L12:;
 if (ECL_FIXNUMP(v1)) {
  goto L23;
 }
 si_structure_type_error(v1, VV[1], VV[94], VV[1]);
L23:;
 value0 = si_make_structure(5, VV[114], v1, v2, v3, v4);
 return value0;
}
/* local function LAMBDA196                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2576__lambda196(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[94]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[94]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2576__lambda196_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2576__lambda196(v5, v6x);
}
/* local function LAMBDA201                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2577__lambda201(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[94]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[94]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2577__lambda201_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2577__lambda201(v5, v6x);
}
/* local function LAMBDA206                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2578__lambda206(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[94]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[94]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2578__lambda206_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2578__lambda206(v5, v6x);
}
/* local function LAMBDA211                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2579__lambda211(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[94]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[94]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2579__lambda211_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2579__lambda211(v5, v6x);
}
/* function definition for ENQUEUE-NEWLINE                                    */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2580enqueue_newline(cl_object v1stream, cl_object v2kind)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3depth;
  cl_object v4newline;
  T0 = (v1stream)->instance.slots[(cl_fixnum)(13)];
  v3depth = ecl_make_fixnum(ecl_length(T0));
  {
   cl_object v5;
   {
    cl_object v6;
    v6 = (v1stream)->instance.slots[(cl_fixnum)(4)];
    T1 = (v1stream)->instance.slots[(cl_fixnum)(5)];
    T0 = ecl_plus(v6,T1);
   }
   v5 = L2575make_newline(6, VV[126], T0, VV[127], v2kind, VV[128], v3depth);
   {
    cl_object v6;
    v6 = ecl_list1(v5);
    {
     cl_object v7;
     v7 = (v1stream)->instance.slots[(cl_fixnum)(12)];
     if (Null(v7)){
      goto L17;
     }
     {
      cl_object v8;
      v8 = v7;
      {
       cl_object v9;
       v9 = v6;
       (ECL_CONS_CDR(v8)=v9,v8);
       goto L16;
      }
     }
L17:;
     (v1stream)->instance.slots[(cl_fixnum)(11)]=(v6);
L16:;
     (v1stream)->instance.slots[(cl_fixnum)(12)]=(v6);
     v4newline = v5;
    }
   }
  }
  {
   cl_object v5;
   v5 = (v1stream)->instance.slots[(cl_fixnum)(11)];
   goto L29;
L28:;
   {
    cl_object v6entry;
    v6entry = _ecl_car(v5);
    if ((v4newline)==(v6entry)) {
     goto L33;
    }
    if (Null((cl_env_copy->function=(VV[92]->symbol.gfdef))->cfun.entry(1, v6entry) /*  SECTION-START-P */)){
     goto L33;
    }
    T0 = (cl_env_copy->function=(VV[101]->symbol.gfdef))->cfun.entry(1, v6entry) /*  SECTION-START-SECTION-END */;
    if (!(T0==ECL_NIL)){
     goto L33;
    }
    T0 = (cl_env_copy->function=(VV[103]->symbol.gfdef))->cfun.entry(1, v6entry) /*  SECTION-START-DEPTH */;
    if (!(ecl_lowereq(v3depth,T0))){
     goto L33;
    }
    {
     cl_object v7;
     v7 = v4newline;
     {
      cl_object v8;
      v8 = v6entry;
      (v8)->instance.slots[(cl_fixnum)(2)]=v7;
     }
    }
L33:;
   }
   v5 = _ecl_cdr(v5);
L29:;
   if (Null(v5)){
    goto L42;
   }
   goto L28;
L42:;
  }
 }
 value0 = ecl_make_bool((v2kind)==(VV[33]));
 if (value0!=ECL_NIL) {
  goto L46;
 }
 T0 = ecl_make_bool((v2kind)==(VV[134]));
 goto L44;
L46:;
 T0 = value0;
 goto L44;
L44:;
 value0 = L2609maybe_output(v1stream, T0);
 return value0;
}
/* function definition for MAKE-INDENTATION                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2581make_indentation(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object v1;
 cl_object v2;
 cl_object v3;
 ecl_va_list args; ecl_va_start(args,narg,narg,0);
 {
  cl_object keyvars[6];
  cl_parse_key(args,3,L2581make_indentationkeys,keyvars,NULL,FALSE);
  ecl_va_end(args);
  if (Null(keyvars[3])) {
   v1 = ecl_make_int8_t(0);
  } else {
   v1 = keyvars[0];
  }
  if (Null(keyvars[4])) {
   v2 = (cl_env_copy->function=(VV[109]->symbol.gfdef))->cfun.entry(0) /*  REQUIRED-ARGUMENT */;
  } else {
   v2 = keyvars[1];
  }
  if (Null(keyvars[5])) {
   v3 = ecl_make_int8_t(0);
  } else {
   v3 = keyvars[2];
  }
 }
 if (ECL_FIXNUMP(v3)) {
  goto L4;
 }
 si_structure_type_error(v3, ECL_SYM("FIXNUM",374), VV[135], VV[139]);
L4:;
 if (!((v2)==(ECL_SYM("BLOCK",1232)))){
  goto L10;
 }
 goto L6;
L10:;
 goto L8;
L8:;
 if (!((v2)==(VV[141]))){
  goto L13;
 }
 goto L6;
L13:;
 goto L7;
L7:;
 si_structure_type_error(v2, VV[143], VV[135], VV[113]);
L6:;
 if (ECL_FIXNUMP(v1)) {
  goto L15;
 }
 si_structure_type_error(v1, VV[1], VV[135], VV[1]);
L15:;
 value0 = si_make_structure(4, VV[144], v1, v2, v3);
 return value0;
}
/* local function LAMBDA250                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2582__lambda250(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[135]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[135]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2582__lambda250_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2582__lambda250(v5, v6x);
}
/* local function LAMBDA255                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2583__lambda255(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[135]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[135]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2583__lambda255_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2583__lambda255(v5, v6x);
}
/* local function LAMBDA260                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2584__lambda260(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[135]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[135]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2584__lambda260_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2584__lambda260(v5, v6x);
}
/* function definition for ENQUEUE-INDENT                                     */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2585enqueue_indent(cl_object v1stream, cl_object v2kind, cl_object v3amount)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v4;
  {
   cl_object v5;
   v5 = (v1stream)->instance.slots[(cl_fixnum)(4)];
   T1 = (v1stream)->instance.slots[(cl_fixnum)(5)];
   T0 = ecl_plus(v5,T1);
  }
  v4 = L2581make_indentation(6, VV[126], T0, VV[127], v2kind, VV[153], v3amount);
  {
   cl_object v5;
   v5 = ecl_list1(v4);
   {
    cl_object v6;
    v6 = (v1stream)->instance.slots[(cl_fixnum)(12)];
    if (Null(v6)){
     goto L12;
    }
    {
     cl_object v7;
     v7 = v6;
     {
      cl_object v8;
      v8 = v5;
      (ECL_CONS_CDR(v7)=v8,v7);
      goto L11;
     }
    }
L12:;
    (v1stream)->instance.slots[(cl_fixnum)(11)]=(v5);
L11:;
    (v1stream)->instance.slots[(cl_fixnum)(12)]=(v5);
    value0 = v4;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for MAKE-BLOCK-START                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2586make_block_start(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object v1;
 cl_object v2;
 cl_object v3;
 cl_object v4;
 cl_object v5;
 cl_object v6;
 ecl_va_list args; ecl_va_start(args,narg,narg,0);
 {
  cl_object keyvars[12];
  cl_parse_key(args,6,L2586make_block_startkeys,keyvars,NULL,FALSE);
  ecl_va_end(args);
  if (Null(keyvars[6])) {
   v1 = ecl_make_int8_t(0);
  } else {
   v1 = keyvars[0];
  }
  if (Null(keyvars[7])) {
   v2 = ecl_make_int8_t(0);
  } else {
   v2 = keyvars[1];
  }
  v3 = keyvars[2];
  v4 = keyvars[3];
  v5 = keyvars[4];
  v6 = keyvars[5];
 }
 if (v6==ECL_NIL) {
  goto L3;
 }
 if (ECL_STRINGP(v6)) {
  goto L3;
 }
 si_structure_type_error(v6, VV[158], VV[154], VV[159]);
L3:;
 if (v5==ECL_NIL) {
  goto L6;
 }
 if (ECL_STRINGP(v5)) {
  goto L6;
 }
 si_structure_type_error(v5, VV[158], VV[154], VV[160]);
L6:;
 if (v4==ECL_NIL) {
  goto L9;
 }
 if (si_of_class_p(2, v4, VV[95])!=ECL_NIL) {
  goto L9;
 }
 si_structure_type_error(v4, VV[161], VV[154], VV[95]);
L9:;
 if (v3==ECL_NIL) {
  goto L12;
 }
 if (si_of_class_p(2, v3, VV[94])!=ECL_NIL) {
  goto L12;
 }
 if (si_of_class_p(2, v3, VV[95])!=ECL_NIL) {
  goto L12;
 }
 si_structure_type_error(v3, VV[96], VV[154], VV[97]);
L12:;
 {
  cl_fixnum v7;
  v7 = (cl_fixnum)(0);
  if (!(ECL_FIXNUMP(v2))){
   goto L20;
  }
  v7 = ecl_fixnum(v2);
  if (!((v7)<=(2305843009213693951))){
   goto L25;
  }
  if ((v7)>=((cl_fixnum)(0))) {
   goto L16;
  }
  goto L17;
L25:;
  goto L17;
L20:;
  goto L17;
 }
L17:;
 si_structure_type_error(v2, VV[44], VV[154], VV[98]);
L16:;
 if (ECL_FIXNUMP(v1)) {
  goto L27;
 }
 si_structure_type_error(v1, VV[1], VV[154], VV[1]);
L27:;
 value0 = si_make_structure(7, VV[162], v1, v2, v3, v4, v5, v6);
 return value0;
}
/* local function LAMBDA292                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2587__lambda292(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[154]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(5), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[154]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(5));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2587__lambda292_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2587__lambda292(v5, v6x);
}
/* local function LAMBDA297                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2588__lambda297(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[154]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(4), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[154]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(4));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2588__lambda297_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2588__lambda297(v5, v6x);
}
/* local function LAMBDA302                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2589__lambda302(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[154]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[154]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2589__lambda302_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2589__lambda302(v5, v6x);
}
/* local function LAMBDA307                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2590__lambda307(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[154]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[154]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2590__lambda307_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2590__lambda307(v5, v6x);
}
/* local function LAMBDA312                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2591__lambda312(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[154]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[154]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2591__lambda312_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2591__lambda312(v5, v6x);
}
/* local function LAMBDA317                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2592__lambda317(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[154]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[154]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2592__lambda317_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2592__lambda317(v5, v6x);
}
/* function definition for START-LOGICAL-BLOCK                                */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2593start_logical_block(cl_object v1stream, cl_object v2prefix, cl_object v3per_line_p, cl_object v4suffix)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 T0 = si_of_class_p(2, v1stream, VV[3]);
 if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[3],v1stream);
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 0;
 {
  bool v5;
  v5 = ECL_STRINGP(v2prefix);
  if (ecl_unlikely(!(v5)))
         FEwrong_type_argument(ECL_SYM("STRING",808),v2prefix);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
 }
 {
  bool v5;
  v5 = ECL_STRINGP(v4suffix);
  if (ecl_unlikely(!(v5)))
         FEwrong_type_argument(ECL_SYM("STRING",808),v4suffix);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
 }
 {
  cl_object v5prefix_len;
  v5prefix_len = ecl_make_fixnum((v2prefix)->vector.fillp);
  if (!((ecl_fixnum(v5prefix_len))>0)){
   goto L6;
  }
  L2558pretty_sout(v1stream, v2prefix, ecl_make_int8_t(0), v5prefix_len);
L6:;
  {
   cl_object v6pending_blocks;
   cl_object v7start;
   v6pending_blocks = (v1stream)->instance.slots[(cl_fixnum)(13)];
   {
    cl_object v8;
    {
     cl_object v9;
     v9 = (v1stream)->instance.slots[(cl_fixnum)(4)];
     T1 = (v1stream)->instance.slots[(cl_fixnum)(5)];
     T0 = ecl_plus(v9,T1);
    }
    if (!((ecl_fixnum(v5prefix_len))>0)){
     goto L19;
    }
    if (Null(v3per_line_p)){
     goto L19;
    }
    T1 = v2prefix;
    goto L17;
L19:;
    T1 = ECL_NIL;
    goto L17;
L17:;
    {
     cl_fixnum v9;
     v9 = (v4suffix)->vector.fillp;
     if (!((v9)>0)){
      goto L24;
     }
    }
    T2 = v4suffix;
    goto L22;
L24:;
    T2 = ECL_NIL;
    goto L22;
L22:;
    {
     cl_fixnum v9;
     v9 = ecl_length(v6pending_blocks);
     v8 = L2586make_block_start(8, VV[126], T0, VV[178], T1, VV[179], T2, VV[128], ecl_make_fixnum(v9));
    }
    {
     cl_object v9;
     v9 = ecl_list1(v8);
     {
      cl_object v10;
      v10 = (v1stream)->instance.slots[(cl_fixnum)(12)];
      if (Null(v10)){
       goto L30;
      }
      {
       cl_object v11;
       v11 = v10;
       {
        cl_object v12;
        v12 = v9;
        (ECL_CONS_CDR(v11)=v12,v11);
        goto L29;
       }
      }
L30:;
      (v1stream)->instance.slots[(cl_fixnum)(11)]=(v9);
L29:;
      (v1stream)->instance.slots[(cl_fixnum)(12)]=(v9);
      v7start = v8;
     }
    }
   }
   {
    cl_object v8;
    v8 = CONS(v7start,v6pending_blocks);
    value0 = (v1stream)->instance.slots[(cl_fixnum)(13)]=(v8);
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for MAKE-BLOCK-END                                     */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2594make_block_end(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object v1;
 cl_object v2;
 ecl_va_list args; ecl_va_start(args,narg,narg,0);
 {
  cl_object keyvars[4];
  cl_parse_key(args,2,L2594make_block_endkeys,keyvars,NULL,FALSE);
  ecl_va_end(args);
  if (Null(keyvars[2])) {
   v1 = ecl_make_int8_t(0);
  } else {
   v1 = keyvars[0];
  }
  v2 = keyvars[1];
 }
 if (v2==ECL_NIL) {
  goto L2;
 }
 if (ECL_STRINGP(v2)) {
  goto L2;
 }
 si_structure_type_error(v2, VV[158], VV[95], VV[159]);
L2:;
 if (ECL_FIXNUMP(v1)) {
  goto L5;
 }
 si_structure_type_error(v1, VV[1], VV[95], VV[1]);
L5:;
 value0 = si_make_structure(3, VV[184], v1, v2);
 return value0;
}
/* local function LAMBDA345                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2595__lambda345(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[95]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[95]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2595__lambda345_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2595__lambda345(v5, v6x);
}
/* local function LAMBDA350                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2596__lambda350(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[95]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[95]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2596__lambda350_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2596__lambda350(v5, v6x);
}
/* function definition for END-LOGICAL-BLOCK                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2597end_logical_block(cl_object v1stream)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v2start;
  cl_object v3suffix;
  cl_object v4end;
  {
   cl_object v5;
   v5 = (v1stream)->instance.slots[(cl_fixnum)(13)];
   if (Null(v5)){
    goto L6;
   }
   {
    cl_object v6;
    v6 = ECL_CONS_CDR(v5);
    (v1stream)->instance.slots[(cl_fixnum)(13)]=(v6);
    v5 = ECL_CONS_CAR(v5);
   }
L6:;
   v2start = v5;
  }
  v3suffix = (cl_env_copy->function=(VV[164]->symbol.gfdef))->cfun.entry(1, v2start) /*  BLOCK-START-SUFFIX */;
  {
   cl_object v5;
   {
    cl_object v6;
    v6 = (v1stream)->instance.slots[(cl_fixnum)(4)];
    T1 = (v1stream)->instance.slots[(cl_fixnum)(5)];
    T0 = ecl_plus(v6,T1);
   }
   v5 = L2594make_block_end(4, VV[126], T0, VV[179], v3suffix);
   {
    cl_object v6;
    v6 = ecl_list1(v5);
    {
     cl_object v7;
     v7 = (v1stream)->instance.slots[(cl_fixnum)(12)];
     if (Null(v7)){
      goto L24;
     }
     {
      cl_object v8;
      v8 = v7;
      {
       cl_object v9;
       v9 = v6;
       (ECL_CONS_CDR(v8)=v9,v8);
       goto L23;
      }
     }
L24:;
     (v1stream)->instance.slots[(cl_fixnum)(11)]=(v6);
L23:;
     (v1stream)->instance.slots[(cl_fixnum)(12)]=(v6);
     v4end = v5;
    }
   }
  }
  if (Null(v3suffix)){
   goto L32;
  }
  {
   cl_fixnum v5;
   v5 = ecl_length(v3suffix);
   L2558pretty_sout(v1stream, v3suffix, ecl_make_int8_t(0), ecl_make_fixnum(v5));
  }
L32:;
  {
   cl_object v5;
   v5 = v4end;
   {
    cl_object v6;
    v6 = v2start;
    value0 = (v6)->instance.slots[(cl_fixnum)(3)]=v5;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for MAKE-TAB                                           */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2598make_tab(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object v1;
 cl_object v2;
 cl_object v3;
 cl_object v4;
 cl_object v5;
 ecl_va_list args; ecl_va_start(args,narg,narg,0);
 {
  cl_object keyvars[10];
  cl_parse_key(args,5,L2598make_tabkeys,keyvars,NULL,FALSE);
  ecl_va_end(args);
  if (Null(keyvars[5])) {
   v1 = ecl_make_int8_t(0);
  } else {
   v1 = keyvars[0];
  }
  v2 = keyvars[1];
  v3 = keyvars[2];
  if (Null(keyvars[8])) {
   v4 = ecl_make_int8_t(0);
  } else {
   v4 = keyvars[3];
  }
  if (Null(keyvars[9])) {
   v5 = ecl_make_int8_t(0);
  } else {
   v5 = keyvars[4];
  }
 }
 if (!(ECL_FIXNUMP(v5))){
  goto L7;
 }
 {
  cl_object v6;
  v6 = ecl_make_int8_t(0);
  if (!(ECL_FIXNUMP(v5)||ECL_BIGNUMP(v5))){
   goto L11;
  }
  v6 = v5;
  if (ecl_greatereq(v6,ecl_make_int8_t(0))) {
   goto L4;
  }
  goto L5;
L11:;
  goto L5;
 }
L7:;
 goto L5;
L5:;
 si_structure_type_error(v5, VV[0], VV[191], VV[195]);
L4:;
 if (!(ECL_FIXNUMP(v4))){
  goto L18;
 }
 {
  cl_object v6;
  v6 = ecl_make_int8_t(0);
  if (!(ECL_FIXNUMP(v4)||ECL_BIGNUMP(v4))){
   goto L22;
  }
  v6 = v4;
  if (ecl_greatereq(v6,ecl_make_int8_t(0))) {
   goto L15;
  }
  goto L16;
L22:;
  goto L16;
 }
L18:;
 goto L16;
L16:;
 si_structure_type_error(v4, VV[0], VV[191], VV[196]);
L15:;
 if (!((v3)==(ECL_T))){
  goto L30;
 }
 goto L26;
L30:;
 goto L28;
L28:;
 if (!((v3)==(ECL_NIL))){
  goto L33;
 }
 goto L26;
L33:;
 goto L27;
L27:;
 si_structure_type_error(v3, VV[199], VV[191], VV[200]);
L26:;
 if (!((v2)==(ECL_T))){
  goto L39;
 }
 goto L35;
L39:;
 goto L37;
L37:;
 if (!((v2)==(ECL_NIL))){
  goto L42;
 }
 goto L35;
L42:;
 goto L36;
L36:;
 si_structure_type_error(v2, VV[199], VV[191], VV[201]);
L35:;
 if (ECL_FIXNUMP(v1)) {
  goto L44;
 }
 si_structure_type_error(v1, VV[1], VV[191], VV[1]);
L44:;
 value0 = si_make_structure(6, VV[202], v1, v2, v3, v4, v5);
 return value0;
}
/* local function LAMBDA413                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2599__lambda413(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[191]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(4), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[191]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(4));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2599__lambda413_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2599__lambda413(v5, v6x);
}
/* local function LAMBDA418                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2600__lambda418(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[191]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[191]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2600__lambda418_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2600__lambda418(v5, v6x);
}
/* local function LAMBDA423                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2601__lambda423(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[191]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[191]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2601__lambda423_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2601__lambda423(v5, v6x);
}
/* local function LAMBDA428                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2602__lambda428(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[191]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[191]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2602__lambda428_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2602__lambda428(v5, v6x);
}
/* local function LAMBDA433                                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2603__lambda433(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[191]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[191]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2603__lambda433_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2603__lambda433(v5, v6x);
}
/* function definition for ENQUEUE-TAB                                        */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2604enqueue_tab(cl_object v1stream, cl_object v2kind, cl_object v3colnum, cl_object v4colinc)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v5;                                   /*  SECTIONP                */
  cl_object v6;                                   /*  RELATIVEP               */
  if (!((v2kind)==(ECL_SYM("LINE",1677)))){
   goto L3;
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  value0 = cl_env_copy->values[0];
  goto L2;
L3:;
  if (!((v2kind)==(VV[215]))){
   goto L5;
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = ECL_T;
  cl_env_copy->values[0] = ECL_NIL;
  value0 = cl_env_copy->values[0];
  goto L2;
L5:;
  if (!((v2kind)==(VV[216]))){
   goto L7;
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_T;
  value0 = cl_env_copy->values[0];
  goto L2;
L7:;
  if (!((v2kind)==(VV[217]))){
   goto L9;
  }
  cl_env_copy->nvalues = 2;
  cl_env_copy->values[1] = ECL_T;
  cl_env_copy->values[0] = ECL_T;
  value0 = cl_env_copy->values[0];
  goto L2;
L9:;
  value0 = si_ecase_error(v2kind, VV[218]);
L2:;
  {
   const int v7 = cl_env_copy->nvalues;
   v5 = value0;
   cl_object v8;
   v8 = (v7<=1)? ECL_NIL : cl_env_copy->values[1];
   v6 = v8;
  }
  {
   cl_object v7;
   {
    cl_object v8;
    v8 = (v1stream)->instance.slots[(cl_fixnum)(4)];
    T1 = (v1stream)->instance.slots[(cl_fixnum)(5)];
    T0 = ecl_plus(v8,T1);
   }
   v7 = L2598make_tab(10, VV[126], T0, VV[219], v5, VV[220], v6, VV[221], v3colnum, VV[222], v4colinc);
   {
    cl_object v8;
    v8 = ecl_list1(v7);
    {
     cl_object v9;
     v9 = (v1stream)->instance.slots[(cl_fixnum)(12)];
     if (Null(v9)){
      goto L21;
     }
     {
      cl_object v10;
      v10 = v9;
      {
       cl_object v11;
       v11 = v8;
       (ECL_CONS_CDR(v10)=v11,v10);
       goto L20;
      }
     }
L21:;
     (v1stream)->instance.slots[(cl_fixnum)(11)]=(v8);
L20:;
     (v1stream)->instance.slots[(cl_fixnum)(12)]=(v8);
     value0 = v7;
     cl_env_copy->nvalues = 1;
     return value0;
    }
   }
  }
 }
}
/* function definition for COMPUTE-TAB-SIZE                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2605compute_tab_size(cl_object v1tab, cl_object v2section_start, cl_object v3column)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v4;
  cl_object v5;
  cl_object v6colnum;
  v4 = (cl_env_copy->function=(VV[206]->symbol.gfdef))->cfun.entry(1, v1tab) /*  TAB-COLNUM */;
  v5 = (cl_env_copy->function=(VV[204]->symbol.gfdef))->cfun.entry(1, v1tab) /*  TAB-COLINC */;
  v6colnum = v4;
  if (Null((cl_env_copy->function=(VV[210]->symbol.gfdef))->cfun.entry(1, v1tab) /*  TAB-SECTIONP */)){
   goto L5;
  }
  v3column = ecl_minus(v3column,v2section_start);
L5:;
  if (Null((cl_env_copy->function=(VV[208]->symbol.gfdef))->cfun.entry(1, v1tab) /*  TAB-RELATIVEP */)){
   goto L8;
  }
  if (ecl_lowereq(v5,ecl_make_int8_t(1))) {
   goto L10;
  }
  {
   cl_object v7newposn;
   v7newposn = ecl_plus(v3column,v6colnum);
   {
    cl_object v8rem;
    v8rem = (ecl_truncate2(v7newposn,v5),cl_env_copy->values[1]);
    if (ecl_zerop(v8rem)) {
     goto L10;
    }
    {
     cl_object v9;
     v9 = ecl_minus(v5,v8rem);
     v6colnum = ecl_plus(v6colnum,v9);
    }
   }
  }
L10:;
  value0 = v6colnum;
  cl_env_copy->nvalues = 1;
  return value0;
L8:;
  if (!(ecl_lower(v3column,v6colnum))){
   goto L17;
  }
  value0 = ecl_minus(v6colnum,v3column);
  cl_env_copy->nvalues = 1;
  return value0;
L17:;
  if (!(ecl_number_equalp(v3column,v6colnum))){
   goto L19;
  }
  value0 = v5;
  cl_env_copy->nvalues = 1;
  return value0;
L19:;
  if (!(ecl_plusp(v5))){
   goto L21;
  }
  T0 = ecl_minus(v3column,v6colnum);
  T1 = (ecl_truncate2(T0,v5),cl_env_copy->values[1]);
  value0 = ecl_minus(v5,T1);
  cl_env_copy->nvalues = 1;
  return value0;
L21:;
  value0 = ecl_make_int8_t(0);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for INDEX-COLUMN                                       */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2606index_column(cl_object v1index, cl_object v2stream)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6column;
  cl_object v7section_start;
  v3 = (v2stream)->instance.slots[(cl_fixnum)(6)];
  T0 = (v2stream)->instance.slots[(cl_fixnum)(8)];
  T1 = _ecl_car(T0);
  v4 = (cl_env_copy->function=(VV[62]->symbol.gfdef))->cfun.entry(1, T1) /*  LOGICAL-BLOCK-SECTION-COLUMN */;
  T0 = (v2stream)->instance.slots[(cl_fixnum)(5)];
  v5 = ecl_plus(v1index,T0);
  v6column = v3;
  v7section_start = v4;
  {
   cl_object v8;
   v8 = (v2stream)->instance.slots[(cl_fixnum)(11)];
   goto L17;
L16:;
   {
    cl_object v9op;
    v9op = _ecl_car(v8);
    T0 = (cl_env_copy->function=(VV[88]->symbol.gfdef))->cfun.entry(1, v9op) /*  QUEUED-OP-POSN */;
    if (!(ecl_greatereq(T0,v5))){
     goto L21;
    }
    goto L12;
L21:;
    if (Null(si_of_class_p(2, v9op, VV[191]))){
     goto L24;
    }
    {
     cl_object v10;
     {
      cl_object v11;
      v11 = (cl_env_copy->function=(VV[212]->symbol.gfdef))->cfun.entry(1, v9op) /*  TAB-POSN */;
      T1 = (v2stream)->instance.slots[(cl_fixnum)(5)];
      T0 = ecl_minus(v11,T1);
     }
     T1 = ecl_plus(v6column,T0);
     v10 = L2605compute_tab_size(v9op, v7section_start, T1);
     v6column = ecl_plus(v6column,v10);
     goto L23;
    }
L24:;
    if (si_of_class_p(2, v9op, VV[94])!=ECL_NIL) {
     goto L33;
    }
    if (Null(si_of_class_p(2, v9op, VV[154]))){
     goto L23;
    }
    goto L32;
L33:;
L32:;
    {
     cl_object v11;
     v11 = (cl_env_copy->function=(VV[88]->symbol.gfdef))->cfun.entry(1, v9op) /*  QUEUED-OP-POSN */;
     T1 = (v2stream)->instance.slots[(cl_fixnum)(5)];
     T0 = ecl_minus(v11,T1);
    }
    v7section_start = ecl_plus(v6column,T0);
L23:;
   }
   v8 = _ecl_cdr(v8);
L17:;
   if (Null(v8)){
    goto L42;
   }
   goto L16;
L42:;
  }
L12:;
  value0 = ecl_plus(v6column,v1index);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for EXPAND-TABS                                        */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2607expand_tabs(cl_object v1stream, cl_object v2through)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5insertions;
  cl_object v6additional;
  cl_object v7column;
  cl_object v8section_start;
  v3 = (v1stream)->instance.slots[(cl_fixnum)(6)];
  T0 = (v1stream)->instance.slots[(cl_fixnum)(8)];
  T1 = _ecl_car(T0);
  v4 = (cl_env_copy->function=(VV[62]->symbol.gfdef))->cfun.entry(1, T1) /*  LOGICAL-BLOCK-SECTION-COLUMN */;
  v5insertions = ECL_NIL;
  v6additional = ecl_make_int8_t(0);
  v7column = v3;
  v8section_start = v4;
  {
   cl_object v9;
   v9 = (v1stream)->instance.slots[(cl_fixnum)(11)];
   goto L16;
L15:;
   {
    cl_object v10op;
    v10op = _ecl_car(v9);
    if (Null(si_of_class_p(2, v10op, VV[191]))){
     goto L21;
    }
    {
     cl_object v11index;
     cl_object v12tabsize;
     {
      cl_object v13;
      v13 = (cl_env_copy->function=(VV[212]->symbol.gfdef))->cfun.entry(1, v10op) /*  TAB-POSN */;
      T0 = (v1stream)->instance.slots[(cl_fixnum)(5)];
      v11index = ecl_minus(v13,T0);
     }
     T0 = ecl_plus(v7column,v11index);
     v12tabsize = L2605compute_tab_size(v10op, v8section_start, T0);
     if (ecl_zerop(v12tabsize)) {
      goto L20;
     }
     T0 = CONS(v11index,v12tabsize);
     v5insertions = CONS(T0,v5insertions);
     v6additional = ecl_plus(v6additional,v12tabsize);
     v7column = ecl_plus(v7column,v12tabsize);
     goto L20;
    }
L21:;
    if (si_of_class_p(2, v10op, VV[94])!=ECL_NIL) {
     goto L35;
    }
    if (Null(si_of_class_p(2, v10op, VV[154]))){
     goto L20;
    }
    goto L34;
L35:;
L34:;
    {
     cl_object v13;
     v13 = (cl_env_copy->function=(VV[88]->symbol.gfdef))->cfun.entry(1, v10op) /*  QUEUED-OP-POSN */;
     T1 = (v1stream)->instance.slots[(cl_fixnum)(5)];
     T0 = ecl_minus(v13,T1);
    }
    v8section_start = ecl_plus(v7column,T0);
L20:;
    if (!((v10op)==(v2through))){
     goto L42;
    }
    goto L11;
L42:;
   }
   v9 = _ecl_cdr(v9);
L16:;
   if (Null(v9)){
    goto L46;
   }
   goto L15;
L46:;
  }
L11:;
  if (Null(v5insertions)){
   goto L48;
  }
  {
   cl_object v9fill_ptr;
   cl_object v10new_fill_ptr;
   cl_object v11buffer;
   cl_object v12new_buffer;
   cl_object v13length;
   cl_object v14end;
   v9fill_ptr = (v1stream)->instance.slots[(cl_fixnum)(4)];
   v10new_fill_ptr = ecl_plus(v9fill_ptr,v6additional);
   v11buffer = (v1stream)->instance.slots[(cl_fixnum)(3)];
   v12new_buffer = v11buffer;
   v13length = ecl_make_fixnum(ecl_length(v11buffer));
   v14end = v9fill_ptr;
   if (!(ecl_greater(v10new_fill_ptr,v13length))){
    goto L58;
   }
   {
    cl_object v15new_length;
    T0 = ecl_times(v13length,ecl_make_int8_t(2));
    T1 = ecl_times(v6additional,ecl_make_int8_t(5));
    T2 = ecl_floor2(T1,ecl_make_int8_t(4));
    T3 = ecl_plus(v9fill_ptr,T2);
    v15new_length = ((ecl_float_nan_p(T3) || ecl_greatereq(T0,T3))?T0:T3);
    v12new_buffer = cl_make_string(1, v15new_length);
    (v1stream)->instance.slots[(cl_fixnum)(3)]=(v12new_buffer);
   }
L58:;
   (v1stream)->instance.slots[(cl_fixnum)(4)]=(v10new_fill_ptr);
   {
    cl_object v15;
    T0 = (v1stream)->instance.slots[(cl_fixnum)(5)];
    v15 = ecl_minus(T0,v6additional);
    (v1stream)->instance.slots[(cl_fixnum)(5)]=(v15);
   }
   {
    cl_object v15;
    v15 = v5insertions;
    goto L75;
L74:;
    {
     cl_object v16insertion;
     v16insertion = _ecl_car(v15);
     {
      cl_object v17srcpos;
      cl_object v18amount;
      cl_object v19dstpos;
      v17srcpos = _ecl_car(v16insertion);
      v18amount = _ecl_cdr(v16insertion);
      v19dstpos = ecl_plus(v17srcpos,v6additional);
      cl_replace(8, v12new_buffer, v11buffer, ECL_SYM("START1",1348), v19dstpos, ECL_SYM("START2",1349), v17srcpos, ECL_SYM("END2",1258), v14end);
      T0 = ecl_minus(v19dstpos,v18amount);
      cl_fill(6, v12new_buffer, ECL_CODE_CHAR(32), ECL_SYM("START",1347), T0, ECL_SYM("END",1256), v19dstpos);
      v6additional = ecl_minus(v6additional,v18amount);
      v14end = v17srcpos;
     }
    }
    v15 = _ecl_cdr(v15);
L75:;
    if (Null(v15)){
     goto L90;
    }
    goto L74;
L90:;
   }
   if ((v12new_buffer)==(v11buffer)) {
    goto L92;
   }
   value0 = cl_replace(6, v12new_buffer, v11buffer, ECL_SYM("END1",1257), v14end, ECL_SYM("END2",1258), v14end);
   return value0;
L92:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
L48:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for ASSURE-SPACE-IN-BUFFER                             */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2608assure_space_in_buffer(cl_object v1stream, cl_object v2want)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_fixnum v3want;
 v3want = ecl_fixnum(v2want);
L1:;
 {
  cl_object v4buffer;
  cl_object v5length;
  cl_object v6fill_ptr;
  cl_object v7available;
  v4buffer = (v1stream)->instance.slots[(cl_fixnum)(3)];
  v5length = ecl_make_fixnum(ecl_length(v4buffer));
  v6fill_ptr = (v1stream)->instance.slots[(cl_fixnum)(4)];
  v7available = ecl_minus(v5length,v6fill_ptr);
  if (!(ecl_plusp(v7available))){
   goto L8;
  }
  value0 = v7available;
  cl_env_copy->nvalues = 1;
  return value0;
L8:;
  T0 = (v1stream)->instance.slots[(cl_fixnum)(2)];
  if (!(ecl_greater(v6fill_ptr,T0))){
   goto L10;
  }
  if (L2609maybe_output(v1stream, ECL_NIL)!=ECL_NIL) {
   goto L14;
  }
  L2613output_partial_line(v1stream);
L14:;
  goto L1;
L10:;
  {
   cl_object v8new_length;
   cl_object v9new_buffer;
   T0 = ecl_times(v5length,ecl_make_int8_t(2));
   T1 = ecl_times(ecl_make_fixnum(v3want),ecl_make_int8_t(5));
   T2 = ecl_floor2(T1,ecl_make_int8_t(4));
   T3 = ecl_plus(v5length,T2);
   v8new_length = ((ecl_float_nan_p(T3) || ecl_greatereq(T0,T3))?T0:T3);
   v9new_buffer = cl_make_string(1, v8new_length);
   (v1stream)->instance.slots[(cl_fixnum)(3)]=(v9new_buffer);
   cl_replace(4, v9new_buffer, v4buffer, ECL_SYM("END1",1257), v6fill_ptr);
   value0 = ecl_minus(v8new_length,v6fill_ptr);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for MAYBE-OUTPUT                                       */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2609maybe_output(cl_object v1stream, cl_object v2force_newlines_p)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4tail;
  cl_object v5output_anything;
  v3 = (v1stream)->instance.slots[(cl_fixnum)(11)];
  v4tail = v3;
  v5output_anything = ECL_NIL;
L7:;
  if (v4tail!=ECL_NIL) {
   goto L9;
  }
  (v1stream)->instance.slots[(cl_fixnum)(12)]=(ECL_NIL);
  goto L6;
L9:;
  {
   cl_object v6next;
   {
    cl_object v7;
    v7 = v4tail;
    if (Null(v7)){
     goto L17;
    }
    {
     cl_object v8;
     v8 = ECL_CONS_CDR(v7);
     v4tail = v8;
     v7 = ECL_CONS_CAR(v7);
    }
L17:;
    v6next = v7;
   }
   if (Null(si_of_class_p(2, v6next, VV[94]))){
    goto L23;
   }
   {
    cl_object v7;
    v7 = (cl_env_copy->function=(VV[116]->symbol.gfdef))->cfun.entry(1, v6next) /*  NEWLINE-KIND */;
    if (!((v7)==(VV[33]))){
     goto L32;
    }
    goto L29;
L32:;
    goto L30;
L30:;
    if (!((v7)==(VV[134]))){
     goto L36;
    }
    goto L29;
L36:;
    goto L34;
L34:;
    if (!((v7)==(VV[231]))){
     goto L27;
    }
    goto L28;
L29:;
L28:;
    goto L25;
L27:;
    if (!((v7)==(VV[233]))){
     goto L39;
    }
    if (Null(L2610misering_p(v1stream))){
     goto L13;
    }
    goto L25;
L39:;
    if (!((v7)==(VV[235]))){
     goto L41;
    }
    if (L2610misering_p(v1stream)!=ECL_NIL) {
     goto L43;
    }
    T0 = (v1stream)->instance.slots[(cl_fixnum)(7)];
    T1 = (v1stream)->instance.slots[(cl_fixnum)(8)];
    T2 = _ecl_car(T1);
    T3 = (cl_env_copy->function=(VV[53]->symbol.gfdef))->cfun.entry(1, T2) /*  LOGICAL-BLOCK-SECTION-START-LINE */;
    if (ecl_greater(T0,T3)) {
     goto L43;
    }
    {
     cl_object v8;
     T0 = (cl_env_copy->function=(VV[118]->symbol.gfdef))->cfun.entry(1, v6next) /*  NEWLINE-SECTION-END */;
     v8 = L2611fits_on_line_p(v1stream, T0, v2force_newlines_p);
     if (!((v8)==(ECL_T))){
      goto L51;
     }
     goto L13;
L51:;
     if (!((v8)==(ECL_NIL))){
      goto L54;
     }
     goto L25;
L54:;
     if (!((v8)==(VV[237]))){
      goto L57;
     }
     goto L6;
L57:;
     if (Null(si_ecase_error(v8, VV[238]))){
      goto L13;
     }
     goto L25;
    }
L43:;
    goto L25;
L41:;
    if (Null(si_ecase_error(v7, VV[239]))){
     goto L13;
    }
   }
L25:;
   v5output_anything = ECL_T;
   L2612output_line(v1stream, v6next);
   goto L13;
L23:;
   if (Null(si_of_class_p(2, v6next, VV[135]))){
    goto L61;
   }
   if (L2610misering_p(v1stream)!=ECL_NIL) {
    goto L13;
   }
   {
    cl_object v7;
    v7 = (cl_env_copy->function=(VV[148]->symbol.gfdef))->cfun.entry(1, v6next) /*  INDENTATION-KIND */;
    if (!((v7)==(ECL_SYM("BLOCK",1232)))){
     goto L66;
    }
    T1 = (v1stream)->instance.slots[(cl_fixnum)(8)];
    T2 = _ecl_car(T1);
    T0 = (cl_env_copy->function=(VV[64]->symbol.gfdef))->cfun.entry(1, T2) /*  LOGICAL-BLOCK-START-COLUMN */;
    goto L64;
L66:;
    if (!((v7)==(VV[141]))){
     goto L70;
    }
    {
     cl_object v8;
     v8 = (cl_env_copy->function=(VV[150]->symbol.gfdef))->cfun.entry(1, v6next) /*  INDENTATION-POSN */;
     T2 = (v1stream)->instance.slots[(cl_fixnum)(5)];
     T1 = ecl_minus(v8,T2);
     T0 = L2606index_column(T1, v1stream);
     goto L64;
    }
L70:;
    T0 = si_ecase_error(v7, VV[140]);
   }
L64:;
   T1 = (cl_env_copy->function=(VV[146]->symbol.gfdef))->cfun.entry(1, v6next) /*  INDENTATION-AMOUNT */;
   T2 = ecl_plus(T0,T1);
   L2567set_indentation(v1stream, T2);
   goto L13;
L61:;
   if (Null(si_of_class_p(2, v6next, VV[154]))){
    goto L76;
   }
   {
    cl_object v7;
    T0 = (cl_env_copy->function=(VV[170]->symbol.gfdef))->cfun.entry(1, v6next) /*  BLOCK-START-SECTION-END */;
    v7 = L2611fits_on_line_p(v1stream, T0, v2force_newlines_p);
    if (!((v7)==(ECL_T))){
     goto L79;
    }
    {
     cl_object v8end;
     v8end = (cl_env_copy->function=(VV[168]->symbol.gfdef))->cfun.entry(1, v6next) /*  BLOCK-START-BLOCK-END */;
     L2607expand_tabs(v1stream, v8end);
     {
      cl_object v9;
      cl_object v10;
      v9 = v8end;
      v10 = v4tail;
      T0 = ecl_memql(v9,v10);
     }
     v4tail = _ecl_cdr(T0);
     goto L13;
    }
L79:;
    if (!((v7)==(ECL_NIL))){
     goto L88;
    }
    {
     cl_object v9;
     v9 = (cl_env_copy->function=(VV[174]->symbol.gfdef))->cfun.entry(1, v6next) /*  BLOCK-START-POSN */;
     T2 = (v1stream)->instance.slots[(cl_fixnum)(5)];
     T1 = ecl_minus(v9,T2);
     T0 = L2606index_column(T1, v1stream);
    }
    T1 = (cl_env_copy->function=(VV[166]->symbol.gfdef))->cfun.entry(1, v6next) /*  BLOCK-START-PREFIX */;
    T2 = (cl_env_copy->function=(VV[164]->symbol.gfdef))->cfun.entry(1, v6next) /*  BLOCK-START-SUFFIX */;
    L2566really_start_logical_block(v1stream, T0, T1, T2);
    goto L13;
L88:;
    if (!((v7)==(VV[237]))){
     goto L96;
    }
    goto L6;
L96:;
    si_ecase_error(v7, VV[238]);
    goto L13;
   }
L76:;
   if (Null(si_of_class_p(2, v6next, VV[95]))){
    goto L98;
   }
   L2568really_end_logical_block(v1stream);
   goto L13;
L98:;
   if (Null(si_of_class_p(2, v6next, VV[191]))){
    goto L100;
   }
   L2607expand_tabs(v1stream, v6next);
   goto L13;
L100:;
   si_etypecase_error(v6next, VV[241]);
  }
L13:;
  (v1stream)->instance.slots[(cl_fixnum)(11)]=(v4tail);
  goto L7;
L6:;
  value0 = v5output_anything;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for MISERING-P                                         */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2610misering_p(cl_object v1stream)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 if (Null(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-MISER-WIDTH*",55)))){
  goto L3;
 }
 T0 = (v1stream)->instance.slots[(cl_fixnum)(2)];
 T1 = (v1stream)->instance.slots[(cl_fixnum)(8)];
 T2 = _ecl_car(T1);
 T3 = (cl_env_copy->function=(VV[64]->symbol.gfdef))->cfun.entry(1, T2) /*  LOGICAL-BLOCK-START-COLUMN */;
 T4 = ecl_minus(T0,T3);
 value0 = ecl_make_bool(ecl_lowereq(T4,ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-MISER-WIDTH*",55))));
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for FITS-ON-LINE-P                                     */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2611fits_on_line_p(cl_object v1stream, cl_object v2until, cl_object v3force_newlines_p)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v4available;
  v4available = (v1stream)->instance.slots[(cl_fixnum)(2)];
  if (ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59))!=ECL_NIL) {
   goto L4;
  }
  if (Null(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-LINES*",54)))){
   goto L4;
  }
  T0 = ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-LINES*",54));
  T1 = (v1stream)->instance.slots[(cl_fixnum)(7)];
  if (!(ecl_number_equalp(T0,T1))){
   goto L4;
  }
  v4available = ecl_minus(v4available,ecl_make_int8_t(3));
  {
   cl_object v5;
   T0 = (v1stream)->instance.slots[(cl_fixnum)(8)];
   T1 = _ecl_car(T0);
   v5 = (cl_env_copy->function=(VV[56]->symbol.gfdef))->cfun.entry(1, T1) /*  LOGICAL-BLOCK-SUFFIX-LENGTH */;
   v4available = ecl_minus(v4available,v5);
  }
L4:;
  if (Null(v2until)){
   goto L17;
  }
  {
   cl_object v5;
   v5 = (cl_env_copy->function=(VV[88]->symbol.gfdef))->cfun.entry(1, v2until) /*  QUEUED-OP-POSN */;
   T2 = (v1stream)->instance.slots[(cl_fixnum)(5)];
   T1 = ecl_minus(v5,T2);
   T0 = L2606index_column(T1, v1stream);
  }
  value0 = ecl_make_bool(ecl_lowereq(T0,v4available));
  cl_env_copy->nvalues = 1;
  return value0;
L17:;
  if (Null(v3force_newlines_p)){
   goto L24;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L24:;
  T0 = (v1stream)->instance.slots[(cl_fixnum)(4)];
  T1 = L2606index_column(T0, v1stream);
  if (!(ecl_greater(T1,v4available))){
   goto L26;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L26:;
  value0 = VV[237];
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for OUTPUT-LINE                                        */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2612output_line(cl_object v1stream, cl_object v2until)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3target;
  cl_object v4buffer;
  cl_object v5kind;
  cl_object v6literal_p;
  cl_object v7amount_to_consume;
  cl_object v8amount_to_print;
  v3target = (v1stream)->instance.slots[(cl_fixnum)(1)];
  v4buffer = (v1stream)->instance.slots[(cl_fixnum)(3)];
  v5kind = (cl_env_copy->function=(VV[116]->symbol.gfdef))->cfun.entry(1, v2until) /*  NEWLINE-KIND */;
  v6literal_p = ecl_make_bool((v5kind)==(VV[33]));
  {
   cl_object v9;
   v9 = (cl_env_copy->function=(VV[122]->symbol.gfdef))->cfun.entry(1, v2until) /*  NEWLINE-POSN */;
   T0 = (v1stream)->instance.slots[(cl_fixnum)(5)];
   v7amount_to_consume = ecl_minus(v9,T0);
  }
  if (Null(v6literal_p)){
   goto L13;
  }
  v8amount_to_print = v7amount_to_consume;
  goto L12;
L13:;
  {
   cl_object v9last_non_blank;
   T0 = (ECL_SYM("CHAR/=",218)->symbol.gfdef);
   v9last_non_blank = cl_position(8, ECL_CODE_CHAR(32), v4buffer, ECL_SYM("END",1256), v7amount_to_consume, VV[242], ECL_T, ECL_SYM("TEST",1353), T0);
   if (Null(v9last_non_blank)){
    goto L17;
   }
   v8amount_to_print = ecl_make_integer((ecl_fixnum(v9last_non_blank))+1);
   goto L12;
L17:;
   v8amount_to_print = ecl_make_int8_t(0);
  }
L12:;
  cl_write_string(4, v4buffer, v3target, ECL_SYM("END",1256), v8amount_to_print);
  {
   cl_object v9line_number;
   v9line_number = (v1stream)->instance.slots[(cl_fixnum)(7)];
   v9line_number = ecl_plus(v9line_number,ecl_make_int8_t(1));
   if (ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59))!=ECL_NIL) {
    goto L24;
   }
   if (Null(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-LINES*",54)))){
    goto L24;
   }
   if (!(ecl_greatereq(v9line_number,ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-LINES*",54))))){
    goto L24;
   }
   cl_write_string(2, VV[243], v3target);
   {
    cl_object v10suffix_length;
    T0 = (v1stream)->instance.slots[(cl_fixnum)(8)];
    T1 = _ecl_car(T0);
    v10suffix_length = (cl_env_copy->function=(VV[56]->symbol.gfdef))->cfun.entry(1, T1) /*  LOGICAL-BLOCK-SUFFIX-LENGTH */;
    if (ecl_zerop(v10suffix_length)) {
     goto L29;
    }
    {
     cl_object v11suffix;
     cl_object v12len;
     v11suffix = (v1stream)->instance.slots[(cl_fixnum)(10)];
     v12len = ecl_make_fixnum(ecl_length(v11suffix));
     T0 = ecl_minus(v12len,v10suffix_length);
     cl_write_string(6, v11suffix, v3target, ECL_SYM("START",1347), T0, ECL_SYM("END",1256), v12len);
    }
   }
L29:;
   cl_env_copy->values[0] = ECL_T;
   cl_env_copy->nvalues = 1;
   cl_throw(VV[244]);
L24:;
   (v1stream)->instance.slots[(cl_fixnum)(7)]=(v9line_number);
   cl_write_char(2, ECL_CODE_CHAR(10), v3target);
   (v1stream)->instance.slots[(cl_fixnum)(6)]=(ecl_make_int8_t(0));
   {
    cl_object v10fill_ptr;
    cl_object v11block;
    cl_object v12prefix_len;
    cl_object v13shift;
    cl_object v14new_fill_ptr;
    cl_object v15new_buffer;
    cl_object v16buffer_length;
    v10fill_ptr = (v1stream)->instance.slots[(cl_fixnum)(4)];
    T0 = (v1stream)->instance.slots[(cl_fixnum)(8)];
    v11block = _ecl_car(T0);
    if (Null(v6literal_p)){
     goto L49;
    }
    v12prefix_len = (cl_env_copy->function=(VV[60]->symbol.gfdef))->cfun.entry(1, v11block) /*  LOGICAL-BLOCK-PER-LINE-PREFIX-END */;
    goto L48;
L49:;
    v12prefix_len = (cl_env_copy->function=(VV[58]->symbol.gfdef))->cfun.entry(1, v11block) /*  LOGICAL-BLOCK-PREFIX-LENGTH */;
L48:;
    v13shift = ecl_minus(v7amount_to_consume,v12prefix_len);
    v14new_fill_ptr = ecl_minus(v10fill_ptr,v13shift);
    v15new_buffer = v4buffer;
    v16buffer_length = ecl_make_fixnum(ecl_length(v4buffer));
    if (!(ecl_greater(v14new_fill_ptr,v16buffer_length))){
     goto L55;
    }
    T0 = ecl_times(v16buffer_length,ecl_make_int8_t(2));
    T1 = ecl_minus(v14new_fill_ptr,v16buffer_length);
    T2 = ecl_times(T1,ecl_make_int8_t(5));
    T3 = ecl_floor2(T2,ecl_make_int8_t(4));
    T4 = ecl_plus(v16buffer_length,T3);
    T5 = ((ecl_float_nan_p(T4) || ecl_greatereq(T0,T4))?T0:T4);
    v15new_buffer = cl_make_string(1, T5);
    (v1stream)->instance.slots[(cl_fixnum)(3)]=(v15new_buffer);
L55:;
    cl_replace(8, v15new_buffer, v4buffer, ECL_SYM("START1",1348), v12prefix_len, ECL_SYM("START2",1349), v7amount_to_consume, ECL_SYM("END2",1258), v10fill_ptr);
    T0 = (v1stream)->instance.slots[(cl_fixnum)(9)];
    cl_replace(4, v15new_buffer, T0, ECL_SYM("END1",1257), v12prefix_len);
    (v1stream)->instance.slots[(cl_fixnum)(4)]=(v14new_fill_ptr);
    {
     cl_object v17;
     T0 = (v1stream)->instance.slots[(cl_fixnum)(5)];
     v17 = ecl_plus(T0,v13shift);
     (v1stream)->instance.slots[(cl_fixnum)(5)]=(v17);
    }
    if (v6literal_p!=ECL_NIL) {
     goto L71;
    }
    {
     cl_object v17;
     v17 = v12prefix_len;
     {
      cl_object v18;
      v18 = v11block;
      (v18)->instance.slots[(cl_fixnum)(1)]=v17;
     }
    }
    {
     cl_object v17;
     v17 = v9line_number;
     {
      cl_object v18;
      v18 = v11block;
      value0 = (v18)->instance.slots[(cl_fixnum)(5)]=v17;
      cl_env_copy->nvalues = 1;
      return value0;
     }
    }
L71:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for OUTPUT-PARTIAL-LINE                                */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2613output_partial_line(cl_object v1stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v2fill_ptr;
  cl_object v3tail;
  cl_object v4count;
  cl_object v5new_fill_ptr;
  cl_object v6buffer;
  v2fill_ptr = (v1stream)->instance.slots[(cl_fixnum)(4)];
  v3tail = (v1stream)->instance.slots[(cl_fixnum)(11)];
  if (Null(v3tail)){
   goto L7;
  }
  {
   cl_object v7;
   T0 = _ecl_car(v3tail);
   v7 = (cl_env_copy->function=(VV[88]->symbol.gfdef))->cfun.entry(1, T0) /*  QUEUED-OP-POSN */;
   T0 = (v1stream)->instance.slots[(cl_fixnum)(5)];
   v4count = ecl_minus(v7,T0);
   goto L6;
  }
L7:;
  v4count = v2fill_ptr;
L6:;
  v5new_fill_ptr = ecl_minus(v2fill_ptr,v4count);
  v6buffer = (v1stream)->instance.slots[(cl_fixnum)(3)];
  if (!(ecl_zerop(v4count))){
   goto L15;
  }
  cl_error(1, VV[247]);
L15:;
  T0 = (v1stream)->instance.slots[(cl_fixnum)(1)];
  cl_write_string(6, v6buffer, T0, ECL_SYM("START",1347), ecl_make_int8_t(0), ECL_SYM("END",1256), v4count);
  {
   cl_object v7;
   T0 = (v1stream)->instance.slots[(cl_fixnum)(6)];
   v7 = ecl_plus(T0,v4count);
   (v1stream)->instance.slots[(cl_fixnum)(6)]=(v7);
  }
  cl_replace(8, v6buffer, v6buffer, ECL_SYM("END1",1257), v5new_fill_ptr, ECL_SYM("START2",1349), v4count, ECL_SYM("END2",1258), v2fill_ptr);
  (v1stream)->instance.slots[(cl_fixnum)(4)]=(v5new_fill_ptr);
  {
   cl_object v7;
   T0 = (v1stream)->instance.slots[(cl_fixnum)(5)];
   v7 = ecl_plus(T0,v4count);
   value0 = (v1stream)->instance.slots[(cl_fixnum)(5)]=(v7);
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
}
/* function definition for FORCE-PRETTY-OUTPUT                                */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2614force_pretty_output(cl_object v1stream)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 L2609maybe_output(v1stream, ECL_NIL);
 L2607expand_tabs(v1stream, ECL_NIL);
 T0 = (v1stream)->instance.slots[(cl_fixnum)(3)];
 T1 = (v1stream)->instance.slots[(cl_fixnum)(1)];
 T2 = (v1stream)->instance.slots[(cl_fixnum)(4)];
 value0 = cl_write_string(4, T0, T1, ECL_SYM("END",1256), T2);
 return value0;
}
/* function definition for PPRINT-POP-HELPER                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
cl_object si_pprint_pop_helper(cl_object v1object, cl_object v2count, cl_object v3stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v4code;
  v4code = ECL_NIL;
  if (ECL_LISTP(v1object)) {
   goto L3;
  }
  cl_write_string(2, VV[250], v3stream);
  si_write_object(v1object, v3stream);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59))!=ECL_NIL) {
   goto L7;
  }
  if (!(ecl_eql(v2count,ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-LENGTH*",52))))){
   goto L7;
  }
  cl_write_string(2, VV[251], v3stream);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L7:;
  if (v1object==ECL_NIL) {
   goto L13;
  }
  if (ecl_zerop(v2count)) {
   goto L13;
  }
  if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*CIRCLE-COUNTER*",1018))==ECL_NIL)){
   goto L11;
  }
  goto L12;
L13:;
L12:;
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L11:;
  v4code = ecl_gethash_safe(v1object,ECL_SYM_VAL(cl_env_copy,ECL_SYM("*CIRCLE-STACK*",1019)),ECL_SYM("NULL",607));
  if (!((ECL_SYM("NULL",607))==(v4code))){
   goto L16;
  }
  si_search_print_circle(v1object);
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L16:;
  if (!(v4code==ECL_NIL)){
   goto L20;
  }
  if (!(ECL_FIXNUMP(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*CIRCLE-COUNTER*",1018)))||ECL_BIGNUMP(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*CIRCLE-COUNTER*",1018))))){
   goto L20;
  }
  value0 = ECL_T;
  cl_env_copy->nvalues = 1;
  return value0;
L20:;
  cl_write_string(2, VV[250], v3stream);
  si_write_object(v1object, v3stream);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
cl_object si_pprint_pop_helper_va(cl_narg narg, cl_object v5object, cl_object v6count, cl_object v7stream, ...)
{
 return si_pprint_pop_helper(v5object, v6count, v7stream);
}
/* function definition for CHECK-PRINT-LEVEL                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2615check_print_level()
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 if (ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59))!=ECL_NIL) {
  goto L4;
 }
 if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-LEVEL*",53))==ECL_NIL)){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (!(ecl_zerop(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-LEVEL*",53))))){
  goto L6;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L6:;
 T0 = ecl_one_minus(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-LEVEL*",53)));
 ECL_SETQ(cl_env_copy,ECL_SYM("*PRINT-LEVEL*",53),T0);
 value0 = ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-LEVEL*",53));
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for DO-PPRINT-LOGICAL-BLOCK                            */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2617do_pprint_logical_block(cl_object v1function, cl_object v2object, cl_object v3stream, cl_object v4prefix, cl_object v5per_line_prefix_p, cl_object v6suffix)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1function,env0);             /*  FUNCTION                */
 CLV1 = env0 = CONS(v4prefix,env0);               /*  PREFIX                  */
 CLV2 = env0 = CONS(v5per_line_prefix_p,env0);    /*  PER-LINE-PREFIX-P       */
 CLV3 = env0 = CONS(v6suffix,env0);               /*  SUFFIX                  */
 if (ECL_LISTP(v2object)) {
  goto L1;
 }
 si_write_object(v2object, v3stream);
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L1:;
 if (ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59))!=ECL_NIL) {
  goto L4;
 }
 if (!((ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-LEVEL*",53)))==(ecl_make_int8_t(0)))){
  goto L4;
 }
 cl_write_char(2, ECL_CODE_CHAR(35), v3stream);
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 {
  cl_object v7;
  v7 = ecl_make_cclosure_va((cl_objectfn)LC2616__lambda684,env0,Cblock,2);
  T0 = v7;
 }
 si_write_object_with_circle(v2object, v3stream, T0);
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for PPRINT-LOGICAL-BLOCK-HELPER                        */
/* optimize speed 3, debug 0, space 0, safety 0                               */
cl_object si_pprint_logical_block_helper(cl_object volatile v1function, cl_object volatile v2object, cl_object volatile v3stream, cl_object volatile v4prefix, cl_object volatile v5per_line_prefix_p, cl_object volatile v6suffix)
{
 cl_object volatile env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object volatile value0;
L1:;
 if (!((v3stream)==(ECL_NIL))){
  goto L4;
 }
 v3stream = ECL_SYM_VAL(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69));
 goto L3;
L4:;
 if (!((v3stream)==(ECL_T))){
  goto L7;
 }
 v3stream = ECL_SYM_VAL(cl_env_copy,ECL_SYM("*TERMINAL-IO*",70));
 goto L3;
L7:;
L3:;
 if (Null(L2547pretty_stream_p(v3stream))){
  goto L10;
 }
 value0 = L2617do_pprint_logical_block(v1function, v2object, v3stream, v4prefix, v5per_line_prefix_p, v6suffix);
 return value0;
L10:;
 {
  volatile cl_object v7stream;
  v7stream = L2548make_pretty_stream(v3stream);
  value0 = VV[244];                               /*  BEGIN CATCH CATCH2134   */
  {
   ecl_frs_push(cl_env_copy,value0);
   if (__ecl_frs_push_result!=0) {
   } else {
    L2617do_pprint_logical_block(v1function, v2object, v7stream, v4prefix, v5per_line_prefix_p, v6suffix);
    L2614force_pretty_output(v7stream);
   }
  }
  ecl_frs_pop(cl_env_copy);                       /*  END CATCH CATCH2134     */
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
cl_object si_pprint_logical_block_helper_va(cl_narg narg, cl_object v8function, cl_object v9object, cl_object v10stream, cl_object v11prefix, cl_object v12per_line_prefix_p, cl_object v13suffix, ...)
{
 return si_pprint_logical_block_helper(v8function, v9object, v10stream, v11prefix, v12per_line_prefix_p, v13suffix);
}
/* local function PPRINT-LOGICAL-BLOCK                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2618pprint_logical_block(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6stream_symbol;
  cl_object v7object;
  cl_object v8;
  cl_object v9prefix;
  cl_object v10prefix_p;
  cl_object v11;
  cl_object v12per_line_prefix;
  cl_object v13per_line_prefix_p;
  cl_object v14;
  cl_object v15suffix;
  cl_object v16suffix_p;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v17;
   v17 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v17;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v17;
   v17 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6stream_symbol = v17;
  }
  if (!(v5==ECL_NIL)){
   goto L17;
  }
  si_dm_too_few_arguments(v1);
L17:;
  {
   cl_object v17;
   v17 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7object = v17;
  }
  v8 = si_search_keyword(v5, VV[178]);
  if (!((v8)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L24;
  }
  v9prefix = VV[260];
  goto L23;
L24:;
  v9prefix = v8;
L23:;
  {
   bool v17;
   v17 = (v8)==(ECL_SYM("MISSING-KEYWORD",2044));
   v10prefix_p = (v17)?ECL_NIL:ECL_T;
  }
  v11 = si_search_keyword(v5, VV[261]);
  if (!((v11)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L29;
  }
  v12per_line_prefix = VV[260];
  goto L28;
L29:;
  v12per_line_prefix = v11;
L28:;
  {
   bool v17;
   v17 = (v11)==(ECL_SYM("MISSING-KEYWORD",2044));
   v13per_line_prefix_p = (v17)?ECL_NIL:ECL_T;
  }
  v14 = si_search_keyword(v5, VV[179]);
  if (!((v14)==(ECL_SYM("MISSING-KEYWORD",2044)))){
   goto L34;
  }
  v15suffix = VV[260];
  goto L33;
L34:;
  v15suffix = v14;
L33:;
  {
   bool v17;
   v17 = (v14)==(ECL_SYM("MISSING-KEYWORD",2044));
   v16suffix_p = (v17)?ECL_NIL:ECL_T;
  }
  si_check_keyword(2, v5, VV[263]);
  if (Null(v13per_line_prefix_p)){
   goto L38;
  }
  if (Null(v10prefix_p)){
   goto L40;
  }
  cl_error(1, VV[264]);
L40:;
  v9prefix = v12per_line_prefix;
L38:;
  {
   cl_object v17object_var;
   cl_object v18block_name;
   cl_object v19count_name;
   cl_object v20stream_var;
   cl_object v21function;
   v17object_var = cl_gensym(0);
   v18block_name = cl_gensym(1, VV[265]);
   v19count_name = cl_gensym(1, VV[266]);
   if (!((v6stream_symbol)==(ECL_NIL))){
    goto L47;
   }
   v20stream_var = ECL_SYM("*STANDARD-OUTPUT*",69);
   goto L46;
L47:;
   if (!((v6stream_symbol)==(ECL_T))){
    goto L50;
   }
   v20stream_var = ECL_SYM("*TERMINAL-IO*",70);
   goto L46;
L50:;
   v20stream_var = v6stream_symbol;
L46:;
   T0 = cl_list(2, v19count_name, ecl_make_int8_t(0));
   T1 = cl_list(4, v17object_var, v20stream_var, ECL_SYM("&AUX",9), T0);
   T2 = cl_list(4, ECL_SYM("IGNORABLE",429), v17object_var, v20stream_var, v19count_name);
   T3 = cl_list(2, ECL_SYM("DECLARE",276), T2);
   T4 = cl_list(4, VV[249], v17object_var, v19count_name, v20stream_var);
   T5 = cl_list(3, ECL_SYM("RETURN-FROM",728), v18block_name, ECL_NIL);
   T6 = cl_list(3, ECL_SYM("UNLESS",886), T4, T5);
   T7 = cl_list(2, ECL_SYM("INCF",435), v19count_name);
   if (Null(v7object)){
    goto L55;
   }
   T8 = cl_list(2, ECL_SYM("POP",646), v17object_var);
   goto L54;
L55:;
   T8 = ECL_NIL;
L54:;
   T9 = cl_list(4, ECL_SYM("PROGN",674), T6, T7, T8);
   T10 = cl_list(2, ECL_SYM("QUOTE",682), T9);
   T11 = cl_list(3, ECL_SYM("PPRINT-POP",658), ECL_NIL, T10);
   if (Null(v7object)){
    goto L58;
   }
   T13 = cl_list(2, ECL_SYM("NULL",607), v17object_var);
   T14 = cl_list(3, ECL_SYM("RETURN-FROM",728), v18block_name, ECL_NIL);
   T15 = cl_list(3, ECL_SYM("WHEN",909), T13, T14);
   T12 = cl_list(2, ECL_SYM("QUOTE",682), T15);
   goto L57;
L58:;
   T13 = cl_list(3, ECL_SYM("RETURN-FROM",728), v18block_name, ECL_NIL);
   T12 = cl_list(2, ECL_SYM("QUOTE",682), T13);
L57:;
   T13 = cl_list(3, ECL_SYM("PPRINT-EXIT-IF-LIST-EXHAUSTED",652), ECL_NIL, T12);
   T14 = cl_list(2, T11, T13);
   T15 = cl_listX(3, ECL_SYM("MACROLET",523), T14, v3);
   v21function = cl_list(5, ECL_SYM("LAMBDA-BLOCK",1377), v18block_name, T1, T3, T15);
   T0 = cl_list(2, ECL_SYM("FUNCTION",398), v21function);
   value0 = cl_list(7, VV[256], T0, v7object, v6stream_symbol, v9prefix, v13per_line_prefix_p, v15suffix);
   return value0;
  }
 }
}
static cl_object LC2618pprint_logical_block_va(cl_narg narg, cl_object v22, cl_object v23, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[267]);
 {
  return LC2618pprint_logical_block(v22, v23);
 }
}
/* local function PPRINT-EXIT-IF-LIST-EXHAUSTED                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2619pprint_exit_if_list_exhausted(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = cl_error(1, VV[269]);
  return value0;
 }
}
static cl_object LC2619pprint_exit_if_list_exhausted_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[270]);
 {
  return LC2619pprint_exit_if_list_exhausted(v4, v5);
 }
}
/* local function PPRINT-POP                                                  */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2620pprint_pop(cl_object v1, cl_object v2)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (Null(v3)){
   goto L3;
  }
  si_dm_too_many_arguments(v1);
L3:;
  value0 = cl_error(1, VV[271]);
  return value0;
 }
}
static cl_object LC2620pprint_pop_va(cl_narg narg, cl_object v4, cl_object v5, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[272]);
 {
  return LC2620pprint_pop(v4, v5);
 }
}
/* function definition for PPRINT-NEWLINE                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object cl_pprint_newline(cl_narg narg, cl_object v1kind, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("PPRINT-NEWLINE",657));
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(ECL_SYM("PPRINT-NEWLINE",657));
 {
  cl_object v2stream;
  va_list args; va_start(args,v1kind);
  {
   int i = 1;
   if (i >= narg) {
    v2stream = ECL_NIL;
   } else {
    i++;
    v2stream = va_arg(args,cl_object);
    value0 = cl_streamp(v2stream);
    if (value0!=ECL_NIL) {
     goto L5;
    }
    if (!((v2stream)==(ECL_T))){
     goto L11;
    }
    value0 = VV[197];
    goto L9;
L11:;
    value0 = ECL_NIL;
    goto L9;
L9:;
    if (value0!=ECL_NIL) {
     goto L8;
    }
    if (!((v2stream)==(ECL_NIL))){
     goto L14;
    }
    T0 = VV[198];
    goto L3;
L14:;
    T0 = ECL_NIL;
    goto L3;
L8:;
    T0 = value0;
    goto L3;
L5:;
    T0 = value0;
    goto L3;
L3:;
    if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[278],v2stream);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
   }
  }
  va_end(args);
  if (!((v1kind)==(VV[231]))){
   goto L22;
  }
  value0 = VV[273];
  goto L20;
L22:;
  value0 = ECL_NIL;
  goto L20;
L20:;
  if (value0!=ECL_NIL) {
   goto L19;
  }
  if (!((v1kind)==(VV[233]))){
   goto L26;
  }
  value0 = VV[274];
  goto L24;
L26:;
  value0 = ECL_NIL;
  goto L24;
L24:;
  if (value0!=ECL_NIL) {
   goto L19;
  }
  if (!((v1kind)==(VV[235]))){
   goto L30;
  }
  value0 = VV[275];
  goto L28;
L30:;
  value0 = ECL_NIL;
  goto L28;
L28:;
  if (value0!=ECL_NIL) {
   goto L19;
  }
  if (!((v1kind)==(VV[134]))){
   goto L33;
  }
  T0 = VV[276];
  goto L17;
L33:;
  T0 = ECL_NIL;
  goto L17;
L19:;
  T0 = value0;
  goto L17;
L17:;
  if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[277],v1kind);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  {
   cl_object v3stream;
   if (!((v2stream)==(ECL_T))){
    goto L37;
   }
   v3stream = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*TERMINAL-IO*",70));
   goto L36;
L37:;
   if (!((v2stream)==(ECL_NIL))){
    goto L40;
   }
   v3stream = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69));
   goto L36;
L40:;
   v3stream = v2stream;
L36:;
   if (Null(L2547pretty_stream_p(v3stream))){
    goto L35;
   }
   if (Null(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PRINT-PRETTY*",57)))){
    goto L35;
   }
   L2580enqueue_newline(v3stream, v1kind);
  }
L35:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for PPRINT-INDENT                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object cl_pprint_indent(cl_narg narg, cl_object v1relative_to, cl_object v2n, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("PPRINT-INDENT",654));
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(ECL_SYM("PPRINT-INDENT",654));
 {
  cl_object v3stream;
  va_list args; va_start(args,v2n);
  {
   int i = 2;
   if (i >= narg) {
    v3stream = ECL_NIL;
   } else {
    i++;
    v3stream = va_arg(args,cl_object);
    value0 = cl_streamp(v3stream);
    if (value0!=ECL_NIL) {
     goto L5;
    }
    if (!((v3stream)==(ECL_T))){
     goto L11;
    }
    value0 = VV[197];
    goto L9;
L11:;
    value0 = ECL_NIL;
    goto L9;
L9:;
    if (value0!=ECL_NIL) {
     goto L8;
    }
    if (!((v3stream)==(ECL_NIL))){
     goto L14;
    }
    T0 = VV[198];
    goto L3;
L14:;
    T0 = ECL_NIL;
    goto L3;
L8:;
    T0 = value0;
    goto L3;
L5:;
    T0 = value0;
    goto L3;
L3:;
    if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[278],v3stream);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
   }
  }
  va_end(args);
  if (!((v1relative_to)==(ECL_SYM("BLOCK",1232)))){
   goto L22;
  }
  value0 = VV[140];
  goto L20;
L22:;
  value0 = ECL_NIL;
  goto L20;
L20:;
  if (value0!=ECL_NIL) {
   goto L19;
  }
  if (!((v1relative_to)==(VV[141]))){
   goto L25;
  }
  T0 = VV[142];
  goto L17;
L25:;
  T0 = ECL_NIL;
  goto L17;
L19:;
  T0 = value0;
  goto L17;
L17:;
  if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[143],v1relative_to);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  T0 = cl_realp(v2n);
  if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(ECL_SYM("REAL",706),v2n);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  {
   cl_object v4stream;
   if (!((v3stream)==(ECL_T))){
    goto L30;
   }
   v4stream = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*TERMINAL-IO*",70));
   goto L29;
L30:;
   if (!((v3stream)==(ECL_NIL))){
    goto L33;
   }
   v4stream = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69));
   goto L29;
L33:;
   v4stream = v3stream;
L29:;
   if (Null(L2547pretty_stream_p(v4stream))){
    goto L28;
   }
   if (Null(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PRINT-PRETTY*",57)))){
    goto L28;
   }
   T0 = ecl_round1(v2n);
   L2585enqueue_indent(v4stream, v1relative_to, T0);
  }
L28:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for PPRINT-TAB                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object cl_pprint_tab(cl_narg narg, cl_object v1kind, cl_object v2colnum, cl_object v3colinc, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(ECL_SYM("PPRINT-TAB",659));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("PPRINT-TAB",659));
 {
  cl_object v4stream;
  va_list args; va_start(args,v3colinc);
  {
   int i = 3;
   if (i >= narg) {
    v4stream = ECL_NIL;
   } else {
    i++;
    v4stream = va_arg(args,cl_object);
    value0 = cl_streamp(v4stream);
    if (value0!=ECL_NIL) {
     goto L5;
    }
    if (!((v4stream)==(ECL_T))){
     goto L11;
    }
    value0 = VV[197];
    goto L9;
L11:;
    value0 = ECL_NIL;
    goto L9;
L9:;
    if (value0!=ECL_NIL) {
     goto L8;
    }
    if (!((v4stream)==(ECL_NIL))){
     goto L14;
    }
    T0 = VV[198];
    goto L3;
L14:;
    T0 = ECL_NIL;
    goto L3;
L8:;
    T0 = value0;
    goto L3;
L5:;
    T0 = value0;
    goto L3;
L3:;
    if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[278],v4stream);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
   }
  }
  va_end(args);
  if (!((v1kind)==(ECL_SYM("LINE",1677)))){
   goto L22;
  }
  value0 = VV[279];
  goto L20;
L22:;
  value0 = ECL_NIL;
  goto L20;
L20:;
  if (value0!=ECL_NIL) {
   goto L19;
  }
  if (!((v1kind)==(VV[216]))){
   goto L26;
  }
  value0 = VV[280];
  goto L24;
L26:;
  value0 = ECL_NIL;
  goto L24;
L24:;
  if (value0!=ECL_NIL) {
   goto L19;
  }
  if (!((v1kind)==(VV[215]))){
   goto L30;
  }
  value0 = VV[281];
  goto L28;
L30:;
  value0 = ECL_NIL;
  goto L28;
L28:;
  if (value0!=ECL_NIL) {
   goto L19;
  }
  if (!((v1kind)==(VV[217]))){
   goto L33;
  }
  T0 = VV[282];
  goto L17;
L33:;
  T0 = ECL_NIL;
  goto L17;
L19:;
  T0 = value0;
  goto L17;
L17:;
  if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[283],v1kind);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  {
   cl_object v5;
   cl_object v6;
   v5 = ecl_make_int8_t(0);
   v6 = v5;
   if (!(ECL_FIXNUMP(v2colnum)||ECL_BIGNUMP(v2colnum))){
    goto L40;
   }
   v6 = v2colnum;
   T0 = ecl_make_bool(ecl_greatereq(v6,ecl_make_int8_t(0)));
   goto L36;
L40:;
   T0 = ECL_NIL;
   goto L36;
  }
L36:;
  if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(ECL_SYM("UNSIGNED-BYTE",889),v2colnum);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  {
   cl_object v5;
   cl_object v6;
   v5 = ecl_make_int8_t(0);
   v6 = v5;
   if (!(ECL_FIXNUMP(v3colinc)||ECL_BIGNUMP(v3colinc))){
    goto L49;
   }
   v6 = v3colinc;
   T0 = ecl_make_bool(ecl_greatereq(v6,ecl_make_int8_t(0)));
   goto L45;
L49:;
   T0 = ECL_NIL;
   goto L45;
  }
L45:;
  if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(ECL_SYM("UNSIGNED-BYTE",889),v3colinc);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  {
   cl_object v5stream;
   if (!((v4stream)==(ECL_T))){
    goto L55;
   }
   v5stream = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*TERMINAL-IO*",70));
   goto L54;
L55:;
   if (!((v4stream)==(ECL_NIL))){
    goto L58;
   }
   v5stream = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*STANDARD-OUTPUT*",69));
   goto L54;
L58:;
   v5stream = v4stream;
L54:;
   if (Null(L2547pretty_stream_p(v5stream))){
    goto L53;
   }
   if (Null(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*PRINT-PRETTY*",57)))){
    goto L53;
   }
   L2604enqueue_tab(v5stream, v1kind, v2colnum, v3colinc);
  }
L53:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for PPRINT-FILL                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object cl_pprint_fill(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("PPRINT-FILL",653));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("PPRINT-FILL",653));
 {
  cl_object v3colon_;
  cl_object v4atsign_;
  va_list args; va_start(args,v2list);
  {
   int i = 2;
   if (i >= narg) {
    v3colon_ = ECL_T;
   } else {
    i++;
    v3colon_ = va_arg(args,cl_object);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
   }
   if (i >= narg) {
    v4atsign_ = ECL_NIL;
   } else {
    i++;
    v4atsign_ = va_arg(args,cl_object);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
   }
  }
  va_end(args);
  value0 = cl_streamp(v1stream);
  if (value0!=ECL_NIL) {
   goto L8;
  }
  if (!((v1stream)==(ECL_T))){
   goto L14;
  }
  value0 = VV[197];
  goto L12;
L14:;
  value0 = ECL_NIL;
  goto L12;
L12:;
  if (value0!=ECL_NIL) {
   goto L11;
  }
  if (!((v1stream)==(ECL_NIL))){
   goto L17;
  }
  T0 = VV[198];
  goto L6;
L17:;
  T0 = ECL_NIL;
  goto L6;
L11:;
  T0 = value0;
  goto L6;
L8:;
  T0 = value0;
  goto L6;
L6:;
  if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[278],v1stream);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  {
   cl_object v5;
   v5 = ecl_make_cfun_va((cl_objectfn)LC2621__pprint_logical_block_922_va,ECL_NIL,Cblock,2);
   T0 = v5;
  }
  if (Null(v3colon_)){
   goto L21;
  }
  T1 = VV[287];
  goto L20;
L21:;
  T1 = VV[260];
L20:;
  if (Null(v3colon_)){
   goto L24;
  }
  T2 = VV[288];
  goto L23;
L24:;
  T2 = VV[260];
L23:;
  value0 = si_pprint_logical_block_helper(T0, v2list, v1stream, T1, ECL_NIL, T2);
  return value0;
 }
}
/* function definition for PPRINT-LINEAR                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object cl_pprint_linear(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("PPRINT-LINEAR",655));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("PPRINT-LINEAR",655));
 {
  cl_object v3colon_;
  cl_object v4atsign_;
  va_list args; va_start(args,v2list);
  {
   int i = 2;
   if (i >= narg) {
    v3colon_ = ECL_T;
   } else {
    i++;
    v3colon_ = va_arg(args,cl_object);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
   }
   if (i >= narg) {
    v4atsign_ = ECL_NIL;
   } else {
    i++;
    v4atsign_ = va_arg(args,cl_object);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
   }
  }
  va_end(args);
  value0 = cl_streamp(v1stream);
  if (value0!=ECL_NIL) {
   goto L8;
  }
  if (!((v1stream)==(ECL_T))){
   goto L14;
  }
  value0 = VV[197];
  goto L12;
L14:;
  value0 = ECL_NIL;
  goto L12;
L12:;
  if (value0!=ECL_NIL) {
   goto L11;
  }
  if (!((v1stream)==(ECL_NIL))){
   goto L17;
  }
  T0 = VV[198];
  goto L6;
L17:;
  T0 = ECL_NIL;
  goto L6;
L11:;
  T0 = value0;
  goto L6;
L8:;
  T0 = value0;
  goto L6;
L6:;
  if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[278],v1stream);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  {
   cl_object v5;
   v5 = ecl_make_cfun_va((cl_objectfn)LC2622__pprint_logical_block_949_va,ECL_NIL,Cblock,2);
   T0 = v5;
  }
  if (Null(v3colon_)){
   goto L21;
  }
  T1 = VV[287];
  goto L20;
L21:;
  T1 = VV[260];
L20:;
  if (Null(v3colon_)){
   goto L24;
  }
  T2 = VV[288];
  goto L23;
L24:;
  T2 = VV[260];
L23:;
  value0 = si_pprint_logical_block_helper(T0, v2list, v1stream, T1, ECL_NIL, T2);
  return value0;
 }
}
/* function definition for PPRINT-TABULAR                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object cl_pprint_tabular(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("PPRINT-TABULAR",660));
 if (ecl_unlikely(narg>5)) FEwrong_num_arguments(ECL_SYM("PPRINT-TABULAR",660));
 {
  cl_object v3colon_;
  cl_object v4atsign_;
  cl_object v5tabsize;
  va_list args; va_start(args,v2list);
  {
   int i = 2;
   if (i >= narg) {
    v3colon_ = ECL_T;
   } else {
    i++;
    v3colon_ = va_arg(args,cl_object);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
   }
   if (i >= narg) {
    v4atsign_ = ECL_NIL;
   } else {
    i++;
    v4atsign_ = va_arg(args,cl_object);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
   }
   if (i >= narg) {
    v5tabsize = ecl_make_int8_t(16);
   } else {
    i++;
    v5tabsize = va_arg(args,cl_object);
    {
     cl_object v6;
     cl_object v7;
     v6 = ecl_make_int8_t(0);
     v7 = v6;
     if (!(ECL_FIXNUMP(v5tabsize)||ECL_BIGNUMP(v5tabsize))){
      goto L14;
     }
     v7 = v5tabsize;
     value0 = ecl_make_bool(ecl_greatereq(v7,ecl_make_int8_t(0)));
     goto L10;
L14:;
     value0 = ECL_NIL;
     goto L10;
    }
L10:;
    if (value0!=ECL_NIL) {
     goto L9;
    }
    T0 = ecl_make_bool(v5tabsize==ECL_NIL);
    goto L7;
L9:;
    T0 = value0;
    goto L7;
L7:;
    if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[291],v5tabsize);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
   }
  }
  va_end(args);
  value0 = cl_streamp(v1stream);
  if (value0!=ECL_NIL) {
   goto L21;
  }
  if (!((v1stream)==(ECL_T))){
   goto L27;
  }
  value0 = VV[197];
  goto L25;
L27:;
  value0 = ECL_NIL;
  goto L25;
L25:;
  if (value0!=ECL_NIL) {
   goto L24;
  }
  if (!((v1stream)==(ECL_NIL))){
   goto L30;
  }
  T0 = VV[198];
  goto L19;
L30:;
  T0 = ECL_NIL;
  goto L19;
L24:;
  T0 = value0;
  goto L19;
L21:;
  T0 = value0;
  goto L19;
L19:;
  if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[278],v1stream);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  {
   cl_object env1 = env0;
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(v5tabsize,env1);            /*  TABSIZE                 */
   {
    cl_object v6;
    v6 = ecl_make_cclosure_va((cl_objectfn)LC2623__pprint_logical_block_976,env1,Cblock,2);
    T0 = v6;
   }
   if (Null(v3colon_)){
    goto L34;
   }
   T1 = VV[287];
   goto L33;
L34:;
   T1 = VV[260];
L33:;
   if (Null(v3colon_)){
    goto L37;
   }
   T2 = VV[288];
   goto L36;
L37:;
   T2 = VV[260];
L36:;
   value0 = si_pprint_logical_block_helper(T0, v2list, v1stream, T1, ECL_NIL, T2);
   return value0;
  }
 }
}
/* function definition for MAKE-PPRINT-DISPATCH-ENTRY                         */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2624make_pprint_dispatch_entry(cl_narg narg, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object v1;
 cl_object v2;
 cl_object v3;
 cl_object v4;
 ecl_va_list args; ecl_va_start(args,narg,narg,0);
 {
  cl_object keyvars[8];
  cl_parse_key(args,4,L2624make_pprint_dispatch_entrykeys,keyvars,NULL,FALSE);
  ecl_va_end(args);
  if (Null(keyvars[4])) {
   v1 = (cl_env_copy->function=(VV[109]->symbol.gfdef))->cfun.entry(0) /*  REQUIRED-ARGUMENT */;
  } else {
   v1 = keyvars[0];
  }
  if (Null(keyvars[5])) {
   v2 = ecl_make_int8_t(0);
  } else {
   v2 = keyvars[1];
  }
  if (Null(keyvars[6])) {
   {
    bool v5;
    v5 = ECL_SYM_VAL(cl_env_copy,VV[293])!=OBJNULL;
    v3 = (v5)?ECL_NIL:ECL_T;
   }
  } else {
   v3 = keyvars[2];
  }
  if (Null(keyvars[7])) {
   v4 = (cl_env_copy->function=(VV[109]->symbol.gfdef))->cfun.entry(0) /*  REQUIRED-ARGUMENT */;
  } else {
   v4 = keyvars[3];
  }
 }
 if (cl_functionp(v4)!=ECL_NIL) {
  goto L5;
 }
 if (ECL_SYMBOLP(v4)) {
  goto L5;
 }
 si_structure_type_error(v4, VV[299], VV[294], ECL_SYM("FUNCTION",398));
L5:;
 if (!((v3)==(ECL_T))){
  goto L12;
 }
 goto L8;
L12:;
 goto L10;
L10:;
 if (!((v3)==(ECL_NIL))){
  goto L15;
 }
 goto L8;
L15:;
 goto L9;
L9:;
 si_structure_type_error(v3, VV[199], VV[294], VV[300]);
L8:;
 if (cl_realp(v2)!=ECL_NIL) {
  goto L17;
 }
 si_structure_type_error(v2, ECL_SYM("REAL",706), VV[294], VV[301]);
L17:;
 value0 = si_make_structure(5, VV[302], v1, v2, v3, v4);
 return value0;
}
/* local function LAMBDA1009                                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2625__lambda1009(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[294]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(3), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[294]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(3));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2625__lambda1009_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2625__lambda1009(v5, v6x);
}
/* local function LAMBDA1014                                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2626__lambda1014(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[294]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[294]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2626__lambda1014_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2626__lambda1014(v5, v6x);
}
/* local function LAMBDA1019                                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2627__lambda1019(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[294]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[294]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2627__lambda1019_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2627__lambda1019(v5, v6x);
}
/* local function LAMBDA1024                                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2628__lambda1024(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[294]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[294]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2628__lambda1024_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2628__lambda1024(v5, v6x);
}
/* function definition for %PRINT-PPRINT-DISPATCH-ENTRY                       */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2630_print_pprint_dispatch_entry(cl_object v1entry, cl_object v2stream, cl_object v3depth)
{
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1entry,env0);                /*  ENTRY                   */
 CLV1 = env0 = CONS(v2stream,env0);               /*  STREAM                  */
 {
  cl_object v4;
  v4 = ecl_make_cclosure_va((cl_objectfn)LC2629_print_unreadable_object_body_,env0,Cblock,0);
  value0 = si_print_unreadable_object_function(ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1), ECL_T, ECL_NIL, v4);
  return value0;
 }
}
static cl_object L2630_print_pprint_dispatch_entry_va(cl_narg narg, cl_object v5entry, cl_object v6stream, cl_object v7depth, ...)
{
 return L2630_print_pprint_dispatch_entry(v5entry, v6stream, v7depth);
}
/* function definition for MAKE-PPRINT-DISPATCH-TABLE                         */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2631make_pprint_dispatch_table(cl_narg narg, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object v1;
 cl_object v2;
 cl_object v3;
 ecl_va_list args; ecl_va_start(args,narg,narg,0);
 {
  cl_object keyvars[6];
  cl_parse_key(args,3,L2631make_pprint_dispatch_tablekeys,keyvars,NULL,FALSE);
  ecl_va_end(args);
  v1 = keyvars[0];
  v2 = keyvars[1];
  if (Null(keyvars[5])) {
   T0 = (ECL_SYM("EQL",336)->symbol.gfdef);
   v3 = cl_make_hash_table(2, ECL_SYM("TEST",1353), T0);
  } else {
   v3 = keyvars[2];
  }
 }
 if (ECL_LISTP(v2)) {
  goto L3;
 }
 si_structure_type_error(v2, ECL_SYM("LIST",483), VV[315], VV[320]);
L3:;
 value0 = si_make_structure(4, VV[321], v1, v2, v3);
 return value0;
}
/* local function LAMBDA1032                                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2632__lambda1032(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[315]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(2), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[315]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(2));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2632__lambda1032_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2632__lambda1032(v5, v6x);
}
/* local function LAMBDA1037                                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2633__lambda1037(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[315]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(1), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[315]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(1));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2633__lambda1037_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2633__lambda1037(v5, v6x);
}
/* local function LAMBDA1042                                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2634__lambda1042(cl_object v1, cl_object v2x)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  cl_object v4;
  v3 = cl_gensym(0);
  v4 = cl_gensym(0);
  T0 = cl_list(2, ECL_SYM("QUOTE",682), VV[315]);
  T1 = cl_list(6, ECL_SYM("COMPARE-AND-SWAP-STRUCTURE",1527), v2x, T0, ecl_make_int8_t(0), v3, v4);
  T2 = cl_list(2, ECL_SYM("QUOTE",682), VV[315]);
  T3 = cl_list(4, ECL_SYM("STRUCTURE-REF",1178), v2x, T2, ecl_make_int8_t(0));
  cl_env_copy->nvalues = 6;
  cl_env_copy->values[5] = T3;
  cl_env_copy->values[4] = T1;
  cl_env_copy->values[3] = v4;
  cl_env_copy->values[2] = v3;
  cl_env_copy->values[1] = ECL_NIL;
  cl_env_copy->values[0] = ECL_NIL;
  return cl_env_copy->values[0];
 }
}
static cl_object LC2634__lambda1042_va(cl_narg narg, cl_object v5, cl_object v6x, ...)
{
 return LC2634__lambda1042(v5, v6x);
}
/* function definition for %PRINT-PPRINT-DISPATCH-TABLE                       */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2635_print_pprint_dispatch_table(cl_object v1table, cl_object v2stream, cl_object v3depth)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = si_print_unreadable_object_function(v1table, v2stream, ECL_T, ECL_T, ECL_NIL);
 return value0;
}
static cl_object L2635_print_pprint_dispatch_table_va(cl_narg narg, cl_object v4table, cl_object v5stream, cl_object v6depth, ...)
{
 return L2635_print_pprint_dispatch_table(v4table, v5stream, v6depth);
}
/* function definition for CONS-TYPE-SPECIFIER-P                              */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2636cons_type_specifier_p(cl_object v1spec)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 if (!(ECL_CONSP(v1spec))){
  goto L3;
 }
 T0 = _ecl_car(v1spec);
 if (!((T0)==(ECL_SYM("CONS",253)))){
  goto L3;
 }
 if (Null(_ecl_cdr(v1spec))){
  goto L3;
 }
 T0 = _ecl_cddr(v1spec);
 if (!(T0==ECL_NIL)){
  goto L3;
 }
 {
  cl_object v2car;
  v2car = _ecl_cadr(v1spec);
  if (!(ECL_CONSP(v2car))){
   goto L10;
  }
  {
   cl_object v3carcar;
   v3carcar = _ecl_car(v2car);
   if ((v3carcar)==(ECL_SYM("MEMBER",554))) {
    goto L14;
   }
   if (!((v3carcar)==(ECL_SYM("EQL",336)))){
    goto L10;
   }
   goto L12;
L14:;
  }
L12:;
  if (Null(_ecl_cdr(v2car))){
   goto L10;
  }
  T0 = _ecl_cddr(v2car);
  value0 = ecl_make_bool(T0==ECL_NIL);
  cl_env_copy->nvalues = 1;
  return value0;
L10:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for ENTRY<                                             */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2637entry_(cl_object v1e1, cl_object v2e2)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 if (Null((cl_env_copy->function=(VV[306]->symbol.gfdef))->cfun.entry(1, v1e1) /*  PPRINT-DISPATCH-ENTRY-INITIAL-P */)){
  goto L2;
 }
 if (Null((cl_env_copy->function=(VV[306]->symbol.gfdef))->cfun.entry(1, v2e2) /*  PPRINT-DISPATCH-ENTRY-INITIAL-P */)){
  goto L4;
 }
 T0 = (cl_env_copy->function=(VV[308]->symbol.gfdef))->cfun.entry(1, v1e1) /*  PPRINT-DISPATCH-ENTRY-PRIORITY */;
 T1 = (cl_env_copy->function=(VV[308]->symbol.gfdef))->cfun.entry(1, v2e2) /*  PPRINT-DISPATCH-ENTRY-PRIORITY */;
 value0 = ecl_make_bool(ecl_lower(T0,T1));
 cl_env_copy->nvalues = 1;
 return value0;
L4:;
 value0 = ECL_T;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 if (Null((cl_env_copy->function=(VV[306]->symbol.gfdef))->cfun.entry(1, v2e2) /*  PPRINT-DISPATCH-ENTRY-INITIAL-P */)){
  goto L6;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L6:;
 T0 = (cl_env_copy->function=(VV[308]->symbol.gfdef))->cfun.entry(1, v1e1) /*  PPRINT-DISPATCH-ENTRY-PRIORITY */;
 T1 = (cl_env_copy->function=(VV[308]->symbol.gfdef))->cfun.entry(1, v2e2) /*  PPRINT-DISPATCH-ENTRY-PRIORITY */;
 value0 = ecl_make_bool(ecl_lower(T0,T1));
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for COPY-PPRINT-DISPATCH                               */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object cl_copy_pprint_dispatch(cl_narg narg, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg>1)) FEwrong_num_arguments(ECL_SYM("COPY-PPRINT-DISPATCH",260));
 {
  cl_object v1table;
  va_list args; va_start(args,narg);
  {
   int i = 0;
   if (i >= narg) {
    v1table = ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-PPRINT-DISPATCH*",56));
   } else {
    i++;
    v1table = va_arg(args,cl_object);
    value0 = si_of_class_p(2, v1table, VV[315]);
    if (value0!=ECL_NIL) {
     goto L5;
    }
    T0 = ecl_make_bool(v1table==ECL_NIL);
    goto L3;
L5:;
    T0 = value0;
    goto L3;
L3:;
    if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[334],v1table);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
   }
  }
  va_end(args);
  {
   cl_object v2orig;
   value0 = v1table;
   if (value0!=ECL_NIL) {
    goto L9;
   }
   v2orig = ecl_cmp_symbol_value(cl_env_copy,VV[293]);
   goto L7;
L9:;
   v2orig = value0;
   goto L7;
L7:;
   {
    cl_object v3new;
    cl_object env1 = env0;
    T0 = (cl_env_copy->function=(VV[325]->symbol.gfdef))->cfun.entry(1, v2orig) /*  PPRINT-DISPATCH-TABLE-ENTRIES */;
    T1 = cl_copy_list(T0);
    v3new = L2631make_pprint_dispatch_table(2, VV[332], T1);
    T0 = (cl_env_copy->function=(VV[323]->symbol.gfdef))->cfun.entry(1, v3new) /*  PPRINT-DISPATCH-TABLE-CONS-ENTRIES */;
    env1 = ECL_NIL;
    CLV0 = env1 = CONS(T0,env1);                  /*  NEW-CONS-ENTRIES        */
    {
     cl_object v4;
     v4 = ecl_make_cclosure_va((cl_objectfn)LC2638__lambda1050,env1,Cblock,2);
     T0 = v4;
    }
    T1 = (cl_env_copy->function=(VV[323]->symbol.gfdef))->cfun.entry(1, v2orig) /*  PPRINT-DISPATCH-TABLE-CONS-ENTRIES */;
    cl_maphash(T0, T1);
    value0 = v3new;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
}
/* function definition for DEFAULT-PPRINT-DISPATCH                            */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2639default_pprint_dispatch(cl_object v1stream, cl_object v2object)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 value0 = si_write_ugly_object(v2object, v1stream);
 return value0;
}
static cl_object L2639default_pprint_dispatch_va(cl_narg narg, cl_object v3stream, cl_object v4object, ...)
{
 return L2639default_pprint_dispatch(v3stream, v4object);
}
/* function definition for PPRINT-DISPATCH                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object cl_pprint_dispatch(cl_narg narg, cl_object v1object, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(ECL_SYM("PPRINT-DISPATCH",651));
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(ECL_SYM("PPRINT-DISPATCH",651));
 {
  cl_object v2table;
  va_list args; va_start(args,v1object);
  {
   int i = 1;
   if (i >= narg) {
    v2table = ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-PPRINT-DISPATCH*",56));
   } else {
    i++;
    v2table = va_arg(args,cl_object);
    value0 = si_of_class_p(2, v2table, VV[315]);
    if (value0!=ECL_NIL) {
     goto L5;
    }
    T0 = ecl_make_bool(v2table==ECL_NIL);
    goto L3;
L5:;
    T0 = value0;
    goto L3;
L3:;
    if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[334],v2table);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
   }
  }
  va_end(args);
  {
   cl_object v3table;
   cl_object v4cons_entry;
   cl_object v5entry;
   value0 = v2table;
   if (value0!=ECL_NIL) {
    goto L9;
   }
   v3table = ecl_cmp_symbol_value(cl_env_copy,VV[293]);
   goto L7;
L9:;
   v3table = value0;
   goto L7;
L7:;
   if (!(ECL_CONSP(v1object))){
    goto L13;
   }
   T0 = ecl_car(v1object);
   T1 = (cl_env_copy->function=(VV[323]->symbol.gfdef))->cfun.entry(1, v3table) /*  PPRINT-DISPATCH-TABLE-CONS-ENTRIES */;
   v4cons_entry = ecl_gethash_safe(T0,T1,ECL_NIL);
   goto L11;
L13:;
   v4cons_entry = ECL_NIL;
   goto L11;
L11:;
   {
    cl_object v6;
    v6 = (cl_env_copy->function=(VV[325]->symbol.gfdef))->cfun.entry(1, v3table) /*  PPRINT-DISPATCH-TABLE-ENTRIES */;
    goto L19;
L18:;
    {
     cl_object v7entry;
     v7entry = ecl_car(v6);
     if (Null(v4cons_entry)){
      goto L23;
     }
     if (Null(L2637entry_(v7entry, v4cons_entry))){
      goto L23;
     }
     v5entry = v4cons_entry;
     goto L15;
L23:;
     T0 = (cl_env_copy->function=(VV[310]->symbol.gfdef))->cfun.entry(1, v7entry) /*  PPRINT-DISPATCH-ENTRY-TYPE */;
     if (Null(cl_typep(2, v1object, T0))){
      goto L26;
     }
     v5entry = v7entry;
     goto L15;
L26:;
    }
    v6 = ecl_cdr(v6);
L19:;
    if (Null(v6)){
     goto L30;
    }
    goto L18;
L30:;
    v5entry = v4cons_entry;
   }
L15:;
   if (Null(v5entry)){
    goto L32;
   }
   T0 = (cl_env_copy->function=(VV[304]->symbol.gfdef))->cfun.entry(1, v5entry) /*  PPRINT-DISPATCH-ENTRY-FUNCTION */;
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = ECL_T;
   cl_env_copy->values[0] = T0;
   return cl_env_copy->values[0];
L32:;
   T0 = (VV[335]->symbol.gfdef);
   cl_env_copy->nvalues = 2;
   cl_env_copy->values[1] = ECL_NIL;
   cl_env_copy->values[0] = T0;
   return cl_env_copy->values[0];
  }
 }
}
/* function definition for SET-PPRINT-DISPATCH                                */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object cl_set_pprint_dispatch(cl_narg narg, cl_object v1type, cl_object v2function, ...)
{
 cl_object T0, T1, T2, T3;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("SET-PPRINT-DISPATCH",751));
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(ECL_SYM("SET-PPRINT-DISPATCH",751));
 {
  cl_object v3priority;
  cl_object v4table;
  va_list args; va_start(args,v2function);
  {
   int i = 2;
   if (i >= narg) {
    v3priority = ecl_make_int8_t(0);
   } else {
    i++;
    v3priority = va_arg(args,cl_object);
    T0 = cl_realp(v3priority);
    if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(ECL_SYM("REAL",706),v3priority);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
   }
   if (i >= narg) {
    v4table = ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-PPRINT-DISPATCH*",56));
   } else {
    i++;
    v4table = va_arg(args,cl_object);
    T0 = si_of_class_p(2, v4table, VV[315]);
    if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[315],v4table);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
   }
  }
  va_end(args);
  value0 = ecl_make_bool(v2function==ECL_NIL);
  if (value0!=ECL_NIL) {
   goto L8;
  }
  value0 = cl_functionp(v2function);
  if (value0!=ECL_NIL) {
   goto L8;
  }
  T0 = ecl_make_bool(ECL_SYMBOLP(v2function));
  goto L6;
L8:;
  T0 = value0;
  goto L6;
L6:;
  if (ecl_unlikely(!((T0)!=ECL_NIL)))
         FEwrong_type_argument(VV[337],v2function);
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 0;
  if (Null((cl_env_copy->function=(VV[327]->symbol.gfdef))->cfun.entry(1, v4table) /*  PPRINT-DISPATCH-TABLE-READ-ONLY-P */)){
   goto L11;
  }
  cl_cerror(3, VV[338], VV[339], v4table);
L11:;
  if (Null(v2function)){
   goto L15;
  }
  if (Null(L2636cons_type_specifier_p(v1type))){
   goto L17;
  }
  T0 = ecl_cadr(v1type);
  T1 = ecl_cadr(T0);
  T2 = (cl_env_copy->function=(VV[323]->symbol.gfdef))->cfun.entry(1, v4table) /*  PPRINT-DISPATCH-TABLE-CONS-ENTRIES */;
  T3 = L2624make_pprint_dispatch_entry(6, ECL_SYM("TYPE",1356), v1type, VV[340], v3priority, ECL_SYM("FUNCTION",1273), v2function);
  si_hash_set(T1, T2, T3);
  goto L14;
L17:;
  {
   cl_object v5;
   cl_object v6;
   cl_object v7list;
   T0 = (cl_env_copy->function=(VV[325]->symbol.gfdef))->cfun.entry(1, v4table) /*  PPRINT-DISPATCH-TABLE-ENTRIES */;
   T1 = (VV[310]->symbol.gfdef);
   T2 = (ECL_SYM("EQUAL",337)->symbol.gfdef);
   v5 = cl_delete(6, v1type, T0, ECL_SYM("KEY",1297), T1, ECL_SYM("TEST",1353), T2);
   v6 = L2624make_pprint_dispatch_entry(6, ECL_SYM("TYPE",1356), v1type, VV[340], v3priority, ECL_SYM("FUNCTION",1273), v2function);
   v7list = v5;
   {
    cl_object v8;
    cl_object v9prev;
    cl_object v10next;
    v8 = v7list;
    v9prev = ECL_NIL;
    v10next = v8;
    goto L30;
L29:;
    T0 = ecl_car(v10next);
    if (Null(L2637entry_(T0, v6))){
     goto L32;
    }
    if (Null(v9prev)){
     goto L35;
    }
    {
     cl_object v11;
     v11 = CONS(v6,v10next);
     {
      cl_object v12;
      v12 = v9prev;
      if (ecl_unlikely(ECL_ATOM(v12))) FEtype_error_cons(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v12;
     }
     (ECL_CONS_CDR(T0)=v11,T0);
     goto L34;
    }
L35:;
    v7list = CONS(v6,v10next);
L34:;
    goto L24;
L32:;
    v9prev = v10next;
    v10next = ecl_cdr(v10next);
L30:;
    if (v10next==ECL_NIL) {
     goto L46;
    }
    goto L29;
L46:;
    if (Null(v9prev)){
     goto L48;
    }
    {
     cl_object v11;
     v11 = ecl_list1(v6);
     {
      cl_object v12;
      v12 = v9prev;
      if (ecl_unlikely(ECL_ATOM(v12))) FEtype_error_cons(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T0 = v12;
     }
     (ECL_CONS_CDR(T0)=v11,T0);
     goto L24;
    }
L48:;
    v7list = ecl_list1(v6);
   }
L24:;
   ecl_structure_set(v4table,VV[315],(cl_fixnum)(1),v7list);
   goto L14;
  }
L15:;
  if (Null(L2636cons_type_specifier_p(v1type))){
   goto L56;
  }
  T0 = ecl_cadr(v1type);
  T1 = ecl_cadr(T0);
  T2 = (cl_env_copy->function=(VV[323]->symbol.gfdef))->cfun.entry(1, v4table) /*  PPRINT-DISPATCH-TABLE-CONS-ENTRIES */;
  cl_remhash(T1, T2);
  goto L14;
L56:;
  {
   cl_object v8;
   T0 = (cl_env_copy->function=(VV[325]->symbol.gfdef))->cfun.entry(1, v4table) /*  PPRINT-DISPATCH-TABLE-ENTRIES */;
   T1 = (VV[310]->symbol.gfdef);
   T2 = (ECL_SYM("EQUAL",337)->symbol.gfdef);
   v8 = cl_delete(6, v1type, T0, ECL_SYM("KEY",1297), T1, ECL_SYM("TEST",1353), T2);
   ecl_structure_set(v4table,VV[315],(cl_fixnum)(1),v8);
  }
L14:;
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
/* function definition for PPRINT-ARRAY                                       */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2640pprint_array(cl_object v1stream, cl_object v2array)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-ARRAY*",46))==ECL_NIL)){
  goto L7;
 }
 if (ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59))==ECL_NIL) {
  goto L4;
 }
 goto L5;
L7:;
 goto L5;
L5:;
 if (ECL_STRINGP(v2array)) {
  goto L4;
 }
 if (!(ECL_BIT_VECTOR_P(v2array))){
  goto L2;
 }
 goto L3;
L4:;
L3:;
 value0 = si_write_ugly_object(v2array, v1stream);
 return value0;
L2:;
 if (Null(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59)))){
  goto L10;
 }
 value0 = L2651pprint_raw_array(v1stream, v2array);
 return value0;
L10:;
 if (!(ECL_VECTORP(v2array))){
  goto L12;
 }
 value0 = L2643pprint_vector(v1stream, v2array);
 return value0;
L12:;
 value0 = L2648pprint_multi_dim_array(v1stream, v2array);
 return value0;
}
static cl_object L2640pprint_array_va(cl_narg narg, cl_object v3stream, cl_object v4array, ...)
{
 return L2640pprint_array(v3stream, v4array);
}
/* function definition for PPRINT-VECTOR                                      */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2643pprint_vector(cl_object v1stream, cl_object v2vector)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  v3 = ecl_make_cfun_va((cl_objectfn)LC2642__lambda1085_va,ECL_NIL,Cblock,2);
  T0 = v3;
 }
 value0 = si_write_object_with_circle(v2vector, v1stream, T0);
 return value0;
}
static cl_object L2643pprint_vector_va(cl_narg narg, cl_object v3stream, cl_object v4vector, ...)
{
 return L2643pprint_vector(v3stream, v4vector);
}
/* function definition for PPRINT-ARRAY-CONTENTS                              */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2646pprint_array_contents(cl_object v1stream, cl_object v2array)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v2array,env0);                /*  ARRAY                   */
 T0 = cl_array_dimensions(ECL_CONS_CAR(CLV0));
 value0 = (aux_closure.env=env0,cl_env_copy->function=(cl_object)&aux_closure,LC2645output_guts(3, v1stream, ecl_make_int8_t(0), T0));
 return value0;
}
/* function definition for PPRINT-MULTI-DIM-ARRAY                             */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2648pprint_multi_dim_array(cl_object v1stream, cl_object v2array)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  v3 = ecl_make_cfun_va((cl_objectfn)LC2647__lambda1126_va,ECL_NIL,Cblock,2);
  T0 = v3;
 }
 value0 = si_write_object_with_circle(v2array, v1stream, T0);
 return value0;
}
/* function definition for PPRINT-RAW-ARRAY                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2651pprint_raw_array(cl_object v1stream, cl_object v2array)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  v3 = ecl_make_cfun_va((cl_objectfn)LC2650__lambda1132_va,ECL_NIL,Cblock,2);
  T0 = v3;
 }
 value0 = si_write_object_with_circle(v2array, v1stream, T0);
 return value0;
}
/* function definition for PPRINT-LAMBDA-LIST                                 */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2655pprint_lambda_list(cl_narg narg, cl_object v1stream, cl_object v2lambda_list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2lambda_list);
 va_end(args);
 {
  cl_object v3;
  v3 = ecl_make_cfun_va((cl_objectfn)LC2654__pprint_logical_block_1146_va,ECL_NIL,Cblock,2);
  T0 = v3;
 }
 value0 = si_pprint_logical_block_helper(T0, v2lambda_list, v1stream, VV[287], ECL_NIL, VV[288]);
 return value0;
}
/* function definition for PPRINT-LAMBDA                                      */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2657pprint_lambda(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(v2list,env1);                /*  ARG                     */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC2656__pprint_logical_block_1241,env1,Cblock,2);
   T0 = v3;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v1stream, VV[287], ECL_NIL, VV[288]);
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for PPRINT-BLOCK                                       */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2659pprint_block(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(v2list,env1);                /*  ARG                     */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC2658__pprint_logical_block_1282,env1,Cblock,2);
   T0 = v3;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v1stream, VV[287], ECL_NIL, VV[288]);
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for PPRINT-FLET                                        */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2663pprint_flet(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(v2list,env1);                /*  ARG                     */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC2662__pprint_logical_block_1323,env1,Cblock,2);
   T0 = v3;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v1stream, VV[287], ECL_NIL, VV[288]);
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for PPRINT-LET                                         */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2667pprint_let(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(v2list,env1);                /*  ARG                     */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC2666__pprint_logical_block_1429,env1,Cblock,2);
   T0 = v3;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v1stream, VV[287], ECL_NIL, VV[288]);
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for PPRINT-PROGN                                       */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2669pprint_progn(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(v2list,env1);                /*  ARG                     */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC2668__pprint_logical_block_1523,env1,Cblock,2);
   T0 = v3;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v1stream, VV[287], ECL_NIL, VV[288]);
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for PPRINT-PROGV                                       */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2671pprint_progv(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(v2list,env1);                /*  ARG                     */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC2670__pprint_logical_block_1555,env1,Cblock,2);
   T0 = v3;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v1stream, VV[287], ECL_NIL, VV[288]);
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for PPRINT-QUOTE                                       */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2672pprint_quote(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 if (!(ECL_CONSP(v2list))){
  goto L1;
 }
 T0 = _ecl_cdr(v2list);
 if (!(ECL_CONSP(T0))){
  goto L1;
 }
 T0 = _ecl_cddr(v2list);
 if (!(T0==ECL_NIL)){
  goto L1;
 }
 {
  cl_object v3;
  v3 = _ecl_car(v2list);
  if (!((v3)==(ECL_SYM("FUNCTION",398)))){
   goto L6;
  }
  cl_write_string(2, VV[403], v1stream);
  T0 = _ecl_cadr(v2list);
  value0 = si_write_object(T0, v1stream);
  return value0;
L6:;
  if (!((v3)==(ECL_SYM("QUOTE",682)))){
   goto L9;
  }
  cl_write_char(2, ECL_CODE_CHAR(39), v1stream);
  T0 = _ecl_cadr(v2list);
  value0 = si_write_object(T0, v1stream);
  return value0;
L9:;
  if (!((v3)==(ECL_SYM("QUASIQUOTE",1545)))){
   goto L12;
  }
  cl_write_char(2, ECL_CODE_CHAR(96), v1stream);
  T0 = _ecl_cadr(v2list);
  value0 = si_write_object(T0, v1stream);
  return value0;
L12:;
  if (!((v3)==(ECL_SYM("UNQUOTE",1038)))){
   goto L15;
  }
  cl_write_char(2, ECL_CODE_CHAR(44), v1stream);
  T0 = _ecl_cadr(v2list);
  value0 = si_write_object(T0, v1stream);
  return value0;
L15:;
  if (!((v3)==(ECL_SYM("UNQUOTE-SPLICE",1040)))){
   goto L18;
  }
  cl_write_string(2, VV[404], v1stream);
  T0 = _ecl_cadr(v2list);
  value0 = si_write_object(T0, v1stream);
  return value0;
L18:;
  if (!((v3)==(ECL_SYM("UNQUOTE-NSPLICE",1039)))){
   goto L21;
  }
  cl_write_string(2, VV[405], v1stream);
  T0 = _ecl_cadr(v2list);
  value0 = si_write_object(T0, v1stream);
  return value0;
L21:;
  value0 = cl_pprint_fill(2, v1stream, v2list);
  return value0;
 }
L1:;
 value0 = cl_pprint_fill(2, v1stream, v2list);
 return value0;
}
/* function definition for PPRINT-SETQ                                        */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2674pprint_setq(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v2list,env0);                 /*  LIST                    */
 va_end(args);
 {
  cl_object v3;
  v3 = ecl_make_cclosure_va((cl_objectfn)LC2673__pprint_logical_block_1607,env0,Cblock,2);
  T0 = v3;
 }
 value0 = si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v1stream, VV[287], ECL_NIL, VV[288]);
 return value0;
}
/* function definition for PPRINT-TAGBODY                                     */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2676pprint_tagbody(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object v3;
  v3 = ecl_make_cfun_va((cl_objectfn)LC2675__pprint_logical_block_1639_va,ECL_NIL,Cblock,2);
  T0 = v3;
 }
 value0 = si_pprint_logical_block_helper(T0, v2list, v1stream, VV[287], ECL_NIL, VV[288]);
 return value0;
}
/* function definition for PPRINT-CASE                                        */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2679pprint_case(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(v2list,env1);                /*  ARG                     */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC2678__pprint_logical_block_1662,env1,Cblock,2);
   T0 = v3;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v1stream, VV[287], ECL_NIL, VV[288]);
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for PPRINT-DEFUN                                       */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2681pprint_defun(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(v2list,env1);                /*  ARG                     */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC2680__pprint_logical_block_1734,env1,Cblock,2);
   T0 = v3;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v1stream, VV[287], ECL_NIL, VV[288]);
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for PPRINT-DESTRUCTURING-BIND                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2683pprint_destructuring_bind(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(v2list,env1);                /*  ARG                     */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC2682__pprint_logical_block_1784,env1,Cblock,2);
   T0 = v3;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v1stream, VV[287], ECL_NIL, VV[288]);
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for PPRINT-DO                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2687pprint_do(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object v3;
  v3 = ecl_make_cfun_va((cl_objectfn)LC2686__pprint_logical_block_1834_va,ECL_NIL,Cblock,2);
  T0 = v3;
 }
 value0 = si_pprint_logical_block_helper(T0, v2list, v1stream, VV[287], ECL_NIL, VV[288]);
 return value0;
}
/* function definition for PPRINT-DOLIST                                      */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2690pprint_dolist(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object v3;
  v3 = ecl_make_cfun_va((cl_objectfn)LC2689__pprint_logical_block_1924_va,ECL_NIL,Cblock,2);
  T0 = v3;
 }
 value0 = si_pprint_logical_block_helper(T0, v2list, v1stream, VV[287], ECL_NIL, VV[288]);
 return value0;
}
/* function definition for PPRINT-TYPECASE                                    */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2693pprint_typecase(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(v2list,env1);                /*  ARG                     */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC2692__pprint_logical_block_1991,env1,Cblock,2);
   T0 = v3;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v1stream, VV[287], ECL_NIL, VV[288]);
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for PPRINT-PROG                                        */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2695pprint_prog(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object v3;
  v3 = ecl_make_cfun_va((cl_objectfn)LC2694__pprint_logical_block_2060_va,ECL_NIL,Cblock,2);
  T0 = v3;
 }
 value0 = si_pprint_logical_block_helper(T0, v2list, v1stream, VV[287], ECL_NIL, VV[288]);
 return value0;
}
/* function definition for PPRINT-FUNCTION-CALL                               */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object L2697pprint_function_call(cl_narg narg, cl_object v1stream, cl_object v2list, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 va_list args; va_start(args,v2list);
 va_end(args);
 {
  cl_object env1 = env0;
  env1 = ECL_NIL;
  CLV0 = env1 = CONS(v2list,env1);                /*  ARG                     */
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC2696__pprint_logical_block_2087,env1,Cblock,2);
   T0 = v3;
  }
  si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v1stream, VV[287], ECL_NIL, VV[288]);
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* closure LAMBDA684                                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2616__lambda684(cl_narg narg, cl_object v1object, cl_object v2s, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2, CLV3;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV3 = env0;                                     /*  SUFFIX                  */
 CLV2 = _ecl_cdr(CLV3);
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
L1:;
 if (L2547pretty_stream_p(v2s)!=ECL_NIL) {
  goto L2;
 }
 v2s = L2548make_pretty_stream(v2s);
L2:;
 if (ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-READABLY*",59))!=ECL_NIL) {
  goto L7;
 }
 if (Null(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-LEVEL*",53)))){
  goto L7;
 }
 T0 = ecl_one_minus(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-LEVEL*",53)));
 goto L5;
L7:;
 T0 = ECL_NIL;
 goto L5;
L5:;
 ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-LEVEL*",53),T0); /*  *PRINT-LEVEL*  */
 L2593start_logical_block(v2s, ECL_CONS_CAR(CLV1), ECL_CONS_CAR(CLV2), ECL_CONS_CAR(CLV3));
 ecl_function_dispatch(cl_env_copy,ECL_CONS_CAR(CLV0))(2, v1object, v2s);
 value0 = L2597end_logical_block(v2s);
 ecl_bds_unwind1(cl_env_copy);
 return value0;
 }
}
/* local function PPRINT-LOGICAL-BLOCK-922                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2621__pprint_logical_block_922(cl_object v1, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  if (!(v1==ECL_NIL)){
   goto L3;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
L5:;
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L8;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L8:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   {
    cl_object v5;
    v5 = v4;
    {
     bool v6;
     v6 = ECL_LISTP(v5);
     if (ecl_unlikely(!(v6)))
         FEwrong_type_argument(VV[286],v5);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v4)){
    goto L17;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L17:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
  if (!(v1==ECL_NIL)){
   goto L23;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L23:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_newline(2, VV[235], v2stream);
  goto L5;
 }
}
static cl_object LC2621__pprint_logical_block_922_va(cl_narg narg, cl_object v4, cl_object v5stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[284]);
 {
  return LC2621__pprint_logical_block_922(v4, v5stream);
 }
}
/* local function PPRINT-LOGICAL-BLOCK-949                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2622__pprint_logical_block_949(cl_object v1, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  if (!(v1==ECL_NIL)){
   goto L3;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
L5:;
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L8;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L8:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   {
    cl_object v5;
    v5 = v4;
    {
     bool v6;
     v6 = ECL_LISTP(v5);
     if (ecl_unlikely(!(v6)))
         FEwrong_type_argument(VV[286],v5);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
    }
   }
   if (Null(v4)){
    goto L17;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L17:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
  if (!(v1==ECL_NIL)){
   goto L23;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L23:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_newline(2, VV[231], v2stream);
  goto L5;
 }
}
static cl_object LC2622__pprint_logical_block_949_va(cl_narg narg, cl_object v4, cl_object v5stream, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[289]);
 {
  return LC2622__pprint_logical_block_949(v4, v5stream);
 }
}
/* closure PPRINT-LOGICAL-BLOCK-976                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2623__pprint_logical_block_976(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  TABSIZE                 */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[290]);
 {
L1:;
  {
   cl_object v3;
   v3 = ecl_make_int8_t(0);
   if (!(v1==ECL_NIL)){
    goto L3;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L3:;
L5:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L8;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L8:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v4;
    v4 = v1;
    {
     cl_object v5;
     v5 = v4;
     {
      bool v6;
      v6 = ECL_LISTP(v5);
      if (ecl_unlikely(!(v6)))
         FEwrong_type_argument(VV[286],v5);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
     }
    }
    if (Null(v4)){
     goto L17;
    }
    {
     cl_object v5;
     v5 = ECL_CONS_CDR(v4);
     v1 = v5;
     v4 = ECL_CONS_CAR(v4);
    }
L17:;
    T0 = v4;
   }
   si_write_object(T0, v2stream);
   if (!(v1==ECL_NIL)){
    goto L23;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L23:;
   cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
   value0 = ECL_CONS_CAR(CLV0);
   if (value0!=ECL_NIL) {
    goto L29;
   }
   T0 = ecl_make_int8_t(16);
   goto L27;
L29:;
   T0 = value0;
   goto L27;
L27:;
   cl_pprint_tab(4, VV[217], ecl_make_int8_t(0), T0, v2stream);
   cl_pprint_newline(2, VV[235], v2stream);
   goto L5;
  }
 }
 }
}
/* closure .PRINT-UNREADABLE-OBJECT-BODY.                                     */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2629_print_unreadable_object_body_(cl_narg narg, ...)
{
 cl_object T0, T1, T2;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  STREAM                  */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
L1:;
 T0 = (cl_env_copy->function=(VV[310]->symbol.gfdef))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  PPRINT-DISPATCH-ENTRY-TYPE */;
 T1 = (cl_env_copy->function=(VV[308]->symbol.gfdef))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  PPRINT-DISPATCH-ENTRY-PRIORITY */;
 T2 = (cl_env_copy->function=(VV[306]->symbol.gfdef))->cfun.entry(1, ECL_CONS_CAR(CLV0)) /*  PPRINT-DISPATCH-ENTRY-INITIAL-P */;
 value0 = cl_format(5, ECL_CONS_CAR(CLV1), VV[313], T0, T1, T2);
 return value0;
 }
}
/* closure LAMBDA1050                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC2638__lambda1050(cl_narg narg, cl_object v1key, cl_object v2value, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  NEW-CONS-ENTRIES        */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[333]);
 {
L1:;
  value0 = si_hash_set(v1key, ECL_CONS_CAR(CLV0), v2value);
  return value0;
 }
 }
}
/* local function LAMBDA1085                                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2642__lambda1085(cl_object v1vector, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1vector,env0);               /*  VECTOR                  */
 {
  cl_object v3;
  v3 = ecl_make_cclosure_va((cl_objectfn)LC2641__pprint_logical_block_1088,env0,Cblock,2);
  T0 = v3;
 }
 value0 = si_pprint_logical_block_helper(T0, ECL_NIL, v2stream, VV[348], ECL_NIL, VV[288]);
 return value0;
}
static cl_object LC2642__lambda1085_va(cl_narg narg, cl_object v3vector, cl_object v4stream, ...)
{
 return LC2642__lambda1085(v3vector, v4stream);
}
/* closure OUTPUT-GUTS                                                        */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2645output_guts(cl_narg narg, cl_object v1stream, cl_object v2index, cl_object v3dimensions, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARRAY                   */
 { /* ... closure scanning finished */
 CLV1 = env0 = CONS(v2index,env0);                /*  INDEX                   */
 CLV2 = env0 = CONS(v3dimensions,env0);           /*  DIMENSIONS              */
 if (!(ECL_CONS_CAR(CLV2)==ECL_NIL)){
  goto L1;
 }
 T0 = ecl_aref_unsafe(ECL_CONS_CAR(CLV0),ecl_fixnum(ECL_CONS_CAR(CLV1)));
 value0 = si_write_object(T0, v1stream);
 return value0;
L1:;
 {
  cl_object v4;
  v4 = ecl_make_cclosure_va((cl_objectfn)LC2644__pprint_logical_block_1109,env0,Cblock,2);
  T0 = v4;
 }
 value0 = si_pprint_logical_block_helper(T0, ECL_NIL, v1stream, VV[287], ECL_NIL, VV[288]);
 return value0;
 }
}
/* local function LAMBDA1126                                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2647__lambda1126(cl_object v1array, cl_object v2stream)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  v3 = ecl_make_fixnum((((v1array)->d.t == t_array)?(v1array)->array.rank:1));
  cl_write_string(2, VV[354], v2stream);
  cl_write(9, v3, ECL_SYM("STREAM",1350), v2stream, ECL_SYM("BASE",1231), ecl_make_int8_t(10), ECL_SYM("RADIX",1332), ECL_NIL, ECL_SYM("ESCAPE",1261), ECL_NIL);
  cl_write_string(2, VV[355], v2stream);
 }
 value0 = L2646pprint_array_contents(v2stream, v1array);
 return value0;
}
static cl_object LC2647__lambda1126_va(cl_narg narg, cl_object v3array, cl_object v4stream, ...)
{
 return LC2647__lambda1126(v3array, v4stream);
}
/* local function LAMBDA1132                                                  */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2650__lambda1132(cl_object v1array, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v1array,env0);                /*  ARRAY                   */
 {
  cl_object v3;
  v3 = ecl_make_cclosure_va((cl_objectfn)LC2649__pprint_logical_block_1135,env0,Cblock,2);
  T0 = v3;
 }
 value0 = si_pprint_logical_block_helper(T0, ECL_NIL, v2stream, VV[358], ECL_NIL, VV[288]);
 return value0;
}
static cl_object LC2650__lambda1132_va(cl_narg narg, cl_object v3array, cl_object v4stream, ...)
{
 return LC2650__lambda1132(v3array, v4stream);
}
/* local function PPRINT-LOGICAL-BLOCK-1146                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2654__pprint_logical_block_1146(cl_object v1, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4first;
   cl_object env1 = env0;
   env1 = ECL_NIL;
   CLV0 = env1 = CONS(ECL_SYM("REQUIRED",1012),env1); /*  STATE               */
   v4first = ECL_T;
L4:;
   if (!(v1==ECL_NIL)){
    goto L6;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L6:;
   if (v4first!=ECL_NIL) {
    goto L8;
   }
   cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
L8:;
   {
    cl_object v5arg;
    if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
     goto L12;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L12:;
    v3 = ecl_plus(v3,ecl_make_int8_t(1));
    {
     cl_object v6;
     v6 = v1;
     if (Null(v6)){
      goto L18;
     }
     {
      cl_object v7;
      v7 = ECL_CONS_CDR(v6);
      v1 = v7;
      v6 = ECL_CONS_CAR(v6);
     }
L18:;
     v5arg = v6;
    }
    if (v4first!=ECL_NIL) {
     goto L24;
    }
    if (!((v5arg)==(ECL_SYM("&OPTIONAL",13)))){
     goto L26;
    }
    ECL_CONS_CAR(CLV0) = VV[361];
    cl_pprint_newline(2, VV[231], v2stream);
    goto L24;
L26:;
    if (!((v5arg)==(ECL_SYM("&REST",14)))){
     goto L35;
    }
    goto L32;
L35:;
    goto L33;
L33:;
    if (!((v5arg)==(ECL_SYM("&BODY",10)))){
     goto L30;
    }
    goto L31;
L32:;
L31:;
    ECL_CONS_CAR(CLV0) = ECL_SYM("REQUIRED",1012);
    cl_pprint_newline(2, VV[231], v2stream);
    goto L24;
L30:;
    if (!((v5arg)==(ECL_SYM("&KEY",12)))){
     goto L40;
    }
    ECL_CONS_CAR(CLV0) = ECL_SYM("KEY",1297);
    cl_pprint_newline(2, VV[231], v2stream);
    goto L24;
L40:;
    if (!((v5arg)==(ECL_SYM("&AUX",9)))){
     goto L44;
    }
    ECL_CONS_CAR(CLV0) = VV[361];
    cl_pprint_newline(2, VV[231], v2stream);
    goto L24;
L44:;
    cl_pprint_newline(2, VV[235], v2stream);
L24:;
    if (!((ECL_CONS_CAR(CLV0))==(ECL_SYM("REQUIRED",1012)))){
     goto L48;
    }
    L2655pprint_lambda_list(2, v2stream, v5arg);
    goto L10;
L48:;
    if (!((ECL_CONS_CAR(CLV0))==(VV[361]))){
     goto L55;
    }
    goto L52;
L55:;
    goto L53;
L53:;
    if (!((ECL_CONS_CAR(CLV0))==(ECL_SYM("KEY",1297)))){
     goto L50;
    }
    goto L51;
L52:;
L51:;
    {
     cl_object v6;
     v6 = ecl_make_cclosure_va((cl_objectfn)LC2653__pprint_logical_block_1190,env1,Cblock,2);
     T0 = v6;
    }
    si_pprint_logical_block_helper(T0, v5arg, v2stream, VV[287], ECL_NIL, VV[288]);
    goto L10;
L50:;
    si_ecase_error(ECL_CONS_CAR(CLV0), VV[368]);
   }
L10:;
   v4first = ECL_NIL;
   goto L4;
  }
 }
}
static cl_object LC2654__pprint_logical_block_1146_va(cl_narg narg, cl_object v5, cl_object v6stream, ...)
{
 return LC2654__pprint_logical_block_1146(v5, v6stream);
}
/* closure PPRINT-LOGICAL-BLOCK-1241                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2656__pprint_logical_block_1241(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[375], ECL_SYM("OFFSET",1316), ecl_make_int8_t(6));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(3), v2stream);
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[235], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L43;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[375], ECL_SYM("OFFSET",1316), ecl_make_int8_t(39));
L43:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L46;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L46:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L52;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L52:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L61;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L61:;
    T0 = v5;
   }
   L2655pprint_lambda_list(4, v2stream, T0, ECL_NIL, ECL_NIL);
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(1), v2stream);
L68:;
   if (!(v4args==ECL_NIL)){
    goto L70;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L70:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L74;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[375], ECL_SYM("OFFSET",1316), ecl_make_int8_t(50));
L74:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L77;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L77:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L83;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L83:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L92;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L92:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   goto L68;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1282                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2658__pprint_logical_block_1282(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[380], ECL_SYM("OFFSET",1316), ecl_make_int8_t(6));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(3), v2stream);
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[235], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L43;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[380], ECL_SYM("OFFSET",1316), ecl_make_int8_t(17));
L43:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L46;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L46:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L52;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L52:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L61;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L61:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(1), v2stream);
L68:;
   if (!(v4args==ECL_NIL)){
    goto L70;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L70:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L74;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[380], ECL_SYM("OFFSET",1316), ecl_make_int8_t(28));
L74:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L77;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L77:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L83;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L83:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L92;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L92:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   goto L68;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1323                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2662__pprint_logical_block_1323(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[384], ECL_SYM("OFFSET",1316), ecl_make_int8_t(6));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[233], v2stream);
   {
    cl_object env1 = env0;
    if (!(v4args==ECL_NIL)){
     goto L42;
    }
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[384], ECL_SYM("OFFSET",1316), ecl_make_int8_t(15));
L42:;
    if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
     goto L45;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L45:;
    v3 = ecl_plus(v3,ecl_make_int8_t(1));
    {
     cl_object v5;
     v5 = v1;
     if (Null(v5)){
      goto L51;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v1 = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L51:;
    }
    {
     cl_object v5;
     v5 = v4args;
     if (Null(v5)){
      goto L60;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v4args = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L60:;
     T0 = v5;
    }
    CLV1 = env1 = CONS(T0,env1);                  /*  ARG                     */
    {
     cl_object v5;
     v5 = ecl_make_cclosure_va((cl_objectfn)LC2661__pprint_logical_block_1353,env1,Cblock,2);
     T0 = v5;
    }
    si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV1), v2stream, VV[287], ECL_NIL, VV[288]);
   }
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(1), v2stream);
   cl_pprint_newline(2, VV[134], v2stream);
L69:;
   if (!(v4args==ECL_NIL)){
    goto L71;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L71:;
   if (!(v4args==ECL_NIL)){
    goto L74;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[384], ECL_SYM("OFFSET",1316), ecl_make_int8_t(102));
L74:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L77;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L77:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L83;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L83:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L92;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L92:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L98;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L98:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   goto L69;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1429                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2666__pprint_logical_block_1429(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[390], ECL_SYM("OFFSET",1316), ecl_make_int8_t(6));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[233], v2stream);
   {
    cl_object env1 = env0;
    if (!(v4args==ECL_NIL)){
     goto L42;
    }
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[390], ECL_SYM("OFFSET",1316), ecl_make_int8_t(15));
L42:;
    if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
     goto L45;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L45:;
    v3 = ecl_plus(v3,ecl_make_int8_t(1));
    {
     cl_object v5;
     v5 = v1;
     if (Null(v5)){
      goto L51;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v1 = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L51:;
    }
    {
     cl_object v5;
     v5 = v4args;
     if (Null(v5)){
      goto L60;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v4args = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L60:;
     T0 = v5;
    }
    CLV1 = env1 = CONS(T0,env1);                  /*  ARG                     */
    {
     cl_object v5;
     v5 = ecl_make_cclosure_va((cl_objectfn)LC2665__pprint_logical_block_1459,env1,Cblock,2);
     T0 = v5;
    }
    si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV1), v2stream, VV[287], ECL_NIL, VV[288]);
   }
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(1), v2stream);
   cl_pprint_newline(2, VV[134], v2stream);
L69:;
   if (!(v4args==ECL_NIL)){
    goto L71;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L71:;
   if (!(v4args==ECL_NIL)){
    goto L74;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[390], ECL_SYM("OFFSET",1316), ecl_make_int8_t(60));
L74:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L77;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L77:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L83;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L83:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L92;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L92:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L98;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L98:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   goto L69;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1523                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2668__pprint_logical_block_1523(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[396], ECL_SYM("OFFSET",1316), ecl_make_int8_t(6));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
L34:;
   if (!(v4args==ECL_NIL)){
    goto L36;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L36:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L40;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[396], ECL_SYM("OFFSET",1316), ecl_make_int8_t(14));
L40:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L43;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L43:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L49;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L49:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L58;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L58:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   goto L34;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1555                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2670__pprint_logical_block_1555(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[400], ECL_SYM("OFFSET",1316), ecl_make_int8_t(6));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(3), v2stream);
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L43;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[400], ECL_SYM("OFFSET",1316), ecl_make_int8_t(16));
L43:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L46;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L46:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L52;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L52:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L61;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L61:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L67;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L67:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L75;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[400], ECL_SYM("OFFSET",1316), ecl_make_int8_t(23));
L75:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L78;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L78:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L84;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L84:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L93;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L93:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L99;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L99:;
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(1), v2stream);
L105:;
   if (!(v4args==ECL_NIL)){
    goto L107;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L107:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L111;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[400], ECL_SYM("OFFSET",1316), ecl_make_int8_t(36));
L111:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L114;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L114:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L120;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L120:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L129;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L129:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   goto L105;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1607                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2673__pprint_logical_block_1607(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  LIST                    */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  if (!(v1==ECL_NIL)){
   goto L3;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L6;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L13;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L13:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
  if (!(v1==ECL_NIL)){
   goto L19;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L19:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_newline(2, VV[233], v2stream);
  T0 = _ecl_cdr(ECL_CONS_CAR(CLV0));
  if (!(ECL_CONSP(T0))){
   goto L23;
  }
  T0 = _ecl_cddr(ECL_CONS_CAR(CLV0));
  if (!(ECL_CONSP(T0))){
   goto L23;
  }
L26:;
  cl_pprint_indent(3, VV[141], ecl_make_int8_t(2), v2stream);
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L30;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L30:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L37;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L37:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
  if (!(v1==ECL_NIL)){
   goto L43;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L43:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_newline(2, VV[231], v2stream);
  cl_pprint_indent(3, VV[141], ecl_make_int8_t(-2), v2stream);
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L49;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L49:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L56;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L56:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
  if (!(v1==ECL_NIL)){
   goto L62;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L62:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_newline(2, VV[231], v2stream);
  goto L26;
L23:;
  cl_pprint_indent(3, VV[141], ecl_make_int8_t(0), v2stream);
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L68;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L68:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L75;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L75:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
  if (!(v1==ECL_NIL)){
   goto L81;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L81:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_newline(2, VV[231], v2stream);
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L85;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L85:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L92;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L92:;
   T0 = v4;
  }
  value0 = si_write_object(T0, v2stream);
  return value0;
 }
 }
}
/* local function PPRINT-LOGICAL-BLOCK-1639                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2675__pprint_logical_block_1639(cl_object v1, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  if (!(v1==ECL_NIL)){
   goto L3;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L6;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L13;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L13:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
L19:;
  if (!(v1==ECL_NIL)){
   goto L21;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L21:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  {
   cl_object v4form_or_tag;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L25;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L25:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L31;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L31:;
    v4form_or_tag = v5;
   }
   if (!(ECL_ATOM(v4form_or_tag))){
    goto L39;
   }
   T0 = ecl_make_int8_t(0);
   goto L38;
L39:;
   T0 = ecl_make_int8_t(1);
L38:;
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), T0, v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   si_write_object(v4form_or_tag, v2stream);
  }
  goto L19;
 }
}
static cl_object LC2675__pprint_logical_block_1639_va(cl_narg narg, cl_object v4, cl_object v5stream, ...)
{
 return LC2675__pprint_logical_block_1639(v4, v5stream);
}
/* closure PPRINT-LOGICAL-BLOCK-1662                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2678__pprint_logical_block_1662(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[416], ECL_SYM("OFFSET",1316), ecl_make_int8_t(6));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(3), v2stream);
   cl_pprint_newline(2, VV[235], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L43;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[416], ECL_SYM("OFFSET",1316), ecl_make_int8_t(17));
L43:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L46;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L46:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L52;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L52:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L61;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L61:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(1), v2stream);
L68:;
   if (!(v4args==ECL_NIL)){
    goto L70;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L70:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   {
    cl_object env1 = env0;
    if (!(v4args==ECL_NIL)){
     goto L74;
    }
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[416], ECL_SYM("OFFSET",1316), ecl_make_int8_t(29));
L74:;
    if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
     goto L77;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L77:;
    v3 = ecl_plus(v3,ecl_make_int8_t(1));
    {
     cl_object v5;
     v5 = v1;
     if (Null(v5)){
      goto L83;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v1 = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L83:;
    }
    {
     cl_object v5;
     v5 = v4args;
     if (Null(v5)){
      goto L92;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v4args = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L92:;
     T0 = v5;
    }
    CLV1 = env1 = CONS(T0,env1);                  /*  ARG                     */
    {
     cl_object v5;
     v5 = ecl_make_cclosure_va((cl_objectfn)LC2677__pprint_logical_block_1699,env1,Cblock,2);
     T0 = v5;
    }
    si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV1), v2stream, VV[287], ECL_NIL, VV[288]);
   }
   goto L68;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1734                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2680__pprint_logical_block_1734(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[421], ECL_SYM("OFFSET",1316), ecl_make_int8_t(6));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[233], v2stream);
   cl_pprint_indent(3, VV[141], ecl_make_int8_t(0), v2stream);
   if (!(v4args==ECL_NIL)){
    goto L43;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[421], ECL_SYM("OFFSET",1316), ecl_make_int8_t(17));
L43:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L46;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L46:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L52;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L52:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L61;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L61:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L67;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L67:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[235], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L75;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[421], ECL_SYM("OFFSET",1316), ecl_make_int8_t(47));
L75:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L78;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L78:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L84;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L84:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L93;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L93:;
    T0 = v5;
   }
   L2655pprint_lambda_list(4, v2stream, T0, ECL_NIL, ECL_NIL);
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(1), v2stream);
L100:;
   if (!(v4args==ECL_NIL)){
    goto L102;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L102:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L106;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[421], ECL_SYM("OFFSET",1316), ecl_make_int8_t(58));
L106:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L109;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L109:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L115;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L115:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L124;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L124:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   goto L100;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1784                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2682__pprint_logical_block_1784(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[425], ECL_SYM("OFFSET",1316), ecl_make_int8_t(6));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(3), v2stream);
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L43;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[425], ECL_SYM("OFFSET",1316), ecl_make_int8_t(39));
L43:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L46;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L46:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L52;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L52:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L61;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L61:;
    T0 = v5;
   }
   L2655pprint_lambda_list(4, v2stream, T0, ECL_T, ECL_NIL);
   if (!(v4args==ECL_NIL)){
    goto L67;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L67:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L75;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[425], ECL_SYM("OFFSET",1316), ecl_make_int8_t(46));
L75:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L78;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L78:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L84;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L84:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L93;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L93:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L99;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L99:;
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(1), v2stream);
L105:;
   if (!(v4args==ECL_NIL)){
    goto L107;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L107:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L111;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[425], ECL_SYM("OFFSET",1316), ecl_make_int8_t(59));
L111:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L114;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L114:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L120;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L120:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L129;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L129:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   goto L105;
  }
 }
 }
}
/* local function PPRINT-LOGICAL-BLOCK-1834                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2686__pprint_logical_block_1834(cl_object v1, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  if (!(v1==ECL_NIL)){
   goto L3;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L6;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L13;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L13:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
  if (!(v1==ECL_NIL)){
   goto L19;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L19:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_indent(3, VV[141], ecl_make_int8_t(0), v2stream);
  {
   cl_object v4;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L25;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L25:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L31;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L31:;
    v4 = v5;
   }
   {
    cl_object env1 = env0;
    env1 = ECL_NIL;
    CLV0 = env1 = CONS(v4,env1);                  /*  ARG                     */
    {
     cl_object v5;
     v5 = ecl_make_cclosure_va((cl_objectfn)LC2685__pprint_logical_block_1855,env1,Cblock,2);
     T0 = v5;
    }
    si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v2stream, VV[287], ECL_NIL, VV[288]);
   }
  }
  if (!(v1==ECL_NIL)){
   goto L39;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L39:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_newline(2, VV[231], v2stream);
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L44;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L44:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L51;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L51:;
   T0 = v4;
  }
  cl_pprint_linear(2, v2stream, T0);
L57:;
  if (!(v1==ECL_NIL)){
   goto L59;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L59:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  {
   cl_object v4form_or_tag;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L63;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L63:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L69;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L69:;
    v4form_or_tag = v5;
   }
   if (!(ECL_ATOM(v4form_or_tag))){
    goto L77;
   }
   T0 = ecl_make_int8_t(0);
   goto L76;
L77:;
   T0 = ecl_make_int8_t(1);
L76:;
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), T0, v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   si_write_object(v4form_or_tag, v2stream);
  }
  goto L57;
 }
}
static cl_object LC2686__pprint_logical_block_1834_va(cl_narg narg, cl_object v4, cl_object v5stream, ...)
{
 return LC2686__pprint_logical_block_1834(v4, v5stream);
}
/* local function PPRINT-LOGICAL-BLOCK-1924                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2689__pprint_logical_block_1924(cl_object v1, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  if (!(v1==ECL_NIL)){
   goto L3;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L6;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L13;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L13:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
  if (!(v1==ECL_NIL)){
   goto L19;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L19:;
  cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(3), v2stream);
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_newline(2, VV[235], v2stream);
  {
   cl_object v4;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L26;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L26:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L32;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L32:;
    v4 = v5;
   }
   {
    cl_object env1 = env0;
    env1 = ECL_NIL;
    CLV0 = env1 = CONS(v4,env1);                  /*  ARG                     */
    {
     cl_object v5;
     v5 = ecl_make_cclosure_va((cl_objectfn)LC2688__pprint_logical_block_1945,env1,Cblock,2);
     T0 = v5;
    }
    si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV0), v2stream, VV[287], ECL_NIL, VV[288]);
   }
  }
L40:;
  if (!(v1==ECL_NIL)){
   goto L42;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L42:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  {
   cl_object v4form_or_tag;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L46;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L46:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L52;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L52:;
    v4form_or_tag = v5;
   }
   if (!(ECL_ATOM(v4form_or_tag))){
    goto L60;
   }
   T0 = ecl_make_int8_t(0);
   goto L59;
L60:;
   T0 = ecl_make_int8_t(1);
L59:;
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), T0, v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   si_write_object(v4form_or_tag, v2stream);
  }
  goto L40;
 }
}
static cl_object LC2689__pprint_logical_block_1924_va(cl_narg narg, cl_object v4, cl_object v5stream, ...)
{
 return LC2689__pprint_logical_block_1924(v4, v5stream);
}
/* closure PPRINT-LOGICAL-BLOCK-1991                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2692__pprint_logical_block_1991(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[440], ECL_SYM("OFFSET",1316), ecl_make_int8_t(6));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(3), v2stream);
   cl_pprint_newline(2, VV[235], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L43;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[440], ECL_SYM("OFFSET",1316), ecl_make_int8_t(17));
L43:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L46;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L46:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L52;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L52:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L61;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L61:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(1), v2stream);
L68:;
   if (!(v4args==ECL_NIL)){
    goto L70;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L70:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   {
    cl_object env1 = env0;
    if (!(v4args==ECL_NIL)){
     goto L74;
    }
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[440], ECL_SYM("OFFSET",1316), ecl_make_int8_t(29));
L74:;
    if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
     goto L77;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L77:;
    v3 = ecl_plus(v3,ecl_make_int8_t(1));
    {
     cl_object v5;
     v5 = v1;
     if (Null(v5)){
      goto L83;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v1 = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L83:;
    }
    {
     cl_object v5;
     v5 = v4args;
     if (Null(v5)){
      goto L92;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v4args = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L92:;
     T0 = v5;
    }
    CLV1 = env1 = CONS(T0,env1);                  /*  ARG                     */
    {
     cl_object v5;
     v5 = ecl_make_cclosure_va((cl_objectfn)LC2691__pprint_logical_block_2028,env1,Cblock,2);
     T0 = v5;
    }
    si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV1), v2stream, VV[287], ECL_NIL, VV[288]);
   }
   goto L68;
  }
 }
 }
}
/* local function PPRINT-LOGICAL-BLOCK-2060                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2694__pprint_logical_block_2060(cl_object v1, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  if (!(v1==ECL_NIL)){
   goto L3;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L6;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L13;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L13:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
  if (!(v1==ECL_NIL)){
   goto L19;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L19:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_newline(2, VV[233], v2stream);
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L24;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L24:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L31;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L31:;
   T0 = v4;
  }
  cl_pprint_fill(2, v2stream, T0);
L37:;
  if (!(v1==ECL_NIL)){
   goto L39;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L39:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  {
   cl_object v4form_or_tag;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L43;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L43:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L49;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L49:;
    v4form_or_tag = v5;
   }
   if (!(ECL_ATOM(v4form_or_tag))){
    goto L57;
   }
   T0 = ecl_make_int8_t(0);
   goto L56;
L57:;
   T0 = ecl_make_int8_t(1);
L56:;
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), T0, v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   si_write_object(v4form_or_tag, v2stream);
  }
  goto L37;
 }
}
static cl_object LC2694__pprint_logical_block_2060_va(cl_narg narg, cl_object v4, cl_object v5stream, ...)
{
 return LC2694__pprint_logical_block_2060(v4, v5stream);
}
/* closure PPRINT-LOGICAL-BLOCK-2087                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2696__pprint_logical_block_2087(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[448], ECL_SYM("OFFSET",1316), ecl_make_int8_t(6));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[235], v2stream);
   cl_pprint_indent(3, VV[141], ecl_make_int8_t(0), v2stream);
L42:;
   if (!(v4args==ECL_NIL)){
    goto L44;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L44:;
   if (!(v4args==ECL_NIL)){
    goto L47;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[448], ECL_SYM("OFFSET",1316), ecl_make_int8_t(20));
L47:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L50;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L50:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L56;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L56:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L65;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L65:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L71;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L71:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   goto L42;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1088                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2641__pprint_logical_block_1088(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  VECTOR                  */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4;
   v4 = ecl_make_fixnum(ecl_length(ECL_CONS_CAR(CLV0)));
   {
    cl_fixnum v5i;
    v5i = (cl_fixnum)(0);
    goto L6;
L5:;
    if ((v5i)==0) {
     goto L8;
    }
    cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
    cl_pprint_newline(2, VV[235], v2stream);
L8:;
    if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
     goto L12;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L12:;
    v3 = ecl_plus(v3,ecl_make_int8_t(1));
    T0 = ecl_aref_unsafe(ECL_CONS_CAR(CLV0),v5i);
    si_write_object(T0, v2stream);
    v5i = (v5i)+1;
L6:;
    if (!((v5i)<(ecl_fixnum(v4)))){
     goto L20;
    }
    goto L5;
L20:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
   }
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1109                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2644__pprint_logical_block_1109(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 volatile struct ecl_cclosure aux_closure;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  DIMENSIONS              */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4dim;
   v4dim = _ecl_car(ECL_CONS_CAR(CLV2));
   if (ecl_zerop(v4dim)) {
    goto L4;
   }
   {
    cl_object v5dims;
    cl_object v6index;
    cl_object v7step;
    cl_object v8count;
    v5dims = _ecl_cdr(ECL_CONS_CAR(CLV2));
    v6index = ECL_CONS_CAR(CLV1);
    T0 = (ECL_SYM("*",20)->symbol.gfdef);
    v7step = cl_reduce(2, T0, v5dims);
    v8count = ecl_make_int8_t(0);
L11:;
    if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
     goto L14;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L14:;
    v3 = ecl_plus(v3,ecl_make_int8_t(1));
    (aux_closure.env=ecl_nthcdr(2,env0),cl_env_copy->function=(cl_object)&aux_closure,LC2645output_guts(3, v2stream, v6index, v5dims));
    v8count = ecl_plus(v8count,ecl_make_int8_t(1));
    T0 = v8count;
    if (!(ecl_number_equalp(T0,v4dim))){
     goto L19;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L19:;
    cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
    if (Null(v5dims)){
     goto L26;
    }
    T0 = VV[231];
    goto L25;
L26:;
    T0 = VV[235];
L25:;
    cl_pprint_newline(2, T0, v2stream);
    v6index = ecl_plus(v6index,v7step);
    goto L11;
   }
L4:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1135                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2649__pprint_logical_block_1135(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARRAY                   */
 { /* ... closure scanning finished */
L1:;
 T0 = cl_array_element_type(ECL_CONS_CAR(CLV0));
 si_write_object(T0, v2stream);
 cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
 cl_pprint_newline(2, VV[235], v2stream);
 T0 = cl_array_dimensions(ECL_CONS_CAR(CLV0));
 si_write_object(T0, v2stream);
 cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
 cl_pprint_newline(2, VV[235], v2stream);
 value0 = L2646pprint_array_contents(v2stream, ECL_CONS_CAR(CLV0));
 return value0;
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1190                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2653__pprint_logical_block_1190(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0, T1;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  STATE                   */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  if (!(v1==ECL_NIL)){
   goto L3;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (!((ECL_CONS_CAR(CLV0))==(ECL_SYM("KEY",1297)))){
   goto L6;
  }
  {
   cl_object v4;
   v4 = ecl_make_cfun_va((cl_objectfn)LC2652__pprint_logical_block_1200_va,ECL_NIL,Cblock,2);
   T0 = v4;
  }
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L9;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L9:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L16;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L16:;
   T1 = v4;
  }
  si_pprint_logical_block_helper(T0, T1, v2stream, VV[287], ECL_NIL, VV[288]);
  goto L5;
L6:;
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L22;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L22:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L29;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L29:;
   T0 = v4;
  }
  L2655pprint_lambda_list(2, v2stream, T0);
L5:;
L35:;
  if (!(v1==ECL_NIL)){
   goto L37;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L37:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_newline(2, VV[231], v2stream);
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L41;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L41:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L48;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L48:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
  goto L35;
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1353                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2661__pprint_logical_block_1353(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  ARG                     */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV1);
L4:;
   if (!(v4args==ECL_NIL)){
    goto L6;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L6:;
   {
    cl_object env1 = env0;
    if (!(v4args==ECL_NIL)){
     goto L9;
    }
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[384], ECL_SYM("OFFSET",1316), ecl_make_int8_t(21));
L9:;
    if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
     goto L12;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L12:;
    v3 = ecl_plus(v3,ecl_make_int8_t(1));
    {
     cl_object v5;
     v5 = v1;
     if (Null(v5)){
      goto L18;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v1 = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L18:;
    }
    {
     cl_object v5;
     v5 = v4args;
     if (Null(v5)){
      goto L27;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v4args = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L27:;
     T0 = v5;
    }
    CLV2 = env1 = CONS(T0,env1);                  /*  ARG                     */
    {
     cl_object v5;
     v5 = ecl_make_cclosure_va((cl_objectfn)LC2660__pprint_logical_block_1372,env1,Cblock,2);
     T0 = v5;
    }
    si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV2), v2stream, VV[287], ECL_NIL, VV[288]);
   }
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   goto L4;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1459                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2665__pprint_logical_block_1459(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  ARG                     */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV1);
L4:;
   if (!(v4args==ECL_NIL)){
    goto L6;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L6:;
   {
    cl_object env1 = env0;
    if (!(v4args==ECL_NIL)){
     goto L9;
    }
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[390], ECL_SYM("OFFSET",1316), ecl_make_int8_t(21));
L9:;
    if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
     goto L12;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L12:;
    v3 = ecl_plus(v3,ecl_make_int8_t(1));
    {
     cl_object v5;
     v5 = v1;
     if (Null(v5)){
      goto L18;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v1 = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L18:;
    }
    {
     cl_object v5;
     v5 = v4args;
     if (Null(v5)){
      goto L27;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v4args = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L27:;
     T0 = v5;
    }
    CLV2 = env1 = CONS(T0,env1);                  /*  ARG                     */
    {
     cl_object v5;
     v5 = ecl_make_cclosure_va((cl_objectfn)LC2664__pprint_logical_block_1478,env1,Cblock,2);
     T0 = v5;
    }
    si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV2), v2stream, VV[287], ECL_NIL, VV[288]);
   }
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   goto L4;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1699                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2677__pprint_logical_block_1699(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  ARG                     */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV1);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[416], ECL_SYM("OFFSET",1316), ecl_make_int8_t(49));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   cl_pprint_fill(4, v2stream, T0, ECL_T, ECL_NIL);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
L39:;
   if (!(v4args==ECL_NIL)){
    goto L41;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L41:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L45;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[416], ECL_SYM("OFFSET",1316), ecl_make_int8_t(59));
L45:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L48;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L48:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L54;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L54:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L63;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L63:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   goto L39;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1855                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2685__pprint_logical_block_1855(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
L4:;
   if (!(v4args==ECL_NIL)){
    goto L6;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L6:;
   {
    cl_object env1 = env0;
    if (!(v4args==ECL_NIL)){
     goto L9;
    }
    cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[430], ECL_SYM("OFFSET",1316), ecl_make_int8_t(8));
L9:;
    if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
     goto L12;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L12:;
    v3 = ecl_plus(v3,ecl_make_int8_t(1));
    {
     cl_object v5;
     v5 = v1;
     if (Null(v5)){
      goto L18;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v1 = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L18:;
    }
    {
     cl_object v5;
     v5 = v4args;
     if (Null(v5)){
      goto L27;
     }
     {
      cl_object v6;
      v6 = ECL_CONS_CDR(v5);
      v4args = v6;
      v5 = ECL_CONS_CAR(v5);
     }
L27:;
     T0 = v5;
    }
    CLV1 = env1 = CONS(T0,env1);                  /*  ARG                     */
    {
     cl_object v5;
     v5 = ecl_make_cclosure_va((cl_objectfn)LC2684__pprint_logical_block_1874,env1,Cblock,2);
     T0 = v5;
    }
    si_pprint_logical_block_helper(T0, ECL_CONS_CAR(CLV1), v2stream, VV[287], ECL_NIL, VV[288]);
   }
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_pprint_newline(2, VV[134], v2stream);
   goto L4;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1945                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2688__pprint_logical_block_1945(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ARG                     */
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV0);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[436], ECL_SYM("OFFSET",1316), ecl_make_int8_t(6));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[235], v2stream);
   cl_pprint_indent(3, VV[141], ecl_make_int8_t(0), v2stream);
   if (!(v4args==ECL_NIL)){
    goto L43;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[436], ECL_SYM("OFFSET",1316), ecl_make_int8_t(17));
L43:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L46;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L46:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L52;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L52:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L61;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L61:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
L67:;
   if (!(v4args==ECL_NIL)){
    goto L69;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L69:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L73;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[436], ECL_SYM("OFFSET",1316), ecl_make_int8_t(25));
L73:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L76;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L76:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L82;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L82:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L91;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L91:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   goto L67;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-2028                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2691__pprint_logical_block_2028(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  ARG                     */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV1);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[440], ECL_SYM("OFFSET",1316), ecl_make_int8_t(33));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
L39:;
   if (!(v4args==ECL_NIL)){
    goto L41;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L41:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L45;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[440], ECL_SYM("OFFSET",1316), ecl_make_int8_t(43));
L45:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L48;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L48:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L54;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L54:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L63;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L63:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   goto L39;
  }
 }
 }
}
/* local function PPRINT-LOGICAL-BLOCK-1200                                   */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2652__pprint_logical_block_1200(cl_object v1, cl_object v2stream)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  if (!(v1==ECL_NIL)){
   goto L3;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L6;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L6:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L13;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L13:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
  if (!(v1==ECL_NIL)){
   goto L19;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L19:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_newline(2, VV[235], v2stream);
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L24;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L24:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L31;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L31:;
   T0 = v4;
  }
  L2655pprint_lambda_list(2, v2stream, T0);
L37:;
  if (!(v1==ECL_NIL)){
   goto L39;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L39:;
  cl_write_char(2, ECL_CODE_CHAR(32), v2stream);
  cl_pprint_newline(2, VV[235], v2stream);
  if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
   goto L43;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L43:;
  v3 = ecl_plus(v3,ecl_make_int8_t(1));
  {
   cl_object v4;
   v4 = v1;
   if (Null(v4)){
    goto L50;
   }
   {
    cl_object v5;
    v5 = ECL_CONS_CDR(v4);
    v1 = v5;
    v4 = ECL_CONS_CAR(v4);
   }
L50:;
   T0 = v4;
  }
  si_write_object(T0, v2stream);
  goto L37;
 }
}
static cl_object LC2652__pprint_logical_block_1200_va(cl_narg narg, cl_object v4, cl_object v5stream, ...)
{
 return LC2652__pprint_logical_block_1200(v4, v5stream);
}
/* closure PPRINT-LOGICAL-BLOCK-1372                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2660__pprint_logical_block_1372(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  ARG                     */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV2);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[384], ECL_SYM("OFFSET",1316), ecl_make_int8_t(25));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(3), v2stream);
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[235], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L43;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[384], ECL_SYM("OFFSET",1316), ecl_make_int8_t(58));
L43:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L46;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L46:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L52;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L52:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L61;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L61:;
    T0 = v5;
   }
   L2655pprint_lambda_list(4, v2stream, T0, ECL_NIL, ECL_NIL);
   cl_pprint_indent(3, ECL_SYM("BLOCK",1232), ecl_make_int8_t(1), v2stream);
   cl_pprint_newline(2, VV[134], v2stream);
L69:;
   if (!(v4args==ECL_NIL)){
    goto L71;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L71:;
   if (!(v4args==ECL_NIL)){
    goto L74;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[384], ECL_SYM("OFFSET",1316), ecl_make_int8_t(70));
L74:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L77;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L77:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L83;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L83:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L92;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L92:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L98;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L98:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   goto L69;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1478                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2664__pprint_logical_block_1478(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  ARG                     */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV2);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[390], ECL_SYM("OFFSET",1316), ecl_make_int8_t(25));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
L34:;
   if (!(v4args==ECL_NIL)){
    goto L36;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L36:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L40;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[390], ECL_SYM("OFFSET",1316), ecl_make_int8_t(33));
L40:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L43;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L43:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L49;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L49:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L58;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L58:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   goto L34;
  }
 }
 }
}
/* closure PPRINT-LOGICAL-BLOCK-1874                                          */
/* optimize speed 3, debug 0, space 0, safety 0                               */
static cl_object LC2684__pprint_logical_block_1874(cl_narg narg, cl_object v1, cl_object v2stream, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 /* Scanning closure data ... */
 CLV1 = env0;                                     /*  ARG                     */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
L1:;
 {
  cl_object v3;
  v3 = ecl_make_int8_t(0);
  {
   cl_object v4args;
   v4args = ECL_CONS_CAR(CLV1);
   if (!(v4args==ECL_NIL)){
    goto L4;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L4:;
   if (!(v4args==ECL_NIL)){
    goto L10;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[430], ECL_SYM("OFFSET",1316), ecl_make_int8_t(12));
L10:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L13;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L13:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L19;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L19:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L28;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L28:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   if (!(v4args==ECL_NIL)){
    goto L34;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L34:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[233], v2stream);
   cl_pprint_indent(3, VV[141], ecl_make_int8_t(0), v2stream);
   if (!(v4args==ECL_NIL)){
    goto L43;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[430], ECL_SYM("OFFSET",1316), ecl_make_int8_t(23));
L43:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L46;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L46:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L52;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L52:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L61;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L61:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
L67:;
   if (!(v4args==ECL_NIL)){
    goto L69;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L69:;
   cl_write_string(2, VV[376], v2stream);
   cl_pprint_newline(2, VV[231], v2stream);
   if (!(v4args==ECL_NIL)){
    goto L73;
   }
   cl_error(7, ECL_SYM("FORMAT-ERROR",1084), VV[373], VV[374], ECL_SYM("CONTROL-STRING",1242), VV[430], ECL_SYM("OFFSET",1316), ecl_make_int8_t(31));
L73:;
   if (si_pprint_pop_helper(v1, v3, v2stream)!=ECL_NIL) {
    goto L76;
   }
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
L76:;
   v3 = ecl_plus(v3,ecl_make_int8_t(1));
   {
    cl_object v5;
    v5 = v1;
    if (Null(v5)){
     goto L82;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v1 = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L82:;
   }
   {
    cl_object v5;
    v5 = v4args;
    if (Null(v5)){
     goto L91;
    }
    {
     cl_object v6;
     v6 = ECL_CONS_CDR(v5);
     v4args = v6;
     v5 = ECL_CONS_CAR(v5);
    }
L91:;
    T0 = v5;
   }
   si_write_object(T0, v2stream);
   goto L67;
  }
 }
 }
}
#include "clos/pprint.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecluqu66Xj3TlRr9_xOC0M881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:LSP;PPRINT.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecluqu66Xj3TlRr9_xOC0M881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[1]) /*  MAPC */;
  si_do_deftype(3, VV[0], VVtemp[2], VVtemp[3]);
  si_do_deftype(3, VV[1], VVtemp[4], ECL_SYM("FIXNUM",374));
  si_Xmake_constant(VV[2], ecl_make_uint8_t(128));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2543__lambda6_va,ECL_NIL,Cblock,0);
   T0 = v1;
  }
  T1 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T0, VVtemp[8]);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2544__lambda8_va,ECL_NIL,Cblock,0);
   T2 = v1;
  }
  T3 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T2, VVtemp[13]);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2545__lambda10_va,ECL_NIL,Cblock,0);
   T4 = v1;
  }
  T5 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T4, VVtemp[14]);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2546__lambda12_va,ECL_NIL,Cblock,0);
   T6 = v1;
  }
  T7 = cl_listX(3, ECL_SYM("INITFUNCTION",1001), T6, VVtemp[15]);
  T8 = cl_list(13, VVtemp[6], VVtemp[7], T1, VVtemp[9], VVtemp[10], VVtemp[11], VVtemp[12], T3, T5, T7, VVtemp[16], VVtemp[17], VVtemp[18]);
  T9 = cl_list(2, VV[9], VV[10]);
  clos_load_defclass(VV[3], VVtemp[5], T8, T9);
  ecl_cmp_defun(VV[450]);                         /*  PRETTY-STREAM-P         */
  ecl_cmp_defun(VV[451]);                         /*  MAKE-PRETTY-STREAM      */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2549print_object_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("PRINT-OBJECT",965), ECL_NIL, VVtemp[19], VVtemp[20], T0);
  (cl_env_copy->function=(ECL_SYM("MAPC",545)->symbol.gfdef))->cfun.entry(2, ECL_SYM("PROCLAIM",669), VVtemp[21]) /*  MAPC */;
  ecl_cmp_defun(VV[452]);                         /*  INDEX-POSN              */
  si_put_sysprop(VV[20], ECL_SYM("INLINE",436), VVtemp[22]);
  ecl_cmp_defun(VV[453]);                         /*  POSN-INDEX              */
  si_put_sysprop(VV[24], ECL_SYM("INLINE",436), VVtemp[23]);
  ecl_cmp_defun(VV[454]);                         /*  POSN-COLUMN             */
  si_put_sysprop(VV[26], ECL_SYM("INLINE",436), VVtemp[24]);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2553gray_stream_line_length_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-LINE-LENGTH",1707), ECL_NIL, VVtemp[25], VVtemp[26], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2554gray_stream_write_char_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-WRITE-CHAR",1721), ECL_NIL, VVtemp[19], VVtemp[27], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2555gray_stream_force_output_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-FORCE-OUTPUT",1703), ECL_NIL, VVtemp[25], VVtemp[26], T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC2556gray_stream_clear_output_va,ECL_NIL,Cblock,1);
   T0 = v1;
  }
  clos_install_method(5, ECL_SYM("STREAM-CLEAR-OUTPUT",1696), ECL_NIL, VVtemp[25], VVtemp[26], T0);
  (void)0; /* No entry created for PRETTY-OUT */
  (void)0; /* No entry created for PRETTY-SOUT */
  si_define_structure(VV[40], _ecl_static_0, ECL_NIL, ECL_NIL, VVtemp[28], VVtemp[29], VV[41], ECL_NIL, ECL_NIL, ECL_NIL, VVtemp[30], ecl_make_int8_t(6), ECL_NIL, ECL_NIL, VV[42]);
  VV[51]=cl_find_class(1, VV[40]);
  ecl_cmp_defun(VV[455]);                         /*  MAKE-LOGICAL-BLOCK      */
  {
   cl_object v1package;
   v1package = cl_symbol_package(VV[53]);
   if (Null(v1package)){
    goto L56;
   }
   if (Null(si_package_locked_p(v1package))){
    goto L56;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L56;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[33], ECL_SYM("PACKAGE",1321), v1package);
  }
L56:;
  {
   cl_object volatile v2;
   v2 = ecl_make_cfun_va((cl_objectfn)LC2560__lambda78_va,ECL_NIL,Cblock,2);
   T0 = v2;
  }
  si_put_sysprop(VV[53], VV[54], T0);
  {
   cl_object v2package;
   v2package = cl_symbol_package(VV[56]);
   if (Null(v2package)){
    goto L64;
   }
   if (Null(si_package_locked_p(v2package))){
    goto L64;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L64;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[34], ECL_SYM("PACKAGE",1321), v2package);
  }
L64:;
  {
   cl_object volatile v3;
   v3 = ecl_make_cfun_va((cl_objectfn)LC2561__lambda83_va,ECL_NIL,Cblock,2);
   T0 = v3;
  }
  si_put_sysprop(VV[56], VV[54], T0);
  {
   cl_object v3package;
   v3package = cl_symbol_package(VV[58]);
   if (Null(v3package)){
    goto L72;
   }
   if (Null(si_package_locked_p(v3package))){
    goto L72;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L72;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[35], ECL_SYM("PACKAGE",1321), v3package);
  }
L72:;
  {
   cl_object volatile v4;
   v4 = ecl_make_cfun_va((cl_objectfn)LC2562__lambda88_va,ECL_NIL,Cblock,2);
   T0 = v4;
  }
  si_put_sysprop(VV[58], VV[54], T0);
  {
   cl_object v4package;
   v4package = cl_symbol_package(VV[60]);
   if (Null(v4package)){
    goto L80;
   }
   if (Null(si_package_locked_p(v4package))){
    goto L80;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L80;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[36], ECL_SYM("PACKAGE",1321), v4package);
  }
L80:;
  {
   cl_object volatile v5;
   v5 = ecl_make_cfun_va((cl_objectfn)LC2563__lambda93_va,ECL_NIL,Cblock,2);
   T0 = v5;
  }
  si_put_sysprop(VV[60], VV[54], T0);
  {
   cl_object v5package;
   v5package = cl_symbol_package(VV[62]);
   if (Null(v5package)){
    goto L88;
   }
   if (Null(si_package_locked_p(v5package))){
    goto L88;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L88;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[37], ECL_SYM("PACKAGE",1321), v5package);
  }
L88:;
  {
   cl_object volatile v6;
   v6 = ecl_make_cfun_va((cl_objectfn)LC2564__lambda98_va,ECL_NIL,Cblock,2);
   T0 = v6;
  }
  si_put_sysprop(VV[62], VV[54], T0);
  {
   cl_object v6package;
   v6package = cl_symbol_package(VV[64]);
   if (Null(v6package)){
    goto L96;
   }
   if (Null(si_package_locked_p(v6package))){
    goto L96;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L96;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[38], ECL_SYM("PACKAGE",1321), v6package);
  }
L96:;
  {
   cl_object volatile v7;
   v7 = ecl_make_cfun_va((cl_objectfn)LC2565__lambda103_va,ECL_NIL,Cblock,2);
   T0 = v7;
  }
  si_put_sysprop(VV[64], VV[54], T0);
  (void)0; /* No entry created for REALLY-START-LOGICAL-BLOCK */
  (void)0; /* No entry created for SET-INDENTATION */
  (void)0; /* No entry created for REALLY-END-LOGICAL-BLOCK */
  si_define_structure(VV[82], _ecl_static_1, ECL_NIL, ECL_NIL, VVtemp[39], VVtemp[40], VV[83], ECL_NIL, ECL_NIL, ECL_NIL, VVtemp[41], ecl_make_int8_t(1), ECL_NIL, ECL_NIL, VV[84]);
  VV[86]=cl_find_class(1, VV[82]);
  ecl_cmp_defun(VV[456]);                         /*  MAKE-QUEUED-OP          */
  {
   cl_object v7package;
   v7package = cl_symbol_package(VV[88]);
   if (Null(v7package)){
    goto L121;
   }
   if (Null(si_package_locked_p(v7package))){
    goto L121;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L121;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[42], ECL_SYM("PACKAGE",1321), v7package);
  }
L121:;
  {
   cl_object volatile v8;
   v8 = ecl_make_cfun_va((cl_objectfn)LC2570__lambda141_va,ECL_NIL,Cblock,2);
   T0 = v8;
  }
  si_put_sysprop(VV[88], VV[54], T0);
  si_define_structure(VV[90], _ecl_static_2, ECL_NIL, ECL_NIL, VVtemp[43], VVtemp[44], VV[91], VV[82], ECL_NIL, ECL_NIL, VVtemp[45], ecl_make_int8_t(3), ECL_NIL, ECL_NIL, VV[92]);
  VV[99]=cl_find_class(1, VV[90]);
  ecl_cmp_defun(VV[457]);                         /*  MAKE-SECTION-START      */
  {
   cl_object v8package;
   v8package = cl_symbol_package(VV[101]);
   if (Null(v8package)){
    goto L138;
   }
   if (Null(si_package_locked_p(v8package))){
    goto L138;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L138;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[46], ECL_SYM("PACKAGE",1321), v8package);
  }
L138:;
  {
   cl_object volatile v9;
   v9 = ecl_make_cfun_va((cl_objectfn)LC2572__lambda164_va,ECL_NIL,Cblock,2);
   T0 = v9;
  }
  si_put_sysprop(VV[101], VV[54], T0);
  {
   cl_object v9package;
   v9package = cl_symbol_package(VV[103]);
   if (Null(v9package)){
    goto L146;
   }
   if (Null(si_package_locked_p(v9package))){
    goto L146;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L146;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[47], ECL_SYM("PACKAGE",1321), v9package);
  }
L146:;
  {
   cl_object volatile v10;
   v10 = ecl_make_cfun_va((cl_objectfn)LC2573__lambda169_va,ECL_NIL,Cblock,2);
   T0 = v10;
  }
  si_put_sysprop(VV[103], VV[54], T0);
  {
   cl_object v10package;
   v10package = cl_symbol_package(VV[105]);
   if (Null(v10package)){
    goto L154;
   }
   if (Null(si_package_locked_p(v10package))){
    goto L154;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L154;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[48], ECL_SYM("PACKAGE",1321), v10package);
  }
L154:;
  {
   cl_object volatile v11;
   v11 = ecl_make_cfun_va((cl_objectfn)LC2574__lambda174_va,ECL_NIL,Cblock,2);
   T0 = v11;
  }
  si_put_sysprop(VV[105], VV[54], T0);
  si_define_structure(VV[94], _ecl_static_3, ECL_NIL, ECL_NIL, VVtemp[49], VVtemp[50], VV[107], VV[90], ECL_NIL, ECL_NIL, VVtemp[51], ecl_make_int8_t(4), ECL_NIL, ECL_NIL, VV[108]);
  VV[114]=cl_find_class(1, VV[94]);
  ecl_cmp_defun(VV[458]);                         /*  MAKE-NEWLINE            */
  {
   cl_object v11package;
   v11package = cl_symbol_package(VV[116]);
   if (Null(v11package)){
    goto L170;
   }
   if (Null(si_package_locked_p(v11package))){
    goto L170;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L170;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[52], ECL_SYM("PACKAGE",1321), v11package);
  }
L170:;
  {
   cl_object volatile v12;
   v12 = ecl_make_cfun_va((cl_objectfn)LC2576__lambda196_va,ECL_NIL,Cblock,2);
   T0 = v12;
  }
  si_put_sysprop(VV[116], VV[54], T0);
  {
   cl_object v12package;
   v12package = cl_symbol_package(VV[118]);
   if (Null(v12package)){
    goto L178;
   }
   if (Null(si_package_locked_p(v12package))){
    goto L178;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L178;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[53], ECL_SYM("PACKAGE",1321), v12package);
  }
L178:;
  {
   cl_object volatile v13;
   v13 = ecl_make_cfun_va((cl_objectfn)LC2577__lambda201_va,ECL_NIL,Cblock,2);
   T0 = v13;
  }
  si_put_sysprop(VV[118], VV[54], T0);
  {
   cl_object v13package;
   v13package = cl_symbol_package(VV[120]);
   if (Null(v13package)){
    goto L186;
   }
   if (Null(si_package_locked_p(v13package))){
    goto L186;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L186;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[54], ECL_SYM("PACKAGE",1321), v13package);
  }
L186:;
  {
   cl_object volatile v14;
   v14 = ecl_make_cfun_va((cl_objectfn)LC2578__lambda206_va,ECL_NIL,Cblock,2);
   T0 = v14;
  }
  si_put_sysprop(VV[120], VV[54], T0);
  {
   cl_object v14package;
   v14package = cl_symbol_package(VV[122]);
   if (Null(v14package)){
    goto L194;
   }
   if (Null(si_package_locked_p(v14package))){
    goto L194;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L194;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[55], ECL_SYM("PACKAGE",1321), v14package);
  }
L194:;
  {
   cl_object volatile v15;
   v15 = ecl_make_cfun_va((cl_objectfn)LC2579__lambda211_va,ECL_NIL,Cblock,2);
   T0 = v15;
  }
  si_put_sysprop(VV[122], VV[54], T0);
  (void)0; /* No entry created for ENQUEUE-NEWLINE */
  si_define_structure(VV[135], _ecl_static_4, ECL_NIL, ECL_NIL, VVtemp[56], VVtemp[57], VV[136], VV[82], ECL_NIL, ECL_NIL, VVtemp[58], ecl_make_int8_t(3), ECL_NIL, ECL_NIL, VV[137]);
  VV[144]=cl_find_class(1, VV[135]);
  ecl_cmp_defun(VV[459]);                         /*  MAKE-INDENTATION        */
  {
   cl_object v15package;
   v15package = cl_symbol_package(VV[146]);
   if (Null(v15package)){
    goto L213;
   }
   if (Null(si_package_locked_p(v15package))){
    goto L213;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L213;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[59], ECL_SYM("PACKAGE",1321), v15package);
  }
L213:;
  {
   cl_object volatile v16;
   v16 = ecl_make_cfun_va((cl_objectfn)LC2582__lambda250_va,ECL_NIL,Cblock,2);
   T0 = v16;
  }
  si_put_sysprop(VV[146], VV[54], T0);
  {
   cl_object v16package;
   v16package = cl_symbol_package(VV[148]);
   if (Null(v16package)){
    goto L221;
   }
   if (Null(si_package_locked_p(v16package))){
    goto L221;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L221;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[60], ECL_SYM("PACKAGE",1321), v16package);
  }
L221:;
  {
   cl_object volatile v17;
   v17 = ecl_make_cfun_va((cl_objectfn)LC2583__lambda255_va,ECL_NIL,Cblock,2);
   T0 = v17;
  }
  si_put_sysprop(VV[148], VV[54], T0);
  {
   cl_object v17package;
   v17package = cl_symbol_package(VV[150]);
   if (Null(v17package)){
    goto L229;
   }
   if (Null(si_package_locked_p(v17package))){
    goto L229;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L229;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[61], ECL_SYM("PACKAGE",1321), v17package);
  }
L229:;
  {
   cl_object volatile v18;
   v18 = ecl_make_cfun_va((cl_objectfn)LC2584__lambda260_va,ECL_NIL,Cblock,2);
   T0 = v18;
  }
  si_put_sysprop(VV[150], VV[54], T0);
  (void)0; /* No entry created for ENQUEUE-INDENT */
  si_define_structure(VV[154], _ecl_static_5, ECL_NIL, ECL_NIL, VVtemp[62], VVtemp[63], VV[155], VV[90], ECL_NIL, ECL_NIL, VVtemp[64], ecl_make_int8_t(6), ECL_NIL, ECL_NIL, VV[156]);
  VV[162]=cl_find_class(1, VV[154]);
  ecl_cmp_defun(VV[460]);                         /*  MAKE-BLOCK-START        */
  {
   cl_object v18package;
   v18package = cl_symbol_package(VV[164]);
   if (Null(v18package)){
    goto L248;
   }
   if (Null(si_package_locked_p(v18package))){
    goto L248;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L248;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[65], ECL_SYM("PACKAGE",1321), v18package);
  }
L248:;
  {
   cl_object volatile v19;
   v19 = ecl_make_cfun_va((cl_objectfn)LC2587__lambda292_va,ECL_NIL,Cblock,2);
   T0 = v19;
  }
  si_put_sysprop(VV[164], VV[54], T0);
  {
   cl_object v19package;
   v19package = cl_symbol_package(VV[166]);
   if (Null(v19package)){
    goto L256;
   }
   if (Null(si_package_locked_p(v19package))){
    goto L256;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L256;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[66], ECL_SYM("PACKAGE",1321), v19package);
  }
L256:;
  {
   cl_object volatile v20;
   v20 = ecl_make_cfun_va((cl_objectfn)LC2588__lambda297_va,ECL_NIL,Cblock,2);
   T0 = v20;
  }
  si_put_sysprop(VV[166], VV[54], T0);
  {
   cl_object v20package;
   v20package = cl_symbol_package(VV[168]);
   if (Null(v20package)){
    goto L264;
   }
   if (Null(si_package_locked_p(v20package))){
    goto L264;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L264;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[67], ECL_SYM("PACKAGE",1321), v20package);
  }
L264:;
  {
   cl_object volatile v21;
   v21 = ecl_make_cfun_va((cl_objectfn)LC2589__lambda302_va,ECL_NIL,Cblock,2);
   T0 = v21;
  }
  si_put_sysprop(VV[168], VV[54], T0);
  {
   cl_object v21package;
   v21package = cl_symbol_package(VV[170]);
   if (Null(v21package)){
    goto L272;
   }
   if (Null(si_package_locked_p(v21package))){
    goto L272;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L272;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[68], ECL_SYM("PACKAGE",1321), v21package);
  }
L272:;
  {
   cl_object volatile v22;
   v22 = ecl_make_cfun_va((cl_objectfn)LC2590__lambda307_va,ECL_NIL,Cblock,2);
   T0 = v22;
  }
  si_put_sysprop(VV[170], VV[54], T0);
  {
   cl_object v22package;
   v22package = cl_symbol_package(VV[172]);
   if (Null(v22package)){
    goto L280;
   }
   if (Null(si_package_locked_p(v22package))){
    goto L280;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L280;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[69], ECL_SYM("PACKAGE",1321), v22package);
  }
L280:;
  {
   cl_object volatile v23;
   v23 = ecl_make_cfun_va((cl_objectfn)LC2591__lambda312_va,ECL_NIL,Cblock,2);
   T0 = v23;
  }
  si_put_sysprop(VV[172], VV[54], T0);
  {
   cl_object v23package;
   v23package = cl_symbol_package(VV[174]);
   if (Null(v23package)){
    goto L288;
   }
   if (Null(si_package_locked_p(v23package))){
    goto L288;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L288;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[70], ECL_SYM("PACKAGE",1321), v23package);
  }
L288:;
  {
   cl_object volatile v24;
   v24 = ecl_make_cfun_va((cl_objectfn)LC2592__lambda317_va,ECL_NIL,Cblock,2);
   T0 = v24;
  }
  si_put_sysprop(VV[174], VV[54], T0);
  (void)0; /* No entry created for START-LOGICAL-BLOCK */
  si_define_structure(VV[95], _ecl_static_6, ECL_NIL, ECL_NIL, VVtemp[71], VVtemp[72], VV[181], VV[82], ECL_NIL, ECL_NIL, VVtemp[73], ecl_make_int8_t(2), ECL_NIL, ECL_NIL, VV[182]);
  VV[184]=cl_find_class(1, VV[95]);
  ecl_cmp_defun(VV[461]);                         /*  MAKE-BLOCK-END          */
  {
   cl_object v24package;
   v24package = cl_symbol_package(VV[186]);
   if (Null(v24package)){
    goto L307;
   }
   if (Null(si_package_locked_p(v24package))){
    goto L307;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L307;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[74], ECL_SYM("PACKAGE",1321), v24package);
  }
L307:;
  {
   cl_object volatile v25;
   v25 = ecl_make_cfun_va((cl_objectfn)LC2595__lambda345_va,ECL_NIL,Cblock,2);
   T0 = v25;
  }
  si_put_sysprop(VV[186], VV[54], T0);
  {
   cl_object v25package;
   v25package = cl_symbol_package(VV[188]);
   if (Null(v25package)){
    goto L315;
   }
   if (Null(si_package_locked_p(v25package))){
    goto L315;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L315;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[75], ECL_SYM("PACKAGE",1321), v25package);
  }
L315:;
  {
   cl_object volatile v26;
   v26 = ecl_make_cfun_va((cl_objectfn)LC2596__lambda350_va,ECL_NIL,Cblock,2);
   T0 = v26;
  }
  si_put_sysprop(VV[188], VV[54], T0);
  (void)0; /* No entry created for END-LOGICAL-BLOCK */
  si_define_structure(VV[191], _ecl_static_7, ECL_NIL, ECL_NIL, VVtemp[76], VVtemp[77], VV[192], VV[82], ECL_NIL, ECL_NIL, VVtemp[78], ecl_make_int8_t(5), ECL_NIL, ECL_NIL, VV[193]);
  VV[202]=cl_find_class(1, VV[191]);
  ecl_cmp_defun(VV[462]);                         /*  MAKE-TAB                */
  {
   cl_object v26package;
   v26package = cl_symbol_package(VV[204]);
   if (Null(v26package)){
    goto L334;
   }
   if (Null(si_package_locked_p(v26package))){
    goto L334;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L334;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[79], ECL_SYM("PACKAGE",1321), v26package);
  }
L334:;
  {
   cl_object volatile v27;
   v27 = ecl_make_cfun_va((cl_objectfn)LC2599__lambda413_va,ECL_NIL,Cblock,2);
   T0 = v27;
  }
  si_put_sysprop(VV[204], VV[54], T0);
  {
   cl_object v27package;
   v27package = cl_symbol_package(VV[206]);
   if (Null(v27package)){
    goto L342;
   }
   if (Null(si_package_locked_p(v27package))){
    goto L342;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L342;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[80], ECL_SYM("PACKAGE",1321), v27package);
  }
L342:;
  {
   cl_object volatile v28;
   v28 = ecl_make_cfun_va((cl_objectfn)LC2600__lambda418_va,ECL_NIL,Cblock,2);
   T0 = v28;
  }
  si_put_sysprop(VV[206], VV[54], T0);
  {
   cl_object v28package;
   v28package = cl_symbol_package(VV[208]);
   if (Null(v28package)){
    goto L350;
   }
   if (Null(si_package_locked_p(v28package))){
    goto L350;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L350;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[81], ECL_SYM("PACKAGE",1321), v28package);
  }
L350:;
  {
   cl_object volatile v29;
   v29 = ecl_make_cfun_va((cl_objectfn)LC2601__lambda423_va,ECL_NIL,Cblock,2);
   T0 = v29;
  }
  si_put_sysprop(VV[208], VV[54], T0);
  {
   cl_object v29package;
   v29package = cl_symbol_package(VV[210]);
   if (Null(v29package)){
    goto L358;
   }
   if (Null(si_package_locked_p(v29package))){
    goto L358;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L358;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[82], ECL_SYM("PACKAGE",1321), v29package);
  }
L358:;
  {
   cl_object volatile v30;
   v30 = ecl_make_cfun_va((cl_objectfn)LC2602__lambda428_va,ECL_NIL,Cblock,2);
   T0 = v30;
  }
  si_put_sysprop(VV[210], VV[54], T0);
  {
   cl_object v30package;
   v30package = cl_symbol_package(VV[212]);
   if (Null(v30package)){
    goto L366;
   }
   if (Null(si_package_locked_p(v30package))){
    goto L366;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L366;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[83], ECL_SYM("PACKAGE",1321), v30package);
  }
L366:;
  {
   cl_object volatile v31;
   v31 = ecl_make_cfun_va((cl_objectfn)LC2603__lambda433_va,ECL_NIL,Cblock,2);
   T0 = v31;
  }
  si_put_sysprop(VV[212], VV[54], T0);
  (void)0; /* No entry created for ENQUEUE-TAB */
  (void)0; /* No entry created for COMPUTE-TAB-SIZE */
  (void)0; /* No entry created for INDEX-COLUMN */
  (void)0; /* No entry created for EXPAND-TABS */
  (void)0; /* No entry created for ASSURE-SPACE-IN-BUFFER */
  (void)0; /* No entry created for MAYBE-OUTPUT */
  (void)0; /* No entry created for MISERING-P */
  (void)0; /* No entry created for FITS-ON-LINE-P */
  (void)0; /* No entry created for OUTPUT-LINE */
  (void)0; /* No entry created for OUTPUT-PARTIAL-LINE */
  (void)0; /* No entry created for FORCE-PRETTY-OUTPUT */
  ecl_cmp_defun(VV[463]);                         /*  PPRINT-POP-HELPER       */
  (void)0; /* No entry created for CHECK-PRINT-LEVEL */
  (void)0; /* No entry created for DO-PPRINT-LOGICAL-BLOCK */
  ecl_cmp_defun(VV[464]);                         /*  PPRINT-LOGICAL-BLOCK-HELPER */
  ecl_cmp_defmacro(VV[465]);                      /*  PPRINT-LOGICAL-BLOCK    */
  ecl_cmp_defmacro(VV[466]);                      /*  PPRINT-EXIT-IF-LIST-EXHAUSTED */
  ecl_cmp_defmacro(VV[467]);                      /*  PPRINT-POP              */
  (void)0; /* No entry created for PPRINT-NEWLINE */
  (void)0; /* No entry created for PPRINT-INDENT */
  (void)0; /* No entry created for PPRINT-TAB */
  (void)0; /* No entry created for PPRINT-FILL */
  (void)0; /* No entry created for PPRINT-LINEAR */
  (void)0; /* No entry created for PPRINT-TABULAR */
  si_Xmake_special(VV[292]);
  si_Xmake_special(VV[293]);
  si_define_structure(VV[294], _ecl_static_8, ECL_NIL, ECL_NIL, VVtemp[84], VVtemp[85], VV[295], ECL_NIL, VV[296], ECL_NIL, VVtemp[86], ecl_make_int8_t(4), ECL_NIL, ECL_NIL, VV[297]);
  VV[302]=cl_find_class(1, VV[294]);
  ecl_cmp_defun(VV[468]);                         /*  MAKE-PPRINT-DISPATCH-ENTRY */
  {
   cl_object v31package;
   v31package = cl_symbol_package(VV[304]);
   if (Null(v31package)){
    goto L459;
   }
   if (Null(si_package_locked_p(v31package))){
    goto L459;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L459;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[87], ECL_SYM("PACKAGE",1321), v31package);
  }
L459:;
  {
   cl_object volatile v32;
   v32 = ecl_make_cfun_va((cl_objectfn)LC2625__lambda1009_va,ECL_NIL,Cblock,2);
   T0 = v32;
  }
  si_put_sysprop(VV[304], VV[54], T0);
  {
   cl_object v32package;
   v32package = cl_symbol_package(VV[306]);
   if (Null(v32package)){
    goto L467;
   }
   if (Null(si_package_locked_p(v32package))){
    goto L467;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L467;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[88], ECL_SYM("PACKAGE",1321), v32package);
  }
L467:;
  {
   cl_object volatile v33;
   v33 = ecl_make_cfun_va((cl_objectfn)LC2626__lambda1014_va,ECL_NIL,Cblock,2);
   T0 = v33;
  }
  si_put_sysprop(VV[306], VV[54], T0);
  {
   cl_object v33package;
   v33package = cl_symbol_package(VV[308]);
   if (Null(v33package)){
    goto L475;
   }
   if (Null(si_package_locked_p(v33package))){
    goto L475;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L475;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[89], ECL_SYM("PACKAGE",1321), v33package);
  }
L475:;
  {
   cl_object volatile v34;
   v34 = ecl_make_cfun_va((cl_objectfn)LC2627__lambda1019_va,ECL_NIL,Cblock,2);
   T0 = v34;
  }
  si_put_sysprop(VV[308], VV[54], T0);
  {
   cl_object v34package;
   v34package = cl_symbol_package(VV[310]);
   if (Null(v34package)){
    goto L483;
   }
   if (Null(si_package_locked_p(v34package))){
    goto L483;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L483;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[90], ECL_SYM("PACKAGE",1321), v34package);
  }
L483:;
  {
   cl_object volatile v35;
   v35 = ecl_make_cfun_va((cl_objectfn)LC2628__lambda1024_va,ECL_NIL,Cblock,2);
   T0 = v35;
  }
  si_put_sysprop(VV[310], VV[54], T0);
  ecl_cmp_defun(VV[469]);                         /*  %PRINT-PPRINT-DISPATCH-ENTRY */
  si_define_structure(VV[315], _ecl_static_9, ECL_NIL, ECL_NIL, VVtemp[91], VVtemp[92], VV[316], ECL_NIL, VV[317], ECL_NIL, VVtemp[93], ecl_make_int8_t(3), ECL_NIL, ECL_NIL, VV[318]);
  VV[321]=cl_find_class(1, VV[315]);
  ecl_cmp_defun(VV[470]);                         /*  MAKE-PPRINT-DISPATCH-TABLE */
  {
   cl_object v35package;
   v35package = cl_symbol_package(VV[323]);
   if (Null(v35package)){
    goto L502;
   }
   if (Null(si_package_locked_p(v35package))){
    goto L502;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L502;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[94], ECL_SYM("PACKAGE",1321), v35package);
  }
L502:;
  {
   cl_object volatile v36;
   v36 = ecl_make_cfun_va((cl_objectfn)LC2632__lambda1032_va,ECL_NIL,Cblock,2);
   T0 = v36;
  }
  si_put_sysprop(VV[323], VV[54], T0);
  {
   cl_object v36package;
   v36package = cl_symbol_package(VV[325]);
   if (Null(v36package)){
    goto L510;
   }
   if (Null(si_package_locked_p(v36package))){
    goto L510;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L510;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[95], ECL_SYM("PACKAGE",1321), v36package);
  }
L510:;
  {
   cl_object volatile v37;
   v37 = ecl_make_cfun_va((cl_objectfn)LC2633__lambda1037_va,ECL_NIL,Cblock,2);
   T0 = v37;
  }
  si_put_sysprop(VV[325], VV[54], T0);
  {
   cl_object v37package;
   v37package = cl_symbol_package(VV[327]);
   if (Null(v37package)){
    goto L518;
   }
   if (Null(si_package_locked_p(v37package))){
    goto L518;
   }
   if (!(ECL_SYM_VAL(cl_env_copy,ECL_SYM("*IGNORE-PACKAGE-LOCKS*",1128))==ECL_NIL)){
    goto L518;
   }
   si_signal_simple_error(6, ECL_SYM("PACKAGE-ERROR",620), VVtemp[31], VVtemp[32], VVtemp[96], ECL_SYM("PACKAGE",1321), v37package);
  }
L518:;
  {
   cl_object volatile v38;
   v38 = ecl_make_cfun_va((cl_objectfn)LC2634__lambda1042_va,ECL_NIL,Cblock,2);
   T0 = v38;
  }
  si_put_sysprop(VV[327], VV[54], T0);
  ecl_cmp_defun(VV[471]);                         /*  %PRINT-PPRINT-DISPATCH-TABLE */
  (void)0; /* No entry created for CONS-TYPE-SPECIFIER-P */
  (void)0; /* No entry created for ENTRY< */
  (void)0; /* No entry created for COPY-PPRINT-DISPATCH */
  ecl_cmp_defun(VV[472]);                         /*  DEFAULT-PPRINT-DISPATCH */
  (void)0; /* No entry created for PPRINT-DISPATCH */
  (void)0; /* No entry created for SET-PPRINT-DISPATCH */
  ecl_cmp_defun(VV[473]);                         /*  PPRINT-ARRAY            */
  ecl_cmp_defun(VV[474]);                         /*  PPRINT-VECTOR           */
  (void)0; /* No entry created for PPRINT-ARRAY-CONTENTS */
  (void)0; /* No entry created for PPRINT-MULTI-DIM-ARRAY */
  (void)0; /* No entry created for PPRINT-RAW-ARRAY */
  ecl_cmp_defun(VV[475]);                         /*  PPRINT-LAMBDA-LIST      */
  ecl_cmp_defun(VV[476]);                         /*  PPRINT-LAMBDA           */
  ecl_cmp_defun(VV[477]);                         /*  PPRINT-BLOCK            */
  ecl_cmp_defun(VV[478]);                         /*  PPRINT-FLET             */
  ecl_cmp_defun(VV[479]);                         /*  PPRINT-LET              */
  ecl_cmp_defun(VV[480]);                         /*  PPRINT-PROGN            */
  ecl_cmp_defun(VV[481]);                         /*  PPRINT-PROGV            */
  ecl_cmp_defun(VV[482]);                         /*  PPRINT-QUOTE            */
  ecl_cmp_defun(VV[483]);                         /*  PPRINT-SETQ             */
  ecl_cmp_defun(VV[484]);                         /*  PPRINT-TAGBODY          */
  ecl_cmp_defun(VV[485]);                         /*  PPRINT-CASE             */
  ecl_cmp_defun(VV[486]);                         /*  PPRINT-DEFUN            */
  ecl_cmp_defun(VV[487]);                         /*  PPRINT-DESTRUCTURING-BIND */
  ecl_cmp_defun(VV[488]);                         /*  PPRINT-DO               */
  ecl_cmp_defun(VV[489]);                         /*  PPRINT-DOLIST           */
  ecl_cmp_defun(VV[490]);                         /*  PPRINT-TYPECASE         */
  ecl_cmp_defun(VV[491]);                         /*  PPRINT-PROG             */
  ecl_cmp_defun(VV[492]);                         /*  PPRINT-FUNCTION-CALL    */
  T0 = L2631make_pprint_dispatch_table(0);
  ecl_bds_bind(cl_env_copy,ECL_SYM("*PRINT-PPRINT-DISPATCH*",56),T0); /*  *PRINT-PPRINT-DISPATCH* */
  T0 = (VV[341]->symbol.gfdef);
  cl_set_pprint_dispatch(2, ECL_SYM("ARRAY",98), T0);
  T0 = (VV[446]->symbol.gfdef);
  cl_set_pprint_dispatch(3, VVtemp[97], T0, ecl_make_int8_t(-1));
  T0 = (ECL_SYM("PPRINT-FILL",653)->symbol.gfdef);
  cl_set_pprint_dispatch(3, ECL_SYM("CONS",253), T0, ecl_make_int8_t(-2));
  {
   cl_object v38;
   v38 = VVtemp[98];
   goto L629;
L628:;
   {
    cl_object v39magic_form;
    v39magic_form = _ecl_car(v38);
    T0 = _ecl_car(v39magic_form);
    T1 = cl_list(2, ECL_SYM("EQL",336), T0);
    T2 = cl_list(2, ECL_SYM("CONS",253), T1);
    T3 = _ecl_cadr(v39magic_form);
    T4 = cl_symbol_function(T3);
    cl_set_pprint_dispatch(2, T2, T4);
   }
   v38 = _ecl_cdr(v38);
L629:;
   if (Null(v38)){
    goto L636;
   }
   goto L628;
L636:;
  }
  T0 = ECL_SYM_VAL(cl_env_copy,ECL_SYM("*PRINT-PPRINT-DISPATCH*",56));
  ECL_SETQ(cl_env_copy,VV[293],T0);
  ecl_bds_unwind1(cl_env_copy);
  T0 = cl_copy_pprint_dispatch(1, ECL_NIL);
  ECL_SETQ(cl_env_copy,ECL_SYM("*PRINT-PPRINT-DISPATCH*",56),T0);
  T0 = ECL_SYM_VAL(cl_env_copy,VV[293]);
  ECL_SETQ(cl_env_copy,VV[292],T0);
  {
   cl_object v38;
   v38 = ECL_SYM_VAL(cl_env_copy,VV[292]);
   {
    cl_object v39;
    v39 = ECL_T;
    {
     cl_object v40;
     v40 = v38;
     (v40)->instance.slots[(cl_fixnum)(0)]=v39;
    }
   }
  }
  {
   cl_object v41;
   v41 = _ecl_cdr(ECL_SYM_VAL(cl_env_copy,ECL_SYM("+IO-SYNTAX-PROGV-LIST+",1805)));
   {
    cl_object v42;
    v42 = ECL_SYM_VAL(cl_env_copy,VV[292]);
    (ECL_CONS_CAR(v41)=v42,v41);
   }
  }
  {
   cl_object v43;
   v43 = _ecl_cdr(ECL_SYM_VAL(cl_env_copy,ECL_SYM("+ECL-SYNTAX-PROGV-LIST+",1806)));
   {
    cl_object v44;
    v44 = ECL_SYM_VAL(cl_env_copy,VV[292]);
    (ECL_CONS_CAR(v43)=v44,v43);
   }
  }
  T0 = ECL_T;
  ECL_SETQ(cl_env_copy,ECL_SYM("*PRINT-PRETTY*",57),T0);
 }
}
